<?php

/**
 * Posts Preview Style: Fullwidth Backgrounds
 */
$post_meta_set       = get_theme_mod( 'post_meta_set', array( 'date', 'categories', 'comments', 'author' ) );
$post_show_info      = get_theme_mod( 'post_show_info', true ) && ! empty( $post_meta_set );
$post_thumbnail_size = get_theme_mod( 'blog_style_posts_thumbnail', 'full' );
$post_permalink      = get_permalink();
$animation_enabled   = get_theme_mod( 'blog_os_animation_enabled', false );

$post_attributes = array(
	'id'    => 'post-' . get_the_ID(),
	'class' => get_post_class( 'post background-hover py-medium h-100' ),
);

$thumbnail_args = array(
	'id'   => get_post_thumbnail_id(),
	'type' => 'background',
	'size' => $post_thumbnail_size,
);

$info_attributes = array(
	'class' => array( 'mt-2' ),
);

$date_attributes = array(
	'class' => array( 'h5', 'mt-md-1', 'mb-md-1', 'mb-2' ),
);

$link_heading_attributes = array(
	'class'           => array( 'd-inline-block', 'underline-hover' ),
	'href'            => $post_permalink,
	'data-arts-hover' => 'trigger',
);

$link_heading_attributes = arts_get_cursor_attributes_theme_mod( $link_heading_attributes, 'blog_home_cursor_clickable_links' );

$container_attributes = array(
	'class' => array( 'container', 'background-hover__content' ),
);

if ( $animation_enabled ) {
	$container_attributes = arts_get_animation_attributes( $container_attributes, 'animateJump' );
}

$col_content = array(
	'class' => array(),
);

$col_meta = array(
	'class' => array(),
);

$post_meta_set_footer = array();
$has_date             = $post_show_info && in_array( 'date', $post_meta_set );
$has_categories       = $post_show_info && in_array( 'categories', $post_meta_set );
$has_author           = $post_show_info && in_array( 'author', $post_meta_set );
$has_comments         = $post_show_info && in_array( 'comments', $post_meta_set );

if ( $has_date ) {
	$col_meta['class'][]    = 'col-lg-4';
	$col_content['class'][] = 'col-lg-8';
} else {
	$col_meta['class'][]    = 'col-lg-12';
	$col_content['class'][] = 'col-lg-12';
}

if ( $has_categories ) {
	$post_meta_set_footer[] = 'categories';
}

if ( $has_author ) {
	$post_meta_set_footer[] = 'author';
}

if ( $has_comments ) {
	$post_meta_set_footer[] = 'comments';
}

?>

<article <?php arts_print_attributes( $post_attributes ); ?>>
	<div class="background-hover__image list-backgrounds__wrapper-img">
		<?php if ( has_post_thumbnail() ) : ?>
			<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
		<?php endif; ?>
	</div>

	<div class="list-backgrounds__overlay background-hover__overlay overlay overlay_dark-60"></div>

	<div <?php arts_print_attributes( $container_attributes ); ?>>
		<div class="row align-items-center">
			<?php if ( $has_date ) : ?>
				<div <?php arts_print_attributes( $col_meta ); ?>>
					<div <?php arts_print_attributes( $date_attributes ); ?>><?php echo esc_html( get_the_date() ); ?></div>
				</div>
			<?php endif; ?>
			<div <?php arts_print_attributes( $col_content ); ?>>
				<a <?php arts_print_attributes( $link_heading_attributes ); ?>>
					<h2 class="h3 my-0 underline-hover__target"><?php the_title(); ?></h2>
				</a>
				<?php if ( ! empty( $post_meta_set_footer ) ) : ?>
					<div <?php arts_print_attributes( $info_attributes ); ?>>
						<?php
							get_template_part(
								'template-parts/blog/post/partials/meta',
								'',
								array(
									'attributes' => array(
										'class' => array( 'post-meta', 'categories' ),
									),
									'set'        => $post_meta_set_footer,
								)
							);
						?>
					</div>
				<?php endif; ?>
			</div>
		</div>
	</div>
</article>
