<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Custom Fonts ACF Fields
 */
if ( function_exists( 'acf_add_local_field_group' ) ) {
	acf_add_local_field_group(
		array(
			'key'                   => Arts_Custom_Fonts::KEY_FIELDS_GROUP,
			'title'                 => esc_html__( 'Custom Fonts', 'arts' ),
			'fields'                => array(
				array(
					'key'               => Arts_Custom_Fonts::KEY_REPEATER,
					'label'             => '',
					'name'              => Arts_Custom_Fonts::KEY_NAME,
					'type'              => 'repeater',
					'instructions'      => '',
					'required'          => 0,
					'conditional_logic' => 0,
					'wrapper'           => array(
						'width' => '',
						'class' => '',
						'id'    => '',
					),
					'collapsed'         => Arts_Custom_Fonts::KEY_FONT_NAME,
					'min'               => 0,
					'max'               => 0,
					'layout'            => 'block',
					'button_label'      => esc_html__( 'Add Custom Font', 'arts' ),
					'sub_fields'        => array(
						array(
							'key'               => Arts_Custom_Fonts::KEY_FONT_NAME,
							'label'             => esc_html__( 'Font Family Name', 'arts' ),
							'name'              => 'font_name',
							'type'              => 'text',
							'instructions'      => '',
							'required'          => 1,
							'conditional_logic' => 0,
							'wrapper'           => array(
								'width' => '',
								'class' => '',
								'id'    => '',
							),
							'default_value'     => '',
							'placeholder'       => '',
							'prepend'           => '',
							'append'            => '',
							'maxlength'         => '',
						),
						array(
							'key'               => Arts_Custom_Fonts::KEY_FONT_DISPLAY,
							'label'             => esc_html__( 'Font Display', 'arts' ),
							'name'              => 'font_display',
							'type'              => 'select',
							'instructions'      => sprintf(
								'<a href="https://developer.mozilla.org/en-US/docs/Web/CSS/@font-face/font-display" target="_blank">%1s</a> %2s',
								esc_html__( 'More information', 'arts' ),
								esc_html__( 'related to "font-display" descriptor.', 'arts' )
							),
							'required'          => 1,
							'conditional_logic' => 0,
							'wrapper'           => array(
								'width' => '',
								'class' => '',
								'id'    => '',
							),
							'choices'           => array(
								'auto'     => 'auto',
								'block'    => 'block',
								'swap'     => 'swap',
								'fallback' => 'fallback',
								'optional' => 'optional',
							),
							'default_value'     => array(
								0 => 'auto',
							),
							'allow_null'        => 0,
							'multiple'          => 0,
							'ui'                => 0,
							'return_format'     => 'value',
							'ajax'              => 0,
							'placeholder'       => '',
						),
						array(
							'key'               => Arts_Custom_Fonts::KEY_FONT_FILES,
							'label'             => esc_html__( 'Font Files', 'arts' ),
							'name'              => 'font_files',
							'type'              => 'repeater',
							'instructions'      => '',
							'required'          => 1,
							'conditional_logic' => 0,
							'wrapper'           => array(
								'width' => '',
								'class' => '',
								'id'    => '',
							),
							'collapsed'         => Arts_Custom_Fonts::KEY_FONT_FILES_FONT_WEIGHT,
							'min'               => 0,
							'max'               => 0,
							'layout'            => 'block',
							'button_label'      => esc_html__( 'Add Font File', 'arts' ),
							'sub_fields'        => array(
								array(
									'key'               => Arts_Custom_Fonts::KEY_FONT_FILES_FONT_FILE,
									'label'             => 'Font File',
									'name'              => 'font_file',
									'type'              => 'file',
									'instructions'      => esc_html__( 'Upload .woff or .woff2 font file', 'arts' ),
									'required'          => 1,
									'conditional_logic' => 0,
									'wrapper'           => array(
										'width' => '',
										'class' => '',
										'id'    => '',
									),
									'return_format'     => 'array',
									'library'           => 'all',
									'min_size'          => '',
									'max_size'          => '',
									'mime_types'        => 'woff, woff2',
								),
								array(
									'key'               => Arts_Custom_Fonts::KEY_FONT_FILES_FONT_WEIGHT,
									'label'             => esc_html__( 'Font Weight', 'arts' ),
									'name'              => 'font_weight',
									'type'              => 'select',
									'instructions'      => esc_html__( 'Select a font weight of the uploaded font file', 'arts' ),
									'required'          => 1,
									'conditional_logic' => 0,
									'wrapper'           => array(
										'width' => '',
										'class' => '',
										'id'    => '',
									),
									'choices'           => array(
										100         => esc_html__( '100 (Thin)', 'arts' ),
										'100italic' => esc_html__( '100i (Thin Italic)', 'arts' ),
										200         => esc_html__( ' 200 (Ultra Light)', 'arts' ),
										'200italic' => esc_html__( '200i (Ultra Light Italic)', 'arts' ),
										300         => esc_html__( ' 300 (Light)', 'arts' ),
										'300italic' => esc_html__( '300i (Light Italic)', 'arts' ),
										400         => esc_html__( '400 (Regular)', 'arts' ),
										'400italic' => esc_html__( '400i (Regular Italic)', 'arts' ),
										500         => esc_html__( '500 (Medium)', 'arts' ),
										'500italic' => esc_html__( '500i (Medium Italic)', 'arts' ),
										600         => esc_html__( '600 (Semi Bold)', 'arts' ),
										'600italic' => esc_html__( '600i (Semi Bold Italic)', 'arts' ),
										700         => esc_html__( '700 (Bold)', 'arts' ),
										'700italic' => esc_html__( '700i (Bold Italic)', 'arts' ),
										800         => esc_html__( '800 (Extra Bold)', 'arts' ),
										'800italic' => esc_html__( '800i (Extra Bold Italic)', 'arts' ),
										900         => esc_html__( '900 (Black)', 'arts' ),
										'900italic' => esc_html__( '900i (Black Italic)', 'arts' ),
									),
									'default_value'     => array(),
									'allow_null'        => 0,
									'multiple'          => 0,
									'ui'                => 0,
									'return_format'     => 'value',
									'ajax'              => 0,
									'placeholder'       => '',
								),
							),
						),
					),
				),
			),
			'location'              => array(
				array(
					array(
						'param'    => 'options_page',
						'operator' => '==',
						'value'    => 'custom-fonts-settings',
					),
				),
			),
			'menu_order'            => 0,
			'position'              => 'normal',
			'style'                 => 'default',
			'label_placement'       => 'top',
			'instruction_placement' => 'label',
			'hide_on_screen'        => '',
			'active'                => true,
			'description'           => '',
		)
	);
}
