<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Arts_Custom_Fonts {
	const KEY_NAME                   = 'arts_custom_fonts';
	const KEY_FIELDS_GROUP           = 'group_art01c79399ce';
	const KEY_REPEATER               = 'field_art01caa50c9a';
	const KEY_FONT_NAME              = 'field_art01cfa50c9b';
	const KEY_FONT_DISPLAY           = 'field_art3c469ba39d';
	const KEY_FONT_FILES             = 'field_art01d3550c9c';
	const KEY_FONT_FILES_FONT_FILE   = 'field_5da01d7250c9d';
	const KEY_FONT_FILES_FONT_WEIGHT = 'field_art01e9550c9e';

	private static $_instance = null;

	public static $options_prefix;
	public static $fonts_amount;

	public static function instance() {
		if ( ! isset( self::$_instance ) ) {
			self::$_instance = new self();
		}

		if ( ! isset( self::$options_prefix ) ) {
			self::$options_prefix = 'options_' . self::KEY_NAME;
		}

		if ( ! isset( self::$fonts_amount ) ) {
			self::$fonts_amount = intval( get_option( self::$options_prefix ) );
		}

		return self::$_instance;
	}

	function __construct() {
		$this->include_files();

		add_action( 'init', array( $this, 'load_textdomain' ) );
	}

	private function include_files() {
		require_once ARTS_CUSTOM_FONTS_PLUGIN_PATH . '/inc/core/plugin_actions.php';
		require_once ARTS_CUSTOM_FONTS_PLUGIN_PATH . '/inc/plugins/load_plugins.php';
		require_once ARTS_CUSTOM_FONTS_PLUGIN_PATH . '/inc/acf/acf_helpers.php';
		require_once ARTS_CUSTOM_FONTS_PLUGIN_PATH . '/inc/acf/acf_fields.php';
		require_once ARTS_CUSTOM_FONTS_PLUGIN_PATH . '/inc/acf/acf_pages.php';
		require_once ARTS_CUSTOM_FONTS_PLUGIN_PATH . '/inc/fonts/custom_mime_types.php';
		require_once ARTS_CUSTOM_FONTS_PLUGIN_PATH . '/inc/fonts/add_fonts.php';
	}

	public function add_fonts( $fonts_map ) {
		if ( ! is_array( $fonts_map ) || empty( $fonts_map ) ) {
			// Fonts are not added
			return false;
		}

		foreach ( $fonts_map as $font ) {
			// Fonts without name can't be checked/referenced
			if ( array_key_exists( 'name', $font ) ) {

				// Font with that name already exists?
				$existing_font_name_index = $this->font_name_exists( $font['name'] );

				// Get correct index for the added font
				$new_font_options_prefix = $this->get_new_font_option_prefix( $existing_font_name_index );

				/**
				 * Create a font name if it doesn't exist
				 */
				if ( $existing_font_name_index === false ) {
					$this->update_font_name( $font['name'], $new_font_options_prefix );
				}

				/**
				 * Update "font-display" property
				 */
				if ( array_key_exists( 'display', $font ) ) {
					$this->update_font_display( $font['display'], $new_font_options_prefix );
				}

				/**
				 * Update font files
				 */
				if ( array_key_exists( 'files', $font ) ) {
					$this->update_font_files( $font['files'], $new_font_options_prefix );
				}
			}
		}

		return true;
	}

	private function font_name_exists( $name ) {
		$options_prefix = self::$options_prefix;

		if ( is_string( $name ) && ! empty( $name ) ) {
			for ( $i = 0; $i < self::$fonts_amount; $i++ ) {
				if ( get_option( "{$options_prefix}_{$i}_font_name" ) === $name ) {
					return $i;
				}
			}
		}

		return false;
	}

	private function get_new_font_option_prefix( $existing_index ) {
		$options_prefix = self::$options_prefix;

		if ( $existing_index === false ) {
			$new_font_index = self::$fonts_amount === 0 ? 0 : self::$fonts_amount;
		} else {
			$new_font_index = $existing_index;
		}

		return "{$options_prefix}_{$new_font_index}";
	}

	private function update_font_name( $name, $new_font_options_prefix ) {
		$options_prefix = self::$options_prefix;

		/** Increment number of registered fonts */
		self::$fonts_amount++;
		update_option( "_{$options_prefix}", self::KEY_REPEATER );
		update_option( "{$options_prefix}", self::$fonts_amount );

		/** Add new font name */
		update_option( "_{$new_font_options_prefix}_font_name", self::KEY_FONT_NAME );
		update_option( "{$new_font_options_prefix}_font_name", esc_attr( $name ) );
	}

	private function update_font_display( $display, $new_font_options_prefix ) {
		if ( $new_font_options_prefix ) {
			update_option( "_{$new_font_options_prefix}_font_display", self::KEY_FONT_DISPLAY );
			update_option( "{$new_font_options_prefix}_font_display", esc_attr( $display ) );
		}
	}

	private function update_font_files( $files, $new_font_options_prefix ) {
		$new_font_files_amount = is_array( $files ) ? count( $files ) : 0;

		if ( $new_font_files_amount > 0 ) {
			/** Set amount of files */
			update_option( "_{$new_font_options_prefix}_font_files", self::KEY_FONT_FILES );
			update_option( "{$new_font_options_prefix}_font_files", esc_attr( $new_font_files_amount ) );

			foreach ( $files as $index => $file ) {
				/** Set font file path */
				if ( array_key_exists( 'id', $file ) ) {
					update_option( "_{$new_font_options_prefix}_font_files_{$index}_font_file", self::KEY_FONT_FILES_FONT_FILE );
					update_option( "{$new_font_options_prefix}_font_files_{$index}_font_file", esc_attr( $file['id'] ) );
				}

				/** Set font weight */
				if ( array_key_exists( 'weight', $file ) ) {
					update_option( "_{$new_font_options_prefix}_font_files_{$index}_font_weight", self::KEY_FONT_FILES_FONT_WEIGHT );
					update_option( "{$new_font_options_prefix}_font_files_{$index}_font_weight", esc_attr( $file['weight'] ) );
				}
			}
		}
	}

	public function load_textdomain() {
		load_plugin_textdomain( 'arts' );
	}
}

add_action( 'plugins_loaded', 'arts_cf_init' );
function arts_cf_init() {
	Arts_Custom_Fonts::instance();
}
