<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Localize Theme Options
 */
add_action( 'wp_enqueue_scripts', 'arts_mcf_localize_data' );
function arts_mcf_localize_data() {
	$defaults = array(
		'highlight_elements'          => 'a:not(a[data-arts-cursor]):not(.social__item a):not(.soc1al__item a):not(a.page-numbers):not(.js-arts-cursor-no-highlight):not(.wp-social-link a), .js-arts-cursor-highlight, button:not(button[data-arts-cursor])',
		'magnetic_elements'           => '[data-arts-cursor-magnetic]',
		'hide_native_cursor_elements' => '[data-arts-cursor-hide-native]',
		'hide_scale_magnet_elements'  => '.slider__dot, .social__item, .soc1al__item, a.page-numbers',
		'highlight_elements_scale'    => 1.5,
		'helper_color'                => '#ffffff',
		'helper_background'           => '#ed4830',
		'trailing_factor'             => 6,
		'animation_duration'          => 0.25,
	);
	$args     = get_option( 'arts_mouse_cursor_follower' );
	$settings = wp_parse_args( $args, $defaults );

	$settings = apply_filters(
		'arts/mouse_cursor_follower/settings', array(
			'enabled' => isset( $_GET['mouse_cursor_follower'] ) && $_GET['mouse_cursor_follower'] === 'no' ? false : true,
			'target'   => array(
				'cursor'            => '[data-arts-cursor]',
				'highlight'         => esc_js( $settings['highlight_elements'] ),
				'magnetic'          => esc_js( $settings['magnetic_elements'] ),
				'hideNative'        => esc_js( $settings['hide_native_cursor_elements'] ),
				'hideScaleMagnetic' => esc_js( $settings['hide_scale_magnet_elements'] ),
			),
			'elements' => array(
				'follower'  => '.js-arts-cursor__follower',
				'stroke'    => array(
					'inner' => '.js-arts-cursor__stroke-inner',
					'outer' => '.js-arts-cursor__stroke-outer',
				),
				'arrow'     => array(
					'up'    => '.js-arts-cursor__arrow-up',
					'down'  => '.js-arts-cursor__arrow-down',
					'left'  => '.js-arts-cursor__arrow-left',
					'right' => '.js-arts-cursor__arrow-right',
				),
				'container' => array(
					'label' => '.js-arts-cursor__label',
					'icon'  => '.js-arts-cursor__icon',
				),
			),
			'effect'   => array(
				'helper'            => array(
					'color'      => esc_js( $settings['helper_color'] ),
					'background' => esc_js( $settings['helper_background'] ),
				),
				'highlight'         => array(
					'scale' => esc_js( $settings['highlight_elements_scale'] ),
				),
				'trailing'          => esc_js( $settings['trailing_factor'] ),
				'animationDuration' => esc_js( $settings['animation_duration'] ),
			),
		)
	);

	if ( $settings['enabled'] ) {
		wp_localize_script( 'arts-mouse-cursor-follower', 'arts_mcf_settings', $settings );
		wp_add_inline_script( 'arts-mouse-cursor-follower', trim( 'document.addEventListener("DOMContentLoaded", (e) => { if (!e.detail && !Modernizr.touchevents) { jQuery("#js-arts-cursor").artsCursor(arts_mcf_settings); jQuery("html").removeClass("no-cursorfollower").addClass("cursorfollower"); }});' ) );
	}
}
