<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Page Bottom Navigation in Elementor Document Settings
 */
add_action( 'elementor/element/wp-page/document_settings/after_section_end', 'arts_add_elementor_document_settings_page_bottom_navigation' );
add_action( 'elementor/element/wp-post/document_settings/after_section_end', 'arts_add_elementor_document_settings_page_bottom_navigation' );
function arts_add_elementor_document_settings_page_bottom_navigation( \Elementor\Core\DocumentTypes\PageBase $page ) {
	$page->start_controls_section(
		'page_bottom_navigation_section',
		array(
			'label' => esc_html__( 'Page Bottom Navigation', 'kinsey' ),
			'tab'   => \Elementor\Controls_Manager::TAB_SETTINGS,
		)
	);

	$page->add_control(
		'page_bottom_navigation_settings_overridden',
		array(
			'label'       => esc_html__( 'Override Page Bottom Navigation Settings', 'kinsey' ),
			'description' => esc_html__( 'Use custom bottom navigation settings for this page instead of WordPress Customizer settings', 'kinsey' ),
			'type'        => \Elementor\Controls_Manager::SWITCHER,
			'default'     => '',
		)
	);

	$page->add_control(
		'page_bottom_navigation_previous_post',
		array(
			'label'         => esc_html__( 'Previous Post', 'kinsey' ),
			'type'          => \Elementor\Controls_Manager::URL,
			'show_external' => false,
			'options'       => false,
			'autocomplete'  => true,
			'condition'     => array(
				'page_bottom_navigation_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_bottom_navigation_next_post',
		array(
			'label'         => esc_html__( 'Next Post', 'kinsey' ),
			'type'          => \Elementor\Controls_Manager::URL,
			'show_external' => false,
			'options'       => false,
			'autocomplete'  => true,
			'condition'     => array(
				'page_bottom_navigation_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_bottom_navigation_internal_urls',
		array(
			'type'            => \Elementor\Controls_Manager::RAW_HTML,
			'raw'             => sprintf(
				'%1$s <strong>%2$s</strong> %3$s.',
				esc_html__( 'Please note that only', 'kinsey' ),
				esc_html__( 'internal site URLs', 'kinsey' ),
				esc_html( 'are supported for overriding', 'kinsey' )
			),
			'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
			'condition'       => array(
				'page_bottom_navigation_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_bottom_navigation_elementor_update_button',
		array(
			'type'      => \Elementor\Controls_Manager::RAW_HTML,
			'raw'       => sprintf(
				"
				<div class=\"elementor-update-preview\">
					<div class=\"elementor-update-preview-title\">%1\$s</div>
					<div class=\"elementor-update-preview-button-wrapper\">
						<button class=\"kinsey-reload-preview-button elementor-button elementor-button-success\" style=\"padding: 8px 15px; text-transform: uppercase;\" onclick='javascript:elementor.\$preview.trigger(\"arts/elementor/reload_preview\", {detail: {openedPageAfter: \"page_settings\", openedTabAfter: \"settings\", openedSectionAfter: \"page_bottom_navigation_section\"}});'>%2\$s</button>
					</div>
				</div>
				",
				esc_html__( 'Update changes to page', 'kinsey' ),
				esc_html__( 'Apply', 'kinsey' )
			),
			'condition' => array(
				'page_bottom_navigation_settings_overridden' => 'yes',
			),
		)
	);

	$page->end_controls_section();
};
