<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Page Footer in Elementor Document Settings
 */
add_action( 'elementor/element/wp-page/document_settings/after_section_end', 'arts_add_elementor_document_settings_page_footer' );
add_action( 'elementor/element/wp-post/document_settings/after_section_end', 'arts_add_elementor_document_settings_page_footer' );
function arts_add_elementor_document_settings_page_footer( \Elementor\Core\DocumentTypes\PageBase $page ) {
	$page->start_controls_section(
		'page_footer_section',
		array(
			'label' => esc_html__( 'Page Footer', 'kinsey' ),
			'tab'   => \Elementor\Controls_Manager::TAB_SETTINGS,
		)
	);

	$page->add_control(
		'page_footer_settings_overridden',
		array(
			'label'       => esc_html__( 'Override Page Footer Settings', 'kinsey' ),
			'description' => esc_html__( 'Use custom footer settings for this page instead of WordPress Customizer settings', 'kinsey' ),
			'type'        => \Elementor\Controls_Manager::SWITCHER,
			'default'     => '',
		)
	);

	$page->add_control(
		'page_footer_hide',
		array(
			'label'     => esc_html__( 'Remove Footer from this Page', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SWITCHER,
			'default'   => '',
			'condition' => array(
				'page_footer_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_footer_theme',
		array(
			'label'     => esc_html__( 'Color Theme', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SELECT,
			'default'   => get_theme_mod( 'footer_theme', 'bg-dark-1' ),
			'options'   => ARTS_THEME_COLORS_ARRAY,
			'condition' => array(
				'page_footer_hide'                => '',
				'page_footer_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_footer_main_theme',
		array(
			'label'     => esc_html__( 'Elements Color', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SELECT,
			'default'   => get_theme_mod( 'footer_main_theme', 'light' ),
			'options'   => ARTS_THEME_COLOR_THEMES_ARRAY,
			'condition' => array(
				'page_footer_hide'                => '',
				'page_footer_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_footer_main_logo',
		array(
			'label'     => esc_html__( 'Logo to Display', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SELECT,
			'default'   => get_theme_mod( 'footer_main_logo', 'primary' ),
			'options'   => array(
				'primary'   => esc_html__( 'Primary', 'kinsey' ),
				'secondary' => esc_html__( 'Secondary', 'kinsey' ),
			),
			'condition' => array(
				'page_footer_hide'                => '',
				'page_footer_settings_overridden' => 'yes',
			),
		)
	);

	$page->end_controls_section();
}
