<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Page Header in Elementor Document Settings
 */
add_action( 'elementor/element/wp-page/document_settings/after_section_end', 'arts_add_elementor_document_settings_page_header' );
add_action( 'elementor/element/wp-post/document_settings/after_section_end', 'arts_add_elementor_document_settings_page_header' );
function arts_add_elementor_document_settings_page_header( \Elementor\Core\DocumentTypes\PageBase $page ) {
	$menu_style            = get_theme_mod( 'menu_style', 'classic' );
	$custom_logo_secondary = get_theme_mod( 'custom_logo_secondary', false );

	$page->start_controls_section(
		'page_header_section',
		array(
			'label' => esc_html__( 'Page Header', 'kinsey' ),
			'tab'   => \Elementor\Controls_Manager::TAB_SETTINGS,
		)
	);

	$page->add_control(
		'page_header_settings_overridden',
		array(
			'label'       => esc_html__( 'Override Page Header Settings', 'kinsey' ),
			'description' => esc_html__( 'Use custom header settings for this page instead of WordPress Customizer settings', 'kinsey' ),
			'type'        => \Elementor\Controls_Manager::SWITCHER,
			'default'     => '',
		)
	);

	$page->add_control(
		'page_header_heading_main',
		array(
			'label'     => esc_html__( 'Color Theme', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::HEADING,
			'condition' => array(
				'page_header_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_header_main_theme',
		array(
			'label'     => esc_html__( 'Elements Color', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SELECT,
			'default'   => 'dark',
			'options'   => ARTS_THEME_COLOR_THEMES_ARRAY,
			'condition' => array(
				'page_header_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_header_main_logo',
		array(
			'label'     => esc_html__( 'Logo to Display', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SELECT,
			'default'   => 'primary',
			'options'   => array(
				'primary'   => esc_html__( 'Primary', 'kinsey' ),
				'secondary' => esc_html__( 'Secondary', 'kinsey' ),
			),
			'condition' => array(
				'page_header_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_header_has_secondary_logo',
		array(
			'type'    => \Elementor\Controls_Manager::HIDDEN,
			'default' => $custom_logo_secondary ? 'yes' : '',
		)
	);

	$page->add_control(
		'page_header_message_secondary_logo_missing',
		array(
			'type'            => \Elementor\Controls_Manager::RAW_HTML,
			'raw'             => sprintf(
				'%1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
				esc_html__( 'The chosen logo version is missing. Please upload', 'kinsey' ),
				admin_url( 'customize.php?autofocus[section]=title_tagline' ),
				esc_html__( 'secondary logo', 'kinsey' ),
				esc_html( 'version or refine your selection.', 'kinsey' )
			),
			'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
			'condition'       => array(
				'page_header_main_logo'          => 'secondary',
				'page_header_has_secondary_logo' => '',
			),
		)
	);

	$page->add_control(
		'page_header_heading_sticky',
		array(
			'label'     => esc_html__( 'Sticky Color Theme', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::HEADING,
			'separator' => 'before',
			'condition' => array(
				'page_header_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_header_sticky_theme',
		array(
			'label'     => esc_html__( 'Background Color', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SELECT,
			'default'   => 'bg-dark-1',
			'options'   => ARTS_THEME_COLORS_ARRAY,
			'condition' => array(
				'page_header_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_header_sticky_elements_theme',
		array(
			'label'     => esc_html__( 'Elements Color', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SELECT,
			'default'   => 'dark',
			'options'   => ARTS_THEME_COLOR_THEMES_ARRAY,
			'condition' => array(
				'page_header_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_header_sticky_logo',
		array(
			'label'     => esc_html__( 'Sticky Logo to Display', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SELECT,
			'default'   => 'secondary',
			'options'   => array(
				'primary'   => esc_html__( 'Primary', 'kinsey' ),
				'secondary' => esc_html__( 'Secondary', 'kinsey' ),
			),
			'condition' => array(
				'page_header_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_header_message_secondary_logo_missing_sticky',
		array(
			'type'            => \Elementor\Controls_Manager::RAW_HTML,
			'raw'             => sprintf(
				'%1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
				esc_html__( 'The chosen sticky logo version is missing. Please upload', 'kinsey' ),
				admin_url( 'customize.php?autofocus[section]=title_tagline' ),
				esc_html__( 'secondary logo', 'kinsey' ),
				esc_html( 'version or refine your selection.', 'kinsey' )
			),
			'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
			'condition'       => array(
				'page_header_settings_overridden' => 'yes',
				'page_header_sticky_logo'         => 'secondary',
				'page_header_has_secondary_logo'  => '',
			),
		)
	);

	$page->add_control(
		'page_header_heading_menu',
		array(
			'label'     => $menu_style === 'classic' ? esc_html__( 'Mobile Overlay Menu Theme', 'kinsey' ) : esc_html__( 'Overlay Menu Theme', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::HEADING,
			'separator' => 'before',
			'condition' => array(
				'page_header_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_header_overlay_menu_background',
		array(
			'label'     => esc_html__( 'Background Color', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SELECT,
			'default'   => 'bg-dark-2',
			'options'   => ARTS_THEME_COLORS_ARRAY,
			'condition' => array(
				'page_header_settings_overridden' => 'yes',
			),
		)
	);

	$page->add_control(
		'page_header_overlay_menu_elements_theme',
		array(
			'label'     => esc_html__( 'Elements Color', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SELECT,
			'default'   => 'light',
			'options'   => ARTS_THEME_COLOR_THEMES_ARRAY,
			'condition' => array(
				'page_header_settings_overridden' => 'yes',
			),
		)
	);

	if ( $menu_style === 'fullscreen' ) {
		$page->add_control(
			'page_header_heading_fullscreen_sidebar',
			array(
				'label'     => esc_html__( 'Overlay Sidebar Theme', 'kinsey' ),
				'type'      => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => array(
					'page_header_settings_overridden' => 'yes',
				),
			)
		);

		$page->add_control(
			'page_fullscreen_sidebar_background',
			array(
				'label'     => esc_html__( 'Background Color', 'kinsey' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'default'   => 'bg-dark-1',
				'options'   => ARTS_THEME_COLORS_ARRAY,
				'condition' => array(
					'page_header_settings_overridden' => 'yes',
				),
			)
		);
	}

	$page->end_controls_section();
}
