<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Page Masthead in Elementor Document Settings
 */
add_action( 'elementor/element/wp-page/document_settings/after_section_end', 'arts_add_elementor_document_settings_page_masthead' );
add_action( 'elementor/element/wp-post/document_settings/after_section_end', 'arts_add_elementor_document_settings_page_masthead' );
function arts_add_elementor_document_settings_page_masthead( \Elementor\Core\DocumentTypes\PageBase $page ) {
	$post_id                                = get_the_ID();
	$has_featured_video                     = arts_get_field( 'featured_video', $post_id );
	$masthead_selector                      = "{{WRAPPER}} .section-masthead_post-{$post_id}";
	$masthead_desktop_selector              = "(desktop){{WRAPPER}} .section-masthead_post-{$post_id}";
	$masthead_tablet_selector               = "(tablet){{WRAPPER}} .section-masthead_post-{$post_id}";
	$masthead_mobile_selector               = "(mobile){{WRAPPER}} .section-masthead_post-{$post_id}";
	$layout_beneath_or_behind               = array(
		'relation' => 'or',
		'terms'    => array(
			array(
				'name'     => 'page_masthead_layout',
				'operator' => '===',
				'value'    => 'elementor-beneath',
			),
			array(
				'name'     => 'page_masthead_layout',
				'operator' => '===',
				'value'    => 'elementor-behind',
			),
		),
	);
	$layout_fullscreen_or_behind            = array(
		'relation' => 'or',
		'terms'    => array(
			array(
				'name'     => 'page_masthead_layout',
				'operator' => '===',
				'value'    => 'elementor-fullscreen',
			),
			array(
				'name'     => 'page_masthead_layout',
				'operator' => '===',
				'value'    => 'elementor-behind',
			),
		),
	);
	$layout_fullscreen_or_beneath_or_behind = array(
		'relation' => 'or',
		'terms'    => array(
			array(
				'name'     => 'page_masthead_layout',
				'operator' => '===',
				'value'    => 'elementor-fullscreen',
			),
			array(
				'name'     => 'page_masthead_layout',
				'operator' => '===',
				'value'    => 'elementor-beneath',
			),
			array(
				'name'     => 'page_masthead_layout',
				'operator' => '===',
				'value'    => 'elementor-behind',
			),
		),
	);

	/**
	 * START: Page Masthead Settings
	 */
	$page->start_controls_section(
		'page_masthead_section',
		array(
			'label' => esc_html__( 'Page Masthead', 'kinsey' ),
			'tab'   => \Elementor\Controls_Manager::TAB_SETTINGS,
		)
	);

	$page->add_control(
		'page_masthead_layout',
		array(
			'label'   => esc_html__( 'Template', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'options' => array(
				'elementor-beneath'    => esc_html__( 'Background Beneath Content', 'kinsey' ),
				'elementor-behind'     => esc_html__( 'Background Behind Content', 'kinsey' ),
				'elementor-fullscreen' => esc_html__( 'Fullscreen', 'kinsey' ),
			),
			'default' => 'elementor-beneath',
		)
	);

	$page->add_control(
		'page_masthead_heading_layout',
		array(
			'label'     => esc_html__( 'Layout', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::HEADING,
			'separator' => 'before',
		)
	);

	$page->add_control(
		'page_masthead_fullscreen_fixed_enabled',
		array(
			'label'     => esc_html__( 'Enable Fixed Layout', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SWITCHER,
			'default'   => '',
			'condition' => array(
				'page_masthead_layout' => 'elementor-fullscreen',
			),
		)
	);

	$page->add_control(
		'page_masthead_pt',
		array(
			'label'      => esc_html__( 'Padding Top', 'kinsey' ),
			'type'       => \Elementor\Controls_Manager::SELECT,
			'default'    => 'pt-xlarge',
			'options'    => ARTS_THEME_DISTANCE_ARRAY['padding']['top'],
			'conditions' => $layout_beneath_or_behind,
		)
	);

	$page->add_control(
		'page_masthead_pb',
		array(
			'label'      => esc_html__( 'Padding Bottom', 'kinsey' ),
			'type'       => \Elementor\Controls_Manager::SELECT,
			'default'    => 'pb-large',
			'options'    => ARTS_THEME_DISTANCE_ARRAY['padding']['bottom'],
			'conditions' => $layout_beneath_or_behind,
		)
	);

	$page->add_control(
		'page_masthead_mt',
		array(
			'label'      => esc_html__( 'Margin Top', 'kinsey' ),
			'type'       => \Elementor\Controls_Manager::SELECT,
			'default'    => '',
			'options'    => ARTS_THEME_DISTANCE_ARRAY['margin']['top'],
			'conditions' => $layout_beneath_or_behind,
		)
	);

	$page->add_control(
		'page_masthead_mb',
		array(
			'label'      => esc_html__( 'Margin Bottom', 'kinsey' ),
			'type'       => \Elementor\Controls_Manager::SELECT,
			'default'    => '',
			'options'    => ARTS_THEME_DISTANCE_ARRAY['margin']['bottom'],
			'conditions' => $layout_beneath_or_behind,
		)
	);

	$page->add_control(
		'page_masthead_heading_header',
		array(
			'label'     => esc_html__( 'Header', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::HEADING,
			'separator' => 'before',
		)
	);

	$page->add_control(
		'page_masthead_header_alignment',
		array(
			'label'   => esc_html__( 'Alignment', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::CHOOSE,
			'options' => array(
				'text-start'  => array(
					'title' => esc_html__( 'Left', 'kinsey' ),
					'icon'  => 'eicon-text-align-left',
				),
				'text-center' => array(
					'title' => esc_html__( 'Center', 'kinsey' ),
					'icon'  => 'eicon-text-align-center',
				),
				'text-end'    => array(
					'title' => esc_html__( 'Right', 'kinsey' ),
					'icon'  => 'eicon-text-align-right',
				),
			),
			'default' => 'text-center',
			'toggle'  => false,
		)
	);

	$page->add_control(
		'page_masthead_header_container',
		array(
			'label'   => esc_html__( 'Container', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'options' => array(
				'container'       => esc_html__( 'Boxed', 'kinsey' ),
				'container-fluid' => esc_html__( 'Fullwidth with Gutters', 'kinsey' ),
			),
			'default' => 'container-fluid',
		)
	);

	$page->add_control(
		'page_masthead_heading_content',
		array(
			'label'      => esc_html__( 'Content', 'kinsey' ),
			'type'       => \Elementor\Controls_Manager::HEADING,
			'separator'  => 'before',
			'conditions' => $layout_beneath_or_behind,
		)
	);

	$page->add_control(
		'page_masthead_content_alignment',
		array(
			'label'      => esc_html__( 'Alignment', 'kinsey' ),
			'type'       => \Elementor\Controls_Manager::CHOOSE,
			'options'    => array(
				'text-start'  => array(
					'title' => esc_html__( 'Left', 'kinsey' ),
					'icon'  => 'eicon-text-align-left',
				),
				'text-center' => array(
					'title' => esc_html__( 'Center', 'kinsey' ),
					'icon'  => 'eicon-text-align-center',
				),
				'text-end'    => array(
					'title' => esc_html__( 'Right', 'kinsey' ),
					'icon'  => 'eicon-text-align-right',
				),
			),
			'default'    => 'text-center',
			'toggle'     => false,
			'conditions' => $layout_beneath_or_behind,
		)
	);

	$page->add_control(
		'page_masthead_content_container',
		array(
			'label'      => esc_html__( 'Container', 'kinsey' ),
			'type'       => \Elementor\Controls_Manager::SELECT,
			'options'    => array(
				'container'       => esc_html__( 'Boxed', 'kinsey' ),
				'container-fluid' => esc_html__( 'Fullwidth with Gutters', 'kinsey' ),
			),
			'default'    => 'container',
			'conditions' => $layout_beneath_or_behind,
		)
	);

	$page->add_control(
		'page_masthead_heading_image',
		array(
			'label'     => esc_html__( 'Featured Image', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::HEADING,
			'separator' => 'before',
			'condition' => $has_featured_video ? array(
				'page_masthead_layout!'                => 'none',
				'page_masthead_featured_video_enabled' => '',
			) : array(
				'page_masthead_layout!' => 'none',
			),
		)
	);

	if ( $has_featured_video ) {
		$page->add_control(
			'page_masthead_heading_video',
			array(
				'label'     => esc_html__( 'Featured Video', 'kinsey' ),
				'type'      => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => array(
					'page_masthead_layout!'                => 'none',
					'page_masthead_featured_video_enabled' => 'yes',
				),
			)
		);
	}

	$page->add_control(
		'page_masthead_featured_video_enabled',
		array(
			'label'   => esc_html__( 'Use Featured Video (If Available)', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::SWITCHER,
			'default' => 'yes',
		)
	);

	$page->add_control(
		'page_masthead_image_container',
		array(
			'label'     => esc_html__( 'Container', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SELECT,
			'options'   => array(
				'container'       => esc_html__( 'Boxed', 'kinsey' ),
				'container-fluid' => esc_html__( 'Fullwidth with Gutters', 'kinsey' ),
				'w-100 mx-auto'   => esc_html__( 'Max Width', 'kinsey' ),
			),
			'default'   => 'container',
			'condition' => array(
				'page_masthead_layout' => 'elementor-beneath',
			),
		)
	);

	$page->add_responsive_control(
		'page_masthead_image_width',
		array(
			'label'           => esc_html__( 'Maximum Width', 'kinsey' ),
			'type'            => \Elementor\Controls_Manager::SLIDER,
			'desktop_default' => array(
				'size' => 100,
				'unit' => '%',
			),
			'tablet_default'  => array(
				'size' => 100,
				'unit' => '%',
			),
			'mobile_default'  => array(
				'size' => 100,
				'unit' => '%',
			),
			'range'           => array(
				'px' => array(
					'min' => 0,
					'max' => 1440,
				),
				'%'  => array(
					'min' => 0,
					'max' => 100,
				),
			),
			'size_units'      => array( 'px', '%' ),
			'selectors'       => array(
				"{$masthead_selector} .section-masthead__wrapper-image" => 'max-width: {{SIZE}}{{UNIT}};',
			),
			'condition'       => array(
				'page_masthead_layout'          => 'elementor-beneath',
				'page_masthead_image_container' => 'w-100 mx-auto',
			),
		)
	);

	$page->add_control(
		'page_masthead_image_placement',
		array(
			'label'     => esc_html__( 'Placement', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::CHOOSE,
			'options'   => array(
				'image'         => array(
					'title' => esc_html__( 'Responsive (Unlimited Width)', 'kinsey' ),
					'icon'  => 'eicon-image-bold',
				),
				'image_limited' => array(
					'title' => esc_html__( 'Responsive (Limited Width)', 'kinsey' ),
					'icon'  => 'eicon-image-before-after',
				),
				'background'    => array(
					'title' => esc_html__( 'Background', 'kinsey' ),
					'icon'  => 'eicon-image',
				),
			),
			'default'   => 'image_limited',
			'toggle'    => false,
			'condition' => array(
				'page_masthead_layout' => 'elementor-beneath',
			),
		)
	);

	$page->add_control(
		'page_masthead_image_parallax_enabled',
		array(
			'label'     => esc_html__( 'Enable Parallax', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SWITCHER,
			'default'   => 'yes',
			'condition' => array(
				'page_masthead_layout!' => 'none',
			),
		)
	);

	$page->add_control(
		'page_masthead_image_parallax_speed_x',
		array(
			'label'     => esc_html__( 'Parallax Speed X', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SLIDER,
			'range'     => array(
				'factor' => array(
					'min'  => -0.5,
					'max'  => 0.5,
					'step' => 0.01,
				),
			),
			'default'   => array(
				'unit' => 'factor',
				'size' => 0.0,
			),
			'condition' => array(
				'page_masthead_image_parallax_enabled' => 'yes',
				'page_masthead_layout!'                => 'none',
			),
		)
	);

	$page->add_control(
		'page_masthead_image_parallax_speed_y',
		array(
			'label'     => esc_html__( 'Parallax Speed Y', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SLIDER,
			'range'     => array(
				'factor' => array(
					'min'  => -0.5,
					'max'  => 0.5,
					'step' => 0.01,
				),
			),
			'default'   => array(
				'unit' => 'factor',
				'size' => 0.1,
			),
			'condition' => array(
				'page_masthead_image_parallax_enabled' => 'yes',
				'page_masthead_layout!'                => 'none',
			),
		)
	);

	$page->add_control(
		'page_masthead_image_parallax_scale_from',
		array(
			'label'     => esc_html__( 'Parallax Scale From', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SLIDER,
			'range'     => array(
				'factor' => array(
					'min'  => 0.0,
					'max'  => 2.0,
					'step' => 0.01,
				),
			),
			'default'   => array(
				'unit' => 'factor',
				'size' => 1.0,
			),
			'condition' => array(
				'page_masthead_image_parallax_enabled' => 'yes',
				'page_masthead_layout!'                => 'none',
			),
		)
	);

	$page->add_control(
		'page_masthead_image_parallax_scale_to',
		array(
			'label'     => esc_html__( 'Parallax Scale To', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::SLIDER,
			'range'     => array(
				'factor' => array(
					'min'  => 0.0,
					'max'  => 2.0,
					'step' => 0.01,
				),
			),
			'default'   => array(
				'unit' => 'factor',
				'size' => 1.0,
			),
			'condition' => array(
				'page_masthead_image_parallax_enabled' => 'yes',
				'page_masthead_layout!'                => 'none',
			),
		)
	);

	$page->add_responsive_control(
		'page_masthead_image_height',
		array(
			'label'           => esc_html__( 'Height', 'kinsey' ),
			'type'            => \Elementor\Controls_Manager::SLIDER,
			'desktop_default' => array(
				'size' => 900,
				'unit' => 'px',
			),
			'tablet_default'  => array(
				'size' => 70,
				'unit' => 'vh',
			),
			'mobile_default'  => array(
				'size' => 50,
				'unit' => 'vh',
			),
			'range'           => array(
				'px' => array(
					'min' => 0,
					'max' => 1440,
				),
				'vh' => array(
					'min' => 0,
					'max' => 100,
				),
			),
			'size_units'      => array( 'px', 'vh' ),
			'selectors'       => array(
				"{$masthead_selector} .section-masthead__wrapper-image" => 'height: {{SIZE}}{{UNIT}};',
			),
			'condition'       => array(
				'page_masthead_layout'          => 'elementor-beneath',
				'page_masthead_image_placement' => 'background',
			),
		)
	);

	$background_position_selectors = arts_elementor_should_selectors_have_responsive_prefixes() ? array(
		"{$masthead_desktop_selector} .section-masthead__wrapper-image .of-cover" => 'object-position: {{page_masthead_background_position_x.SIZE}}{{page_masthead_background_position_x.UNIT}} {{page_masthead_background_position_y.SIZE}}{{page_masthead_background_position_y.UNIT}};',
		"{$masthead_tablet_selector} .section-masthead__wrapper-image .of-cover" => 'object-position: {{page_masthead_background_position_x_tablet.SIZE}}{{page_masthead_background_position_x_tablet.UNIT}} {{page_masthead_background_position_y_tablet.SIZE}}{{page_masthead_background_position_y_tablet.UNIT}};',
		"{$masthead_mobile_selector} .section-masthead__wrapper-image .of-cover" => 'object-position: {{page_masthead_background_position_x_mobile.SIZE}}{{page_masthead_background_position_x_mobile.UNIT}} {{page_masthead_background_position_y_mobile.SIZE}}{{page_masthead_background_position_y_mobile.UNIT}};',
	) : array(
		"{$masthead_selector} .section-masthead__wrapper-image .of-cover" => 'object-position: {{page_masthead_background_position_x.SIZE}}{{page_masthead_background_position_x.UNIT}} {{page_masthead_background_position_y.SIZE}}{{page_masthead_background_position_y.UNIT}};',
	);
	$page->add_responsive_control(
		'page_masthead_background_position_x',
		array(
			'label'           => esc_html__( 'Background Position X', 'kinsey' ),
			'type'            => \Elementor\Controls_Manager::SLIDER,
			'desktop_default' => array(
				'size' => 50,
				'unit' => '%',
			),
			'tablet_default'  => array(
				'size' => 50,
				'unit' => '%',
			),
			'mobile_default'  => array(
				'size' => 50,
				'unit' => '%',
			),
			'range'           => array(
				'%' => array(
					'min' => 0,
					'max' => 100,
				),
			),
			'size_units'      => array( '%' ),
			'selectors'       => $background_position_selectors,
			'condition'       => array(
				'page_masthead_image_placement' => 'background',
				'page_masthead_layout!'         => 'none',
			),
		)
	);

	$page->add_responsive_control(
		'page_masthead_background_position_y',
		array(
			'label'           => esc_html__( 'Background Position Y', 'kinsey' ),
			'type'            => \Elementor\Controls_Manager::SLIDER,
			'desktop_default' => array(
				'size' => 50,
				'unit' => '%',
			),
			'tablet_default'  => array(
				'size' => 50,
				'unit' => '%',
			),
			'mobile_default'  => array(
				'size' => 50,
				'unit' => '%',
			),
			'range'           => array(
				'%' => array(
					'min' => 0,
					'max' => 100,
				),
			),
			'size_units'      => array( '%' ),
			'selectors'       => $background_position_selectors,
			'condition'       => array(
				'page_masthead_image_placement' => 'background',
				'page_masthead_layout!'         => 'none',
			),
		)
	);

	$page->add_control(
		'page_masthead_heading_themes',
		array(
			'label'     => esc_html__( 'Color Theme', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::HEADING,
			'separator' => 'before',
		)
	);

	$page->add_control(
		'page_masthead_header_background_color',
		array(
			'label'     => esc_html__( 'Header Background Color', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::COLOR,
			'default'   => '#ffffff',
			'selectors' => array(
				$masthead_selector => 'background-color: {{VALUE}}',
			),
			'global'    => array(
				'active' => false,
			),
		)
	);

	$page->add_control(
		'page_masthead_header_elements_theme',
		array(
			'label'   => esc_html__( 'Header Elements Theme', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'options' => ARTS_THEME_COLOR_THEMES_ARRAY,
			'default' => 'dark',
		)
	);

	$page->add_control(
		'page_masthead_heading_overlay',
		array(
			'label'      => esc_html__( 'Background Overlay', 'kinsey' ),
			'type'       => \Elementor\Controls_Manager::HEADING,
			'separator'  => 'before',
			'conditions' => $layout_fullscreen_or_behind,
		)
	);

	$page->add_group_control(
		\Elementor\Group_Control_Background::get_type(),
		array(
			'name'       => 'page_masthead_background_overlay',
			'label'      => esc_html__( 'Background Overlay', 'kinsey' ),
			'selector'   => "{$masthead_selector} .section-masthead__overlay",
			'conditions' => $layout_fullscreen_or_behind,
		)
	);

	$page->add_control(
		'page_masthead_featured_background_color',
		array(
			'label'     => esc_html__( 'Featured Background Color', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::COLOR,
			'default'   => '#f8f8f8',
			'separator' => 'before',
			'selectors' => array(
				"{$masthead_selector} .section__bg" => 'background-color: {{VALUE}}',
			),
			'global'    => array(
				'active' => false,
			),
		)
	);

	$page->add_control(
		'page_masthead_featured_elements_theme',
		array(
			'label'   => esc_html__( 'Featured Elements Theme', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'options' => ARTS_THEME_COLOR_THEMES_ARRAY,
			'default' => 'dark',
		)
	);

	$page->add_control(
		'page_masthead_heading_typography',
		array(
			'label'     => esc_html__( 'Typography', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::HEADING,
			'separator' => 'before',
		)
	);

	$page->add_control(
		'page_masthead_heading_preset',
		array(
			'label'   => esc_html__( 'Heading Preset', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'xl',
			'options' => ARTS_THEME_TYPOGRAHY_ARRAY,
		)
	);

	$page->add_control(
		'page_masthead_category_preset',
		array(
			'label'   => esc_html__( 'Category Preset', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'small',
			'options' => ARTS_THEME_TYPOGRAHY_ARRAY,
		)
	);

	$page->add_control(
		'page_masthead_subheading_preset',
		array(
			'label'   => esc_html__( 'Subheading Preset', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'h6',
			'options' => ARTS_THEME_TYPOGRAHY_ARRAY,
		)
	);

	$page->add_control(
		'page_masthead_properties_name_preset',
		array(
			'label'   => esc_html__( 'Properties: Name Preset', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'small',
			'options' => ARTS_THEME_TYPOGRAHY_ARRAY,
		)
	);

	$page->add_control(
		'page_masthead_properties_value_preset',
		array(
			'label'   => esc_html__( 'Properties: Value Preset', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'h4',
			'options' => ARTS_THEME_TYPOGRAHY_ARRAY,
		)
	);

	$page->add_control(
		'page_masthead_text_preset',
		array(
			'label'   => esc_html__( 'Text Preset', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'h3',
			'options' => ARTS_THEME_TYPOGRAHY_ARRAY,
		)
	);

	$page->add_control(
		'heading_elements',
		array(
			'label'     => esc_html__( 'Elements', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::HEADING,
			'separator' => 'before',
		)
	);

	$page->add_control(
		'page_masthead_subheading_enabled',
		array(
			'type'    => \Elementor\Controls_Manager::SWITCHER,
			'label'   => esc_html__( 'Show Subheading', 'kinsey' ),
			'default' => 'yes',
		)
	);
	$page->add_control(
		'page_masthead_categories_years_enabled',
		array(
			'type'    => \Elementor\Controls_Manager::SWITCHER,
			'label'   => esc_html__( 'Show Categories and Years', 'kinsey' ),
			'default' => 'yes',
		)
	);
	$page->add_control(
		'page_masthead_description_enabled',
		array(
			'type'    => \Elementor\Controls_Manager::SWITCHER,
			'label'   => esc_html__( 'Show Description', 'kinsey' ),
			'default' => 'yes',
		)
	);
	$page->add_control(
		'page_masthead_properties_enabled',
		array(
			'type'    => \Elementor\Controls_Manager::SWITCHER,
			'label'   => esc_html__( 'Show Properties', 'kinsey' ),
			'default' => 'yes',
		)
	);

	$page->add_control(
		'heading_animation',
		array(
			'label'     => esc_html__( 'Animation', 'kinsey' ),
			'type'      => \Elementor\Controls_Manager::HEADING,
			'separator' => 'before',
		)
	);

	$page->add_control(
		'page_masthead_animation_enabled',
		array(
			'label'   => esc_html__( 'Enable On-scroll Animation', 'kinsey' ),
			'type'    => \Elementor\Controls_Manager::SWITCHER,
			'default' => 'yes',
		)
	);

	// AJAX compatibility for "Hide Title" option
	$page->add_control(
		'kinsey_hide_title_enabled',
		array(
			'type'      => \Elementor\Controls_Manager::HIDDEN,
			'default'   => '',
			'condition' => array(
				'hide_title' => 'yes',
			),
			'selectors' => array(
				':root {{WRAPPER}}' => '--page-title-display: none',
			),
		)
	);

	$page->add_control(
		'kinsey_hide_title_disabled',
		array(
			'type'      => \Elementor\Controls_Manager::HIDDEN,
			'default'   => 'yes',
			'condition' => array(
				'hide_title' => '',
			),
			'selectors' => array(
				':root {{WRAPPER}}' => '--page-title-display: block',
			),
		)
	);

	/**
	 * END: Page Masthead Settings
	 */
	$page->end_controls_section();

}
