<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

trait Kinsey_Widget_Trait_Common_Controls {

	/**
	 * Add parallax background controls
	 *
	 * @return void
	 */
	public function add_controls_parallax( $args = array( 'factor_x', 'factor_y', 'scale_from', 'scale_to', 'easing' ) ) {
		if ( ! $args || empty( $args ) || ! is_array( $args ) ) {
			return;
		}

		$this->add_control(
			'image_parallax_enabled',
			array(
				'label'   => esc_html__( 'Enable Parallax', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		if ( in_array( 'factor_x', $args ) ) {
			$this->add_control(
				'image_parallax_speed_x',
				array(
					'label'     => esc_html__( 'Parallax Background Speed X', 'kinsey' ),
					'type'      => Controls_Manager::SLIDER,
					'range'     => array(
						'factor' => array(
							'min'  => -0.5,
							'max'  => 0.5,
							'step' => 0.01,
						),
					),
					'default'   => array(
						'unit' => 'factor',
						'size' => 0.0,
					),
					'condition' => array(
						'image_parallax_enabled' => 'yes',
					),
				)
			);
		}

		if ( in_array( 'factor_y', $args ) ) {
			$this->add_control(
				'image_parallax_speed_y',
				array(
					'label'     => esc_html__( 'Parallax Background Speed Y', 'kinsey' ),
					'type'      => Controls_Manager::SLIDER,
					'range'     => array(
						'factor' => array(
							'min'  => -0.5,
							'max'  => 0.5,
							'step' => 0.01,
						),
					),
					'default'   => array(
						'unit' => 'factor',
						'size' => 0.1,
					),
					'condition' => array(
						'image_parallax_enabled' => 'yes',
					),
				)
			);
		}

		if ( in_array( 'scale_from', $args ) ) {
			$this->add_control(
				'image_parallax_scale_from',
				array(
					'label'     => esc_html__( 'Parallax Scale From', 'kinsey' ),
					'type'      => Controls_Manager::SLIDER,
					'range'     => array(
						'factor' => array(
							'min'  => 0.0,
							'max'  => 2.0,
							'step' => 0.01,
						),
					),
					'default'   => array(
						'unit' => 'factor',
						'size' => 0.0,
					),
					'condition' => array(
						'image_parallax_enabled' => 'yes',
					),
				)
			);
		}

		if ( in_array( 'scale_to', $args ) ) {
			$this->add_control(
				'image_parallax_scale_to',
				array(
					'label'     => esc_html__( 'Parallax Scale To', 'kinsey' ),
					'type'      => Controls_Manager::SLIDER,
					'range'     => array(
						'factor' => array(
							'min'  => 0.0,
							'max'  => 2.0,
							'step' => 0.01,
						),
					),
					'default'   => array(
						'unit' => 'factor',
						'size' => 0.0,
					),
					'condition' => array(
						'image_parallax_enabled' => 'yes',
					),
				)
			);
		}

		if ( in_array( 'easing', $args ) ) {
			$this->add_control(
				'image_parallax_easing_enabled',
				array(
					'label'     => esc_html__( 'Enable Easing', 'kinsey' ),
					'type'      => Controls_Manager::SWITCHER,
					'default'   => '',
					'condition' => array(
						'image_parallax_enabled' => 'yes',
					),
				)
			);

			$this->add_control(
				'image_parallax_easing_factor',
				array(
					'label'     => esc_html__( 'Easing', 'kinsey' ),
					'type'      => Controls_Manager::SLIDER,
					'range'     => array(
						'factor' => array(
							'min'  => 0.0,
							'max'  => 2.0,
							'step' => 0.01,
						),
					),
					'default'   => array(
						'unit' => 'factor',
						'size' => 1.0,
					),
					'condition' => array(
						'image_parallax_enabled'        => 'yes',
						'image_parallax_easing_enabled' => 'yes',
					),
				)
			);
		}
	}

	/**
	 * Add interactive cursor controls
	 *
	 * @return void
	 */
	public function add_controls_cursor_interaction( $args ) {
		if ( ! $args || empty( $args ) || ! is_array( $args ) ) {
			return;
		}

		$this->add_control(
			'is_active_cursor_plugin',
			array(
				'type'    => Controls_Manager::HIDDEN,
				'default' => class_exists( 'Arts_Mouse_Cursor_Follower' ),
			)
		);

		$this->add_control(
			'message_inactive_cursor_plugin',
			array(
				'type'            => Controls_Manager::RAW_HTML,
				'raw'             => sprintf(
					'%1$s<br><br>%2$s <a href="%3$s" target="_blank">%4$s</a> %5$s',
					esc_html__( '"Arts Mouse Cursor Follower" plugin is not activated.', 'kinsey' ),
					esc_html__( 'In order to use the options below please install and activate it in', 'kinsey' ),
					admin_url( 'plugins.php' ),
					esc_html__( 'WordPress Plugins panel', 'kinsey' ),
					esc_html__( 'and return back here.', 'kinsey' )
				),
				'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
				'condition'       => array(
					'is_active_cursor_plugin' => false,
				),
			)
		);

		$index = 0;

		foreach ( $args as $key => $value ) {
			$slug = $this->get_slug_from_string( $key );

			$this->add_control(
				"cursor_{$slug}_enabled",
				array(
					'label'        => '<strong>' . esc_html__( $key, 'kinsey' ) . '</strong>',
					'type'         => Controls_Manager::SWITCHER,
					'default'      => '',
					'return_value' => 'true',
					'separator'    => $index === 0 ? false : 'before',
					'condition'    => array(
						'is_active_cursor_plugin' => true,
					),
				)
			);

			if ( in_array( 'scale', $value ) ) {
				$this->add_control(
					"cursor_{$slug}_scale_selector",
					array(
						'label'     => esc_html__( 'Scale', 'kinsey' ),
						'type'      => Controls_Manager::SELECT,
						'default'   => '',
						'options'   => array(
							''           => esc_html__( 'None', 'kinsey' ),
							'current'    => esc_html__( 'By Element\'s Width or Height', 'kinsey' ),
							'multiplier' => esc_html__( 'By Multiplier', 'kinsey' ),
						),
						'condition' => array(
							'is_active_cursor_plugin' => true,
							"cursor_{$slug}_enabled"  => 'true',
						),
					)
				);

				$this->add_control(
					"cursor_{$slug}_scale",
					array(
						'label'     => esc_html__( 'Scale Multiplier', 'kinsey' ),
						'type'      => Controls_Manager::SLIDER,
						'range'     => array(
							'px' => array(
								'min'  => 0.0,
								'max'  => 4.0,
								'step' => 0.1,
							),
						),
						'default'   => array(
							'unit' => 'px',
							'size' => 1.0,
						),
						'condition' => array(
							'is_active_cursor_plugin' => true,
							"cursor_{$slug}_enabled"  => 'true',
							"cursor_{$slug}_scale_selector" => 'multiplier',
						),
					)
				);
			}

			if ( in_array( 'hide_native', $value ) ) {
				$this->add_control(
					"cursor_hide_native_{$slug}_enabled",
					array(
						'label'        => esc_html__( 'Hide Native Cursor', 'kinsey' ),
						'type'         => Controls_Manager::SWITCHER,
						'default'      => '',
						'return_value' => 'true',
						'condition'    => array(
							'is_active_cursor_plugin' => true,
							"cursor_{$slug}_enabled"  => 'true',
						),
					)
				);
			}

			if ( in_array( 'magnetic', $value ) ) {
				$this->add_control(
					"cursor_magnetic_{$slug}_enabled",
					array(
						'label'        => esc_html__( 'Enable Magnetic Effect', 'kinsey' ),
						'type'         => Controls_Manager::SWITCHER,
						'default'      => '',
						'return_value' => 'true',
						'condition'    => array(
							'is_active_cursor_plugin' => true,
							"cursor_{$slug}_enabled"  => 'true',
						),
					)
				);
			}

			if ( in_array( 'label', $value ) || in_array( 'icon', $value ) ) {
				$this->add_control(
					"cursor_{$slug}_helper_selector",
					array(
						'label'     => esc_html__( 'Cursor Helper', 'kinsey' ),
						'type'      => Controls_Manager::SELECT,
						'default'   => '',
						'options'   => array(
							''      => esc_html__( 'None', 'kinsey' ),
							'label' => esc_html__( 'Label', 'kinsey' ),
							'icon'  => esc_html__( 'Icon', 'kinsey' ),
						),
						'condition' => array(
							'is_active_cursor_plugin' => true,
							"cursor_{$slug}_enabled"  => 'true',
						),
					)
				);

				if ( in_array( 'label', $value ) ) {
					$this->add_control(
						"cursor_{$slug}_label",
						array(
							'label'     => esc_html__( 'Label', 'kinsey' ),
							'type'      => Controls_Manager::TEXT,
							'default'   => '',
							'dynamic'   => array(
								'active' => true,
							),
							'condition' => array(
								'is_active_cursor_plugin' => true,
								"cursor_{$slug}_enabled"  => 'true',
								"cursor_{$slug}_helper_selector" => 'label',
							),
						)
					);
				}

				if ( in_array( 'icon', $value ) ) {
					$this->add_control(
						"cursor_{$slug}_icon",
						array(
							'label'                  => esc_html__( 'Icon', 'kinsey' ),
							'type'                   => Controls_Manager::ICONS,
							'skin'                   => 'inline',
							'exclude_inline_options' => array( 'svg' ),
							'condition'              => array(
								'is_active_cursor_plugin' => true,
								"cursor_{$slug}_enabled"  => 'true',
								"cursor_{$slug}_helper_selector" => 'icon',
							),
						)
					);
				}
			}

			if ( in_array( 'color', $value ) ) {
				$this->add_control(
					"cursor_{$slug}_color",
					array(
						'label'     => esc_html__( 'Text Color', 'kinsey' ),
						'type'      => Controls_Manager::COLOR,
						'default'   => get_theme_mod( 'cursor_color', '#ffffff' ),
						'condition' => array(
							'is_active_cursor_plugin' => true,
							"cursor_{$slug}_enabled"  => 'true',
							"cursor_{$slug}_helper_selector!" => '',
						),
					)
				);
			}

			if ( in_array( 'background_color', $value ) ) {
				$this->add_control(
					"cursor_{$slug}_background_color",
					array(
						'label'     => esc_html__( 'Background Color', 'kinsey' ),
						'type'      => Controls_Manager::COLOR,
						'default'   => get_theme_mod( 'cursor_background_color', '#ed4830' ),
						'condition' => array(
							'is_active_cursor_plugin' => true,
							"cursor_{$slug}_enabled"  => 'true',
							"cursor_{$slug}_helper_selector!" => '',
						),
					)
				);
			}

			$index++;
		}
	}

	/**
	 * Add button controls
	 *
	 * @return void
	 */
	public function add_controls_button( $args = array( 'title', 'title_hover', 'link', 'style', 'border', 'color', 'icon_before', 'icon_after' ) ) {
		if ( ! $args || empty( $args ) || ! is_array( $args ) ) {
			return;
		}

		if ( in_array( 'title', $args ) ) {
			$this->add_control(
				'button_title',
				array(
					'label'     => esc_html__( 'Title', 'kinsey' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => esc_html__( 'Explore Project', 'kinsey' ),
					'dynamic'   => array(
						'active' => true,
					),
					'separator' => 'before',
				)
			);

			if ( in_array( 'title_hover', $args ) ) {
				$this->add_control(
					'button_title_hover',
					array(
						'label'   => esc_html__( 'Hover Title', 'kinsey' ),
						'type'    => Controls_Manager::TEXT,
						'default' => esc_html__( 'Explore Project', 'kinsey' ),
						'dynamic' => array(
							'active' => true,
						),
					)
				);
			}
		}

		if ( in_array( 'link', $args ) ) {
			$this->add_control(
				'button_link',
				array(
					'label'         => esc_html__( 'Link', 'kinsey' ),
					'type'          => Controls_Manager::URL,
					'placeholder'   => 'https://...',
					'show_external' => true,
					'default'       => array(
						'url'         => '#',
						'is_external' => false,
						'nofollow'    => false,
					),
					'dynamic'       => array(
						'active' => true,
					),
				)
			);
		}

		if ( in_array( 'style', $args ) ) {
			$this->add_control(
				'button_style',
				array(
					'label'   => esc_html__( 'Style', 'kinsey' ),
					'type'    => Controls_Manager::SELECT,
					'options' => array(
						''                                => esc_html__( 'Normal', 'kinsey' ),
						'button-circle'                   => esc_html__( 'Circle Small', 'kinsey' ),
						'button-circle button-circle_medium' => esc_html__( 'Circle Medium', 'kinsey' ),
						'button-circle button-circle_big' => esc_html__( 'Circle Big', 'kinsey' ),
					),
					'default' => '',
				)
			);
		}

		if ( in_array( 'border', $args ) ) {
			$this->add_control(
				'button_border',
				array(
					'label'   => esc_html__( 'Border', 'kinsey' ),
					'type'    => Controls_Manager::SELECT,
					'options' => array(
						'button_solid'    => esc_html__( 'Solid', 'kinsey' ),
						'button_bordered' => esc_html__( 'Bordered', 'kinsey' ),
					),
					'default' => 'button_bordered',
				)
			);
		}

		if ( in_array( 'color', $args ) ) {
			$this->add_control(
				'button_color',
				array(
					'label'   => esc_html__( 'Color', 'kinsey' ),
					'type'    => Controls_Manager::SELECT,
					'options' => ARTS_THEME_COLORS_ARRAY,
					'default' => '',
				)
			);
		}

		if ( in_array( 'icon_before', $args ) ) {
			$this->add_control(
				'button_icon_before',
				array(
					'label' => esc_html__( 'Icon Before', 'kinsey' ),
					'type'  => Controls_Manager::ICONS,
				)
			);
		}

		if ( in_array( 'icon_after', $args ) ) {
			$this->add_control(
				'button_icon_after',
				array(
					'label' => esc_html__( 'Icon After', 'kinsey' ),
					'type'  => Controls_Manager::ICONS,
				)
			);
		}
	}

	/**
	 * Generate typography controls set
	 *
	 * @return void
	 */
	public function add_controls_typography( $args ) {
		if ( ! $args || empty( $args ) || ! is_array( $args ) ) {
			return;
		}

		$index = 0;

		foreach ( $args as $key => $value ) {
			$slug = $this->get_slug_from_string( $key );

			$this->add_control(
				"typography_{$slug}",
				array(
					'label'     => esc_html__( $key, 'kinsey' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => $index === 0 ? false : 'before',
				)
			);

			if ( array_key_exists( 'preset', $value ) ) {
				$this->add_control(
					"typography_{$slug}_preset",
					array(
						'label'   => esc_html__( 'Typography Preset', 'kinsey' ),
						'type'    => Controls_Manager::SELECT,
						'default' => $value['preset'],
						'options' => ARTS_THEME_TYPOGRAHY_ARRAY,
					)
				);
			}

			if ( array_key_exists( 'tag', $value ) ) {
				$this->add_control(
					"typography_{$slug}_tag",
					array(
						'label'   => esc_html__( 'HTML Tag', 'kinsey' ),
						'type'    => Controls_Manager::SELECT,
						'default' => $value['tag'],
						'options' => ARTS_THEME_HTML_TAGS_ARRAY,
					)
				);
			}

			$index++;
		}
	}

	/**
	 * Add animation toggle
	 *
	 * @return void
	 */
	public function add_controls_animation( $args = array() ) {
		$this->add_control(
			'animation_enabled',
			array(
				'label'   => esc_html__( 'Enable On-scroll Animation', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		if ( in_array( 'mask', $args ) ) {
			$control_condition = array(
				'animation_enabled' => 'yes',
			);

			$this->add_control(
				'animation_mask_reveal_heading',
				array(
					'label'     => esc_html__( 'Mask Reveal', 'kinsey' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => $control_condition,
				)
			);

			$this->add_control(
				'animation_mask_reveal_direction',
				array(
					'label'     => esc_html__( 'Reveal Direction', 'kinsey' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'down',
					'options'   => array(
						'up'    => esc_html__( 'From Top to Bottom', 'kinsey' ),
						'down'  => esc_html__( 'From Bottom to Top', 'kinsey' ),
						'left'  => esc_html__( 'From Left to Right', 'kinsey' ),
						'right' => esc_html__( 'From Right to Left', 'kinsey' ),
					),
					'condition' => $control_condition,
				)
			);

			$this->add_control(
				'animation_mask_scale_from',
				array(
					'label'     => esc_html__( 'Reveal Scale From', 'kinsey' ),
					'type'      => Controls_Manager::SLIDER,
					'range'     => array(
						'factor' => array(
							'min'  => 0.0,
							'max'  => 2.0,
							'step' => 0.01,
						),
					),
					'default'   => array(
						'unit' => 'factor',
						'size' => 1.2,
					),
					'condition' => $control_condition,
				)
			);
		}
	}
}
