<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

trait Kinsey_Widget_Trait_Common_Helpers {
	public function get_animation_attributes( $attributes, $name = '', $params = array() ) {
		if ( is_array( $attributes ) && ! empty( $attributes ) && $name ) {
			$attributes['data-arts-os-animation']      = 'true';
			$attributes['data-arts-os-animation-name'] = $name;

			if ( is_array( $params ) && ! empty( $params ) ) {
				$attributes['data-arts-os-animation-params'] = json_encode( $params );
			}
		}

		return $attributes;
	}

	public function get_split_text_attributes( $attributes, $args = array() ) {
		if ( ! array_key_exists( 'class', $attributes ) ) {
			$attributes['class'] = array();
		}

		$defaults = array(
			'by'        => 'lines',
			'set'       => 'lines',
			'direction' => '',
			'distance'  => '',
			'overflow'  => 'lines',
			'animation' => true,
		);

		$args = wp_parse_args( $args, $defaults );

		$attributes['class'][] = 'arts-split-text';
		$attributes['class'][] = 'js-arts-split-text';

		if ( $args['by'] ) {
			$attributes['data-arts-split-text'] = $args['by'];
		}

		if ( $args['set'] ) {
			$attributes['data-arts-split-text-set'] = $args['set'];
		}

		if ( $args['direction'] ) {
			$attributes['data-arts-split-text-set-direction'] = $args['direction'];
		}

		if ( $args['distance'] ) {
			$attributes['data-arts-split-text-set-distance'] = $args['distance'];
		}

		if ( $args['overflow'] ) {
			$attributes['data-arts-split-text-overflow-wrap'] = $args['overflow'];
		}

		if ( $args['animation'] === true ) {
			$attributes['data-arts-os-animation']      = 'true';
			$attributes['data-arts-os-animation-name'] = 'animateText';
		}

		if ( is_array( $args['animation'] ) ) {
			$attributes = $this->get_animation_attributes( $attributes, 'animateText', $args['animation'] );
		}

		return $attributes;
	}

	public function get_taxonomy_term_names( $post_id, $taxonomy ) {
		$items = get_the_terms( $post_id, $taxonomy );
		$arr   = array();

		if ( is_array( $items ) ) {
			foreach ( $items as $item ) {
				$temp = array(
					'slug' => $item->slug,
					'name' => $item->name,
					'url'  => get_term_link( $item->slug, $taxonomy ),
				);

				// don't add the same item multiple times
				if ( ! in_array( $arr, $temp ) ) {
					array_push( $arr, $temp );
				}
			}
		}

		return $arr;
	}

	/**
	 * Print HTML tag
	 *
	 * @param string $settings_tag_key
	 * @return void
	 */
	public function print_html_tag( $settings_tag_key ) {
		$html_tag = $this->get_settings( esc_attr( $settings_tag_key ) );

		// fallback
		if ( empty( $html_tag ) ) {
			$html_tag = 'div';
		}

		echo $html_tag;
	}

	public function get_parallax_config() {
		$settings = $this->get_settings_for_display();
		$result   = array();

		if ( $settings['image_parallax_enabled'] ) {
			$result['enabled'] = true;

			if ( array_key_exists( 'image_parallax_speed_x', $settings ) && $settings['image_parallax_speed_x']['size'] ) {
				$result['factor']['x'] = $settings['image_parallax_speed_x']['size'];
			}

			if ( array_key_exists( 'image_parallax_speed_y', $settings ) && $settings['image_parallax_speed_y']['size'] ) {
				$result['factor']['y'] = $settings['image_parallax_speed_y']['size'];
			}

			if ( array_key_exists( 'image_parallax_scale_from', $settings ) && $settings['image_parallax_scale_from']['size'] ) {
				$result['scale']['from'] = $settings['image_parallax_scale_from']['size'];
			}

			if ( array_key_exists( 'image_parallax_scale_to', $settings ) && $settings['image_parallax_scale_to']['size'] ) {
				$result['scale']['to'] = $settings['image_parallax_scale_to']['size'];
			}

			if ( array_key_exists( 'image_parallax_easing_enabled', $settings ) && $settings['image_parallax_easing_enabled'] && $settings['image_parallax_easing_factor'] ) {
				$result['scrub'] = $settings['image_parallax_easing_factor']['size'];
			}
		}

		return $result;
	}

	public function get_animation_mask_config() {
		$settings = $this->get_settings_for_display();
		$result   = array();

		if ( $settings['animation_enabled'] ) {
			$result['enabled']        = true;
			$result['outer']['class'] = array( 'mask-reveal' );

			if ( array_key_exists( 'animation_mask_reveal_direction', $settings ) || array_key_exists( 'animation_mask_scale_from', $settings ) ) {
				$result['params'] = array();

				if ( array_key_exists( 'animation_mask_reveal_direction', $settings ) ) {
					$result['params']['direction'] = $settings['animation_mask_reveal_direction'];
				}

				if ( array_key_exists( 'animation_mask_scale_from', $settings ) ) {
					$result['params']['scale'] = $settings['animation_mask_scale_from']['size'];
				}
			}
		}

		return $result;
	}

	public function get_thumbnail_size( $image_id ) {
		if ( empty( $image_id ) ) {
			return false;
		}

			$settings = $this->get_settings_for_display();
			$result   = $settings['image_size'];

		if ( $settings['image_size'] === 'custom' ) {
			// Use BFI_Thumb script
			require_once ELEMENTOR_PATH . 'includes/libraries/bfi-thumb/bfi-thumb.php';

			$intrinsic_image        = wp_get_attachment_image_src( $image_id, 'full' );
			$intrinsic_aspect_ratio = $intrinsic_image[1] / $intrinsic_image[2];

			$result = array(
				0           => null,
				1           => null,
				'bfi_thumb' => true,
				'crop'      => true,
			);

			$has_custom_size = false;

			if ( ! empty( $settings['image_custom_dimension']['width'] ) ) {
				$has_custom_size = true;
				$result[0]       = $settings['image_custom_dimension']['width'];
			}

			if ( ! empty( $settings['image_custom_dimension']['height'] ) ) {
				$has_custom_size = true;
				$result[1]       = $settings['image_custom_dimension']['height'];
			}

			// restore missing width using the intrinsic image aspect ratio
			if ( ! $result[0] && $settings['image_custom_dimension']['height'] ) {
				$result[0] = $settings['image_custom_dimension']['height'] * $intrinsic_aspect_ratio;
			}

			// restore missing height using the intrinsic image aspect ratio
			if ( ! $result[1] && $settings['image_custom_dimension']['width'] ) {
				$result[1] = $settings['image_custom_dimension']['width'] / $intrinsic_aspect_ratio;
			}

			if ( ! $has_custom_size ) {
				$result = 'full';
			}
		}

			return $result;
	}

	/**
	 * Translate the string values to the correct columns proportion value
	 */
	public function translate_columns_settings( $option ) {
		if ( ! $option ) {
			return 12;
		}

		if ( $option === '2dot4' ) {
			return 2.4;
		}

		return $option;
	}

	public function print_post_categories( $post, $categories = true, $years = true ) {
		$settings = $this->get_settings_for_display();

		$categories = $categories ? $this->get_taxonomy_term_names( $post['id'], 'arts_portfolio_category' ) : false;
		$years      = $years ? $this->get_taxonomy_term_names( $post['id'], 'arts_portfolio_year' ) : false;

		?>

		<?php if ( $settings['categories_years_enabled'] && ( ! empty( $categories ) || ! empty( $years ) ) ) : ?>
<div <?php $this->print_render_attribute_string( 'category' ); ?>>
			<?php
					get_template_part(
						'template-parts/list/list',
						'categories',
						array(
							'categories' => $categories,
							'years'      => $years,
						)
					);
			?>
</div>
		<?php endif; ?>

		<?php
	}

	public function print_social_media_list() {
		$settings = $this->get_settings_for_display();

		if ( ! array_key_exists( 'social', $settings ) ) {
			return;
		}
		?>

<ul class="soc1al">
		<?php foreach ( $settings['social'] as $item ) : ?>
  <li class="soc1al__item">
			<?php
						$this->remove_render_attribute( 'icon_link' );
						$this->add_link_attributes( 'icon_link', $item['social_link'] );
			?>
	<a
			<?php $this->print_render_attribute_string( 'icon_link' ); ?>><?php \Elementor\Icons_Manager::render_icon( $item['social_icon'] ); ?></a>
  </li>
  <?php endforeach; ?>
</ul>

		<?php
	}

	public function get_prefix_zeros( $index ) {
		$settings = $this->get_settings_for_display();
		$result   = $index;

		if ( array_key_exists( 'counters_zeros', $settings ) ) {
			$amount = intval( $settings['counters_zeros'] );
			switch ( $amount ) {
				case 2:
					$result = $amount < 10 ? '00' . $index : '0' . $index;
					break;
				case 1:
					$result = $amount < 10 ? '0' . $index : $index;
					break;
				default:
					$result = $index;
					break;
			}
		}

		return $result;
	}

	/**
	 * Build cursor attributes
	 *
	 * @param array  $attributes input attributes
	 * @param string $string Elementor cursor control slug
	 * @return array result attributes
	 */
	public function add_cursor_attributes( $attributes = array(), $string = '' ) {
		$settings          = $this->get_settings_for_display();
		$slug              = $this->get_slug_from_string( $string );
		$cursor_attributes = array();

		if ( array_key_exists( "cursor_{$slug}_enabled", $settings ) && $settings[ "cursor_{$slug}_enabled" ] ) {

			$cursor_attributes['data-arts-cursor'] = $settings[ "cursor_{$slug}_enabled" ];

			if ( array_key_exists( "cursor_{$slug}_scale_selector", $settings ) && $settings[ "cursor_{$slug}_scale_selector" ] ) {

				if ( $settings[ "cursor_{$slug}_scale_selector" ] === 'current' ) {
					$cursor_attributes['data-arts-cursor-scale'] = 'current';
				}

				if ( $settings[ "cursor_{$slug}_scale_selector" ] === 'multiplier' && array_key_exists( "cursor_{$slug}_scale", $settings ) ) {
					$cursor_attributes['data-arts-cursor-scale'] = $settings[ "cursor_{$slug}_scale" ]['size'];
				}
			}

			if ( array_key_exists( "cursor_hide_native_{$slug}_enabled", $settings ) && $settings[ "cursor_hide_native_{$slug}_enabled" ] ) {
				$cursor_attributes['data-arts-cursor-hide-native'] = $settings[ "cursor_hide_native_{$slug}_enabled" ];
			}

			if ( array_key_exists( "cursor_magnetic_{$slug}_enabled", $settings ) && $settings[ "cursor_magnetic_{$slug}_enabled" ] ) {
				$cursor_attributes['data-arts-cursor-magnetic'] = $settings[ "cursor_magnetic_{$slug}_enabled" ];
			}

			if ( array_key_exists( "cursor_{$slug}_helper_selector", $settings ) ) {

				if ( $settings[ "cursor_{$slug}_helper_selector" ] === 'label' && array_key_exists( "cursor_{$slug}_label", $settings ) && $settings[ "cursor_{$slug}_label" ] ) {
					$cursor_attributes['data-arts-cursor-label'] = $settings[ "cursor_{$slug}_label" ];
				}

				if ( $settings[ "cursor_{$slug}_helper_selector" ] === 'icon' && array_key_exists( "cursor_{$slug}_icon", $settings ) && $settings[ "cursor_{$slug}_icon" ] ) {
					if ( is_string( $settings[ "cursor_{$slug}_icon" ]['value'] ) && ! empty( $settings[ "cursor_{$slug}_icon" ]['value'] ) ) {
						$cursor_attributes['data-arts-cursor-icon-class'] = $settings[ "cursor_{$slug}_icon" ]['value'];
					}

					if ( is_array( $settings[ "cursor_{$slug}_icon" ]['value'] ) && array_key_exists( 'url', $settings[ "cursor_{$slug}_icon" ]['value'] ) ) {
						$cursor_attributes['data-arts-cursor-icon-url'] = $settings[ "cursor_{$slug}_icon" ]['value']['url'];
					}
				}
			}

			if ( array_key_exists( "cursor_{$slug}_color", $settings ) && $settings[ "cursor_{$slug}_color" ] ) {
				$cursor_attributes['data-arts-cursor-color'] = $settings[ "cursor_{$slug}_color" ];
			} elseif ( array_key_exists( 'data-arts-cursor-label', $cursor_attributes ) || array_key_exists( 'data-arts-cursor-icon-class', $cursor_attributes ) ) {
				$cursor_attributes['data-arts-cursor-color'] = 'default';
			}

			if ( array_key_exists( "cursor_{$slug}_background_color", $settings ) && $settings[ "cursor_{$slug}_background_color" ] ) {
				$cursor_attributes['data-arts-cursor-background-color'] = $settings[ "cursor_{$slug}_background_color" ];
			} elseif ( array_key_exists( 'data-arts-cursor-label', $cursor_attributes ) || array_key_exists( 'data-arts-cursor-icon-class', $cursor_attributes ) ) {
				$cursor_attributes['data-arts-cursor-background-color'] = 'default';
			}
		}

		return array_merge( $attributes, $cursor_attributes );
	}

	private function get_slug_from_string( $string ) {
		return str_replace( array( '_', '-', '/', '&', ' ' ), '_', strtolower( $string ) );
	}
}
