<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

trait Kinsey_Widget_Trait_Dynamic_Helpers {
	/**
	 * WordPress DB query for the posts
	 *
	 * @return void
	 */
	protected static function _get_posts() {

		// get class name in lowercase
		$class_name = ( new \ReflectionClass( static::class ) )->getShortName();
		$class_name = strtolower( $class_name );

		// filter to change current widget post type
		$args = apply_filters(
			'arts/elementor/' . $class_name . '/query_args',
			array(
				'post_type'      => static::$_post_type,
				'posts_per_page' => -1,
				'no_found_rows'  => true,
				'lang'           => '',
			)
		);

		// global query filter (affects all dynamic widgets)
		$args               = apply_filters( 'arts/elementor/dynamic_widgets/query_args', $args );
		static::$_post_type = $args['post_type'];

		$posts               = array();
		$counter             = 0;
		$categories_taxonomy = 'arts_portfolio_category';
		$years_taxonomy      = 'arts_portfolio_year';

		// map default blog categories for the 'post' post type
		if ( $args['post_type'] === 'post' ) {
			$categories_taxonomy = 'category';
		}

		$loop = new \WP_Query( $args );

		if ( $loop->have_posts() ) {

			while ( $loop->have_posts() ) {

				$loop->the_post();

				$posts[ $counter ]['id']                 = get_the_ID();
				$posts[ $counter ]['ID']                 = $posts[ $counter ]['id']; // alias
				$posts[ $counter ]['title']              = get_the_title();
				$posts[ $counter ]['permalink']          = get_the_permalink();
				$posts[ $counter ]['image_id']           = get_post_thumbnail_id();
				$posts[ $counter ]['image_secondary_id'] = arts_get_field( 'secondary_image', $posts[ $counter ]['id'] );
				$posts[ $counter ]['video_url']          = arts_get_field( 'featured_video', $posts[ $counter ]['id'] );
				$posts[ $counter ]['subheading']         = arts_get_field( 'subheading', $posts[ $counter ]['id'] );
				$posts[ $counter ]['description']        = arts_get_field( 'description', $posts[ $counter ]['id'] );

				$post_categories                       = get_the_terms( $posts[ $counter ]['id'], $categories_taxonomy );
				$posts[ $counter ]['categories']       = $post_categories;
				$posts[ $counter ]['categories_names'] = array();
				$posts[ $counter ]['categories_slugs'] = array();
				$post_years                            = get_the_terms( $posts[ $counter ]['id'], $years_taxonomy );
				$posts[ $counter ]['years']            = array();
				$posts[ $counter ]['years_terms']      = $post_years;
				$posts[ $counter ]['years_names']      = array();
				$posts[ $counter ]['years_slugs']      = array();

				$posts[ $counter ]['media_gallery'] = arts_get_field( 'media_gallery', $posts[ $counter ]['id'] );

				if ( is_array( $post_categories ) ) {
					foreach ( $post_categories as $item ) {
						array_push( $posts[ $counter ]['categories_names'], $item->name );
						array_push( $posts[ $counter ]['categories_slugs'], $item->slug );
					}
				}

				if ( is_array( $post_years ) ) {
					foreach ( $post_years as $item ) {
						$arr = array(
							'name' => $item->name,
							'slug' => $item->slug,
							'url'  => get_term_link( $item->slug, $years_taxonomy ),
						);
						array_push( $posts[ $counter ]['years_names'], $item->name );
						array_push( $posts[ $counter ]['years_slugs'], $item->slug );
						$posts[ $counter ]['years'][] = $arr;
					}
				}

				$counter++;
			}

			wp_reset_postdata();

		}

		static::$_posts = $posts;
	}

	/**
	 * Get all posts by a pre-set type
	 *
	 * @return array
	 */
	public function get_posts() {
		if ( is_null( static::$_posts ) ) {
			static::_get_posts();
		}

		return static::$_posts;
	}

	/**
	 * Filter out disabled posts
	 *
	 * @return array
	 */
	public function get_posts_to_display() {
		$posts    = $this->get_posts();
		$settings = $this->get_settings_for_display();

		// static data source
		if ( array_key_exists( 'posts_data_source', $settings ) && $settings['posts_data_source'] === 'static' ) {

			if ( is_array( $settings['posts_static'] ) && ! empty( $settings['posts_static'] ) ) {
				foreach ( $settings['posts_static'] as $key => $value ) {

					$settings['posts_static'][ $key ]['id'] = 'STATIC';

					if ( array_key_exists( 'permalink', $settings['posts_static'][ $key ] ) ) {
						$settings['posts_static'][ $key ]['permalink_attributes'] = $settings['posts_static'][ $key ]['permalink'];
						$settings['posts_static'][ $key ]['permalink']            = $settings['posts_static'][ $key ]['permalink']['url'];
					}

					if ( array_key_exists( 'image_id', $settings['posts_static'][ $key ] ) ) {
						$settings['posts_static'][ $key ]['image_id'] = array_key_exists( 'image_id', $settings['posts_static'][ $key ] ) ? $settings['posts_static'][ $key ]['image_id']['id'] : '';
					}

					if ( array_key_exists( 'video_url', $settings['posts_static'][ $key ] ) ) {
						$settings['posts_static'][ $key ]['video_url'] = array_key_exists( 'video_url', $settings['posts_static'][ $key ] ) ? $settings['posts_static'][ $key ]['video_url']['url'] : '';
					}

					if ( array_key_exists( 'category', $settings['posts_static'][ $key ] ) ) {
						$settings['posts_static'][ $key ]['categories_names'][0] = $settings['posts_static'][ $key ]['subheading'];
						$settings['posts_static'][ $key ]['categories_slugs'][0] = sanitize_title( $settings['posts_static'][ $key ]['subheading'] );
					}
				}
			}

			$posts = $settings['posts_static'];

		} else { // dynamic data source

			// limit posts amount
			if ( array_key_exists( 'posts_amount', $settings ) && $settings['posts_amount']['size'] > 0 ) {
				array_splice( $posts, $settings['posts_amount']['size'] );
			}

			// only "enabled" posts
			$posts = array_filter(
				$posts,
				function( $item ) {
					$settings = $this->get_settings_for_display();
					return ( array_key_exists( 'enabled' . $item['id'], $settings ) ) && ( $settings[ 'enabled' . $item['id'] ] );
				}
			);

		}

		return $posts;
	}

	/**
	 * Collect the posts categories, remove duplicates
	 *
	 * @return array
	 */
	public function get_taxonomies_to_display( $posts = array(), $taxonomy = 'arts_portfolio_category' ) {
		$active_taxonomies = array();
		$hicpo_options     = get_option( 'hicpo_options' );
		$is_sortable       = false;
		$amounts           = array();
		$item_terms_set    = 'categories';

		// re-map to years terms
		if ( static::$_post_type === 'arts_portfolio_item' && $taxonomy === 'arts_portfolio_year' ) {
			$item_terms_set = 'years_terms';
		}

		// re-map taxonomy
		if ( static::$_post_type === 'post' ) {
			$taxonomy = 'category';
		}

		// sortable taxonomy via Intuitive Custom Posts Order plugin
		if ( class_exists( 'Hicpo' ) && is_array( $hicpo_options ) && array_key_exists( 'tags', $hicpo_options ) && ! empty( $hicpo_options['tags'] ) ) {
			$hicpo_tags  = $hicpo_options['tags'];
			$is_sortable = in_array( $taxonomy, $hicpo_tags );
		}

		foreach ( $posts as $item ) {
			if ( is_array( $item[ $item_terms_set ] ) ) {
				foreach ( $item[ $item_terms_set ] as $taxonomy ) {
					$arr = array(
						'slug' => $taxonomy->slug,
						'name' => $taxonomy->name,
					);

					// item already exists, increase counter;
					if ( in_array( $arr, $active_taxonomies ) ) {
						$amounts[ $taxonomy->slug ]++;
					} else { // don't add the same item multiple times
						$amounts[ $taxonomy->slug ] = 1;

						if ( $is_sortable ) {
							$active_taxonomies[ $taxonomy->term_order ] = $arr;
						} else {
							array_push( $active_taxonomies, $arr );
						}
					}
				}
			}
		}

		if ( $is_sortable ) {
			ksort( $active_taxonomies );
		}

		return array(
			'items'   => $active_taxonomies,
			'amounts' => $amounts,
		);
	}

	public function render_years_links( $post, $links = false, $divider = ',&nbsp;' ) {
		if ( is_array( $post['years'] ) && ! empty( $post['years'] ) ) {
			$years_amount = count( $post['years'] );
			?>
			<ul class="post-meta post-meta_mini">
				<li class="post-meta__years">
						<?php foreach ( $post['years'] as $index => $year ) : ?>
							<?php if ( $links ) : ?>
								<a href="<?php echo esc_attr( $year['url'] ); ?>"><?php echo esc_html( $year['name'] ); ?></a>
								<?php else : ?>
									<span><?php echo esc_html( $year['name'] ); ?></span>
								<?php endif; ?>
								<?php
								if ( $years_amount > 1 && $index < $years_amount - 1 ) :
									echo esc_html( $divider );
								endif;
								?>
				<?php endforeach; ?>
				</li>
			</ul>
			<?php
		}
	}

	/**
	 * Used for widgets with dynamically fetched posts
	 * Prints posts toggles set in the control panel
	 *
	 * @return void
	 */
	public function add_controls_posts_toggles() {
		$posts         = $this->get_posts();
		$post_type     = static::$_post_type;
		$post_type_obj = get_post_type_object( $post_type );

		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Posts', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_controls_static_fields();

		if ( ! $posts ) {
			$this->end_controls_section();
			return;
		}

		$this->add_control(
			'dynamic_content_info',
			array(
				'type'            => Controls_Manager::RAW_HTML,
				'raw'             => sprintf(
					'%1$s <strong>%2$s.</strong> %3$s<br><br>%4$s <a href="%5$s" target="_blank">%6$s</a>',
					esc_html__( 'This widget displays content dynamically from the existing', 'kinsey' ),
					$post_type_obj->labels->name,
					esc_html__( 'It\'s not editable directly through Elementor Page Builder.', 'kinsey' ),
					esc_html__( 'You can edit or re-order your posts', 'kinsey' ),
					admin_url( 'edit.php?post_type=' . $post_type ),
					esc_html__( 'in WordPress admin panel', 'kinsey' )
				),
				'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
				'condition'       => array(
					'posts_data_source' => 'dynamic',
				),
			)
		);

		$this->add_control(
			'posts_amount',
			array(
				'label'     => esc_html__( 'Posts to Display (0 for all)', 'kinsey' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => array(
					'number' => array(
						'min'  => 0,
						'max'  => 16,
						'step' => 1,
					),
				),
				'default'   => array(
					'unit' => 'number',
					'size' => 0,
				),
				'separator' => 'after',
				'condition' => array(
					'posts_data_source' => 'dynamic',
				),
			)
		);

		foreach ( $posts as $index => $item ) {
			/**
			 * Heading Toggle
			 */
			$id = 'heading_toggle' . $item['id'];
			$this->add_control(
				$id,
				array(
					'raw'        => sprintf(
						'<h3 class="elementor-control-title"><strong>%1$s</strong>&nbsp;&nbsp;<a href="%2$s" target="_blank"><i class="eicon-edit"></i></a></h3>',
						$item['title'],
						admin_url( 'post.php?post=' . $item['id'] . '&action=edit' ),
						esc_html__( 'Edit', 'kinsey' )
					),
					'type'       => Controls_Manager::RAW_HTML,
					'separator'  => 'before',
					'conditions' => array(
						'relation' => 'and',
						'terms'    => array(
							array(
								'relation' => 'or',
								'terms'    => array(
									array(
										'name'     => 'posts_amount[size]',
										'operator' => '>',
										'value'    => $index,
									),
									array(
										'name'     => 'posts_amount[size]',
										'operator' => '<=',
										'value'    => '0',
									),
								),
							),
							array(
								'relation' => 'and',
								'terms'    => array(
									array(
										'name'     => 'posts_data_source',
										'operator' => '==',
										'value'    => 'dynamic',
									),
								),
							),
						),
					),
				)
			);

			/**
			 * Toggle
			 */
			$id = 'enabled' . $item['id'];
			$this->add_control(
				$id,
				array(
					'label'      => esc_html__( 'Enabled', 'kinsey' ),
					'type'       => Controls_Manager::SWITCHER,
					'default'    => 'yes',
					'conditions' => array(
						'relation' => 'and',
						'terms'    => array(
							array(
								'relation' => 'or',
								'terms'    => array(
									array(
										'name'     => 'posts_amount[size]',
										'operator' => '>',
										'value'    => $index,
									),
									array(
										'name'     => 'posts_amount[size]',
										'operator' => '<=',
										'value'    => '0',
									),
								),
							),
							array(
								'relation' => 'and',
								'terms'    => array(
									array(
										'name'     => 'posts_data_source',
										'operator' => '==',
										'value'    => 'dynamic',
									),
								),
							),
						),
					),
				)
			);

		}

		$this->end_controls_section();
	}

	/**
	 * Add controls to handle static data
	 *
	 * @return void
	 */
	public function add_controls_static_fields() {
		$static_fields = static::$_data_static_fields;

		if ( empty( $static_fields ) ) {

			// fallback data source type is "dynamic"
			$this->add_control(
				'posts_data_source',
				array(
					'label'   => esc_html__( 'Data Source Type', 'kinsey' ),
					'type'    => Controls_Manager::HIDDEN,
					'default' => 'dynamic',
				)
			);

			return;
		}

		$this->add_control(
			'posts_data_source',
			array(
				'label'   => esc_html__( 'Data Source Type', 'kinsey' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'dynamic' => esc_html__( 'Dynamic', 'kinsey' ),
					'static'  => esc_html__( 'Static', 'kinsey' ),
				),
				'default' => 'dynamic',
			)
		);

		$repeater = new Repeater();

		if ( in_array( 'title', $static_fields ) ) {
			$repeater->add_control(
				'title',
				array(
					'label'   => esc_html__( 'Title', 'kinsey' ),
					'type'    => Controls_Manager::TEXT,
					'default' => esc_html__( 'Item...', 'kinsey' ),
				)
			);
		}

		if ( in_array( 'subheading', $static_fields ) ) {
			$repeater->add_control(
				'subheading',
				array(
					'label'   => esc_html__( 'Subheading', 'kinsey' ),
					'type'    => Controls_Manager::TEXT,
					'default' => '',
				)
			);
		}

		if ( in_array( 'description', $static_fields ) ) {
			$repeater->add_control(
				'description',
				array(
					'label'   => esc_html__( 'Description', 'kinsey' ),
					'type'    => Controls_Manager::TEXTAREA,
					'default' => '',
				)
			);
		}

		if ( in_array( 'permalink', $static_fields ) ) {
			$repeater->add_control(
				'permalink',
				array(
					'label'         => esc_html__( 'Link', 'kinsey' ),
					'type'          => Controls_Manager::URL,
					'placeholder'   => 'https://...',
					'show_external' => false,
					'default'       => array(
						'url'         => '#',
						'is_external' => false,
						'nofollow'    => false,
					),
				)
			);
		}

		if ( in_array( 'image_id', $static_fields ) ) {
			$repeater->add_control(
				'image_id',
				array(
					'label'   => esc_html__( 'Choose Image', 'kinsey' ),
					'type'    => Controls_Manager::MEDIA,
					'default' => array(
						'url' => Utils::get_placeholder_image_src(),
					),
				)
			);
		}

		if ( in_array( 'video_url', $static_fields ) ) {
			$repeater->add_control(
				'video_url',
				array(
					'label'      => esc_html__( 'Choose Video', 'kinsey' ),
					'type'       => Controls_Manager::MEDIA,
					'media_type' => 'video',
					'default'    => array(
						'url' => Utils::get_placeholder_image_src(),
					),
				)
			);
		}

		if ( array_key_exists( 'dynamic_color_themes', $static_fields ) ) {

			$repeater->add_control(
				'heading_dynamic_color_themes',
				array(
					'label'     => esc_html__( 'Dynamic Color Theme', 'kinsey' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);

			if ( in_array( 'slides_background', $static_fields['dynamic_color_themes'] ) ) {
				$repeater->add_control(
					'dynamic_color_themes_slides_background',
					array(
						'label'   => esc_html__( 'Slide Background Color', 'kinsey' ),
						'type'    => Controls_Manager::COLOR,
						'default' => '#ffffff',
					)
				);
			}

			if ( in_array( 'slides_elements_theme', $static_fields['dynamic_color_themes'] ) ) {
				$repeater->add_control(
					'dynamic_color_themes_slides_elements_theme',
					array(
						'label'       => esc_html__( 'Slide Elements Theme', 'kinsey' ),
						'label_block' => true,
						'type'        => Controls_Manager::SELECT,
						'default'     => '',
						'options'     => ARTS_THEME_COLOR_THEMES_ARRAY,
					)
				);
			}

			if ( in_array( 'header_elements_theme', $static_fields['dynamic_color_themes'] ) ) {
				$repeater->add_control(
					'dynamic_color_themes_slides_header_main_theme',
					array(
						'label'       => esc_html__( 'Switch Header Elements Theme', 'kinsey' ),
						'label_block' => true,
						'type'        => Controls_Manager::SELECT,
						'default'     => '',
						'options'     => ARTS_THEME_COLOR_THEMES_ARRAY,
					)
				);
			}

			if ( in_array( 'header_logo', $static_fields['dynamic_color_themes'] ) ) {
				$repeater->add_control(
					'dynamic_color_themes_slides_header_main_logo',
					array(
						'label'       => esc_html__( 'Switch Header Logo Version', 'kinsey' ),
						'label_block' => true,
						'type'        => Controls_Manager::SELECT,
						'default'     => '',
						'options'     => array(
							''          => esc_html__( 'Auto', 'kinsey' ),
							'primary'   => esc_html__( 'Primary', 'kinsey' ),
							'secondary' => esc_html__( 'Secondary', 'kinsey' ),
						),
					)
				);
			}

			if ( in_array( 'sidebar_background', $static_fields['dynamic_color_themes'] ) ) {
				$repeater->add_control(
					'dynamic_color_themes_slides_sidebar',
					array(
						'label'   => esc_html__( 'Sidebar Background Color', 'kinsey' ),
						'type'    => Controls_Manager::COLOR,
						'default' => '#ffffff',
					)
				);
			}
		}

		$this->add_control(
			'posts_static',
			array(
				'type'          => Controls_Manager::REPEATER,
				'fields'        => $repeater->get_controls(),
				'title_field'   => '{{{ title }}}',
				'prevent_empty' => false,
				'condition'     => array(
					'posts_data_source' => 'static',
				),
			)
		);
	}

	/**
	 * Add show/hide controls for the content elements
	 *
	 * @return void
	 */
	public function add_controls_elements_appearance( $args = array( 'subheading', 'categories_years', 'description', 'properties', 'button' ) ) {
		if ( ! $args || empty( $args ) ) {
			return;
		}

		if ( in_array( 'subheading', $args ) ) {
			$this->add_control(
				'subheading_enabled',
				array(
					'type'    => Controls_Manager::SWITCHER,
					'label'   => esc_html__( 'Show Subheading', 'kinsey' ),
					'default' => '',
				)
			);
		}

		if ( in_array( 'categories_years', $args ) ) {
			$this->add_control(
				'categories_years_enabled',
				array(
					'type'    => Controls_Manager::SWITCHER,
					'label'   => esc_html__( 'Show Categories and Years', 'kinsey' ),
					'default' => 'yes',
				)
			);
		}

		if ( in_array( 'description', $args ) ) {
			$this->add_control(
				'description_enabled',
				array(
					'type'    => Controls_Manager::SWITCHER,
					'label'   => esc_html__( 'Show Description', 'kinsey' ),
					'default' => '',
				)
			);
		}

		if ( in_array( 'properties', $args ) ) {
			$this->add_control(
				'properties_enabled',
				array(
					'type'    => Controls_Manager::SWITCHER,
					'label'   => esc_html__( 'Show Properties', 'kinsey' ),
					'default' => '',
				)
			);
		}

		if ( in_array( 'button', $args ) ) {
			$this->add_control(
				'button_enabled',
				array(
					'type'    => Controls_Manager::SWITCHER,
					'label'   => esc_html__( 'Show Button', 'kinsey' ),
					'default' => 'yes',
				)
			);
		}

		if ( in_array( 'captions', $args ) ) {
			$this->add_control(
				'captions_enabled',
				array(
					'type'    => Controls_Manager::SWITCHER,
					'label'   => esc_html__( 'Show Captions', 'kinsey' ),
					'default' => 'yes',
				)
			);
		}

		if ( in_array( 'counter', $args ) ) {
			$this->add_control(
				'counters_enabled',
				array(
					'label'   => esc_html__( 'Show Counters', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
				)
			);

			$this->add_control(
				'counters_zeros',
				array(
					'label'     => esc_html__( 'Counters Prefix', 'kinsey' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 1,
					'options'   => array(
						0 => esc_html__( 'None', 'kinsey' ),
						1 => esc_html__( '1 Zero', 'kinsey' ),
						2 => esc_html__( '2 Zeros', 'kinsey' ),
					),
					'condition' => array(
						'counters_enabled' => 'yes',
					),
				)
			);
		}

		if ( in_array( 'counter_suffix', $args ) ) {
			$this->add_control(
				'counters_suffix',
				array(
					'label'     => esc_html__( 'Counters Suffix', 'kinsey' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => '&nbsp;&nbsp;/&nbsp;&nbsp;',
					'condition' => array(
						'counters_enabled' => 'yes',
					),
				)
			);
		}
	}
}
