<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

trait Kinsey_Widget_Trait_Grid_Controls {

	public function add_controls_grid_options( $args = array( 'fancy', 'equal_columns', 'columns', 'spacing' ) ) {
		if ( ! $args || empty( $args ) ) {
			return;
		}

		if ( in_array( 'fancy', $args ) ) {
			$this->add_control(
				'grid_fancy_enabled',
				array(
					'label'     => esc_html__( 'Enable Fancy Grid', 'kinsey' ),
					'type'      => Controls_Manager::SWITCHER,
					'default'   => '',
					'condition' => array(
						'grid_columns!' => '12',
					),
				)
			);
		}

		if ( in_array( 'equal_columns', $args ) ) {
			$this->add_control(
				'grid_equal_columns_height_enabled',
				array(
					'label'     => esc_html__( 'Enable Equal Columns Height', 'kinsey' ),
					'type'      => Controls_Manager::SWITCHER,
					'default'   => '',
					'condition' => array(
						'grid_columns!' => '12',
					),
				)
			);
		}

		if ( in_array( 'columns', $args ) ) {
			$this->add_responsive_control(
				'grid_columns',
				array(
					'label'           => esc_html__( 'Columns', 'kinsey' ),
					'type'            => Controls_Manager::SELECT,
					'options'         => array(
						'12'    => esc_html__( 'Single Column', 'kinsey' ),
						'6'     => esc_html__( 'Two Columns', 'kinsey' ),
						'4'     => esc_html__( 'Three Columns', 'kinsey' ),
						'3'     => esc_html__( 'Four Columns', 'kinsey' ),
						'2dot4' => esc_html__( 'Five Columns', 'kinsey' ),
						'2'     => esc_html__( 'Six Columns', 'kinsey' ),
					),
					'render_type'     => 'template',
					'desktop_default' => '6',
					'tablet_default'  => '6',
					'mobile_default'  => '12',
				)
			);
		}

		if ( in_array( 'spacing', $args ) ) {
			$this->add_responsive_control(
				'grid_space_between_h',
				array(
					'label'           => esc_html__( 'Space Between Horizontal', 'kinsey' ),
					'type'            => Controls_Manager::SLIDER,
					'range'           => array(
						'px' => array(
							'min'  => 0,
							'max'  => 200,
							'step' => 1,
						),
						'vw' => array(
							'min'  => 0,
							'max'  => 100,
							'step' => 1,
						),
					),
					'size_units'      => array( 'px', 'vw', 'vh' ),
					'devices'         => array( 'desktop', 'tablet', 'mobile' ),
					'desktop_default' => array(
						'size' => 6,
						'unit' => 'vw',
					),
					'tablet_default'  => array(
						'size' => 40,
						'unit' => 'px',
					),
					'mobile_default'  => array(
						'size' => 20,
						'unit' => 'px',
					),
					'selectors'       => array(
						'{{WRAPPER}} .grid'       => 'margin-left: -{{SIZE}}{{UNIT}}; margin-right: -{{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .grid__item' => 'padding-left: {{SIZE}}{{UNIT}}; padding-right: {{SIZE}}{{UNIT}};',
					),
					'render_type'     => 'template',
				)
			);

			$this->add_responsive_control(
				'grid_space_between_v',
				array(
					'label'           => esc_html__( 'Space Between Vertical', 'kinsey' ),
					'type'            => Controls_Manager::SLIDER,
					'range'           => array(
						'px' => array(
							'min'  => 0,
							'max'  => 200,
							'step' => 1,
						),
						'vw' => array(
							'min'  => 0,
							'max'  => 100,
							'step' => 1,
						),
					),
					'size_units'      => array( 'px', 'vw', 'vh' ),
					'devices'         => array( 'desktop', 'tablet', 'mobile' ),
					'desktop_default' => array(
						'size' => 6,
						'unit' => 'vw',
					),
					'tablet_default'  => array(
						'size' => 40,
						'unit' => 'px',
					),
					'mobile_default'  => array(
						'size' => 20,
						'unit' => 'px',
					),
					'selectors'       => array(
						'{{WRAPPER}} .grid'       => 'margin-top: -{{SIZE}}{{UNIT}}; margin-bottom: -{{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .grid__item' => 'padding-top: {{SIZE}}{{UNIT}}; padding-bottom: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .grid_fancy:not(.grid_filtered) .grid__item:nth-child(3)' => 'margin-top: calc(1.5 * {{SIZE}}{{UNIT}});',
						'(tablet){{WRAPPER}} .grid_fancy .grid__item:nth-child(3)' => 'margin-top: 0 !important;',
						'(mobile){{WRAPPER}} .grid_fancy .grid__item:nth-child(3)' => 'margin-top: 0 !important;',
					),
					'render_type'     => 'template',
				)
			);
		}
	}

	public function add_controls_filter_options( $args = array( 'mobile_style', 'filter_by_taxonomy', 'categories_amounts', 'all_label', 'justify_items', 'margin_bottom' ) ) {
		if ( ! $args || empty( $args ) ) {
			return;
		}

		$this->add_control(
			'filter_enabled',
			array(
				'label'   => esc_html__( 'Enable Grid Filter', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		if ( in_array( 'filter_by_taxonomy', $args ) ) {
			$this->add_control(
				'filter_by_taxonomy',
				array(
					'label'     => esc_html__( 'Filter By', 'kinsey' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'arts_portfolio_category',
					'options'   => array(
						'arts_portfolio_category' => esc_html__( 'Categories', 'kinsey' ),
						'arts_portfolio_year'     => esc_html__( 'Years', 'kinsey' ),
					),
					'condition' => array(
						'filter_enabled' => 'yes',
					),
				)
			);

			$this->add_control(
				'filter_default_active_category',
				array(
					'label'     => esc_html__( 'Default Active Category', 'kinsey' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => '',
					'options'   => $this->get_terms_list( 'arts_portfolio_category' ),
					'condition' => array(
						'filter_enabled'     => 'yes',
						'filter_by_taxonomy' => 'arts_portfolio_category',
					),
				)
			);

			$this->add_control(
				'filter_default_active_year',
				array(
					'label'     => esc_html__( 'Default Active Year', 'kinsey' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => '',
					'options'   => $this->get_terms_list( 'arts_portfolio_year' ),
					'condition' => array(
						'filter_enabled'     => 'yes',
						'filter_by_taxonomy' => 'arts_portfolio_year',
					),
				)
			);
		}

		if ( in_array( 'mobile_style', $args ) ) {
			$this->add_control(
				'filter_mobile_style',
				array(
					'label'     => esc_html__( 'Filter Mobile Style', 'kinsey' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => '',
					'options'   => array(
						''         => esc_html__( 'Auto', 'kinsey' ),
						'dropdown' => esc_html__( 'Dropdown', 'kinsey' ),
					),
					'condition' => array(
						'filter_enabled' => 'yes',
					),
				)
			);
		}

		if ( in_array( 'categories_amounts', $args ) ) {
			$this->add_control(
				'filter_amounts_enabled',
				array(
					'label'     => esc_html__( 'Show Terms Counters', 'kinsey' ),
					'type'      => Controls_Manager::SWITCHER,
					'default'   => 'yes',
					'condition' => array(
						'filter_enabled' => 'yes',
					),
				)
			);
		}

		if ( in_array( 'all_label', $args ) ) {
			$this->add_control(
				'filter_all_label',
				array(
					'label'     => esc_html__( '"All" Label', 'kinsey' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => esc_html__( 'All', 'kinsey' ),
					'dynamic'   => array(
						'active' => true,
					),
					'condition' => array(
						'filter_enabled' => 'yes',
					),
				)
			);
		}

		if ( in_array( 'all_label', $args ) && in_array( 'categories_amounts', $args ) ) {
			$this->add_control(
				'filter_all_counter_label',
				array(
					'label'     => esc_html__( '"All" Counter Label', 'kinsey' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => '*',
					'dynamic'   => array(
						'active' => true,
					),
					'condition' => array(
						'filter_enabled'         => 'yes',
						'filter_amounts_enabled' => 'yes',
						'filter_all_label!'      => '',
					),
				)
			);
		}

		if ( in_array( 'justify_items', $args ) ) {
			$this->add_control(
				'filter_justify_items',
				array(
					'label'     => esc_html__( 'Justify Filter Items', 'kinsey' ),
					'type'      => Controls_Manager::CHOOSE,
					'options'   => array(
						'justify-content-between' => array(
							'title' => esc_html__( 'Space Between', 'kinsey' ),
							'icon'  => 'eicon-text-align-justify',
						),
						'justify-content-start'   => array(
							'title' => esc_html__( 'Start', 'kinsey' ),
							'icon'  => 'eicon-text-align-left',
						),
						'justify-content-center'  => array(
							'title' => esc_html__( 'Center', 'kinsey' ),
							'icon'  => 'eicon-text-align-center',
						),
						'justify-content-end'     => array(
							'title' => esc_html__( 'End', 'kinsey' ),
							'icon'  => 'eicon-text-align-right',
						),
					),
					'default'   => 'justify-content-center',
					'condition' => array(
						'filter_enabled' => 'yes',
					),
					'toggle'    => false,
				)
			);
		}

		if ( in_array( 'margin_bottom', $args ) ) {
			$this->add_control(
				'filter_mb',
				array(
					'label'     => esc_html__( 'Margin Bottom', 'kinsey' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'mb-medium',
					'options'   => ARTS_THEME_DISTANCE_ARRAY['margin']['bottom'],
					'condition' => array(
						'filter_enabled' => 'yes',
					),
				)
			);
		}
	}

}
