<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

trait Kinsey_Widget_Trait_Slider_Controls {

	public function add_controls_slider_options( $args = array( 'direction', 'speed', 'slides_per_view', 'autoplay', 'centered_slides', 'vertical_centered_slides', 'space_between' ) ) {
		if ( ! $args || empty( $args ) ) {
			return;
		}

		$this->add_control(
			'slides_heading',
			array(
				'label' => esc_html__( 'Slides', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);

		if ( in_array( 'direction', $args ) ) {
			$this->add_control(
				'direction',
				array(
					'label'   => esc_html__( 'Direction', 'kinsey' ),
					'type'    => Controls_Manager::CHOOSE,
					'default' => 'horizontal',
					'options' => array(
						'horizontal' => array(
							'title' => esc_html__( 'Horizontal', 'kinsey' ),
							'icon'  => 'eicon-arrow-right',
						),
						'vertical'   => array(
							'title' => esc_html__( 'Vertical', 'kinsey' ),
							'icon'  => 'eicon-arrow-down',
						),
					),
					'toggle'  => false,
				)
			);
		}

		if ( in_array( 'speed', $args ) ) {
			$this->add_control(
				'speed',
				array(
					'label'   => esc_html__( 'Speed', 'kinsey' ),
					'type'    => Controls_Manager::SLIDER,
					'range'   => array(
						'ms' => array(
							'min'  => 100,
							'max'  => 10000,
							'step' => 100,
						),
					),
					'default' => array(
						'unit' => 'ms',
						'size' => 1200,
					),
				)
			);
		}

		if ( in_array( 'slides_per_view', $args ) ) {
			$this->add_responsive_control(
				'slides_per_view',
				array(
					'label'           => esc_html__( 'Slides Per Screen', 'kinsey' ),
					'type'            => Controls_Manager::SLIDER,
					'range'           => array(
						'number' => array(
							'min'  => 1,
							'max'  => 4,
							'step' => 1,
						),
					),
					'devices'         => array( 'desktop', 'tablet', 'mobile' ),
					'desktop_default' => array(
						'size' => 3.5,
						'unit' => 'number',
					),
					'tablet_default'  => array(
						'size' => 1.33,
						'unit' => 'number',
					),
					'mobile_default'  => array(
						'size' => 1.33,
						'unit' => 'number',
					),
				)
			);
		}

		if ( in_array( 'centered_slides', $args ) ) {
			$this->add_responsive_control(
				'centered_slides',
				array(
					'label'           => esc_html__( 'Horizontaly Centered Slides', 'kinsey' ),
					'label_block'     => true,
					'type'            => Controls_Manager::SWITCHER,
					'desktop_default' => true,
					'tablet_default'  => true,
					'mobile_default'  => true,
				)
			);
		}

		if ( in_array( 'vertical_centered_slides', $args ) ) {
			$this->add_control(
				'vertical_centered_slides',
				array(
					'label'   => esc_html__( 'Vertically Centered Slides', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
				)
			);
		}

		if ( in_array( 'space_between', $args ) ) {
			$this->add_responsive_control(
				'space_between',
				array(
					'label'           => esc_html__( 'Space Between Slides', 'kinsey' ),
					'type'            => Controls_Manager::SLIDER,
					'range'           => array(
						'px' => array(
							'min'  => 0,
							'max'  => 160,
							'step' => 1,
						),
					),
					'devices'         => array( 'desktop', 'tablet', 'mobile' ),
					'desktop_default' => array(
						'size' => 30,
						'unit' => 'px',
					),
					'tablet_default'  => array(
						'size' => 20,
						'unit' => 'px',
					),
					'mobile_default'  => array(
						'size' => 20,
						'unit' => 'px',
					),
				)
			);
		}

		if ( in_array( 'autoplay', $args ) ) {
			$this->add_control(
				'autoplay_heading',
				array(
					'label'     => esc_html__( 'Autoplay', 'kinsey' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);

			$this->add_control(
				'autoplay_enabled',
				array(
					'label'   => esc_html__( 'Enable Autoplay', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
				)
			);

			$this->add_control(
				'autoplay_delay',
				array(
					'label'     => esc_html__( 'Delay (ms)', 'kinsey' ),
					'type'      => Controls_Manager::SLIDER,
					'range'     => array(
						'ms' => array(
							'min'  => 1000,
							'max'  => 60000,
							'step' => 100,
						),
					),
					'default'   => array(
						'unit' => 'ms',
						'size' => 6000,
					),
					'condition' => array(
						'autoplay_enabled' => 'yes',
					),
				)
			);
		}
	}

	public function add_controls_slider_controls( $args = array( 'dots', 'arrows', 'counter', 'progress' ) ) {
		if ( ! $args || empty( $args ) ) {
			return;
		}

		if ( in_array( 'dots', $args ) ) {
			$this->add_control(
				'dots_heading',
				array(
					'label' => esc_html__( 'Dots', 'kinsey' ),
					'type'  => Controls_Manager::HEADING,
				)
			);

			$this->add_control(
				'dots_enabled',
				array(
					'label'   => esc_html__( 'Enable Dots', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => '',
				)
			);
		}

		if ( in_array( 'arrows', $args ) ) {
			$this->add_control(
				'arrows_heading',
				array(
					'label'     => esc_html__( 'Arrows', 'kinsey' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => in_array( 'dots', $args ) ? 'before' : false,
				)
			);

			$this->add_control(
				'arrows_enabled',
				array(
					'label'   => esc_html__( 'Enable Arrows', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
				)
			);
		}

		if ( in_array( 'counter', $args ) ) {
			$this->add_control(
				'counter_heading',
				array(
					'label'     => esc_html__( 'Counter', 'kinsey' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => in_array( 'dots', $args ) || in_array( 'arrows', $args ) ? 'before' : false,
				)
			);

			$this->add_control(
				'counter_enabled',
				array(
					'label'   => esc_html__( 'Enable Counter', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
				)
			);

			$this->add_control(
				'counter_zeros',
				array(
					'label'     => esc_html__( 'Counter Prefix', 'kinsey' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 1,
					'options'   => array(
						0 => esc_html__( 'None', 'kinsey' ),
						1 => esc_html__( '1 Zero', 'kinsey' ),
						2 => esc_html__( '2 Zeros', 'kinsey' ),
					),
					'condition' => array(
						'counter_enabled' => 'yes',
					),
				)
			);

			if ( in_array( 'counter_info', $args ) ) {
				$this->add_control(
					'counter_info',
					array(
						'type'            => Controls_Manager::RAW_HTML,
						'raw'             => '<strong>' . esc_html__( 'Counter is available only for horizontal slider direction.', 'kinsey' ) . '</strong>',
						'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
						'condition'       => array(
							'counter_enabled' => 'yes',
							'direction'       => 'vertical',
						),
					)
				);
			}
		}

		if ( in_array( 'progress', $args ) ) {
			$this->add_control(
				'progress_bar_heading',
				array(
					'label'     => esc_html__( 'Progress Bar', 'kinsey' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => in_array( 'dots', $args ) || in_array( 'arrows', $args ) || in_array( 'counter', $args ) ? 'before' : false,
				)
			);

			$this->add_control(
				'progress_bar_enabled',
				array(
					'label'   => esc_html__( 'Enable Progress Bar', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => '',
				)
			);

			$this->add_control(
				'progress_bar_style',
				array(
					'label'     => esc_html__( 'Progress Bar Style', 'kinsey' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => '',
					'options'   => array(
						''     => esc_html__( 'Short', 'kinsey' ),
						'long' => esc_html__( 'Long', 'kinsey' ),
					),
					'condition' => array(
						'progress_bar_enabled' => 'yes',
					),
				)
			);

			$this->add_control(
				'progress_bar_slides_numbers_enabled',
				array(
					'label'     => esc_html__( 'Enable Current Slide Number', 'kinsey' ),
					'type'      => Controls_Manager::SWITCHER,
					'condition' => array(
						'progress_bar_enabled' => 'yes',
					),
					'default'   => 'yes',
				)
			);

			if ( in_array( 'progress_info', $args ) ) {
				$this->add_control(
					'progress_info',
					array(
						'type'            => Controls_Manager::RAW_HTML,
						'raw'             => '<strong>' . esc_html__( 'Progress bar is available only for vertical slider direction.', 'kinsey' ) . '</strong>',
						'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
						'condition'       => array(
							'progress_bar_enabled' => 'yes',
							'direction'            => 'horizontal',
						),
					)
				);
			}
		}
	}

	public function add_controls_slider_interaction( $args = array( 'mouse', 'clickability', 'keyboard', 'drag', 'touch' ) ) {
		if ( ! $args || empty( $args ) ) {
			return;
		}

		if ( in_array( 'clickability', $args ) ) {
			$this->add_control(
				'clickability_heading',
				array(
					'label' => esc_html__( 'Clickability', 'kinsey' ),
					'type'  => Controls_Manager::HEADING,
				)
			);

			$this->add_control(
				'headings_clickable_enabled',
				array(
					'label'   => esc_html__( 'Enable Links on Headings', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => '',
				)
			);

			$this->add_control(
				'images_clickable_enabled',
				array(
					'label'   => esc_html__( 'Enable Links on Images', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => '',
				)
			);
		}

		if ( in_array( 'mouse', $args ) ) {
			$this->add_control(
				'mouse_heading',
				array(
					'label'     => esc_html__( 'Mouse', 'kinsey' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => in_array( 'clickability', $args ) ? 'before' : false,
				)
			);

			$this->add_control(
				'mousewheel_control_enabled',
				array(
					'label'   => esc_html__( 'Enable Mousewheel Control', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
				)
			);
		}

		if ( in_array( 'drag', $args ) ) {
			if ( ! in_array( 'mouse', $args ) ) {
				$this->add_control(
					'mouse_heading',
					array(
						'label' => esc_html__( 'Mouse', 'kinsey' ),
						'type'  => Controls_Manager::HEADING,
					)
				);
			}

			$this->add_control(
				'mouse_drag_enabled',
				array(
					'label'   => esc_html__( 'Enable Mouse Dragging', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
				)
			);

			$this->add_control(
				'mouse_drag_label',
				array(
					'label'     => esc_html__( 'Cursor Drag Label', 'kinsey' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => esc_html__( 'Drag', 'kinsey' ),
					'dynamic'   => array(
						'active' => true,
					),
					'condition' => array(
						'mouse_drag_enabled' => 'yes',
					),
				)
			);

			$this->add_control(
				'mouse_on_drag_cursor_class',
				array(
					'label'       => esc_html__( 'On Mouse Drag Class', 'kinsey' ),
					'description' => sprintf(
						'%1s: <strong>slider-projects-fullscreen__images_scale-up</strong><br>%2s',
						esc_html__( 'Default', 'kinsey' ),
						esc_html__( 'CSS class WITHOUT the dot that will be temporarily applied to the images slider during the dragging.', 'kinsey' )
					),
					'type'        => Controls_Manager::TEXT,
					'dynamic'     => array(
						'active' => true,
					),
					'default'     => esc_html__( 'slider-projects-fullscreen__images_scale-up', 'kinsey' ),
					'condition'   => array(
						'mouse_drag_enabled' => 'yes',
					),
				)
			);
		}

		if ( in_array( 'keyboard', $args ) ) {
			$this->add_control(
				'keyboard_heading',
				array(
					'label'     => esc_html__( 'Keyboard', 'kinsey' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => in_array( 'mouse', $args ) ? 'before' : false,
				)
			);

			$this->add_control(
				'keyboard_control_enabled',
				array(
					'label'   => esc_html__( 'Enable Keyboard Control', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
				)
			);
		}

		if ( in_array( 'touch', $args ) ) {
			$this->add_control(
				'touch_heading',
				array(
					'label'     => esc_html__( 'Touch', 'kinsey' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => in_array( 'mouse', $args ) || in_array( 'keyboard', $args ) ? 'before' : false,
				)
			);

			$this->add_control(
				'touch_ratio',
				array(
					'label'   => esc_html__( 'Touch Ratio', 'kinsey' ),
					'type'    => Controls_Manager::SLIDER,
					'range'   => array(
						'px' => array(
							'min'  => 1,
							'max'  => 4,
							'step' => 0.1,
						),
					),
					'default' => array(
						'unit' => 'px',
						'size' => 1.5,
					),
				)
			);
		}
	}

	public function add_controls_slider_dynamic_color_themes( $args = array( 'slides_background', 'slides_elements_theme', 'header_elements_theme', 'header_logo', 'sidebar_background' ) ) {
		if ( ! $args || empty( $args ) ) {
			return;
		}

		$this->add_control(
			'dynamic_color_themes_enabled',
			array(
				'label'   => esc_html__( 'Enable Dynamic Color Themes', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		if ( in_array( 'slides_background', $args ) ) {
			$this->add_control(
				'dynamic_color_themes_slides_background',
				array(
					'label'       => esc_html__( 'Slides Background Color', 'kinsey' ),
					'label_block' => true,
					'type'        => Controls_Manager::SELECT,
					'default'     => 'page_masthead_featured_background_color',
					'condition'   => array(
						'dynamic_color_themes_enabled' => 'yes',
					),
					'options'     => array(
						'' => esc_html__( 'Auto', 'kinsey' ),
						'page_masthead_header_background_color' => esc_html__( 'Post Masthead Background Color', 'kinsey' ),
						'page_masthead_featured_background_color' => esc_html__( 'Post Mashtead Featured Background Color', 'kinsey' ),
					),
				)
			);
		}

		if ( in_array( 'slides_elements_theme', $args ) ) {
			$this->add_control(
				'dynamic_color_themes_slides_elements_theme',
				array(
					'label'       => esc_html__( 'Slides Elements Theme', 'kinsey' ),
					'label_block' => true,
					'type'        => Controls_Manager::SELECT,
					'default'     => 'page_masthead_header_elements_theme',
					'condition'   => array(
						'dynamic_color_themes_enabled' => 'yes',
					),
					'options'     => array(
						'' => esc_html__( 'Auto', 'kinsey' ),
						'page_masthead_header_elements_theme' => esc_html__( 'Post Masthead Elements Theme', 'kinsey' ),
						'page_masthead_featured_elements_theme' => esc_html__( 'Post Featured Elements Theme', 'kinsey' ),
					),
				)
			);
		}

		if ( in_array( 'header_elements_theme', $args ) ) {
			$this->add_control(
				'dynamic_color_themes_slides_header_main_theme',
				array(
					'label'       => esc_html__( 'Switch Header Elements Theme', 'kinsey' ),
					'label_block' => true,
					'type'        => Controls_Manager::SELECT,
					'default'     => 'header_main_theme',
					'condition'   => array(
						'dynamic_color_themes_enabled' => 'yes',
					),
					'options'     => array(
						''                  => esc_html__( 'Auto', 'kinsey' ),
						'header_main_theme' => esc_html__( 'Post Overridden Header Elements Theme', 'kinsey' ),
					),
				)
			);
		}

		if ( in_array( 'header_logo', $args ) ) {
			$this->add_control(
				'dynamic_color_themes_slides_header_main_logo',
				array(
					'label'       => esc_html__( 'Switch Header Logo Version', 'kinsey' ),
					'label_block' => true,
					'type'        => Controls_Manager::SELECT,
					'default'     => 'header_main_logo',
					'condition'   => array(
						'dynamic_color_themes_enabled' => 'yes',
					),
					'options'     => array(
						''                 => esc_html__( 'Auto', 'kinsey' ),
						'header_main_logo' => esc_html__( 'Post Overridden Header Logo Version (non-sticky)', 'kinsey' ),
					),
				)
			);
		}

		if ( in_array( 'sidebar_background', $args ) ) {
			$this->add_control(
				'dynamic_color_themes_slides_sidebar',
				array(
					'label'       => esc_html__( 'Sidebar Background Color', 'kinsey' ),
					'label_block' => true,
					'type'        => Controls_Manager::SELECT,
					'default'     => 'page_masthead_header_background_color',
					'condition'   => array(
						'dynamic_color_themes_enabled' => 'yes',
					),
					'options'     => array(
						'' => esc_html__( 'Auto', 'kinsey' ),
						'page_masthead_header_background_color' => esc_html__( 'Post Masthead Background Color', 'kinsey' ),
						'page_masthead_featured_background_color' => esc_html__( 'Post Mashtead Featured Background Color', 'kinsey' ),
					),
				)
			);
		}
	}

	public function add_controls_slider_effect_text_transition() {

		$this->add_control(
			'transition_text_enabled',
			array(
				'label'   => esc_html__( 'Enable Text Transition', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'direction_text_transition',
			array(
				'label'     => esc_html__( 'Text Transition Direction', 'kinsey' ),
				'type'      => Controls_Manager::CHOOSE,
				'default'   => 'horizontal',
				'options'   => array(
					'horizontal' => array(
						'title' => esc_html__( 'Horizontal', 'kinsey' ),
						'icon'  => 'eicon-arrow-right',
					),
					'vertical'   => array(
						'title' => esc_html__( 'Vertical', 'kinsey' ),
						'icon'  => 'eicon-arrow-down',
					),
				),
				'toggle'    => false,
				'condition' => array(
					'transition_text_enabled' => 'yes',
				),
			)
		);

	}

	public function add_controls_slider_effect_parallax() {
		$this->add_control(
			'parallax_enabled',
			array(
				'label'   => esc_html__( 'Enable Parallax Effect', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'parallax_effect_offset',
			array(
				'label'     => esc_html__( 'Parallax Images Offset', 'kinsey' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => array(
					'ms' => array(
						'min'  => 1,
						'max'  => 100,
						'step' => 1,
					),
				),
				'default'   => array(
					'unit' => '%',
					'size' => 30,
				),
				'condition' => array(
					'parallax_enabled' => 'yes',
				),
			)
		);
	}

	public function add_controls_ajax_transition( $args = array( 'image_transition', 'prefetch' ) ) {
		if ( ! $args || empty( $args ) ) {
			return;
		}

		if ( in_array( 'image_transition', $args ) ) {
			$this->add_control(
				'ajax_image_transition_enabled',
				array(
					'label'   => esc_html__( 'Enable Seamless Image Transition', 'kinsey' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
				)
			);
		}

		if ( in_array( 'prefetch', $args ) ) {
			$this->add_control(
				'ajax_prefetch_active_slide_enabled',
				array(
					'label'       => esc_html__( 'Prefetch Links on Active Slide', 'kinsey' ),
					'description' => esc_html__( 'Attempt to load next page on the active slide in background. This may potentially reduce the delay before the transition starts, but will increase the network traffic consumption.', 'kinsey' ),
					'type'        => Controls_Manager::SWITCHER,
					'default'     => 'yes',
				)
			);
		}
	}

}