<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

trait Kinsey_Widget_Trait_Slider_Helpers {

	public function get_static_dynamic_slide_theme( $option, $option_condition = null, $option_default = '', $post = null ) {
		$settings = $this->get_settings_for_display();

		// Static data source
		if ( array_key_exists( 'posts_data_source', $settings ) && $settings['posts_data_source'] === 'static' ) {
			return array_key_exists( $option, $post ) && $post[ $option ] ? $post[ $option ] : $option_default;
		} else {
			if ( $option_condition ) {
				return arts_get_overridden_document_option( $settings[ $option ], $option_condition, $option_default, $post['id'] );
			} else {
				return arts_get_document_option( $settings[ $option ], $option_default, $post['id'] );
			}
		}

	}

	public function add_swiper_images_attributes( $swiper_images_attributes ) {
		if ( ! $swiper_images_attributes || ! is_array( $swiper_images_attributes ) ) {
			return array();
		}

		$settings = $this->get_settings_for_display();

		// Speed
		if ( array_key_exists( 'speed', $settings ) && $settings['speed'] ) {
			$swiper_images_attributes['data-speed'] = $settings['speed']['size'];
		}

		// Mouse Dragging
		if ( array_key_exists( 'mouse_drag_enabled', $settings ) && $settings['mouse_drag_enabled'] ) {
			$swiper_images_attributes['data-drag-mouse']  = 'true';
			$swiper_images_attributes['data-drag-cursor'] = 'true';

			if ( ! empty( $settings['mouse_drag_label'] ) ) {
				$swiper_images_attributes['data-drag-hide-cursor'] = 'true';
				$swiper_images_attributes['data-drag-label']       = $settings['mouse_drag_label'];
			}

			if ( ! empty( $settings['mouse_on_drag_cursor_class'] ) ) {
				$swiper_images_attributes['data-drag-class'] = $settings['mouse_on_drag_cursor_class'];
			}
		}

		// Counters
		if ( array_key_exists( 'counter_enabled', $settings ) && $settings['counter_enabled'] ) {
			$swiper_images_attributes['data-counter-add-zeros'] = $settings['counter_zeros'];
		}

		// Mousewheel Control
		if ( array_key_exists( 'mousewheel_control_enabled', $settings ) && $settings['mousewheel_control_enabled'] ) {
			$swiper_images_attributes['data-mousewheel-enabled'] = 'true';
		}

		// Keyboard Control
		if ( array_key_exists( 'keyboard_control_enabled', $settings ) && $settings['keyboard_control_enabled'] ) {
			$swiper_images_attributes['data-keyboard-enabled'] = 'true';
		}

		// Autoplay
		if ( array_key_exists( 'autoplay_enabled', $settings ) && $settings['autoplay_enabled'] ) {
			$swiper_images_attributes['data-autoplay-enabled'] = 'true';
			$swiper_images_attributes['data-autoplay-delay']   = $settings['autoplay_delay']['size'];
		}

		return $swiper_images_attributes;
	}

	public function add_swiper_content_attributes( $swiper_content_attributes ) {
		if ( ! $swiper_content_attributes || ! is_array( $swiper_content_attributes ) ) {
			return array();
		}

		$settings = $this->get_settings_for_display();

		if ( array_key_exists( 'ajax_prefetch_active_slide_enabled', $settings ) && $settings['ajax_prefetch_active_slide_enabled'] ) {
			$swiper_content_attributes['data-prefetch-active-slide-transition'] = 'true';
		}

		if ( array_key_exists( 'transition_text_enabled', $settings ) && $settings['transition_text_enabled'] ) {
			$swiper_content_attributes['data-transition'] = 'text';
			$swiper_content_attributes['class'][]         = 'overflow-initial';

			if ( array_key_exists( 'direction_text_transition', $settings ) && $settings['direction_text_transition'] ) {
				$swiper_content_attributes['data-transition-direction'] = $settings['direction_text_transition'];
			}
		}

		return $swiper_content_attributes;
	}

	public function render_swiper_content_slide( $post, $include = array( 'heading', 'subheading', 'category', 'description', 'button' ) ) {
		if ( empty( $post ) ) {
			return;
		}

		$settings = $this->get_settings_for_display();

		$categories = $this->get_taxonomy_term_names( $post['id'], 'arts_portfolio_category' );
		$years      = $this->get_taxonomy_term_names( $post['id'], 'arts_portfolio_year' );

		if ( in_array( 'button', $include ) ) {
			$button_args = array(
				'title'       => $settings['button_title'],
				'title_hover' => $settings['button_title_hover'],
				'attributes'  => array(
					'href'            => $post['permalink'],
					'class'           => array( 'button', $settings['button_border'], $settings['button_color'] ),
					'data-arts-hover' => 'trigger',
				),
				'icon'        => array(),
			);

			if ( $settings['button_style'] ) {
				$button_args['attributes']['class'][] = $settings['button_style'];
			}

			if ( $settings['button_icon_before'] ) {
				$button_args['class'][]        = 'button_icon';
				$button_args['icon']['before'] = $settings['button_icon_before'];
			}

			if ( $settings['button_icon_after'] ) {
				$button_args['class'][]       = 'button_icon';
				$button_args['icon']['after'] = $settings['button_icon_after'];
			}

			if ( $settings['cursor_button_enabled'] ) {
				$button_args['attributes'] = $this->add_cursor_attributes( $button_args['attributes'], 'Button' );
			}

			if ( array_key_exists( 'permalink_attributes', $post ) ) {

				if ( array_key_exists( 'is_external', $post['permalink_attributes'] ) && $post['permalink_attributes']['is_external'] ) {
					$button_args['attributes']['target'] = '_blank';
				}

				if ( array_key_exists( 'nofollow', $post['permalink_attributes'] ) && $post['permalink_attributes']['nofollow'] ) {
					$button_args['attributes']['rel'] = 'nofollow';
				}
			}
		}

		?>

		<?php if ( in_array( 'subheading', $include ) && $settings['subheading_enabled'] && ! empty( $post['subheading'] ) ) : ?>
<<?php $this->print_html_tag( 'typography_subheading_tag' ); ?>
			<?php $this->print_render_attribute_string( 'subheading' ); ?>><?php echo $post['subheading']; ?>
</<?php $this->print_html_tag( 'typography_subheading_tag' ); ?>>
<div class="w-100"></div>
		<?php endif; ?>
		<?php if ( $settings['text_elements_position'] === 'category_before' ) : ?>
			<?php if ( in_array( 'category', $include ) && $settings['categories_years_enabled'] && ( ! empty( $categories ) || ! empty( $years ) ) ) : ?>
<div <?php $this->print_render_attribute_string( 'category' ); ?>>
				<?php
						get_template_part(
							'template-parts/list/list',
							'categories',
							array(
								'categories' => $categories,
								'years'      => $years,
							)
						);
				?>
</div>
<div class="w-100"></div>
	<?php endif; ?>
		<?php endif; ?>
		<?php if ( in_array( 'heading', $include ) && ! empty( $post['title'] ) ) : ?>
			<?php if ( $settings['headings_clickable_enabled'] ) : ?>
				<?php
					$heading_link_attributes = array(
						'class'           => array( 'd-inline-block', 'underline-hover', 'pointer-events-auto' ),
						'href'            => $post['permalink'],
						'data-arts-hover' => 'trigger',
					);

					if ( $settings['cursor_clickable_links_enabled'] ) {
						$heading_link_attributes = $this->add_cursor_attributes( $heading_link_attributes, 'Clickable Links' );
					}

					$this->add_render_attribute( 'heading_link', $heading_link_attributes, true, true );
					?>
<a <?php $this->print_render_attribute_string( 'heading_link' ); ?>>
	  <?php endif; ?>
  <<?php $this->print_html_tag( 'typography_heading_tag' ); ?>
			<?php $this->print_render_attribute_string( 'heading' ); ?>><?php echo esc_html( $post['title'] ); ?>
  </<?php $this->print_html_tag( 'typography_heading_tag' ); ?>>
			<?php if ( $settings['headings_clickable_enabled'] ) : ?>
</a>
<div class="w-100"></div>
<?php endif; ?>
		<?php endif; ?>
		<?php if ( $settings['text_elements_position'] === 'category_after' || $settings['text_elements_position'] === 'bottom' ) : ?>
			<?php if ( in_array( 'category', $include ) && $settings['categories_years_enabled'] && ( ! empty( $categories ) || ! empty( $years ) ) ) : ?>
<div <?php $this->print_render_attribute_string( 'category' ); ?>>
				<?php
						get_template_part(
							'template-parts/list/list',
							'categories',
							array(
								'categories' => $categories,
								'years'      => $years,
							)
						);
				?>
</div>
<div class="w-100"></div>
	<?php endif; ?>
		<?php endif; ?>
		<?php if ( in_array( 'description', $include ) && $settings['description_enabled'] && ! empty( $post['description'] ) ) : ?>
<<?php $this->print_html_tag( 'typography_description_tag' ); ?>
			<?php $this->print_render_attribute_string( 'description' ); ?>><?php echo $post['description']; ?>
</<?php $this->print_html_tag( 'typography_description_tag' ); ?>>
<div class="w-100"></div>
		<?php endif; ?>
		<?php if ( in_array( 'button', $include ) && $settings['button_enabled'] ) : ?>
<div class="slider__wrapper-button mt-4 pointer-events-auto">
			<?php get_template_part( 'template-parts/button/button', 'normal', $button_args ); ?>
</div>
		<?php endif; ?>

		<?php
	}

	public function add_content_animation_attributes( $type = 'subheading', $attributes = array() ) {
		if ( empty( $attributes ) ) {
			return array();
		}

		switch ( $type ) {
			case 'subheading':
				$attributes = $this->get_split_text_attributes(
					$attributes,
					array(
						'by'        => 'lines, words',
						'set'       => 'words',
						'overflow'  => 'lines',
						'animation' => false,
					)
				);
				break;

			case 'category':
				$attributes = $this->get_split_text_attributes(
					$attributes,
					array(
						'by'        => 'lines, words',
						'set'       => 'words',
						'overflow'  => 'lines',
						'animation' => false,
					)
				);
				break;

			case 'heading':
				$attributes = $this->get_split_text_attributes(
					$attributes,
					array(
						'by'        => 'lines, words, chars',
						'set'       => 'chars',
						'overflow'  => 'chars',
						'animation' => false,
					)
				);
				break;

			case 'description':
				$attributes = $this->get_split_text_attributes(
					$attributes,
					array(
						'by'        => 'lines',
						'set'       => 'lines',
						'overflow'  => 'lines',
						'animation' => false,
					)
				);
				break;

			default:
				$attributes = $this->get_split_text_attributes(
					$attributes,
					array(
						'by'        => 'lines',
						'set'       => 'lines',
						'overflow'  => 'lines',
						'animation' => false,
					)
				);
				break;
		}

		return $attributes;
	}

}
