<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/dynamic/kinsey-widget-trait-dynamic-helpers.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/horizontal/kinsey-widget-trait-horizontal-controls.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-controls.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-helpers.php';

class Kinsey_Widget_Portfolio_Fullscreen_Horizontal_Scrolling extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Dynamic_Helpers;
	use Kinsey_Widget_Trait_Horizontal_Controls;
	use Kinsey_Widget_Trait_Slider_Controls;
	use Kinsey_Widget_Trait_Slider_Helpers;

	protected static $_instance, $_posts;
	protected static $_post_type          = 'arts_portfolio_item';
	protected static $_data_static_fields = array(
		'title',
		'subheading',
		'permalink',
		'description',
		'image_id',
		'video_url',
		'dynamic_color_themes' => array(
			'slides_background',
			'slides_elements_theme',
		),
	);

	public function get_name() {
		return 'kinsey-widget-portfolio-fullscreen-horizontal-scrolling';
	}

	public function get_title() {
		return esc_html__( 'Portfolio Fullscreen Horizontal Scrolling', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-sitemap icon-kinsey-widget-dynamic';
	}

	public function get_categories() {
		return array( 'kinsey-dynamic' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions'        => array( 'widgetType' => $name ),
			'fields'            => array(
				array(
					'field'       => 'section_header_heading',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Section Header: Heading', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'section_header_helper',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Section Header: Helper Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'cursor_clickable_links_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Cursor: Clickable Links Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
			'integration-class' => 'WPML_Elementor_Kinsey_Widget_Portfolio_Fullscreen_Horizontal_Scrolling',
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {

		/**
		 * Section Header
		 */
		$this->start_controls_section(
			'header_section',
			array(
				'label' => esc_html__( 'Section Header', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'section_header_heading',
			array(
				'label'   => esc_html__( 'Heading', 'kinsey' ),
				'type'    => Controls_Manager::TEXT,
				'dynamic' => array(
					'active' => true,
				),
				'default' => esc_html__( 'Portfolio', 'kinsey' ),
			)
		);

		$this->add_control(
			'section_header_helper',
			array(
				'label'     => esc_html__( 'Helper Label', 'kinsey' ),
				'type'      => Controls_Manager::TEXT,
				'dynamic'   => array(
					'active' => true,
				),
				'default'   => esc_html__( 'Scroll', 'kinsey' ),
				'condition' => array(
					'section_header_heading!' => '',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Posts Toggles and Posts Amount Control
		 */
		$this->add_controls_posts_toggles();

		/**
		 * Content Elements to Show
		 */
		$this->start_controls_section(
			'elements_section',
			array(
				'label' => esc_html__( 'Elements', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_elements_appearance( array( 'subheading', 'categories_years', 'description' ) );
		$this->end_controls_section();

		/**
		 * Horizontal Scrolling Options
		 */
		$this->start_controls_section(
			'horizontal_scroll_section',
			array(
				'label' => esc_html__( 'Horizontal Scroll', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_horizontal_scrolling_options();
		$this->end_controls_section();

		/**
		 * Slider Interaction Options
		 */
		$this->start_controls_section(
			'interaction_section',
			array(
				'label' => esc_html__( 'Interaction', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_interaction( array( 'clickability' ) );
		$this->end_controls_section();

		/**
		 * Layout Options
		 */
		$this->start_controls_section(
			'layout_section',
			array(
				'label'       => esc_html__( 'Layout', 'kinsey' ),
				'label_block' => true,
				'tab'         => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'section_header_column_width',
			array(
				'label'       => esc_html__( 'Section Header Column Width', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'options'     => array(
					'1'  => '8%',
					'2'  => '16%',
					'3'  => '25%',
					'4'  => '33%',
					'5'  => '41%',
					'6'  => '50%',
					'7'  => '58%',
					'8'  => '66%',
					'9'  => '75%',
					'10' => '83%',
					'11' => '91%',
					'12' => '100%',
				),
				'render_type' => 'template',
				'default'     => '6',
			)
		);

		$this->add_responsive_control(
			'items_columns_width',
			array(
				'label'           => esc_html__( 'Items Columns Width', 'kinsey' ),
				'label_block'     => true,
				'type'            => Controls_Manager::SELECT,
				'options'         => array(
					'1'  => '8%',
					'2'  => '16%',
					'3'  => '25%',
					'4'  => '33%',
					'5'  => '41%',
					'6'  => '50%',
					'7'  => '58%',
					'8'  => '66%',
					'9'  => '75%',
					'10' => '83%',
					'11' => '91%',
					'12' => '100%',
				),
				'render_type'     => 'template',
				'desktop_default' => '5',
				'tablet_default'  => '6',
				'mobile_default'  => '12',
			)
		);

		$this->add_control(
			'columns_layout',
			array(
				'label'       => esc_html__( 'Columns Layout', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'guttered',
				'options'     => array(
					'guttered'         => esc_html__( 'Guttered', 'kinsey' ),
					'background-hover' => esc_html__( 'Background Hover', 'kinsey' ),
				),
			)
		);

		$this->add_control(
			'text_elements_position',
			array(
				'label'       => esc_html__( 'Category Position', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'category_before',
				'options'     => array(
					'category_before' => esc_html__( 'Before Heading', 'kinsey' ),
					'category_after'  => esc_html__( 'After Heading', 'kinsey' ),
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		/**
		 * Effects
		 */
		$this->start_controls_section(
			'effects_section',
			array(
				'label' => esc_html__( 'Effects', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'effect_dynamic_color_themes_heading',
			array(
				'label' => esc_html__( 'Slides Dynamic Color Themes', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);
		$this->add_controls_slider_dynamic_color_themes( array( 'slides_background', 'slides_elements_theme' ) );
		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Section Heading'      => array(
					'preset' => 'h1',
					'tag'    => 'h1',
				),
				'Section Helper'       => array(
					'preset' => 'h6',
				),
				'Heading'              => array(
					'preset' => 'h3',
					'tag'    => 'h2',
				),
				'Subheading'           => array(
					'preset' => 'h6',
					'tag'    => 'div',
				),
				'Categories and Years' => array(
					'preset' => 'small',
				),
				'Description'          => array(
					'preset' => 'paragraph',
					'tag'    => 'p',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Clickable Links' => array( 'scale', 'hide_native', 'label', 'icon' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$posts    = $this->get_posts_to_display();

		if ( empty( $posts ) ) {
			return;
		}

		$section_attributes = array(
			'class'                                    => array( 'section', 'section-fullheight', 'section-fullscreen-columns', 'section-horizontal-scroll' ),
			'data-arts-horizontal-scroll'              => 'container',
			'data-arts-horizontal-scroll-type'         => $settings['horizontal_scroll_type'],
			'data-arts-horizontal-scroll-toggle-class' => $settings['horizontal_scroll_in_view_class'],
		);

		$section_wrapper_attributes = array(
			'class'                       => array( 'section-horizontal-scroll__wrapper' ),
			'data-arts-horizontal-scroll' => 'wrapper',
		);

		$section_header_attributes = array(
			'class'                       => array( 'section-fullscreen-columns__header', 'd-flex', 'flex-wrap', 'col-lg-' . $settings['section_header_column_width'], 'pt-xlarge', 'pb-large', 'container-fluid' ),
			'data-arts-horizontal-scroll' => 'section',
		);

		$section_header_heading_attributes = array(
			'class' => array( 'section__heading', 'my-0', $settings['typography_section_heading_preset'] ),
		);

		$section_header_helper_attributes = array(
			'class' => array( $settings['typography_section_helper_preset'] ),
		);

		$item_col_attributes = array(
			'class'                       => array( 'section-fullscreen-columns__border', 'col-lg-' . $settings['items_columns_width'], 'col-sm-' . $settings['items_columns_width_tablet'], 'col-' . $settings['items_columns_width_mobile'] ),
			'data-arts-horizontal-scroll' => 'section',
		);

		$subheading_attributes = array(
			'class' => array( 'd-inline-block', $settings['typography_subheading_preset'] ),
		);

		$heading_attributes = array(
			'class' => array( 'd-inline-block', 'my-0', $settings['typography_heading_preset'] ),
		);

		$category_attributes = array(
			'class' => array( 'd-inline-block', $settings['typography_categories_and_years_preset'] ),
		);

		$description_attributes = array(
			'class' => array( $settings['typography_description_preset'], 'my-3' ),
		);

		$content_attributes = array(
			'class' => array( 'figure-project__content', 'mt-4' ),
		);

		if ( $settings['text_elements_position'] === 'category_before' ) {
			$category_attributes['class'][] = 'mb-3';
		}

		if ( $settings['text_elements_position'] === 'category_after' ) {
			$category_attributes['class'][] = 'mt-2';
		}

		if ( $settings['columns_layout'] === 'background-hover' ) {
			$content_attributes = array(
				'class' => array( 'background-hover__content' ),
			);
		}

		if ( $settings['horizontal_scroll_type'] === 'modular' ) {
			$item_col_attributes['data-arts-horizontal-scroll'] = 'section';
		}

		if ( $settings['headings_clickable_enabled'] ) {
			$heading_attributes['class'][] = 'underline-hover__target';
		}

		if ( array_key_exists( 'rtl_scrolling_enabled', $settings ) ) {
			$section_attributes['data-arts-horizontal-scroll-direction'] = $settings['rtl_scrolling_enabled'] ? 'left' : 'right';
		}

		if ( $settings['animation_enabled'] ) {
			$subheading_attributes  = $this->add_content_animation_attributes( 'subheading', $subheading_attributes );
			$heading_attributes     = $this->add_content_animation_attributes( '', $heading_attributes );
			$category_attributes    = $this->add_content_animation_attributes( 'category', $category_attributes );
			$description_attributes = $this->add_content_animation_attributes( 'description', $description_attributes );

			$section_header_attributes = $this->get_animation_attributes( $section_header_attributes, 'animateText' );

			$section_header_helper_attributes = $this->add_content_animation_attributes( 'section_header_heading', $section_header_helper_attributes );

			$section_header_heading_attributes = $this->get_split_text_attributes(
				$section_header_heading_attributes,
				array(
					'set'       => 'lines',
					'direction' => 'y',
					'distance'  => '-100%',
					'animation' => false,
				)
			);

			$section_header_helper_attributes = $this->get_split_text_attributes(
				$section_header_helper_attributes,
				array(
					'set'       => 'lines',
					'direction' => 'y',
					'distance'  => '-100%',
					'animation' => false,
				)
			);

			$content_attributes = $this->get_animation_attributes(
				$content_attributes,
				'animateText',
				array(
					'delay' => '0.3',
				)
			);

			$item_col_attributes['class'][] = 'mask-reveal';

			$item_col_attributes = $this->get_animation_attributes(
				$item_col_attributes,
				'animateMask',
				array(
					'direction' => $settings['animation_mask_reveal_direction'],
					'scale'     => $settings['animation_mask_scale_from']['size'],
				)
			);
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'section_wrapper', $section_wrapper_attributes );
		$this->add_render_attribute( 'section_header', $section_header_attributes );
		$this->add_render_attribute( 'section_header_heading', $section_header_heading_attributes );
		$this->add_render_attribute( 'section_header_helper', $section_header_helper_attributes );
		$this->add_render_attribute( 'item_col', $item_col_attributes );
		$this->add_render_attribute( 'content', $content_attributes );

		$this->add_render_attribute( 'subheading', $subheading_attributes );
		$this->add_render_attribute( 'category', $category_attributes );
		$this->add_render_attribute( 'heading', $heading_attributes );
		$this->add_render_attribute( 'description', $description_attributes );

		?>
		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div <?php $this->print_render_attribute_string( 'section_wrapper' ); ?>>
				<div class="d-flex flex-wrap flex-lg-nowrap w-100vw h-lg-100vh-fix-bar">
					<?php if ( ! empty( $settings['section_header_heading'] ) ) : ?>
						<div <?php $this->print_render_attribute_string( 'section_header' ); ?>>
							<div class="w-100 mt-auto">
								<<?php $this->print_html_tag( 'typography_section_heading_tag' ); ?>
								<?php $this->print_render_attribute_string( 'section_header_heading' ); ?>>
								<?php echo esc_html( $settings['section_header_heading'] ); ?>
								</<?php $this->print_html_tag( 'typography_section_heading_tag' ); ?>>
							</div>
							<?php if ( ! empty( $settings['section_header_helper'] ) ) : ?>
								<div class="w-100 align-self-end">
									<div <?php $this->print_render_attribute_string( 'section_header_helper' ); ?>>
										<?php echo esc_html( $settings['section_header_helper'] ); ?>
									</div>
								</div>
							<?php endif; ?>
						</div>
					<?php endif; ?>
					<?php foreach ( $posts as $post ) : ?>
						<?php
							$thumbnail_args = array(
								'id'           => $post['image_id'],
								'video'        => array(
									'src'        => $post['video_url'],
									'attributes' => array(
										'autoplay' => true,
									),
								),
								'lazy_wrapper' => false,
								'size'         => $this->get_thumbnail_size( $post['image_id'] ),
								'type'         => 'background',
								'outer'        => array(
									'class' => array( 'hover-zoom__inner' ),
								),
								'image'        => array(
									'class' => array( 'lazy-bg', 'of-cover' ),
								),
							);

							$wrapper_background = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_background', null, '#f8f8f8', $post );
							$wrapper_theme_text = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_elements_theme', null, 'dark', $post );

							$wrapper_attributes = array(
								'class'                => array( 'container-fluid', 'h-100' ),
								'data-arts-theme-text' => $wrapper_theme_text,
								'style'                => "background: {$wrapper_background};",
							);

							$project_attributes = array(
								'class'                 => array( 'figure-project', 'd-flex', 'justify-content-between', 'flex-column', 'w-100', 'h-100' ),
								'data-arts-hover-class' => 'hover-zoom-underline',
							);

							$image_link_attributes = array(
								'class' => array( 'figure-project__wrapper-img', 'h-100', 'overflow' ),
							);

							if ( $settings['columns_layout'] === 'guttered' ) {
								$wrapper_attributes['class'][] = 'pt-medium';
								$wrapper_attributes['class'][] = 'pb-small';
							}

							if ( $settings['columns_layout'] === 'background-hover' ) {
								$wrapper_attributes['class'][] = 'background-hover';
								$wrapper_attributes['class'][] = 'w-100';
								$wrapper_attributes['class'][] = 'py-medium';
								$wrapper_attributes['class'][] = 'd-flex';
								$wrapper_attributes['class'][] = 'align-items-center';
							}

							if ( $settings['animation_enabled'] ) {
								$image_link_attributes['class'][] = 'mask-reveal';

								$thumbnail_args['animations']['animateMask'] = array(
									'enabled' => false,
								);
							}

							$this->add_render_attribute( 'image_link', $image_link_attributes, true, true );
							$this->add_render_attribute( 'wrapper', $wrapper_attributes, true, true );
							$this->add_render_attribute( 'project', $project_attributes, true, true );
							?>
					<div <?php $this->print_render_attribute_string( 'item_col' ); ?>>
						<?php if ( $settings['animation_enabled'] ) : ?>
					<div class="mask-reveal__layer mask-reveal__layer-1">
						<div class="mask-reveal__layer mask-reveal__layer-2">
						<?php endif; ?>
						<?php if ( $settings['columns_layout'] === 'guttered' ) : ?>
						<div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
							<div <?php $this->print_render_attribute_string( 'project' ); ?>>
							<?php if ( $settings['images_clickable_enabled'] ) : ?>
								<?php
									$image_link_attributes['href']            = $post['permalink'];
									$image_link_attributes['data-arts-hover'] = 'trigger';

								if ( $settings['cursor_clickable_links_enabled'] ) {
									$image_link_attributes = $this->add_cursor_attributes( $image_link_attributes, 'Clickable Links' );
								}

									$this->add_render_attribute( 'image_link', $image_link_attributes, true, true );
								?>
							<a <?php $this->print_render_attribute_string( 'image_link' ); ?>>
								<?php else : ?>
								<div <?php $this->print_render_attribute_string( 'image_link' ); ?>>
								<?php endif; ?>
								<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
								<?php if ( $settings['images_clickable_enabled'] ) : ?>
							</a>
							<?php else : ?>
							</div>
							<?php endif; ?>
							<div <?php $this->print_render_attribute_string( 'content' ); ?>>
							<?php $this->render_swiper_content_slide( $post, array( 'category', 'heading', 'subheading', 'description' ) ); ?>
							</div>
						</div>
						</div>
						<?php endif; ?>
						<?php if ( $settings['columns_layout'] === 'background-hover' ) : ?>
						<div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
						<div class="background-hover__image">
							<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
						</div>
						<div <?php $this->print_render_attribute_string( 'content' ); ?>>
							<?php $this->render_swiper_content_slide( $post, array( 'category', 'heading', 'subheading', 'description' ) ); ?>
						</div>
						<div class="background-hover__overlay overlay overlay_dark-60"></div>
						</div>
						<?php endif; ?>
						<?php if ( $settings['animation_enabled'] ) : ?>
					</div>
					</div>
					<?php endif; ?>
				</div>
			<?php endforeach; ?>
			</div>
		</div>
		</div>
		<?php
	}
}
