<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/dynamic/kinsey-widget-trait-dynamic-helpers.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-controls.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-helpers.php';

class Kinsey_Widget_Portfolio_Fullscreen_Slider_Backgrounds_2 extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Dynamic_Helpers;
	use Kinsey_Widget_Trait_Slider_Controls;
	use Kinsey_Widget_Trait_Slider_Helpers;

	protected static $_instance, $_posts;
	protected static $_post_type          = 'arts_portfolio_item';
	protected static $_data_static_fields = array(
		'title',
		'subheading',
		'permalink',
		'description',
		'image_id',
		'video_url',
		'dynamic_color_themes' => array(
			'slides_background',
			'slides_elements_theme',
			'header_elements_theme',
			'header_logo',
			'sidebar_background',
		),
	);

	public function get_name() {
		return 'kinsey-widget-portfolio-fullscreen-slider-backgrounds-2';
	}

	public function get_title() {
		return esc_html__( 'Portfolio Fullscreen Slider Backgrounds 2', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-sitemap icon-kinsey-widget-dynamic';
	}

	public function get_categories() {
		return array( 'kinsey-dynamic' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions'        => array( 'widgetType' => $name ),
			'fields'            => array(
				array(
					'field'       => 'button_title',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Button: Title', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'button_title_hover',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Button: Hover Title', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'mouse_drag_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Mouse: Cursor Drag Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
			'integration-class' => 'WPML_Elementor_Kinsey_Widget_Portfolio_Fullscreen_Slider_Backgrounds_2',
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {

		/**
		 * Button Options
		 */
		$this->start_controls_section(
			'button_section',
			array(
				'label' => esc_html__( 'Button', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_controls_button( array( 'title', 'title_hover', 'style', 'border', 'color', 'icon_before', 'icon_after' ) );
		$this->end_controls_section();

		/**
		 * Posts Toggles and Posts Amount Control
		 */
		$this->add_controls_posts_toggles();

		/**
		 * Content Elements to Show
		 */
		$this->start_controls_section(
			'elements_section',
			array(
				'label' => esc_html__( 'Elements', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_elements_appearance();
		$this->end_controls_section();

		/**
		 * Slider Options
		 */
		$this->start_controls_section(
			'slider_section',
			array(
				'label' => esc_html__( 'Slider', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_options( array( 'direction', 'speed', 'autoplay' ) );
		$this->end_controls_section();

		/**
		 * Slider Controls
		 */
		$this->start_controls_section(
			'controls_section',
			array(
				'label' => esc_html__( 'Controls', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_controls( array( 'arrows', 'progress' ) );
		$this->end_controls_section();

		/**
		 * Slider Interaction Options
		 */
		$this->start_controls_section(
			'interaction_section',
			array(
				'label' => esc_html__( 'Interaction', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_interaction( array( 'clickability', 'mouse', 'keyboard', 'drag' ) );
		$this->end_controls_section();

		/**
		 * Sidebar Options
		 */
		$this->start_controls_section(
			'sidebar_section',
			array(
				'label' => esc_html__( 'Sidebar', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$this->add_control(
			'sidebar_heading',
			array(
				'label' => esc_html__( 'Sidebar', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);

		$this->add_control(
			'sidebar_enabled',
			array(
				'label'   => esc_html__( 'Enable Sidebar', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->end_controls_section();

		/**
		 * Layout Options
		 */
		$this->start_controls_section(
			'layout_section',
			array(
				'label'       => esc_html__( 'Layout', 'kinsey' ),
				'label_block' => true,
				'tab'         => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'text_elements_position',
			array(
				'label'       => esc_html__( 'Category Position', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'category_before',
				'options'     => array(
					'category_before' => esc_html__( 'Before Heading', 'kinsey' ),
					'category_after'  => esc_html__( 'After Heading', 'kinsey' ),
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->add_responsive_control(
			'images_opacity',
			array(
				'label'           => esc_html__( 'Opacity', 'kinsey' ),
				'type'            => Controls_Manager::SLIDER,
				'desktop_default' => array(
					'size' => 1.0,
					'unit' => 'px',
				),
				'tablet_default'  => array(
					'size' => 0.2,
					'unit' => 'px',
				),
				'mobile_default'  => array(
					'size' => 0.1,
					'unit' => 'px',
				),
				'size_units'      => array( 'px' ),
				'range'           => array(
					'px' => array(
						'min'  => 0,
						'max'  => 1.0,
						'step' => 0.01,
					),
				),
				'selectors'       => array(
					'{{WRAPPER}} .slider-projects-fullscreen__slide img' => 'opacity: {{SIZE}};',
					'{{WRAPPER}} .slider-projects-fullscreen__slide video' => 'opacity: {{SIZE}};',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Effects
		 */
		$this->start_controls_section(
			'effects_section',
			array(
				'label' => esc_html__( 'Effects', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'effect_dynamic_color_themes_heading',
			array(
				'label' => esc_html__( 'Slides Dynamic Color Themes', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);
		$this->add_controls_slider_dynamic_color_themes();

		$this->add_control(
			'effect_text_transition_heading',
			array(
				'label'     => esc_html__( 'Slides Text Transition', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);
		$this->add_controls_slider_effect_text_transition();

		$this->add_control(
			'effect_parallax_heading',
			array(
				'label'     => esc_html__( 'Parallax Images', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);
		$this->add_controls_slider_effect_parallax();

		$this->add_control(
			'transition_easing_enabled',
			array(
				'label'     => esc_html__( 'Enable Images Transition Easing', 'kinsey' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'yes',
				'separator' => 'before',
			)
		);

		$this->end_controls_section();

		/**
		 * AJAX Transition
		 */
		$this->start_controls_section(
			'ajax_section',
			array(
				'label' => esc_html__( 'AJAX Transition', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_ajax_transition( array( 'prefetch' ) );
		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Heading'              => array(
					'preset' => 'h1',
					'tag'    => 'h2',
				),
				'Subheading'           => array(
					'preset' => 'h6',
					'tag'    => 'div',
				),
				'Categories and Years' => array(
					'preset' => 'small',
				),
				'Description'          => array(
					'preset' => 'paragraph',
					'tag'    => 'p',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Clickable Links'    => array( 'scale', 'hide_native', 'label', 'icon' ),
				'Button'             => array( 'scale', 'hide_native', 'magnetic' ),
				'Prev & Next Arrows' => array( 'scale', 'hide_native', 'magnetic' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$posts    = $this->get_posts_to_display();

		if ( empty( $posts ) ) {
			return;
		}

		$first_post                       = reset( $posts );
		$first_post_background_color      = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_background', null, '#f8f8f8', $first_post );
		$first_post_side_background_color = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_sidebar', null, '#ffffff', $first_post );

		$section_attributes = array(
			'class' => array( 'section', 'section-fullheight', 'section-slider-projects-fullscreen', 'overflow' ),
		);

		$row_attributes = array(
			'class' => array( 'row', 'h-100', 'align-items-center', 'mx-0', 'flex-lg-nowrap' ),
		);

		$col_images_attributes = array(
			'class' => array( 'col-auto', 'slider-projects-fullscreen__col-images', 'h-100', 'px-0', 'mask-reveal' ),
		);

		$col_content_attributes = array(
			'class' => array( 'col-12' ),
		);

		$sidebar_attributes = array(
			'class' => array( 'slider-projects-fullscreen__sidebar' ),
		);

		$swiper_content_attributes = $this->add_swiper_content_attributes(
			array(
				'class' => array( 'slider-projects-fullscreen__content', 'swiper', 'swiper-container', 'js-slider-projects-fullscreen__content' ),
			)
		);

		$swiper_images_attributes = $this->add_swiper_images_attributes(
			array(
				'class'          => array( 'slider-projects-fullscreen__images', 'swiper', 'swiper-container', 'js-slider-projects-fullscreen__images' ),
				'data-direction' => $settings['direction'],
			)
		);

		$swiper_images_wrapper_attributes = array(
			'class' => array( 'swiper-wrapper' ),
		);

		$progress_bar_attributes = array(
			'class' => array( 'slider__scrollbar', 'js-slider-projects-fullscreen__scrollbar', 'small' ),
		);

		$progress_bar_wrapper_attributes = array(
			'class' => array( 'slider-projects-fullscreen__wrapper-scrollbar' ),
		);

		$arrows_attributes = array(
			'class' => array( 'slider__wrapper-arrows', 'slider__wrapper-arrows_vertical', 'slider-projects-fullscreen__arrows', 'slider-projects-fullscreen__arrows_right-bottom' ),
		);

		$arrows_args = array(
			'type' => $settings['direction'],
		);

		$category_attributes = array(
			'class' => array( 'd-inline-block', 'slider__subheading', 'mb-3', $settings['typography_categories_and_years_preset'], 'pointer-events-auto' ),
		);

		$heading_attributes = array(
			'class' => array( 'slider__heading', $settings['typography_heading_preset'], 'my-0' ),
		);

		$subheading_attributes = array(
			'class' => array( 'd-inline-block', 'slider__subheading', 'mb-2', $settings['typography_subheading_preset'] ),
		);

		$description_attributes = array(
			'class' => array( 'slider__text', $settings['typography_description_preset'], 'my-3' ),
		);

		$swiper_images_slide_wrapper_attributes = array(
			'class' => array( 'overflow' ),
		);

		if ( $settings['progress_bar_enabled'] ) {
			if ( $settings['direction'] === 'vertical' ) {
				$progress_bar_wrapper_attributes['class'][] = 'slider-projects-fullscreen__wrapper-scrollbar_right-center';
				$progress_bar_attributes['class'][]         = 'slider__scrollbar_vertical';
			} else {
				$progress_bar_wrapper_attributes['class'][] = 'slider-projects-fullscreen__wrapper-scrollbar_bottom-center';
				$progress_bar_attributes['class'][]         = 'slider__scrollbar_horizontal';
			}

			if ( $settings['progress_bar_style'] === 'long' ) {
				$progress_bar_attributes['class'][] = "slider__scrollbar_{$settings['direction']}_long";
			}

			if ( $settings['progress_bar_slides_numbers_enabled'] ) {
				$progress_bar_attributes['class'][] = 'slider__scrollbar_counter';
			}
		}

		if ( $settings['direction'] === 'vertical' ) {
			$swiper_content_attributes['data-centered-slides'] = 'true';

			if ( ! $settings['transition_text_enabled'] ) {
				$swiper_content_attributes['data-slides-per-view'] = 2.25;
			}
		} else {
			$swiper_content_attributes['data-auto-height'] = 'true';
		}

		if ( $settings['text_elements_position'] === 'category_before' ) {
			$category_attributes['class'][] = 'mb-3';
		}

		if ( $settings['text_elements_position'] === 'category_after' ) {
			$category_attributes['class'][] = 'mt-2';
		}

		if ( $settings['cursor_prev___next_arrows_enabled'] ) {
			$arrows_args['cursor_attributes'] = $this->add_cursor_attributes( array(), 'Prev & Next Arrows' );
		}

		if ( $settings['transition_easing_enabled'] ) {
			$swiper_images_wrapper_attributes['class'][] = 'swiper-wrapper_transition';
		}

		if ( $settings['dynamic_color_themes_enabled'] ) {
			$section_attributes['data-arts-theme-text'] = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_elements_theme', null, 'dark', $first_post );

			$section_attributes['class'][] = 'section-dynamic-background';
			$section_attributes['class'][] = 'js-slider-background';
			$section_attributes['style']   = "background-color: {$first_post_background_color}";

			$sidebar_attributes['class'][] = 'section-dynamic-background';
			$sidebar_attributes['class'][] = 'js-slider-projects-fullscreen__sidebar';
			$sidebar_attributes['style']   = "background-color: {$first_post_side_background_color}";
		}

		if ( $settings['animation_enabled'] ) {
			$section_attributes['data-arts-os-animation'] = 'true';

			$col_images_attributes = $this->get_animation_attributes(
				$col_images_attributes,
				'animateMask',
				array(
					'direction' => $settings['animation_mask_reveal_direction'],
					'scale'     => $settings['animation_mask_scale_from']['size'],
				)
			);

			$sidebar_attributes = $this->get_animation_attributes(
				$sidebar_attributes,
				'animateScale',
				array(
					'direction' => $settings['animation_mask_reveal_direction'],
				)
			);

			$progress_bar_wrapper_attributes = $this->get_animation_attributes(
				$progress_bar_wrapper_attributes,
				'animateJump',
				array(
					'x' => '30',
					'y' => '0',
				)
			);

			$arrows_attributes = $this->get_animation_attributes(
				$arrows_attributes,
				'animateJump',
				array(
					'x' => '0',
					'y' => '30',
				)
			);

			$swiper_images_slide_wrapper_attributes = $this->get_animation_attributes(
				$swiper_images_slide_wrapper_attributes,
				'animateMask',
				array(
					'direction' => $settings['animation_mask_reveal_direction'],
					'scale'     => $settings['animation_mask_scale_from']['size'],
				)
			);
		}

		if ( $settings['animation_enabled'] ) {

			if ( $settings['transition_text_enabled'] ) {
				$subheading_attributes  = $this->add_content_animation_attributes( 'subheading', $subheading_attributes );
				$category_attributes    = $this->add_content_animation_attributes( 'category', $category_attributes );
				$heading_attributes     = $this->add_content_animation_attributes( 'heading', $heading_attributes );
				$description_attributes = $this->add_content_animation_attributes( 'description', $description_attributes );
			} else {
				$col_content_attributes = $this->get_animation_attributes(
					$col_content_attributes,
					'animateJump',
					array(
						'y' => 50,
					)
				);
			}
		}

		if ( $settings['headings_clickable_enabled'] ) {
			$heading_attributes['class'][] = 'underline-hover__target';
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'row', $row_attributes );
		$this->add_render_attribute( 'col_images', $col_images_attributes );
		$this->add_render_attribute( 'col_content', $col_content_attributes );
		$this->add_render_attribute( 'sidebar', $sidebar_attributes );
		$this->add_render_attribute( 'swiper_content', $swiper_content_attributes );
		$this->add_render_attribute( 'swiper_images', $swiper_images_attributes );
		$this->add_render_attribute( 'swiper_images_wrapper', $swiper_images_wrapper_attributes );
		$this->add_render_attribute( 'swiper_images_slide_wrapper', $swiper_images_slide_wrapper_attributes );
		$this->add_render_attribute( 'progress_bar_wrapper', $progress_bar_wrapper_attributes );
		$this->add_render_attribute( 'progress_bar', $progress_bar_attributes );
		$this->add_render_attribute( 'arrows', $arrows_attributes );
		$this->add_render_attribute( 'subheading', $subheading_attributes );
		$this->add_render_attribute( 'category', $category_attributes );
		$this->add_render_attribute( 'heading', $heading_attributes );
		$this->add_render_attribute( 'description', $description_attributes );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div class="section-fullheight__inner section-fullheight__inner_mobile">
				<div class="slider slider-projects-fullscreen js-slider js-slider-projects-fullscreen" data-arts-hover-class="hover-zoom-underline-active-slide">
					<div class="container-fluid h-100 z-50 pointer-events-none">
						<div class="row h-100 align-items-center">
							<!-- slider CONTENT -->
							<div <?php $this->print_render_attribute_string( 'col_content' ); ?>>
								<div <?php $this->print_render_attribute_string( 'swiper_content' ); ?>>
									<div class="swiper-wrapper">
										<?php foreach ( $posts as $index => $post ) : ?>
											<div class="swiper-slide slider__slide-centered">
												<div data-swiper-parallax-opacity="0.1">
													<?php $this->render_swiper_content_slide( $post ); ?>
												</div>
											</div>
										<?php endforeach; ?>
									</div>
								</div>
							</div>
							<!-- - slider CONTENT -->
						</div>
					</div>
					<!-- slider IMAGES -->
					<div <?php $this->print_render_attribute_string( 'swiper_images' ); ?>>
						<div <?php $this->print_render_attribute_string( 'swiper_images_wrapper' ); ?>>
							<?php foreach ( $posts as $index => $post ) : ?>
								<?php
									$thumbnail_args   = array(
										'id'           => $post['image_id'],
										'video'        => array(
											'src'        => $post['video_url'],
											'attributes' => array(
												'autoplay' => true,
											),
										),
										'size'         => $this->get_thumbnail_size( $post['image_id'] ),
										'type'         => 'image',
										'image'        => array(
											'class' => array( 'swiper-lazy', 'of-cover', 'hover-zoom__zoom' ),
										),
										'lazy'         => false,
										'lazy_wrapper' => false,
										'outer'        => array(
											'class' => array( 'w-100', 'h-100' ),
										),
										'inner'        => array(
											'class' => array( 'hover-zoom__inner' ),
										),
									);
									$slide_attributes = array(
										'class' => array( 'swiper-slide', 'slider-projects-fullscreen__slide', 'overflow' ),
									);

									if ( $settings['parallax_enabled'] ) {
										if ( $settings['direction'] === 'horizontal' ) {
											$thumbnail_args['outer']['data-swiper-parallax-x'] = "{$settings['parallax_effect_offset']['size']}%";
										} else {
											$thumbnail_args['outer']['data-swiper-parallax-y'] = "{$settings['parallax_effect_offset']['size']}%";
										}
									}

									if ( $settings['dynamic_color_themes_enabled'] ) {
										$slide_attributes['data-slide-background']      = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_background', null, '#f8f8f8', $post );
										$slide_attributes['data-slide-theme']           = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_elements_theme', null, 'dark', $post );
										$slide_attributes['data-slide-header-theme']    = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_header_main_theme', 'page_header_settings_overridden', 'dark', $post );
										$slide_attributes['data-slide-header-logo']     = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_header_main_logo', 'page_header_settings_overridden', 'primary', $post );
										$slide_attributes['data-slide-side-background'] = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_sidebar', null, '#ffffff', $post );
									}

									$this->add_render_attribute( 'slide', $slide_attributes, true, true );
									?>
								<div <?php $this->print_render_attribute_string( 'slide' ); ?>>
									<div <?php $this->print_render_attribute_string( 'swiper_images_slide_wrapper' ); ?>>
										<?php if ( $settings['animation_enabled'] ) : ?>
											<div class="mask-reveal__layer mask-reveal__layer-1">
												<div class="mask-reveal__layer mask-reveal__layer-2">
										<?php endif; ?>
									<?php if ( $settings['images_clickable_enabled'] ) : ?>
										<?php
											$image_link_attributes = array(
												'class' => array( 'd-block', 'w-100', 'h-100' ),
												'href'  => $post['permalink'],
												'data-arts-hover' => 'trigger',
											);

											if ( $settings['cursor_clickable_links_enabled'] ) {
												$image_link_attributes = $this->add_cursor_attributes( $image_link_attributes, 'Clickable Links' );
											}

											$this->add_render_attribute( 'image_link', $image_link_attributes, true, true );
											?>
										<a <?php $this->print_render_attribute_string( 'image_link' ); ?>>
									<?php endif; ?>
									<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
									<?php if ( $settings['images_clickable_enabled'] ) : ?>
										</a>
									<?php endif; ?>
										<?php if ( $settings['animation_enabled'] ) : ?>
											</div>
										</div>
										<?php endif; ?>
									</div>
								</div>
							<?php endforeach; ?>
						</div>
					</div>
					<!-- - slider IMAGES -->
					<?php if ( $settings['sidebar_enabled'] ) : ?>
						<!-- slider SIDE BACKGROUND -->
						<div <?php $this->print_render_attribute_string( 'sidebar' ); ?>></div>
						<!-- - slider SIDE BACKGROUND -->
					<?php endif; ?>
					<?php if ( $settings['progress_bar_enabled'] ) : ?>
						<!-- slider SCROLLBAR -->
						<div <?php $this->print_render_attribute_string( 'progress_bar_wrapper' ); ?>>
							<div <?php $this->print_render_attribute_string( 'progress_bar' ); ?>></div>
						</div>
						<!-- - slider SCROLLBAR -->
					<?php endif; ?>
					<?php if ( $settings['arrows_enabled'] ) : ?>
						<!-- slider ARROWS -->
						<div <?php $this->print_render_attribute_string( 'arrows' ); ?>>
							<?php get_template_part( 'template-parts/slider/slider', 'arrows', $arrows_args ); ?>
						</div>
						<!-- - slider ARROWS -->
					<?php endif; ?>
				</div>
			</div>
		</div>

		<?php
	}

}
