<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/dynamic/kinsey-widget-trait-dynamic-helpers.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-controls.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-helpers.php';

class Kinsey_Widget_Portfolio_Fullscreen_Slider_Images_1 extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Dynamic_Helpers;
	use Kinsey_Widget_Trait_Slider_Controls;
	use Kinsey_Widget_Trait_Slider_Helpers;

	protected static $_instance, $_posts;
	protected static $_post_type          = 'arts_portfolio_item';
	protected static $_data_static_fields = array( 'title', 'subheading', 'permalink', 'description', 'image_id', 'video_url' );

	public function get_name() {
		return 'kinsey-widget-portfolio-fullscreen-slider-images-1';
	}

	public function get_title() {
		return esc_html__( 'Portfolio Fullscreen Slider Images 1', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-sitemap icon-kinsey-widget-dynamic';
	}

	public function get_categories() {
		return array( 'kinsey-dynamic' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions'        => array( 'widgetType' => $name ),
			'fields'            => array(
				array(
					'field'       => 'button_title',
					'type'        => sprintf( '%1$s / %2$s', $title, esc_html__( 'Button: Title', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'button_title_hover',
					'type'        => sprintf( '%1$s / %2$s', $title, esc_html__( 'Button: Hover Title', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'mouse_drag_label',
					'type'        => sprintf( '%1$s / %2$s', $title, esc_html__( 'Cursor: Drag Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'cursor_clickable_links_label',
					'type'        => sprintf( '%1$s / %2$s', $title, esc_html__( 'Cursor: Clickable Links Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'cursor_button_navbar_label',
					'type'        => sprintf( '%1$s / %2$s', $title, esc_html__( 'Button Navbar: Cursor Hover Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				'bottom_navbar_button_link' => array(
					'field'       => 'url',
					'type'        => sprintf( '%1$s / %2$s', $title, esc_html__( 'Button Navbar: URL', 'kinsey' ) ),
					'editor_type' => 'LINK',
				),
			),
			'integration-class' => 'WPML_Elementor_Kinsey_Widget_Portfolio_Fullscreen_Slider_Images_1',
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {

		/**
		 * Button Options
		 */
		$this->start_controls_section(
			'button_section',
			array(
				'label' => esc_html__( 'Button', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_controls_button( array( 'title', 'title_hover', 'style', 'border', 'color', 'icon_before', 'icon_after' ) );
		$this->end_controls_section();

		/**
		 * Posts Toggles and Posts Amount Control
		 */
		$this->add_controls_posts_toggles();

		/**
		 * Content Elements to Show
		 */
		$this->start_controls_section(
			'elements_section',
			array(
				'label' => esc_html__( 'Elements', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_elements_appearance();
		$this->end_controls_section();

		/**
		 * Slider Options
		 */
		$this->start_controls_section(
			'slider_section',
			array(
				'label' => esc_html__( 'Slider', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_options( array( 'direction', 'speed', 'autoplay' ) );
		$this->end_controls_section();

		/**
		 * Slider Bottom Navigation Bar
		 */
		$this->start_controls_section(
			'bottom_navbar_section',
			array(
				'label' => esc_html__( 'Bottom Navbar', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$this->add_control(
			'bottom_navbar_enabled',
			array(
				'label'       => esc_html__( 'Enable Bottom Navbar', 'kinsey' ),
				'description' => esc_html__( 'Desktop Only', 'kinsey' ),
				'type'        => Controls_Manager::SWITCHER,
				'default'     => '',
			)
		);

		$this->add_control(
			'bottom_navbar_button_heading',
			array(
				'label'     => esc_html__( 'Button', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => array(
					'bottom_navbar_enabled'        => 'yes',
					'bottom_navbar_button_enabled' => 'yes',
				),
			)
		);

		$this->add_control(
			'bottom_navbar_button_enabled',
			array(
				'label'     => esc_html__( 'Enable Button', 'kinsey' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'yes',
				'condition' => array(
					'bottom_navbar_enabled' => 'yes',
				),
			)
		);

		$this->add_control(
			'bottom_navbar_button_link',
			array(
				'label'         => esc_html__( 'Link', 'kinsey' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => 'https://...',
				'show_external' => true,
				'default'       => array(
					'url'         => '#',
					'is_external' => false,
					'nofollow'    => false,
				),
				'dynamic'       => array(
					'active' => true,
				),
				'condition'     => array(
					'bottom_navbar_enabled'        => 'yes',
					'bottom_navbar_button_enabled' => 'yes',
				),
			)
		);

		$this->add_control(
			'bottom_navbar_button_border',
			array(
				'label'     => esc_html__( 'Border', 'kinsey' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => array(
					'button_solid'    => esc_html__( 'Solid', 'kinsey' ),
					'button_bordered' => esc_html__( 'Bordered', 'kinsey' ),
				),
				'default'   => 'button_solid',
				'condition' => array(
					'bottom_navbar_enabled'        => 'yes',
					'bottom_navbar_button_enabled' => 'yes',
				),
			)
		);

		$this->add_control(
			'bottom_navbar_button_color',
			array(
				'label'     => esc_html__( 'Color', 'kinsey' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => ARTS_THEME_COLORS_ARRAY,
				'default'   => 'bg-dark-3',
				'condition' => array(
					'bottom_navbar_enabled'        => 'yes',
					'bottom_navbar_button_enabled' => 'yes',
				),
			)
		);

		$this->add_control(
			'bottom_navbar_button_counter_heading',
			array(
				'label'     => esc_html__( 'Counter', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => array(
					'bottom_navbar_enabled'        => 'yes',
					'bottom_navbar_button_enabled' => 'yes',
				),
			)
		);

		$this->add_control(
			'bottom_navbar_button_counter_enabled',
			array(
				'label'       => esc_html__( 'Enable Total Posts Counter', 'kinsey' ),
				'description' => esc_html__( 'All published posts', 'kinsey' ),
				'type'        => Controls_Manager::SWITCHER,
				'default'     => 'yes',
				'condition'   => array(
					'bottom_navbar_enabled'        => 'yes',
					'bottom_navbar_button_enabled' => 'yes',
				),
			)
		);

		$this->add_control(
			'bottom_navbar_button_counter_custom_string',
			array(
				'label'     => esc_html__( 'Counter Custom Number', 'kinsey' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => '',
				'condition' => array(
					'bottom_navbar_enabled'                => 'yes',
					'bottom_navbar_button_enabled'         => 'yes',
					'bottom_navbar_button_counter_enabled' => 'yes',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Slider Controls
		 */
		$this->start_controls_section(
			'controls_section',
			array(
				'label' => esc_html__( 'Controls', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_controls( array( 'arrows', 'progress' ) );
		$this->end_controls_section();

		/**
		 * Slider Interaction
		 */
		$this->start_controls_section(
			'interaction_section',
			array(
				'label' => esc_html__( 'Interaction', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_interaction( array( 'clickability', 'mouse', 'keyboard', 'drag' ) );
		$this->end_controls_section();

		/**
		 * Layout
		 */
		$this->start_controls_section(
			'layout_section',
			array(
				'label'       => esc_html__( 'Layout', 'kinsey' ),
				'label_block' => true,
				'tab'         => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'content_position',
			array(
				'label'       => esc_html__( 'Content Position', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'center',
				'options'     => array(
					'center' => esc_html__( 'Center', 'kinsey' ),
					'bottom' => esc_html__( 'Bottom', 'kinsey' ),
				),
			)
		);

		$this->add_control(
			'container',
			array(
				'label'       => esc_html__( 'Container', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'container',
				'options'     => array(
					'container'       => esc_html__( 'Boxed', 'kinsey' ),
					'container-fluid' => esc_html__( 'Fullwidth with Gutters', 'kinsey' ),
				),
			)
		);

		$this->add_control(
			'text_elements_position',
			array(
				'label'       => esc_html__( 'Category Position', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'category_before',
				'options'     => array(
					'category_before' => esc_html__( 'Before Heading', 'kinsey' ),
					'category_after'  => esc_html__( 'After Heading', 'kinsey' ),
				),
			)
		);

		$this->add_control(
			'button_position',
			array(
				'label'       => esc_html__( 'Button Position', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'right_side',
				'options'     => array(
					'right_side'      => esc_html__( 'Right Side', 'kinsey' ),
					'beneath_content' => esc_html__( 'Beneath Text Content', 'kinsey' ),
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Overlay
		 */
		$this->start_controls_section(
			'overlay_section',
			array(
				'label' => esc_html__( 'Overlay', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			array(
				'name'     => 'background_overlay',
				'selector' => '{{WRAPPER}} .slider__overlay',
			)
		);

		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		/**
		 * Effects
		 */
		$this->start_controls_section(
			'effects_section',
			array(
				'label' => esc_html__( 'Effects', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'effect_text_transition_heading',
			array(
				'label'     => esc_html__( 'Slides Text Transition', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);
		$this->add_controls_slider_effect_text_transition();

		$this->add_control(
			'effect_parallax_heading',
			array(
				'label'     => esc_html__( 'Parallax Images', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);
		$this->add_controls_slider_effect_parallax();

		$this->add_control(
			'transition_easing_enabled',
			array(
				'label'     => esc_html__( 'Enable Images Transition Easing', 'kinsey' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'yes',
				'separator' => 'before',
			)
		);

		$this->end_controls_section();

		/**
		 * AJAX Transition
		 */
		$this->start_controls_section(
			'ajax_section',
			array(
				'label' => esc_html__( 'AJAX Transition', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_ajax_transition( array( 'prefetch' ) );
		$this->end_controls_section();

		/**
		 * Typography
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Heading'              => array(
					'preset' => 'h1',
					'tag'    => 'h2',
				),
				'Subheading'           => array(
					'preset' => 'h6',
					'tag'    => 'div',
				),
				'Categories and Years' => array(
					'preset' => 'small',
				),
				'Description'          => array(
					'preset' => 'paragraph',
					'tag'    => 'p',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Clickable Links'    => array( 'scale', 'hide_native', 'label', 'icon' ),
				'Button'             => array( 'scale', 'hide_native', 'magnetic' ),
				'Button Navbar'      => array( 'scale', 'hide_native', 'label', 'icon' ),
				'Prev & Next Arrows' => array( 'scale', 'hide_native', 'magnetic' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$posts    = $this->get_posts_to_display();

		if ( empty( $posts ) ) {
			return;
		}

		$section_attributes = array(
			'class' => array( 'section', 'section-fullheight', 'section-slider-projects-fullscreen', 'overflow' ),
		);

		$container_attributes = array(
			'class' => array( $settings['container'], 'h-100', 'z-50', 'pointer-events-none' ),
		);

		$row_attributes = array(
			'class' => array( 'row', 'h-100' ),
		);

		$col_images_attributes = array(
			'class' => array( 'slider-projects-fullscreen__images' ),
		);

		$col_content_attributes = array(
			'class' => array( 'col-12' ),
		);

		$swiper_content_attributes = $this->add_swiper_content_attributes(
			array(
				'class' => array( 'slider-projects-fullscreen__content', 'swiper', 'swiper-container', 'js-slider-projects-fullscreen__content', 'h-100' ),
			)
		);

		$swiper_content_slide_attributes = array(
			'class' => array( 'swiper-slide', 'slider__slide' ),
		);

		$swiper_images_attributes = $this->add_swiper_images_attributes(
			array(
				'class'          => array( 'swiper', 'swiper-container', 'js-slider-projects-fullscreen__images', 'w-100', 'h-100' ),
				'data-direction' => $settings['direction'],
			)
		);

		$swiper_images_wrapper_attributes = array(
			'class' => array( 'swiper-wrapper' ),
		);

		$progress_bar_attributes = array(
			'class' => array( 'slider__scrollbar', 'js-slider-projects-fullscreen__scrollbar', 'small' ),
		);

		$progress_bar_wrapper_attributes = array(
			'class' => array( 'slider-projects-fullscreen__wrapper-scrollbar' ),
		);

		$arrows_attributes = array(
			'class' => array( 'slider__wrapper-arrows', 'slider__wrapper-arrows_vertical', 'slider-projects-fullscreen__arrows' ),
		);

		$arrows_args = array(
			'type' => $settings['direction'],
		);

		$category_attributes = array(
			'class' => array( 'd-inline-block', 'slider__subheading', 'mb-3', $settings['typography_categories_and_years_preset'], 'pointer-events-auto' ),
		);

		$heading_attributes = array(
			'class' => array( 'slider__heading', $settings['typography_heading_preset'], 'my-0' ),
		);

		$subheading_attributes = array(
			'class' => array( 'd-inline-block', 'slider__subheading', 'mb-2', $settings['typography_subheading_preset'] ),
		);

		$description_attributes = array(
			'class' => array( 'slider__text', $settings['typography_description_preset'], 'my-3' ),
		);

		if ( $settings['content_position'] === 'bottom' ) {
			$swiper_content_slide_attributes['class'][] = 'slider__slide-bottom';
			$container_attributes['class'][]            = 'slider-projects-fullscreen__container-bottom';
			$row_attributes['class'][]                  = 'align-items-end';
			$arrows_attributes['class'][]               = 'slider-projects-fullscreen__arrows_left';
			$arrows_attributes['class'][]               = 'slider-projects-fullscreen__arrows_mobile-right-bottom';

			if ( $settings['direction'] === 'vertical' ) {
				$col_content_attributes['class'][] = 'h-100';
			}
		} else {
			$arrows_attributes['class'][]               = 'slider-projects-fullscreen__arrows_right-bottom';
			$swiper_content_slide_attributes['class'][] = 'slider__slide-centered';
			$row_attributes['class'][]                  = 'align-items-center';
		}

		if ( $settings['direction'] === 'vertical' && $settings['content_position'] === 'center' && $settings['progress_bar_enabled'] && $settings['container'] === 'container-fluid' && $settings['button_position'] === 'right_side' ) {
			$swiper_content_slide_attributes['class'][] = 'pr-small';
		}

		if ( $settings['progress_bar_enabled'] ) {
			if ( $settings['direction'] === 'vertical' ) {
				$progress_bar_wrapper_attributes['class'][] = 'slider-projects-fullscreen__wrapper-scrollbar_right-center';
				$progress_bar_attributes['class'][]         = 'slider__scrollbar_vertical';
			} else {
				$progress_bar_wrapper_attributes['class'][] = 'slider-projects-fullscreen__wrapper-scrollbar_bottom-center';
				$progress_bar_attributes['class'][]         = 'slider__scrollbar_horizontal';
			}

			if ( $settings['progress_bar_style'] === 'long' ) {
				$progress_bar_attributes['class'][] = "slider__scrollbar_{$settings['direction']}_long";
			}

			if ( $settings['progress_bar_slides_numbers_enabled'] ) {
				$progress_bar_attributes['class'][] = 'slider__scrollbar_counter';
			}
		}

		if ( $settings['direction'] === 'vertical' ) {
			$swiper_content_attributes['data-centered-slides'] = 'true';

			if ( ! $settings['transition_text_enabled'] && $settings['content_position'] === 'center' && ! $settings['bottom_navbar_enabled'] ) {
				$swiper_content_attributes['data-slides-per-view']        = 2.25;
				$swiper_content_attributes['data-slides-per-view-tablet'] = 1.0;
				$swiper_content_attributes['data-slides-per-view-mobile'] = 1.0;
			}
		} else {
			$swiper_content_attributes['data-auto-height'] = 'true';
		}

		if ( $settings['text_elements_position'] === 'category_before' ) {
			$category_attributes['class'][] = 'mb-3';
		}

		if ( $settings['text_elements_position'] === 'category_after' ) {
			$category_attributes['class'][] = 'mt-2';
		}

		if ( $settings['cursor_prev___next_arrows_enabled'] ) {
			$arrows_args['cursor_attributes'] = $this->add_cursor_attributes( array(), 'Prev & Next Arrows' );
		}

		if ( $settings['transition_easing_enabled'] ) {
			$swiper_images_wrapper_attributes['class'][] = 'swiper-wrapper_transition';
		}

		if ( $settings['animation_enabled'] ) {
			$section_attributes['data-arts-os-animation'] = 'true';

			$col_images_attributes = $this->get_animation_attributes(
				$col_images_attributes,
				'animateMask',
				array(
					'direction' => $settings['animation_mask_reveal_direction'],
					'scale'     => $settings['animation_mask_scale_from']['size'],
				)
			);

			$progress_bar_wrapper_attributes = $this->get_animation_attributes(
				$progress_bar_wrapper_attributes,
				'animateJump',
				array(
					'x' => '30',
					'y' => '0',
				)
			);

			$arrows_attributes = $this->get_animation_attributes(
				$arrows_attributes,
				'animateJump',
				array(
					'x' => '0',
					'y' => '30',
				)
			);
		}

		if ( $settings['animation_enabled'] ) {

			if ( $settings['transition_text_enabled'] ) {
				$subheading_attributes  = $this->add_content_animation_attributes( 'subheading', $subheading_attributes );
				$category_attributes    = $this->add_content_animation_attributes( 'category', $category_attributes );
				$heading_attributes     = $this->add_content_animation_attributes( 'heading', $heading_attributes );
				$description_attributes = $this->add_content_animation_attributes( 'description', $description_attributes );
			} else {
				$col_content_attributes = $this->get_animation_attributes(
					$col_content_attributes,
					'animateJump',
					array(
						'y' => 50,
					)
				);
			}
		}

		if ( $settings['headings_clickable_enabled'] ) {
			$heading_attributes['class'][] = 'underline-hover__target';
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'container', $container_attributes );
		$this->add_render_attribute( 'row', $row_attributes );
		$this->add_render_attribute( 'col_images', $col_images_attributes );
		$this->add_render_attribute( 'col_content', $col_content_attributes );
		$this->add_render_attribute( 'swiper_content', $swiper_content_attributes );
		$this->add_render_attribute( 'swiper_content_slide', $swiper_content_slide_attributes );
		$this->add_render_attribute( 'swiper_images', $swiper_images_attributes );
		$this->add_render_attribute( 'swiper_images_wrapper', $swiper_images_wrapper_attributes );
		$this->add_render_attribute( 'progress_bar_wrapper', $progress_bar_wrapper_attributes );
		$this->add_render_attribute( 'progress_bar', $progress_bar_attributes );
		$this->add_render_attribute( 'arrows', $arrows_attributes );
		$this->add_render_attribute( 'subheading', $subheading_attributes );
		$this->add_render_attribute( 'category', $category_attributes );
		$this->add_render_attribute( 'heading', $heading_attributes );
		$this->add_render_attribute( 'description', $description_attributes );

		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div class="section-fullheight__inner section-fullheight__inner_mobile">
				<div class="slider slider-projects-fullscreen js-slider js-slider-projects-fullscreen" data-arts-hover-class="hover-zoom-underline-active-slide">
					<div <?php $this->print_render_attribute_string( 'container' ); ?>>
						<div <?php $this->print_render_attribute_string( 'row' ); ?>>
							<!-- slider CONTENT -->
							<div <?php $this->print_render_attribute_string( 'col_content' ); ?>>
								<div <?php $this->print_render_attribute_string( 'swiper_content' ); ?>>
									<div class="swiper-wrapper">
										<?php foreach ( $posts as $index => $post ) : ?>
											<?php
												$button_args = array(
													'title' => $settings['button_title'],
													'title_hover' => $settings['button_title_hover'],
													'attributes' => array(
														'href'  => $post['permalink'],
														'class' => array( 'button', $settings['button_border'], $settings['button_color'] ),
														'data-arts-hover' => 'trigger',
													),
													'icon' => array(),
												);

												$render_content_fields = array( 'heading', 'subheading', 'category', 'description' );

												if ( $settings['button_position'] === 'beneath_content' ) {
													$render_content_fields[] = 'button';
												}

												if ( $settings['button_style'] ) {
													$button_args['attributes']['class'][] = $settings['button_style'];
												}

												if ( $settings['button_icon_before'] ) {
													$button_args['class'][]        = 'button_icon';
													$button_args['icon']['before'] = $settings['button_icon_before'];
												}

												if ( $settings['button_icon_after'] ) {
													$button_args['class'][]       = 'button_icon';
													$button_args['icon']['after'] = $settings['button_icon_after'];
												}

												if ( $settings['cursor_button_enabled'] ) {
													$button_args['attributes'] = $this->add_cursor_attributes( $button_args['attributes'], 'Button' );
												}

												if ( array_key_exists( 'permalink_attributes', $post ) ) {

													if ( array_key_exists( 'is_external', $post['permalink_attributes'] ) && $post['permalink_attributes']['is_external'] ) {
														$button_args['attributes']['target'] = '_blank';
													}

													if ( array_key_exists( 'nofollow', $post['permalink_attributes'] ) && $post['permalink_attributes']['nofollow'] ) {
														$button_args['attributes']['rel'] = 'nofollow';
													}
												}
												?>
											<div <?php $this->print_render_attribute_string( 'swiper_content_slide' ); ?>>
												<?php if ( $settings['direction'] === 'vertical' && $settings['content_position'] === 'center' && ! $settings['transition_text_enabled'] ) : ?>
													<div class="slider__slide-border" data-arts-os-animation="true" data-arts-os-animation-name="animateScale" data-arts-os-animation-params="{direction: 'left'}"></div>
												<?php endif; ?>
												<div class="w-100 pe-4 pe-lg-0" data-swiper-parallax-opacity="0.2">
													<div class="row justify-content-center align-items-center">
														<div class="col">
															<?php $this->render_swiper_content_slide( $post, $render_content_fields ); ?>
														</div>
														<?php if ( $settings['button_enabled'] && $settings['button_position'] === 'right_side' ) : ?>
															<div class="col-lg-auto">
																<div class="d-inline-block slider__wrapper-button mt-lg-0 mt-4 pointer-events-auto">
																	<?php get_template_part( 'template-parts/button/button', 'normal', $button_args ); ?>
																</div>
															</div>
														<?php endif; ?>
													</div>
												</div>
											</div>
										<?php endforeach; ?>
									</div>
								</div>
							</div>
							<!-- - slider CONTENT -->
						</div>
					</div>
					<!-- slider IMAGES -->
					<div <?php $this->print_render_attribute_string( 'col_images' ); ?>>
						<?php if ( $settings['animation_enabled'] ) : ?>
						<div class="mask-reveal__layer mask-reveal__layer-1">
							<div class="mask-reveal__layer mask-reveal__layer-2">
						<?php endif; ?>
								<div <?php $this->print_render_attribute_string( 'swiper_images' ); ?>>
									<div <?php $this->print_render_attribute_string( 'swiper_images_wrapper' ); ?>>
										<?php foreach ( $posts as $index => $post ) : ?>
											<?php
												$thumbnail_args   = array(
													'id'   => $post['image_id'],
													'video' => array(
														'src' => $post['video_url'],
														'attributes' => array(
															'autoplay' => true,
														),
													),
													'size' => $this->get_thumbnail_size( $post['image_id'] ),
													'type' => 'background',
													'image' => array(
														'class' => array( 'swiper-lazy', 'of-cover', 'hover-zoom__zoom' ),
													),
													'outer' => array(
														'class' => array( 'w-100', 'h-100' ),
													),
													'inner' => array(
														'class' => array( 'hover-zoom__inner' ),
													),
												);
												$slide_attributes = array(
													'class' => array( 'swiper-slide', 'overflow' ),
												);

												if ( $settings['parallax_enabled'] ) {
													if ( $settings['direction'] === 'horizontal' ) {
														$thumbnail_args['outer']['data-swiper-parallax-x'] = "{$settings['parallax_effect_offset']['size']}%";
													} else {
														$thumbnail_args['outer']['data-swiper-parallax-y'] = "{$settings['parallax_effect_offset']['size']}%";
													}
												}

												$this->add_render_attribute( 'slide', $slide_attributes, true, true );
												?>
											<div <?php $this->print_render_attribute_string( 'slide' ); ?>>
												<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
											</div>
										<?php endforeach; ?>
									</div>
								</div>
						<?php if ( $settings['animation_enabled'] ) : ?>
							</div>
						</div>
						<?php endif; ?>
						<!-- overlay-->
						<div class="slider__overlay overlay overlay_dark-80"></div>
						<!-- - overlay -->
					</div>
					<!-- - slider IMAGES -->
					<?php if ( $settings['progress_bar_enabled'] ) : ?>
						<!-- slider SCROLLBAR -->
						<div <?php $this->print_render_attribute_string( 'progress_bar_wrapper' ); ?>>
							<div <?php $this->print_render_attribute_string( 'progress_bar' ); ?>></div>
						</div>
						<!-- - slider SCROLLBAR -->
					<?php endif; ?>
					<?php if ( $settings['arrows_enabled'] ) : ?>
						<!-- slider ARROWS -->
						<div <?php $this->print_render_attribute_string( 'arrows' ); ?>>
							<?php get_template_part( 'template-parts/slider/slider', 'arrows', $arrows_args ); ?>
						</div>
						<!-- - slider ARROWS -->
					<?php endif; ?>
					<?php if ( $settings['bottom_navbar_enabled'] ) : ?>
						<!-- slider THUMBS [desktop only] -->
						<div class="slider-projects-fullscreen__wrapper-thumbs d-none d-lg-flex" data-arts-os-animation="true" data-arts-os-animation-name="animateJump">
							<div class="swiper swiper-container js-slider-projects-fullscreen__thumbs slider-projects-fullscreen__thumbs" data-slides-per-view="3">
								<div class="swiper-wrapper swiper-wrapper_transition">
									<?php foreach ( $posts as $post ) : ?>
										<div class="swiper-slide slider__thumb js-arts-cursor-highlight">
											<div class="slider__thumb-content">
												<div class="slider__thumb-heading h5"><?php echo esc_html( $post['title'] ); ?></div>
											</div>
										</div>
									<?php endforeach; ?>
								</div>
							</div>
							<?php if ( $settings['bottom_navbar_button_enabled'] ) : ?>
								<?php
									$button_navbar_args = array(
										'attributes' => array(
											'href'  => '#',
											'class' => array( 'button', $settings['bottom_navbar_button_border'], $settings['bottom_navbar_button_color'], 'slider-projects-fullscreen__button', 'js-button-circles' ),
										),
									);

									if ( $settings['cursor_button_navbar_enabled'] ) {
										$button_navbar_args['attributes'] = $this->add_cursor_attributes( $button_navbar_args['attributes'], 'Button Navbar' );
									}

									if ( $settings['bottom_navbar_button_link'] ) {
										$button_navbar_args['attributes']['href'] = $settings['bottom_navbar_button_link']['url'];

										if ( array_key_exists( 'is_external', $settings['bottom_navbar_button_link'] ) && $settings['bottom_navbar_button_link']['is_external'] ) {
											$button_navbar_args['attributes']['target'] = '_blank';
										}

										if ( array_key_exists( 'nofollow', $settings['bottom_navbar_button_link'] ) && $settings['bottom_navbar_button_link']['nofollow'] ) {
											$button_navbar_args['attributes']['rel'] = 'nofollow';
										}
									}

									if ( $settings['bottom_navbar_button_counter_enabled'] ) {

										if ( $settings['bottom_navbar_button_counter_custom_string'] ) {
											$button_navbar_args['counter'] = $settings['bottom_navbar_button_counter_custom_string'];
										} else {
											$button_navbar_args['counter'] = count( static::$_posts );
										}
									}
									?>
								<div class="slider-projects-fullscreen__wrapper-button">
									<?php get_template_part( 'template-parts/button/button', 'circles', $button_navbar_args ); ?>
								</div>
							<?php endif; ?>
						</div>
						<!-- - slider THUMBS [desktop only] -->
					<?php endif; ?>
				</div>
			</div>
		</div>

		<?php
	}

}
