<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/dynamic/kinsey-widget-trait-dynamic-helpers.php';

class Kinsey_Widget_Portfolio_List_Backgrounds extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Dynamic_Helpers;

	protected static $_instance, $_posts, $_data_static_fields = array();
	protected static $_post_type                               = 'arts_portfolio_item';

	public function get_name() {
		return 'kinsey-widget-portfolio-list-backgrounds';
	}

	public function get_title() {
		return esc_html__( 'Portfolio List Backgrounds', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-sitemap icon-kinsey-widget-dynamic';
	}

	public function get_categories() {
		return array( 'kinsey-dynamic' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions' => array( 'widgetType' => $name ),
			'fields'     => array(
				array(
					'field'       => 'button_title',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Button: Title', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'button_title_hover',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Button: Hover Title', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {
		/**
		 * Button Options
		 */
		$this->start_controls_section(
			'button_section',
			array(
				'label' => esc_html__( 'Button', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_controls_button( array( 'title', 'title_hover', 'style', 'border', 'color', 'icon_before', 'icon_after' ) );
		$this->end_controls_section();

		/**
		 * Posts Toggles and Posts Amount Control
		 */
		$this->add_controls_posts_toggles();

		/**
		 * Content Elements to Show
		 */
		$this->start_controls_section(
			'elements_section',
			array(
				'label' => esc_html__( 'Elements', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_elements_appearance( array( 'subheading', 'categories_years', 'description', 'properties', 'button' ) );
		$this->end_controls_section();

		/**
		 * Layout Options
		 */
		$this->start_controls_section(
			'layout_section',
			array(
				'label'       => esc_html__( 'Layout', 'kinsey' ),
				'label_block' => true,
				'tab'         => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'layout',
			array(
				'label'       => esc_html__( 'Layout', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'normal',
				'options'     => array(
					'normal' => esc_html__( 'Normal', 'kinsey' ),
					'hover'  => esc_html__( 'Hover Backgrounds', 'kinsey' ),
				),
			)
		);

		$this->add_control(
			'items_even_background',
			array(
				'label'       => esc_html__( 'Even Items Background', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => '',
				'options'     => ARTS_THEME_COLORS_ARRAY,
				'condition'   => array(
					'layout' => 'hover',
				),
			)
		);

		$this->add_control(
			'items_padding_v',
			array(
				'label'       => esc_html__( 'Items Vertical Space', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'py-large',
				'options'     => ARTS_THEME_DISTANCE_ARRAY['padding']['vertical'],
			)
		);

		$this->add_control(
			'container',
			array(
				'label'       => esc_html__( 'Container', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'container',
				'options'     => array(
					'container'       => esc_html__( 'Boxed', 'kinsey' ),
					'container-fluid' => esc_html__( 'Fullwidth with Gutters', 'kinsey' ),
				),
			)
		);

		$this->add_control(
			'text_elements_position',
			array(
				'label'       => esc_html__( 'Category Position', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'category_before',
				'options'     => array(
					'category_before' => esc_html__( 'Before Heading', 'kinsey' ),
					'category_after'  => esc_html__( 'After Heading', 'kinsey' ),
				),
			)
		);

		$this->add_control(
			'content_centered_mobiles_enabled',
			array(
				'label'   => esc_html__( 'Center Content on Mobiles', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->end_controls_section();

		/**
		 * Overlay
		 */
		$this->start_controls_section(
			'overlay_section',
			array(
				'label' => esc_html__( 'Overlay', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			array(
				'name'     => 'background_overlay',
				'selector' => '{{WRAPPER}} .list-backgrounds__overlay',
			)
		);

		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		/**
		 * Effects
		 */
		$this->start_controls_section(
			'effects_section',
			array(
				'label' => esc_html__( 'Effects', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'heading_parallax',
			array(
				'label' => esc_html__( 'Parallax', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);
		$this->add_controls_parallax();
		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Heading'              => array(
					'preset' => 'h1',
					'tag'    => 'h2',
				),
				'Subheading'           => array(
					'preset' => 'h6',
					'tag'    => 'div',
				),
				'Categories and Years' => array(
					'preset' => 'small',
				),
				'Description'          => array(
					'preset' => 'paragraph',
					'tag'    => 'p',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Clickable Links' => array( 'scale', 'hide_native', 'label', 'icon' ),
				'Button'          => array( 'scale', 'hide_native', 'magnetic' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings        = $this->get_settings_for_display();
		$posts           = $this->get_posts_to_display();
		$parallax_config = $this->get_parallax_config();

		if ( empty( $posts ) ) {
			return;
		}

		$section_attributes = array(
			'class' => array( 'section', 'section-list-backgrounds', 'section-content' ),
		);

		$list_item_attributes = array(
			'class'                 => array( 'list-backgrounds__item', $settings['items_padding_v'] ),
			'data-arts-hover-class' => array( 'hover-zoom-underline', 'list-backgrounds__item_hover' ),
		);

		$list_hover_item_attributes = array(
			'class'                 => array( 'background-hover', 'list-backgrounds__item', $settings['items_padding_v'] ),
			'data-arts-hover-class' => 'hover-zoom-underline',
		);

		$section_image_attributes = array(
			'class' => array(),
		);

		$background_hover_content_attributes = array(
			'class' => array( $settings['container'], 'background-hover__content' ),
		);

		$col_content_attributes = array(
			'class' => array( 'col-12', 'text-lg-start' ),
		);

		$col_button_attributes = array(
			'class' => array( 'col-lg-3', 'text-lg-end', 'mt-4', 'mt-lg-0' ),
		);

		$subheading_attributes = array(
			'class' => array( 'd-inline-block', $settings['typography_subheading_preset'] ),
		);

		$heading_attributes = array(
			'class' => array( 'my-0', 'underline-hover__target', $settings['typography_heading_preset'] ),
		);

		$category_attributes = array(
			'class' => array( $settings['typography_categories_and_years_preset'] ),
		);

		$description_attributes = array(
			'class' => array( $settings['typography_description_preset'], 'mt-3', 'mb-0' ),
		);

		$properties_attributes = array(
			'class' => array( 'w-100', 'mt-3' ),
		);

		$years_attributes = array(
			'class' => array( 'h5', 'mb-3', 'mt-lg-3' ),
		);

		$wrapper_button_attributes = array(
			'class' => array( 'list-backgrounds__wrapper-button', 'mt-5' ),
		);

		if ( $settings['content_centered_mobiles_enabled'] ) {
			$col_content_attributes['class'][] = 'text-center';
			$col_button_attributes['class'][]  = 'text-center';
		} else {
			$col_button_attributes['class'][] = 'text-start';
		}

		if ( $settings['button_enabled'] ) {
			$col_content_attributes['class'][] = 'col-lg-9';
		}

		if ( $settings['text_elements_position'] === 'category_before' ) {
			$category_attributes['class'][] = 'mb-2';
		}

		if ( $settings['text_elements_position'] === 'category_after' ) {
			$category_attributes['class'][] = 'mt-1';
		}

		if ( $settings['animation_enabled'] ) {
			$section_image_attributes = $this->get_animation_attributes(
				$section_image_attributes,
				'animateMask',
				array(
					'direction' => $settings['animation_mask_reveal_direction'],
					'scale'     => $settings['animation_mask_scale_from']['size'],
				)
			);

			$background_hover_content_attributes = $this->get_animation_attributes( $background_hover_content_attributes, 'animateText' );
			$col_button_attributes               = $this->get_animation_attributes( $col_button_attributes, 'animateJump' );
			$wrapper_button_attributes           = $this->get_animation_attributes( $wrapper_button_attributes, 'animateJump' );

			$subheading_attributes = $this->get_split_text_attributes(
				$subheading_attributes,
				array(
					'by'        => 'lines, words',
					'set'       => 'words',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);

			$heading_attributes = $this->get_split_text_attributes(
				$heading_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);

			$category_attributes = $this->get_split_text_attributes(
				$category_attributes,
				array(
					'by'        => 'lines, words',
					'set'       => 'words',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);

			$description_attributes = $this->get_split_text_attributes(
				$description_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);

			$properties_attributes = $this->get_split_text_attributes(
				$properties_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);

			$years_attributes = $this->get_split_text_attributes(
				$years_attributes,
				array(
					'by'        => 'lines, words',
					'set'       => 'words',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'list_item', $list_item_attributes );
		$this->add_render_attribute( 'section_image', $section_image_attributes );
		$this->add_render_attribute( 'background_hover_content', $background_hover_content_attributes );
		$this->add_render_attribute( 'col_button', $col_button_attributes );
		$this->add_render_attribute( 'col_content', $col_content_attributes );
		$this->add_render_attribute( 'subheading', $subheading_attributes );
		$this->add_render_attribute( 'heading', $heading_attributes );
		$this->add_render_attribute( 'description', $description_attributes );
		$this->add_render_attribute( 'category', $category_attributes );
		$this->add_render_attribute( 'properties', $properties_attributes );
		$this->add_render_attribute( 'years', $years_attributes );
		$this->add_render_attribute( 'wrapper_button', $wrapper_button_attributes );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div class="list-backgrounds">
				<?php foreach ( $posts as $index => $post ) : ?>
					<?php
						$thumbnail_args = array(
							'id'       => $post['image_id'],
							'video'    => array(
								'src'        => $post['video_url'],
								'attributes' => array(
									'autoplay' => true,
								),
							),
							'size'     => $this->get_thumbnail_size( $post['image_id'] ),
							'type'     => 'background',
							'image'    => array(
								'class' => array( 'lazy-bg', 'of-cover' ),
							),
							'inner'    => array(
								'class' => array( 'w-100', 'h-100' ),
							),
							'parallax' => $parallax_config,
						);

						$button_args = array(
							'title'       => $settings['button_title'],
							'title_hover' => $settings['button_title_hover'],
							'attributes'  => array(
								'href'            => $post['permalink'],
								'class'           => array( 'button', $settings['button_border'], $settings['button_color'] ),
								'data-arts-hover' => 'trigger',
							),
							'icon'        => array(),
						);

						$properties_args = array(
							'post_id' => $post['id'],
							'list'    => array(
								'class' => array( 'list-backgrounds__works-list' ),
							),
							'name'    => array(),
							'value'   => array(),
						);

						$heading_link_attributes = array(
							'class'           => array( 'd-inline-block' ),
							'data-arts-hover' => 'trigger',
							'href'            => $post['permalink'],
						);

						$thumbnail_args['parallax']['outer']['class'] = array( 'w-100', 'h-100' );

						if ( $settings['animation_enabled'] ) {
							$thumbnail_args['animations'] = array(
								'animateMask' => array(),
							);

							$thumbnail_args['parallax']['outer']['class'][] = 'mask-reveal';
						}

						if ( $settings['cursor_clickable_links_enabled'] ) {
							$heading_link_attributes = $this->add_cursor_attributes( $heading_link_attributes, 'Clickable Links' );
						}

						if ( $settings['button_style'] ) {
							$button_args['attributes']['class'][] = $settings['button_style'];
						}

						if ( $settings['button_icon_before'] ) {
							$button_args['class'][]        = 'button_icon';
							$button_args['icon']['before'] = $settings['button_icon_before'];
						}

						if ( $settings['button_icon_after'] ) {
							$button_args['class'][]       = 'button_icon';
							$button_args['icon']['after'] = $settings['button_icon_after'];
						}

						if ( $settings['cursor_button_enabled'] ) {
							$button_args['attributes'] = $this->add_cursor_attributes( $button_args['attributes'], 'Button' );
						}

						if ( array_key_exists( 'permalink_attributes', $post ) ) {

							if ( array_key_exists( 'is_external', $post['permalink_attributes'] ) && $post['permalink_attributes']['is_external'] ) {
								$button_args['attributes']['target'] = '_blank';
							}

							if ( array_key_exists( 'nofollow', $post['permalink_attributes'] ) && $post['permalink_attributes']['nofollow'] ) {
								$button_args['attributes']['rel'] = 'nofollow';
							}
						}

						$this->add_render_attribute( 'heading_link', $heading_link_attributes, true, true );
						?>
					<?php if ( $settings['layout'] === 'normal' ) : ?>
						<div <?php $this->print_render_attribute_string( 'list_item' ); ?>>
							<div class="list-backgrounds__wrapper-img">
								<div <?php $this->print_render_attribute_string( 'section_image' ); ?>>
									<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
								</div>
							</div>
							<div class="overlay list-backgrounds__overlay"></div>
							<div <?php $this->print_render_attribute_string( 'background_hover_content' ); ?>>
								<div class="row align-items-center">
									<div <?php $this->print_render_attribute_string( 'col_content' ); ?>>
										<?php if ( $settings['subheading_enabled'] && ! empty( $post['subheading'] ) ) : ?>
											<<?php $this->print_html_tag( 'typography_subheading_tag' ); ?> <?php $this->print_render_attribute_string( 'subheading' ); ?>><?php echo $post['subheading']; ?></<?php $this->print_html_tag( 'typography_subheading_tag' ); ?>>
											<div class="w-100"></div>
										<?php endif; ?>
										<?php if ( $settings['text_elements_position'] === 'category_before' ) : ?>
											<?php $this->print_post_categories( $post ); ?>
											<div class="w-100"></div>
										<?php endif; ?>
										<a <?php $this->print_render_attribute_string( 'heading_link' ); ?>>
											<<?php $this->print_html_tag( 'typography_heading_tag' ); ?> <?php $this->print_render_attribute_string( 'heading' ); ?>><?php echo esc_html( $post['title'] ); ?></<?php $this->print_html_tag( 'typography_heading_tag' ); ?>>
										</a>
										<?php if ( $settings['text_elements_position'] === 'category_after' ) : ?>
											<div class="w-100"></div>
											<?php $this->print_post_categories( $post ); ?>
										<?php endif; ?>
										<?php if ( $settings['description_enabled'] && ! empty( $post['description'] ) ) : ?>
											<div class="w-100"></div>
											<<?php $this->print_html_tag( 'typography_description_tag' ); ?> <?php $this->print_render_attribute_string( 'description' ); ?>><?php echo $post['description']; ?></<?php $this->print_html_tag( 'typography_description_tag' ); ?>>
										<?php endif; ?>
									</div>
									<?php if ( $settings['button_enabled'] ) : ?>
										<div <?php $this->print_render_attribute_string( 'col_button' ); ?>>
											<?php get_template_part( 'template-parts/button/button', 'normal', $button_args ); ?>
										</div>
									<?php endif; ?>
								</div>
							</div>
						</div>
					<?php else : ?>
						<?php
							$list_hover_item_attributes_current = $list_hover_item_attributes;

						if ( $index % 2 === 0 ) {
							$list_hover_item_attributes_current['class'][] = $settings['items_even_background'];
						}

							$this->add_render_attribute( 'list_hover_item', $list_hover_item_attributes_current, true, true );
						?>
						<div <?php $this->print_render_attribute_string( 'list_hover_item' ); ?>>
							<div class="background-hover__image list-backgrounds__wrapper-img">
								<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
							</div>
							<div class="overlay list-backgrounds__overlay background-hover__overlay"></div>
							<div <?php $this->print_render_attribute_string( 'background_hover_content' ); ?>>
								<div class="row">
									<?php if ( ! empty( $post['years'] ) ) : ?>
										<div class="col-lg-6">
											<div <?php $this->print_render_attribute_string( 'years' ); ?>><?php $this->render_years_links( $post ); ?></div>
										</div>
									<?php endif; ?>
									<div class="col-lg-6">
										<?php if ( $settings['subheading_enabled'] && ! empty( $post['subheading'] ) ) : ?>
											<<?php $this->print_html_tag( 'typography_subheading_tag' ); ?> <?php $this->print_render_attribute_string( 'subheading' ); ?>><?php echo $post['subheading']; ?></<?php $this->print_html_tag( 'typography_subheading_tag' ); ?>>
											<div class="w-100"></div>
										<?php endif; ?>
										<?php if ( $settings['text_elements_position'] === 'category_before' ) : ?>
											<?php $this->print_post_categories( $post, true, false ); ?>
											<div class="w-100"></div>
										<?php endif; ?>
										<a <?php $this->print_render_attribute_string( 'heading_link' ); ?>>
											<<?php $this->print_html_tag( 'typography_heading_tag' ); ?> <?php $this->print_render_attribute_string( 'heading' ); ?>><?php echo esc_html( $post['title'] ); ?></<?php $this->print_html_tag( 'typography_heading_tag' ); ?>>
										</a>
										<?php if ( $settings['text_elements_position'] === 'category_after' ) : ?>
											<div class="w-100"></div>
											<?php $this->print_post_categories( $post, true, false ); ?>
										<?php endif; ?>
										<?php if ( $settings['description_enabled'] && ! empty( $post['description'] ) ) : ?>
											<div class="w-100"></div>
											<<?php $this->print_html_tag( 'typography_description_tag' ); ?> <?php $this->print_render_attribute_string( 'description' ); ?>><?php echo $post['description']; ?></<?php $this->print_html_tag( 'typography_description_tag' ); ?>>
										<?php endif; ?>
										<?php if ( $settings['properties_enabled'] ) : ?>
											<div <?php $this->print_render_attribute_string( 'properties' ); ?>>
												<?php get_template_part( 'template-parts/list/list', 'properties', $properties_args ); ?>
											</div>
										<?php endif; ?>
										<?php if ( $settings['button_enabled'] ) : ?>
											<div <?php $this->print_render_attribute_string( 'wrapper_button' ); ?>>
												<?php get_template_part( 'template-parts/button/button', 'normal', $button_args ); ?>
											</div>
										<?php endif; ?>
									</div>
								</div>
							</div>
						</div>
					<?php endif; ?>
				<?php endforeach; ?>
			</div>
		</div>

		<?php
	}
}
