<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/dynamic/kinsey-widget-trait-dynamic-helpers.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/grid/kinsey-widget-trait-grid-controls.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/grid/kinsey-widget-trait-grid-helpers.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-controls.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-helpers.php';

class Kinsey_Widget_Portfolio_Masonry_Grid extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Dynamic_Helpers;
	use Kinsey_Widget_Trait_Grid_Controls;
	use Kinsey_Widget_Trait_Grid_Helpers;
	use Kinsey_Widget_Trait_Slider_Controls;
	use Kinsey_Widget_Trait_Slider_Helpers;

	protected static $_instance, $_posts, $_data_static_fields = array();
	protected static $_post_type                               = 'arts_portfolio_item';

	public function get_name() {
		return 'kinsey-widget-portfolio-masonry-grid';
	}

	public function get_title() {
		return esc_html__( 'Portfolio Masonry Grid', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-sitemap icon-kinsey-widget-dynamic';
	}

	public function get_categories() {
		return array( 'kinsey-dynamic' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions' => array( 'widgetType' => $name ),
			'fields'     => array(
				array(
					'field'       => 'section_header_heading',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Section Header: Heading', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'section_header_heading',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Section Header: Heading', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'filter_all_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Filter: "All" Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'filter_all_counter_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Filter: "All" Counter Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'cursor_clickable_links_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Cursor: Clickable Links Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {

		/**
		 * Section Header
		 */
		$this->start_controls_section(
			'header_section',
			array(
				'label' => esc_html__( 'Section Header', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'section_header_heading',
			array(
				'label'   => esc_html__( 'Heading', 'kinsey' ),
				'type'    => Controls_Manager::TEXT,
				'dynamic' => array(
					'active' => true,
				),
				'default' => esc_html__( 'Projects', 'kinsey' ),
			)
		);

		$this->add_control(
			'section_header_alignment',
			array(
				'label'     => esc_html__( 'Text Alignment', 'kinsey' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => array(
					'text-lg-start text-center' => array(
						'title' => esc_html__( 'Left', 'kinsey' ),
						'icon'  => 'eicon-text-align-left',
					),
					'text-center'               => array(
						'title' => esc_html__( 'Center', 'kinsey' ),
						'icon'  => 'eicon-text-align-center',
					),
					'text-lg-end text-center'   => array(
						'title' => esc_html__( 'Right', 'kinsey' ),
						'icon'  => 'eicon-text-align-right',
					),
				),
				'default'   => 'text-center',
				'condition' => array(
					'section_header_heading!' => '',
				),
				'toggle'    => false,
			)
		);

		$this->add_control(
			'section_header_layout',
			array(
				'label'   => esc_html__( 'Layout', 'kinsey' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'heading_left'  => esc_html__( 'Heading Left / Filter Right', 'kinsey' ),
					'heading_above' => esc_html__( 'Heading Above / Filter Beneath', 'kinsey' ),
				),
				'default' => 'heading_left',
			)
		);

		$this->add_control(
			'section_header_mb',
			array(
				'label'     => esc_html__( 'Margin Bottom', 'kinsey' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'default'   => 'mb-small',
				'options'   => ARTS_THEME_DISTANCE_ARRAY['margin']['bottom'],
				'condition' => array(
					'section_header_heading!' => '',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Posts Toggles and Posts Amount Control
		 */
		$this->add_controls_posts_toggles();

		/**
		 * Content Elements to Show
		 */
		$this->start_controls_section(
			'elements_section',
			array(
				'label' => esc_html__( 'Elements', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_elements_appearance( array( 'subheading', 'categories_years', 'description' ) );
		$this->end_controls_section();

		/**
		 * Filter
		 */
		$this->start_controls_section(
			'filter_section',
			array(
				'label' => esc_html__( 'Filter', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_filter_options();
		$this->end_controls_section();

		/**
		 * Grid
		 */
		$this->start_controls_section(
			'grid_section',
			array(
				'label' => esc_html__( 'Grid', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);
		$this->add_controls_grid_options();
		$this->end_controls_section();

		/**
		 * Layout Options
		 */
		$this->start_controls_section(
			'layout_section',
			array(
				'label'       => esc_html__( 'Layout', 'kinsey' ),
				'label_block' => true,
				'tab'         => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'cards_enabled',
			array(
				'label'   => esc_html__( 'Enable Cards Layout', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => '',
			)
		);

		$this->add_control(
			'text_elements_position',
			array(
				'label'       => esc_html__( 'Category Position', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'category_after',
				'options'     => array(
					'category_before' => esc_html__( 'Before Heading', 'kinsey' ),
					'category_after'  => esc_html__( 'After Heading', 'kinsey' ),
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		/**
		 * Effects
		 */
		$this->start_controls_section(
			'effects_section',
			array(
				'label' => esc_html__( 'Effects', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'heading_hover_zoom',
			array(
				'label' => esc_html__( 'Hover', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);

		$this->add_control(
			'hover_zoom_enabled',
			array(
				'label'     => esc_html__( 'Enable Hover Zoom Effect', 'kinsey' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'yes',
				'separator' => 'after',
			)
		);

		$this->add_control(
			'heading_parallax',
			array(
				'label' => esc_html__( 'Parallax', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);
		$this->add_controls_parallax();

		$this->add_control(
			'effect_dynamic_color_themes_heading',
			array(
				'label'     => esc_html__( 'Cards Dynamic Color Themes', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);
		$this->add_controls_slider_dynamic_color_themes( array( 'slides_background', 'slides_elements_theme' ) );
		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Section Heading'      => array(
					'preset' => 'xl',
					'tag'    => 'h1',
				),
				'Heading'              => array(
					'preset' => 'h3',
					'tag'    => 'h2',
				),
				'Subheading'           => array(
					'preset' => 'h6',
					'tag'    => 'div',
				),
				'Categories and Years' => array(
					'preset' => 'small',
				),
				'Description'          => array(
					'preset' => 'paragraph',
					'tag'    => 'p',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Clickable Links' => array( 'scale', 'hide_native', 'label', 'icon' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings        = $this->get_settings_for_display();
		$posts           = $this->get_posts_to_display();
		$parallax_config = $this->get_parallax_config();

		if ( empty( $posts ) ) {
			return;
		}

		$active_taxonomies       = $settings['filter_enabled'] ? $this->get_taxonomies_to_display( $posts, $settings['filter_by_taxonomy'] ) : array();
		$col_desktop             = 'grid__item_desktop-' . $settings['grid_columns'];
		$col_tablet              = 'grid__item_tablet-' . $settings['grid_columns_tablet'];
		$col_mobile              = 'grid__item_mobile-' . $settings['grid_columns_mobile'];
		$filter_enabled          = $settings['filter_enabled'] && ! empty( $active_taxonomies['items'] );
		$filterable_item_prefix  = 'category-';
		$active_default_category = $this->get_default_active_filter_item();
		$counter                 = 0;

		if ( static::$_post_type === 'arts_portfolio_item' && $settings['filter_by_taxonomy'] === 'arts_portfolio_year' ) {
			$filterable_item_prefix = 'year-';
		}

		$section_attributes = array(
			'class' => array( 'section', 'section-grid' ),
		);

		$section_header_heading_attributes = array(
			'class' => array( 'my-0', $settings['typography_section_heading_preset'] ),
		);

		$section_header_col = array(
			'class' => array( $settings['section_header_mb'], $settings['section_header_alignment'] ),
		);

		$subheading_attributes = array(
			'class' => array( 'd-inline-block', $settings['typography_subheading_preset'] ),
		);

		$heading_attributes = array(
			'class' => array( 'my-0', 'underline-hover__target', $settings['typography_heading_preset'] ),
		);

		$category_attributes = array(
			'class' => array( 'figure-project__wrapper-meta', $settings['typography_categories_and_years_preset'] ),
		);

		$description_attributes = array(
			'class' => array( $settings['typography_description_preset'], 'mt-3', 'mb-0' ),
		);

		$sizer_attributes = array(
			'class' => array( 'grid__sizer', 'js-grid__sizer', $col_desktop, $col_tablet, $col_mobile ),
		);

		$filter_row_attributes = array(
			'class' => array( 'row', $settings['filter_justify_items'], 'gx-3' ),
		);

		$filter_col_attributes = array(
			'class' => array( $settings['filter_mb'] ),
		);

		$grid_attributes = array(
			'class' => array( 'grid', 'js-grid' ),
		);

		$filter_attributes = array(
			'class' => array( 'filter', 'js-filter' ),
		);

		$filter_inner_attributes = array(
			'class' => array( 'filter__inner' ),
		);

		$filter_wrapper_dropdown_attributes = array(
			'class' => array( 'filter__wrapper-dropdown', 'd-lg-none' ),
		);

		$item_card_attributes = array(
			'class'                 => array( 'card-portfolio' ),
			'data-arts-hover-class' => 'hover-zoom-underline',
		);

		if ( $settings['section_header_layout'] === 'heading_above' ) {
			$section_header_col['class'][]    = 'col-lg-12';
			$filter_col_attributes['class'][] = 'col-lg-12';
		} else {
			$section_header_col['class'][]    = 'col-lg-6';
			$filter_col_attributes['class'][] = 'col-lg-6';
		}

		if ( $settings['filter_mobile_style'] === 'dropdown' ) {
			$filter_inner_attributes['class'][] = 'd-lg-block';
			$filter_inner_attributes['class'][] = 'd-none';
		}

		if ( $settings['filter_justify_items'] === 'justify-content-between' && $settings['section_header_alignment'] === 'text-center' ) {
			$filter_row_attributes['class'][] = 'text-center';
		}

		if ( $settings['grid_fancy_enabled'] && $settings['grid_columns'] !== '12' ) {
			$grid_attributes['class'][] = 'grid_fancy';
		}

		if ( $settings['grid_equal_columns_height_enabled'] ) {
			$grid_attributes['class'][] = 'js-grid-equal-heights';
		}

		if ( $settings['text_elements_position'] === 'category_before' ) {
			$category_attributes['class'][] = 'mb-2';
		}

		if ( $settings['text_elements_position'] === 'category_after' ) {
			$category_attributes['class'][] = 'mt-1';
		}

		if ( $settings['animation_enabled'] ) {
			$section_header_heading_attributes = $this->get_split_text_attributes(
				$section_header_heading_attributes,
				array(
					'by'        => 'lines,words,chars',
					'set'       => 'chars',
					'overflow'  => 'lines',
					'animation' => array(
						'stagger' => array(
							'amount' => 0.3,
							'from'   => 'left',
						),
					),
				)
			);

			$subheading_attributes = $this->get_split_text_attributes(
				$subheading_attributes,
				array(
					'by'        => 'lines, words',
					'set'       => 'words',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);

			$heading_attributes = $this->get_split_text_attributes(
				$heading_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);

			$category_attributes = $this->get_split_text_attributes(
				$category_attributes,
				array(
					'by'        => 'lines, words',
					'set'       => 'words',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);

			$description_attributes = $this->get_split_text_attributes(
				$description_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);

			$item_card_attributes = $this->get_animation_attributes(
				$item_card_attributes,
				'animateJump',
				array(
					'y'      => '50%',
					'scaleY' => 1.5,
				)
			);

			$filter_attributes = $this->get_animation_attributes( $filter_attributes, 'animateText' );
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'section_header_heading', $section_header_heading_attributes );
		$this->add_render_attribute( 'section_header_col', $section_header_col );
		$this->add_render_attribute( 'filter', $filter_attributes );
		$this->add_render_attribute( 'grid', $grid_attributes );
		$this->add_render_attribute( 'subheading', $subheading_attributes );
		$this->add_render_attribute( 'heading', $heading_attributes );
		$this->add_render_attribute( 'description', $description_attributes );
		$this->add_render_attribute( 'category', $category_attributes );
		$this->add_render_attribute( 'sizer', $sizer_attributes );
		$this->add_render_attribute( 'filter_row', $filter_row_attributes );
		$this->add_render_attribute( 'filter_col', $filter_col_attributes );
		$this->add_render_attribute( 'filter_inner', $filter_inner_attributes );
		$this->add_render_attribute( 'filter_wrapper_dropdown', $filter_wrapper_dropdown_attributes );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<?php if ( ! empty( $settings['section_header_heading'] ) || $filter_enabled ) : ?>
				<div class="row align-items-center position-relative z-50">
					<?php if ( ! empty( $settings['section_header_heading'] ) ) : ?>
						<div <?php $this->print_render_attribute_string( 'section_header_col' ); ?>>
							<<?php $this->print_html_tag( 'typography_section_heading_tag' ); ?> <?php $this->print_render_attribute_string( 'section_header_heading' ); ?>><?php echo esc_html( $settings['section_header_heading'] ); ?></<?php $this->print_html_tag( 'typography_section_heading_tag' ); ?>>
						</div>
					<?php endif; ?>
					<?php if ( $filter_enabled ) : ?>
						<div <?php $this->print_render_attribute_string( 'filter_col' ); ?>>
							<div <?php $this->print_render_attribute_string( 'filter' ); ?>>
								<?php if ( $settings['filter_mobile_style'] === 'dropdown' ) : ?>
									<div <?php $this->print_render_attribute_string( 'filter_wrapper_dropdown' ); ?>>
										<select class="js-filter__select d-block w-100">
											<?php if ( ! empty( $settings['filter_all_label'] ) ) : ?>
												<?php
													$filter_all_name                  = $settings['filter_all_label'];
													$filter_all_first_item_attributes = array(
														'value' => '*',
													);

													if ( $settings['filter_amounts_enabled'] && ! empty( $settings['filter_all_counter_label'] ) ) {
														$filter_all_name .= " [{$settings['filter_all_counter_label']}]";
													}
													if ( ! $active_default_category ) {
														$filter_all_first_item_attributes['selected'] = 'selected';
													}

													$this->add_render_attribute( 'filter_all_first_item', $filter_all_first_item_attributes );
													?>
												<option <?php $this->print_render_attribute_string( 'filter_all_first_item' ); ?>><?php echo esc_html( $filter_all_name ); ?></option>
											<?php endif; ?>
											<?php foreach ( $active_taxonomies['items'] as $index => $item ) : ?>
												<?php
													$this->remove_render_attribute( 'filter_item_option' );

													$filter_item_slug              = $item['slug'];
													$filter_item_name              = $item['name'];
													$amount                        = $active_taxonomies['amounts'][ $filter_item_slug ];
													$filter_item_option_attributes = array(
														'value' => '.' . $filterable_item_prefix . $filter_item_slug,
													);

													if ( $settings['filter_amounts_enabled'] ) {
														$filter_item_name .= " [{$amount}]";
													}

													if ( $active_default_category && $active_default_category === $item['slug'] ) {
														$filter_item_option_attributes['selected'] = 'selected';
													}

													$this->add_render_attribute( 'filter_item_option', $filter_item_option_attributes );
													?>
												<option <?php $this->print_render_attribute_string( 'filter_item_option' ); ?>><?php echo esc_html( $filter_item_name ); ?></option>
											<?php endforeach; ?>
										</select>
									</div>
								<?php endif; ?>
								<div <?php $this->print_render_attribute_string( 'filter_inner' ); ?>>
									<div class="container-fluid no-gutters">
										<div <?php $this->print_render_attribute_string( 'filter_row' ); ?>>
											<?php if ( ! empty( $settings['filter_all_label'] ) ) : ?>
												<?php
													$filter_all_attributes       = array(
														'class' => array( 'col-lg-auto', 'col-12', 'filter__item', 'js-filter__item', 'js-arts-cursor-highlight' ),
														'data-filter' => '*',
													);
													$filter_all_inner_attributes = array(
														'class' => array( 'filter__item-inner', 'h6', 'block-counter' ),
														'data-filter' => '*',
													);

													if ( $settings['animation_enabled'] ) {
														$filter_all_inner_attributes = $this->get_split_text_attributes(
															$filter_all_inner_attributes,
															array(
																'by'        => 'lines, words',
																'set'       => 'words',
																'overflow'  => 'lines',
																'animation' => false,
															)
														);
													}

													if ( ! $active_default_category ) {
														$filter_all_attributes['class'][] = 'filter__item_active';
													}

													$this->add_render_attribute( 'filter_all', $filter_all_attributes, true, true );
													$this->add_render_attribute( 'filter_all_inner', $filter_all_inner_attributes, true, true );
													?>
												<!-- all (*) -->
												<div <?php $this->print_render_attribute_string( 'filter_all' ); ?>>
													<div <?php $this->print_render_attribute_string( 'filter_all_inner' ); ?>>
														<span class="filter__item-label"><?php echo esc_html( $settings['filter_all_label'] ); ?></span>
														<?php if ( $settings['filter_amounts_enabled'] && ! empty( $settings['filter_all_counter_label'] ) ) : ?>
															<span class="block-counter__counter"><?php echo esc_html( $settings['filter_all_counter_label'] ); ?></span>
														<?php endif; ?>
													</div>
												</div>
												<!-- - all (*) -->
											<?php endif; ?>
											<?php foreach ( $active_taxonomies['items'] as $index => $item ) : ?>
												<?php
													$this->remove_render_attribute( 'filter_item' );

													$filter_item_slug       = $item['slug'];
													$filter_item_attributes = array(
														'class' => array( 'col-lg-auto', 'col-12', 'filter__item', 'js-filter__item', 'js-arts-cursor-highlight' ),
														'data-filter' => '.' . $filterable_item_prefix . $filter_item_slug,
													);

													$filter_item_inner_attributes = array(
														'class' => array( 'filter__item-inner', 'h6', 'block-counter' ),
													);

													$amount = $active_taxonomies['amounts'][ $filter_item_slug ];

													if ( $settings['animation_enabled'] ) {
														$filter_item_inner_attributes = $this->get_split_text_attributes(
															$filter_item_inner_attributes,
															array(
																'by'        => 'lines, words',
																'set'       => 'words',
																'overflow'  => 'lines',
																'animation' => false,
															)
														);
													}

													if ( $active_default_category && $active_default_category === $item['slug'] ) {
														$filter_item_attributes['class'][] = 'filter__item_active';
													}

													if ( ! $active_default_category && empty( $settings['filter_all_label'] ) && $counter === 0 ) {
														$filter_item_attributes['class'][] = 'filter__item_active';
													}

													$counter++;

													$this->add_render_attribute( 'filter_item', $filter_item_attributes, true, true );
													$this->add_render_attribute( 'filter_item_inner', $filter_item_inner_attributes, true, true );
													?>
												<div <?php $this->print_render_attribute_string( 'filter_item' ); ?>>
													<div <?php $this->print_render_attribute_string( 'filter_item_inner' ); ?>>
														<span class="filter__item-label"><?php echo esc_html( $item['name'] ); ?></span>
														<?php if ( $settings['filter_amounts_enabled'] ) : ?>
															<span class="block-counter__counter"><?php echo esc_html( $amount ); ?></span>
														<?php endif; ?>
													</div>
												</div>
											<?php endforeach; ?>
											<!-- - items -->
										</div>
										<!-- underline -->
										<div class="filter__underline js-filter__underline" data-arts-os-animation="true" data-arts-os-animation-name="animateHeadline" data-arts-os-animation-params="{transformOrigin: 'left center'}"></div>
										<!-- - underline -->
									</div>
								</div>
							</div>
						</div>
					<?php endif; ?>
				</div>
			<?php endif; ?>
			<div <?php $this->print_render_attribute_string( 'grid' ); ?>>
				<!-- sizer -->
				<div <?php $this->print_render_attribute_string( 'sizer' ); ?>></div>
				<?php foreach ( $posts as $index => $post ) : ?>
					<?php
						$thumbnail_args = array(
							'id'       => $post['image_id'],
							'video'    => array(
								'src'        => $post['video_url'],
								'attributes' => array(
									'autoplay' => true,
								),
							),
							'size'     => $this->get_thumbnail_size( $post['image_id'] ),
							'type'     => $settings['cards_enabled'] ? 'background' : 'image_limited',
							'image'    => array(
								'class' => array( 'va-middle' ),
							),
							'outer'    => array(
								'class' => array(),
							),
							'parallax' => $parallax_config,
						);

						if ( $settings['hover_zoom_enabled'] ) {
							$thumbnail_args['image']['class'][] = 'hover-zoom__zoom';
							$thumbnail_args['outer']['class'][] = 'hover-zoom__inner';
						}

						$item_attributes = array(
							'class' => array( 'grid__item', 'js-grid__item', $col_desktop, $col_tablet, $col_mobile ),
						);

						$image_link_attributes = array(
							'class'           => array( 'figure-project__wrapper-img' ),
							'href'            => $post['permalink'],
							'data-arts-hover' => 'trigger',
						);

						$content_attributes = array(
							'class' => array( 'figure-project__content', 'pt-4' ),
						);

						$heading_link_attributes = array(
							'class'           => array( 'd-inline-block', 'va-middle' ),
							'href'            => $post['permalink'],
							'data-arts-hover' => 'trigger',
						);

						if ( $settings['cards_enabled'] ) {
							$thumbnail_args['image']['class'][] = 'of-cover';
							$thumbnail_args['image']['class'][] = 'lazy-bg';
							$heading_link_attributes['class'][] = 'my-auto';
							$image_link_attributes['class'][]   = 'overflow';
						}

						if ( $settings['animation_enabled'] ) {
							$image_link_attributes = $this->get_animation_attributes( $image_link_attributes, 'animateMask' );
							$content_attributes    = $this->get_animation_attributes( $content_attributes, 'animateText' );
						}

						if ( $settings['animation_enabled'] && ! $settings['cards_enabled'] ) {
							$thumbnail_args['animations']['animateMask'] = $this->get_animation_mask_config();
						}

						if ( $settings['cursor_clickable_links_enabled'] ) {
							$image_link_attributes   = $this->add_cursor_attributes( $image_link_attributes, 'Clickable Links' );
							$heading_link_attributes = $this->add_cursor_attributes( $heading_link_attributes, 'Clickable Links' );
						}

						if ( static::$_post_type === 'arts_portfolio_item' && $settings['filter_by_taxonomy'] === 'arts_portfolio_year' ) {
							if ( array_key_exists( 'years_slugs', $post ) && is_array( $post['years_slugs'] ) && ! empty( $post['years_slugs'] ) ) {
								foreach ( $post['years_slugs'] as $slug ) {
									$item_attributes['class'][] = $filterable_item_prefix . $slug;
								}
							}
						} elseif ( array_key_exists( 'categories_slugs', $post ) && is_array( $post['categories_slugs'] ) ) {
							foreach ( $post['categories_slugs'] as $slug ) {
								$item_attributes['class'][] = $filterable_item_prefix . $slug;
							}
						}

						$this->add_render_attribute( 'image_link', $image_link_attributes, true, true );
						$this->add_render_attribute( 'heading_link', $heading_link_attributes, true, true );
						$this->add_render_attribute( 'content', $content_attributes, true, true );
						$this->add_render_attribute( 'item', $item_attributes, true, true );

						?>
					<div <?php $this->print_render_attribute_string( 'item' ); ?>>
						<?php if ( $settings['grid_equal_columns_height_enabled'] ) : ?>
							<div class="d-flex align-items-center w-100 h-100">
						<?php endif; ?>
						<?php if ( $settings['cards_enabled'] ) : ?>
							<?php

							$item_card_current = $item_card_attributes;
							$background_color  = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_background', null, '#f8f8f8', $post );

							$button_args = array(
								'attributes' => array(
									'href'            => $post['permalink'],
									'class'           => array( 'button', 'p-0' ),
									'data-arts-hover' => 'trigger',
								),
								'icon'       => array(
									'after' => 'knz-arrow-right-long',
								),
							);

							if ( $settings['cursor_clickable_links_enabled'] ) {
								$button_args['attributes'] = $this->add_cursor_attributes( $button_args['attributes'], 'Clickable Links' );
							}

							$item_card_current['style']                = "background-color: {$background_color};";
							$item_card_current['data-arts-theme-text'] = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_elements_theme', null, 'dark', $post );

							$this->add_render_attribute( 'item_card', $item_card_current, true, true );
							?>
							<div <?php $this->print_render_attribute_string( 'item_card' ); ?>>
								<div class="row g-0">
									<div class="col-lg-8 order-lg-2">
										<a <?php $this->print_render_attribute_string( 'image_link' ); ?>>
											<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
										</a>
									</div>
									<div class="col-lg-4 order-lg-1">
										<div class="card-portfolio__content p-xsmall" data-arts-os-animation="true" data-arts-os-animation-name="animateText">
											<div class="card-portfolio__wrapper-meta mb-3 arts-split-text js-arts-split-text" data-arts-split-text="lines,words" data-arts-split-text-set="words" data-arts-split-text-overflow-wrap="lines">
												<?php $this->print_post_categories( $post ); ?>
											</div>
											<a <?php $this->print_render_attribute_string( 'heading_link' ); ?>>
												<<?php $this->print_html_tag( 'typography_heading_tag' ); ?> <?php $this->print_render_attribute_string( 'heading' ); ?>><?php echo esc_html( $post['title'] ); ?></<?php $this->print_html_tag( 'typography_heading_tag' ); ?>>
											</a>
											<div class="card-portfolio__wrapper-button mt-3">
												<?php get_template_part( 'template-parts/button/button', 'normal', $button_args ); ?>
											</div>
										</div>
									</div>
								</div>
							</div>
						<?php else : ?>
							<div class="figure-project" data-arts-hover-class="hover-zoom-underline">
								<a <?php $this->print_render_attribute_string( 'image_link' ); ?>>
									<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
								</a>
								<div <?php $this->print_render_attribute_string( 'content' ); ?>>
									<?php if ( $settings['subheading_enabled'] && ! empty( $post['subheading'] ) ) : ?>
										<<?php $this->print_html_tag( 'typography_subheading_tag' ); ?> <?php $this->print_render_attribute_string( 'subheading' ); ?>><?php echo $post['subheading']; ?></<?php $this->print_html_tag( 'typography_subheading_tag' ); ?>>
										<div class="w-100"></div>
									<?php endif; ?>
									<?php if ( $settings['text_elements_position'] === 'category_before' ) : ?>
										<?php $this->print_post_categories( $post ); ?>
										<div class="w-100"></div>
									<?php endif; ?>
									<a <?php $this->print_render_attribute_string( 'heading_link' ); ?>>
										<<?php $this->print_html_tag( 'typography_heading_tag' ); ?> <?php $this->print_render_attribute_string( 'heading' ); ?>><?php echo esc_html( $post['title'] ); ?></<?php $this->print_html_tag( 'typography_heading_tag' ); ?>>
									</a>
									<?php if ( $settings['text_elements_position'] === 'category_after' ) : ?>
										<div class="w-100"></div>
										<?php $this->print_post_categories( $post ); ?>
									<?php endif; ?>
									<?php if ( $settings['description_enabled'] && ! empty( $post['description'] ) ) : ?>
										<div class="w-100"></div>
										<<?php $this->print_html_tag( 'typography_description_tag' ); ?> <?php $this->print_render_attribute_string( 'description' ); ?>><?php echo $post['description']; ?></<?php $this->print_html_tag( 'typography_description_tag' ); ?>>
									<?php endif; ?>
								</div>
							</div>
						<?php endif; ?>
						<?php if ( $settings['grid_equal_columns_height_enabled'] ) : ?>
							</div>
						<?php endif; ?>
					</div>
				<?php endforeach; ?>
			</div>
		</div>

		<?php
	}
}
