<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/dynamic/kinsey-widget-trait-dynamic-helpers.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-controls.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-helpers.php';

class Kinsey_Widget_Portfolio_Slider_Cards_Backgrounds extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Dynamic_Helpers;
	use Kinsey_Widget_Trait_Slider_Controls;
	use Kinsey_Widget_Trait_Slider_Helpers;

	protected static $_instance, $_posts;
	protected static $_post_type          = 'arts_portfolio_item';
	protected static $_data_static_fields = array(
		'title',
		'subheading',
		'permalink',
		'description',
		'image_id',
		'video_url',
		'dynamic_color_themes' => array(
			'slides_background',
			'slides_elements_theme',
			'header_elements_theme',
			'header_logo',
			'sidebar_background',
		),
	);

	public function get_name() {
		return 'kinsey-widget-portfolio-slider-cards-backgrounds';
	}

	public function get_title() {
		return esc_html__( 'Portfolio Slider Cards Backgrounds', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-sitemap icon-kinsey-widget-dynamic';
	}

	public function get_categories() {
		return array( 'kinsey-dynamic' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions'        => array( 'widgetType' => $name ),
			'fields'            => array(
				array(
					'field'       => 'section_header_heading',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Section Header: Heading', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'mouse_drag_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Mouse: Cursor Drag Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'cursor_clickable_links_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Cursor: Clickable Links Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
			'integration-class' => 'WPML_Elementor_Kinsey_Widget_Portfolio_Slider_Cards_Backgrounds',
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {

		/**
		 * Section Header
		 */
		$this->start_controls_section(
			'header_section',
			array(
				'label' => esc_html__( 'Section Header', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'section_header_heading',
			array(
				'label'   => esc_html__( 'Heading', 'kinsey' ),
				'type'    => Controls_Manager::TEXT,
				'dynamic' => array(
					'active' => true,
				),
				'default' => esc_html__( 'Portfolio', 'kinsey' ),
			)
		);

		$this->add_control(
			'section_header_indicator_enabled',
			array(
				'label'       => esc_html__( 'Enable Indicator on Slider Progress', 'kinsey' ),
				'description' => esc_html__( 'A small backup heading that appears in the bottom right corner (desktop only).', 'kinsey' ),
				'type'        => Controls_Manager::SWITCHER,
				'default'     => 'yes',
				'condition'   => array(
					'section_header_heading!' => '',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Posts Toggles and Posts Amount Control
		 */
		$this->add_controls_posts_toggles();

		/**
		 * Content Elements to Show
		 */
		$this->start_controls_section(
			'elements_section',
			array(
				'label' => esc_html__( 'Elements', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_elements_appearance( array( 'subheading', 'categories_years', 'description' ) );
		$this->end_controls_section();

		/**
		 * Slider Options
		 */
		$this->start_controls_section(
			'slider_section',
			array(
				'label' => esc_html__( 'Slider', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_options( array( 'speed', 'autoplay' ) );

		$this->add_responsive_control(
			'space_between',
			array(
				'label'           => esc_html__( 'Space Between Slides', 'kinsey' ),
				'type'            => Controls_Manager::SLIDER,
				'range'           => array(
					'px' => array(
						'min'  => 0,
						'max'  => 160,
						'step' => 1,
					),
				),
				'devices'         => array( 'desktop', 'tablet', 'mobile' ),
				'desktop_default' => array(
					'size' => 60,
					'unit' => 'px',
				),
				'tablet_default'  => array(
					'size' => 30,
					'unit' => 'px',
				),
				'mobile_default'  => array(
					'size' => 0,
					'unit' => 'px',
				),
			)
		);

		$this->add_responsive_control(
			'slides_per_view',
			array(
				'label'           => esc_html__( 'Slides Per Screen', 'kinsey' ),
				'type'            => Controls_Manager::SLIDER,
				'range'           => array(
					'number' => array(
						'min'  => 1,
						'max'  => 4,
						'step' => 1,
					),
				),
				'devices'         => array( 'desktop', 'tablet', 'mobile' ),
				'desktop_default' => array(
					'size' => 2.25,
					'unit' => 'number',
				),
				'tablet_default'  => array(
					'size' => 2.0,
					'unit' => 'number',
				),
				'mobile_default'  => array(
					'size' => 1.25,
					'unit' => 'number',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Slider Controls
		 */
		$this->start_controls_section(
			'controls_section',
			array(
				'label' => esc_html__( 'Controls', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_controls( array( 'arrows', 'progress' ) );
		$this->end_controls_section();

		/**
		 * Slider Interaction Options
		 */
		$this->start_controls_section(
			'interaction_section',
			array(
				'label' => esc_html__( 'Interaction', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_interaction( array( 'clickability', 'mouse', 'keyboard', 'drag' ) );
		$this->end_controls_section();

		/**
		 * Layout Options
		 */
		$this->start_controls_section(
			'layout_section',
			array(
				'label'       => esc_html__( 'Layout', 'kinsey' ),
				'label_block' => true,
				'tab'         => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'layout_fullscreen_enabled',
			array(
				'label'   => esc_html__( 'Enable Fullscreen Layout', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'section_heading_position',
			array(
				'label'       => esc_html__( 'Section Heading Position', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'vertical_center',
				'options'     => array(
					'vertical_center' => esc_html__( 'Vertical Center', 'kinsey' ),
					'before_slider'   => esc_html__( 'Before Slider', 'kinsey' ),
				),
			)
		);

		$this->add_control(
			'text_elements_position',
			array(
				'label'       => esc_html__( 'Category Position', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'category_before',
				'options'     => array(
					'category_before' => esc_html__( 'Before Heading', 'kinsey' ),
					'category_after'  => esc_html__( 'After Heading', 'kinsey' ),
				),
			)
		);

		$this->add_control(
			'slides_alignment',
			array(
				'label'       => esc_html__( 'Slides Alignment', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'text-start',
				'options'     => array(
					'text-start'  => esc_html__( 'Left', 'kinsey' ),
					'text-center' => esc_html__( 'Center', 'kinsey' ),
				),
			)
		);

		$this->add_control(
			'slides_padding_top',
			array(
				'label'       => esc_html__( 'Slides Padding Top', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'pt-large',
				'options'     => ARTS_THEME_DISTANCE_ARRAY['padding']['top'],
			)
		);

		$this->add_control(
			'slides_padding_bottom',
			array(
				'label'       => esc_html__( 'Slides Padding Bottom', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'pb-medium',
				'options'     => ARTS_THEME_DISTANCE_ARRAY['padding']['bottom'],
			)
		);

		$this->add_control(
			'header_padding_top',
			array(
				'label'       => esc_html__( 'Header Padding Top', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'pt-large',
				'options'     => ARTS_THEME_DISTANCE_ARRAY['padding']['top'],
				'condition'   => array(
					'section_heading_position' => 'before_slider',
				),
			)
		);

		$this->add_control(
			'header_padding_bottom',
			array(
				'label'       => esc_html__( 'Header Padding Bottom', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'pb-small',
				'options'     => ARTS_THEME_DISTANCE_ARRAY['padding']['bottom'],
				'condition'   => array(
					'section_heading_position' => 'before_slider',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		/**
		 * Effects
		 */
		$this->start_controls_section(
			'effects_section',
			array(
				'label' => esc_html__( 'Effects', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'effect_dynamic_color_themes_heading',
			array(
				'label' => esc_html__( 'Slides Dynamic Color Themes', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);
		$this->add_controls_slider_dynamic_color_themes(
			array(
				'slides_background',
				'slides_elements_theme',
				'header_elements_theme',
				'header_logo',
			)
		);

		$this->add_control(
			'effect_parallax_heading',
			array(
				'label'     => esc_html__( 'Parallax Images', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);
		$this->add_controls_slider_effect_parallax();

		$this->end_controls_section();

		/**
		 * AJAX Transition
		 */
		$this->start_controls_section(
			'ajax_section',
			array(
				'label' => esc_html__( 'AJAX Transition', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_ajax_transition( array( 'prefetch' ) );
		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Section Heading'           => array(
					'preset' => 'h1',
					'tag'    => 'h1',
				),
				'Section Heading Indicator' => array(
					'preset' => 'h6',
				),
				'Heading'                   => array(
					'preset' => 'h3',
					'tag'    => 'h2',
				),
				'Subheading'                => array(
					'preset' => 'h6',
					'tag'    => 'div',
				),
				'Categories and Years'      => array(
					'preset' => 'small',
				),
				'Description'               => array(
					'preset' => 'paragraph',
					'tag'    => 'p',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Clickable Links'    => array( 'scale', 'hide_native', 'label', 'icon' ),
				'Prev & Next Arrows' => array( 'scale', 'hide_native', 'magnetic' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$posts    = $this->get_posts_to_display();

		if ( empty( $posts ) ) {
			return;
		}

		$first_post                  = reset( $posts );
		$first_post_background_color = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_background', null, '#f8f8f8', $first_post );

		$section_attributes = array(
			'class' => array( 'section', 'section-slider-projects', 'js-slider-projects' ),
		);

		if ( $settings['section_heading_position'] === 'vertical_center' ) {
			$arrows_attributes = array(
				'class' => array( 'slider__wrapper-arrows', 'slider-projects__arrows' ),
			);

			$section_header_attributes = array(
				'class' => array( 'section-fullheight__header', 'container-fluid', 'pt-xlarge', 'section-slider-projects__header' ),
			);
		} else {
			$arrows_attributes = array(
				'class' => array( 'slider__wrapper-arrows', 'd-inline-flex', 'mt-3' ),
			);

			$section_header_attributes = array(
				'class' => array( 'container', 'section-slider-projects__header', $settings['header_padding_top'], $settings['header_padding_bottom'], 'd-flex', 'justify-content-between', 'flex-wrap' ),
			);
		}

		$section_header_heading_attributes = array(
			'class' => array( 'section__heading', 'my-0', $settings['typography_section_heading_preset'] ),
		);

		$section_header_heading_attributes = $this->get_split_text_attributes(
			$section_header_heading_attributes,
			array(
				'by'        => 'lines',
				'set'       => false,
				'direction' => false,
				'distance'  => false,
				'overflow'  => 'lines',
				'animation' => false,
			)
		);

		$swiper_attributes = array(
			'class'                        => array( 'slider', 'slider-projects', 'swiper', 'swiper-container', 'js-slider-projects__slider' ),
			'data-centered-slides'         => 'true',
			'data-slides-per-view'         => $settings['slides_per_view']['size'],
			'data-slides-per-view-tablet'  => $settings['slides_per_view_tablet']['size'],
			'data-slides-per-view-mobile ' => $settings['slides_per_view_mobile']['size'],
			'data-space-between'           => $settings['space_between']['size'],
			'data-space-between-tablet'    => $settings['space_between_tablet']['size'],
			'data-space-between-mobile'    => $settings['space_between_mobile']['size'],
		);

		$swiper_attributes = $this->add_swiper_images_attributes( $swiper_attributes );

		$arrows_args = array(
			'type' => 'horizontal',
		);

		$progress_bar_attributes = array(
			'class' => array( 'slider__scrollbar', 'slider__scrollbar_horizontal', 'slider-projects__scrollbar', 'js-slider-projects__scrollbar', 'small' ),
		);

		$progress_bar_wrapper_attributes = array(
			'class' => array( 'slider-projects__wrapper_bottom-center' ),
		);

		$category_attributes = array(
			'class' => array( 'd-inline-block', 'slider__subheading', $settings['typography_categories_and_years_preset'] ),
		);

		$heading_attributes = array(
			'class' => array( 'slider__heading', $settings['typography_heading_preset'], 'my-0' ),
		);

		$subheading_attributes = array(
			'class' => array( 'd-inline-block', 'slider__subheading', 'mb-2', $settings['typography_subheading_preset'] ),
		);

		$description_attributes = array(
			'class' => array( 'slider__text', $settings['typography_description_preset'], 'my-3' ),
		);

		$indicator_attributes = array(
			'class' => array( 'slider-projects__indicator', 'js-slider-projects__indicator', $settings['typography_section_heading_indicator_preset'] ),
		);

		$indicator_wrapper_attributes = array(
			'class' => array( 'slider-projects__wrapper_bottom-right', 'text-end', 'overflow', 'd-none', 'd-lg-block' ),
		);

		if ( $settings['text_elements_position'] === 'category_before' ) {
			$category_attributes['class'][] = 'mb-3';
		}

		if ( $settings['text_elements_position'] === 'category_after' ) {
			$category_attributes['class'][] = 'mt-2';
		}

		if ( $settings['section_header_indicator_enabled'] ) {
			$section_header_attributes['class'][]         = 'js-slider-projects__header';
			$section_header_heading_attributes['class'][] = 'js-slider-projects__source-indicator';
		}

		if ( $settings['layout_fullscreen_enabled'] ) {
			$section_attributes['class'][] = 'section-fullheight';
		}

		if ( $settings['progress_bar_enabled'] ) {

			if ( $settings['progress_bar_style'] === 'long' ) {
				$progress_bar_attributes['class'][] = 'slider__scrollbar_horizontal_long';
			}

			if ( $settings['progress_bar_slides_numbers_enabled'] ) {
				$progress_bar_attributes['class'][] = 'slider__scrollbar_counter';
			}
		}

		if ( $settings['cursor_prev___next_arrows_enabled'] ) {
			$arrows_args['cursor_attributes'] = $this->add_cursor_attributes( array(), 'Prev & Next Arrows' );
		}

		if ( $settings['dynamic_color_themes_enabled'] ) {
			$section_attributes['data-arts-theme-text'] = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_elements_theme', null, 'dark', $first_post );

			$section_attributes['class'][] = 'section-dynamic-background';
			$section_attributes['class'][] = 'js-slider-background';
			$section_attributes['style']   = "background-color: {$first_post_background_color}";
		}

		if ( $settings['animation_enabled'] ) {
			$progress_bar_wrapper_attributes = $this->get_animation_attributes(
				$progress_bar_wrapper_attributes,
				'animateJump',
				array(
					'x' => '0',
					'y' => '30',
				)
			);

			$arrows_attributes = $this->get_animation_attributes(
				$arrows_attributes,
				'animateJump',
				array(
					'x' => '0',
					'y' => '30',
				)
			);

			$indicator_wrapper_attributes = $this->get_animation_attributes(
				$indicator_wrapper_attributes,
				'animateJump',
				array(
					'x' => '0',
					'y' => '30',
				)
			);

			$section_header_attributes = $this->get_animation_attributes( $section_header_attributes, 'animateText' );

			$section_header_heading_attributes = $this->get_split_text_attributes(
				$section_header_heading_attributes,
				array(
					'set'       => 'lines',
					'direction' => 'y',
					'distance'  => $settings['section_header_indicator_enabled'] ? '-100%' : '100%',
					'animation' => false,
				)
			);
		}

		if ( $settings['headings_clickable_enabled'] ) {
			$heading_attributes['class'][] = 'underline-hover__target';
		}

		if ( $settings['ajax_prefetch_active_slide_enabled'] ) {
			$swiper_attributes['data-prefetch-active-slide-transition'] = 'true';
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'section_header', $section_header_attributes );
		$this->add_render_attribute( 'section_header_heading', $section_header_heading_attributes );
		$this->add_render_attribute( 'swiper', $swiper_attributes );
		$this->add_render_attribute( 'progress_bar_wrapper', $progress_bar_wrapper_attributes );
		$this->add_render_attribute( 'progress_bar', $progress_bar_attributes );
		$this->add_render_attribute( 'arrows', $arrows_attributes );
		$this->add_render_attribute( 'indicator', $indicator_attributes );
		$this->add_render_attribute( 'indicator_wrapper', $indicator_wrapper_attributes );

		$this->add_render_attribute( 'subheading', $subheading_attributes );
		$this->add_render_attribute( 'category', $category_attributes );
		$this->add_render_attribute( 'heading', $heading_attributes );
		$this->add_render_attribute( 'description', $description_attributes );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<?php if ( $settings['layout_fullscreen_enabled'] ) : ?>
				<div class="section-fullheight__inner section-fullheight__inner_mobile">
			<?php endif; ?>
				<?php if ( ! empty( $settings['section_header_heading'] ) ) : ?>
					<div <?php $this->print_render_attribute_string( 'section_header' ); ?>>
						<<?php $this->print_html_tag( 'typography_section_heading_tag' ); ?> <?php $this->print_render_attribute_string( 'section_header_heading' ); ?>><?php echo esc_html( $settings['section_header_heading'] ); ?></<?php $this->print_html_tag( 'typography_section_heading_tag' ); ?>>
						<?php if ( $settings['arrows_enabled'] && $settings['section_heading_position'] === 'before_slider' ) : ?>
							<!-- slider ARROWS -->
							<div <?php $this->print_render_attribute_string( 'arrows' ); ?>>
								<?php get_template_part( 'template-parts/slider/slider', 'arrows', $arrows_args ); ?>
							</div>
							<!-- - slider ARROWS -->
						<?php endif; ?>
					</div>
				<?php endif; ?>
				<div <?php $this->print_render_attribute_string( 'swiper' ); ?>>
					<div class="swiper-wrapper">
						<?php foreach ( $posts as $post ) : ?>
							<?php
								$thumbnail_args = array(
									'id'           => $post['image_id'],
									'video'        => array(
										'src'        => $post['video_url'],
										'attributes' => array(
											'autoplay' => true,
										),
									),
									'lazy_wrapper' => false,
									'size'         => $this->get_thumbnail_size( $post['image_id'] ),
									'type'         => 'image_limited',
									'image'        => array(
										'class' => array( 'swiper-lazy', 'hover-zoom__zoom', 'm-auto' ),
									),
									'outer'        => array(
										'class' => array( 'hover-zoom__inner' ),
									),
									'inner'        => array(
										'class' => array( 'd-flex', 'overflow', 'w-100', 'h-100' ),
									),
								);

								$slide_attributes = array(
									'class' => array( 'swiper-slide', 'slider-projects__slide', 'd-flex-centered', 'flex-column', 'overflow-initial', $settings['slides_padding_top'], $settings['slides_padding_bottom'] ),
									'data-arts-hover-class' => 'hover-zoom-underline',
								);

								$slide_wrapper_attributes = array(
									'class' => array( 'w-100', 'h-100', 'd-flex', 'flex-column', 'justify-content-center' ),
									'data-swiper-parallax-opacity' => '0.1',
								);

								$slide_header_attributes = array(
									'class' => array( 'slider-projects__header', $settings['slides_alignment'] ),
								);

								if ( $settings['slides_alignment'] === 'text-center' ) {
									$slide_wrapper_attributes['class'][] = 'align-items-center';
								}

								if ( $settings['parallax_enabled'] ) {
									$thumbnail_args['inner']['data-swiper-parallax-x'] = "{$settings['parallax_effect_offset']['size']}%";
								}

								if ( $settings['dynamic_color_themes_enabled'] ) {
									$slide_attributes['data-slide-background']   = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_background', null, '#f8f8f8', $post );
									$slide_attributes['data-slide-theme']        = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_elements_theme', null, 'dark', $post );
									$slide_attributes['data-slide-header-theme'] = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_header_main_theme', 'page_header_settings_overridden', 'dark', $post );
									$slide_attributes['data-slide-header-logo']  = $this->get_static_dynamic_slide_theme( 'dynamic_color_themes_slides_header_main_logo', 'page_header_settings_overridden', 'primary', $post );
								}

								if ( $settings['animation_enabled'] ) {
									$thumbnail_args['animations']['animateMask'] = $this->get_animation_mask_config();

									$slide_header_attributes = $this->get_animation_attributes(
										$slide_header_attributes,
										'animateJump',
										array(
											'y' => 50,
										)
									);
								}

								$this->add_render_attribute( 'slide', $slide_attributes, true, true );
								$this->add_render_attribute( 'slide_wrapper', $slide_wrapper_attributes, true, true );
								$this->add_render_attribute( 'slide_header', $slide_header_attributes, true, true );
								?>
							<!-- thumb -->
							<div <?php $this->print_render_attribute_string( 'slide' ); ?>>
								<div <?php $this->print_render_attribute_string( 'slide_wrapper' ); ?>>
									<?php if ( $settings['images_clickable_enabled'] ) : ?>
										<?php
											$image_link_attributes = array(
												'class' => array( 'slider-projects__wrapper-image', 'overflow' ),
												'href'  => $post['permalink'],
												'data-arts-hover' => 'trigger',
											);

											if ( $settings['cursor_clickable_links_enabled'] ) {
												$image_link_attributes = $this->add_cursor_attributes( $image_link_attributes, 'Clickable Links' );
											}

											$this->add_render_attribute( 'image_link', $image_link_attributes, true, true );
											?>
										<a <?php $this->print_render_attribute_string( 'image_link' ); ?>>
									<?php endif; ?>
										<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
									<?php if ( $settings['images_clickable_enabled'] ) : ?>
										</a>
									<?php endif; ?>
									<div <?php $this->print_render_attribute_string( 'slide_header' ); ?>>
										<?php $this->render_swiper_content_slide( $post, array( 'heading', 'subheading', 'category', 'description' ) ); ?>
									</div>
								</div>
							</div>
						<?php endforeach; ?>
					</div>
					<?php if ( $settings['progress_bar_enabled'] ) : ?>
						<!-- slider SCROLLBAR -->
						<div <?php $this->print_render_attribute_string( 'progress_bar_wrapper' ); ?>>
							<div <?php $this->print_render_attribute_string( 'progress_bar' ); ?>></div>
						</div>
						<!-- - slider SCROLLBAR -->
					<?php endif; ?>
					<?php if ( ! empty( $settings['section_header_heading'] ) && $settings['section_header_indicator_enabled'] ) : ?>
						<!-- slider INDICATOR [desktop only] -->
						<div <?php $this->print_render_attribute_string( 'indicator_wrapper' ); ?>>
							<div <?php $this->print_render_attribute_string( 'indicator' ); ?>><?php echo esc_html( $settings['section_header_heading'] ); ?></div>
						</div>
						<!-- - slider INDICATOR [desktop only] -->
					<?php endif; ?>
					<div class="arts-is-dragging__blocker"></div>
				</div>
				<?php if ( $settings['arrows_enabled'] && $settings['section_heading_position'] === 'vertical_center' ) : ?>
					<!-- slider ARROWS -->
					<div <?php $this->print_render_attribute_string( 'arrows' ); ?>>
						<?php get_template_part( 'template-parts/slider/slider', 'arrows', $arrows_args ); ?>
					</div>
					<!-- - slider ARROWS -->
				<?php endif; ?>
			<?php if ( $settings['layout_fullscreen_enabled'] ) : ?>
				</div>
			<?php endif; ?>
		</div>

		<?php
	}
}
