<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/dynamic/kinsey-widget-trait-dynamic-helpers.php';

class Kinsey_Widget_Posts_List_Backgrounds extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Dynamic_Helpers;

	protected static $_instance, $_posts;
	protected static $_post_type          = 'post';
	protected static $_data_static_fields = array(
		'title',
		'permalink',
	);

	public function get_name() {
		return 'kinsey-widget-posts-list-backgrounds';
	}

	public function get_title() {
		return esc_html__( 'Posts List Backgrounds', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-sitemap icon-kinsey-widget-dynamic';
	}

	public function get_categories() {
		return array( 'kinsey-dynamic' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions'        => array( 'widgetType' => $name ),
			'fields'            => array(
				array(
					'field'       => 'cursor_heading_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Cursor: Heading Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
			'integration-class' => 'WPML_Elementor_Kinsey_Widget_Posts_List_Backgrounds',
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {

		/**
		 * Posts Toggles and Posts Amount Control
		 */
		$this->add_controls_posts_toggles();

		/**
		 * Content Elements to Show
		 */
		$this->start_controls_section(
			'elements_section',
			array(
				'label' => esc_html__( 'Elements', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$this->add_control(
			'dates_enabled',
			array(
				'type'    => Controls_Manager::SWITCHER,
				'label'   => esc_html__( 'Show Dates', 'kinsey' ),
				'default' => 'yes',
			)
		);

		$this->add_control(
			'categories_enabled',
			array(
				'type'    => Controls_Manager::SWITCHER,
				'label'   => esc_html__( 'Show Categories', 'kinsey' ),
				'default' => 'yes',
			)
		);

		$this->end_controls_section();

		/**
		 * Layout Options
		 */
		$this->start_controls_section(
			'layout_section',
			array(
				'label'       => esc_html__( 'Layout', 'kinsey' ),
				'label_block' => true,
				'tab'         => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'items_even_background',
			array(
				'label'       => esc_html__( 'Even Items Background', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => '',
				'options'     => ARTS_THEME_COLORS_ARRAY,
			)
		);

		$this->add_control(
			'items_padding_v',
			array(
				'label'       => esc_html__( 'Items Vertical Space', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'py-medium',
				'options'     => ARTS_THEME_DISTANCE_ARRAY['padding']['vertical'],
			)
		);

		$this->add_control(
			'text_elements_position',
			array(
				'label'       => esc_html__( 'Category Position', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'category_after',
				'options'     => array(
					'category_before' => esc_html__( 'Before Heading', 'kinsey' ),
					'category_after'  => esc_html__( 'After Heading', 'kinsey' ),
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		/**
		 * Overlay
		 */
		$this->start_controls_section(
			'overlay_section',
			array(
				'label' => esc_html__( 'Overlay', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			array(
				'name'     => 'background_overlay',
				'selector' => '{{WRAPPER}} .list-backgrounds__overlay',
			)
		);

		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Heading' => array(
					'preset' => 'h3',
					'tag'    => 'h2',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Heading' => array( 'scale', 'hide_native', 'label', 'icon' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation();
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$posts    = $this->get_posts_to_display();

		if ( empty( $posts ) ) {
			return;
		}

		$section_attributes = array(
			'class' => array( 'section', 'section-blog', 'section-list-backgrounds', 'section-content' ),
		);

		$list_item_wrapper_attributes = array(
			'class' => array( 'w-100', 'h-100', 'overflow' ),
		);

		$list_item_attributes = array(
			'class' => array( 'background-hover', 'list-backgrounds__item', $settings['items_padding_v'] ),
		);

		$item_container_attributes = array(
			'class' => array( 'container', 'background-hover__content' ),
		);

		$item_date_attributes = array(
			'class' => array( 'h5', 'mt-md-1', 'mb-md-1', 'mb-2' ),
		);

		$item_info_attributes = array(
			'class' => array( 'mt-2' ),
		);

		$heading_attributes = array(
			'class' => array( $settings['typography_heading_preset'], 'my-0', 'underline-hover__target' ),
		);

		if ( $settings['animation_enabled'] ) {
			$list_item_wrapper_attributes = $this->get_animation_attributes( $list_item_wrapper_attributes, 'animateJump' );
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'list_item_wrapper', $list_item_wrapper_attributes );
		$this->add_render_attribute( 'item_container', $item_container_attributes );
		$this->add_render_attribute( 'item_date', $item_date_attributes );
		$this->add_render_attribute( 'item_info', $item_info_attributes );
		$this->add_render_attribute( 'heading', $heading_attributes );
		?>
		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div class="list-backgrounds">
				<?php foreach ( $posts as $index => $post ) : ?>
					<?php
						if ( array_key_exists( 'image_id', $post ) ) {
							$thumbnail_args = array(
								'id'   => $post['image_id'],
								'type' => 'background',
								'size' => $this->get_thumbnail_size( $post['image_id'] ),
							);
						} else {
							$thumbnail_args = array();
						}

						$heading_link_attributes = array(
							'class'           => array( 'd-inline-block', 'underline-hover' ),
							'href'            => $post['permalink'],
							'data-arts-hover' => 'trigger',
						);

						$info_args = array(
							'id' => $post['id'],
						);

						if ( $settings['cursor_heading_enabled'] ) {
							$heading_link_attributes = $this->add_cursor_attributes( $heading_link_attributes, 'Heading' );
						}

						$list_item_attributes_current = $list_item_attributes;

						if ( $index % 2 === 0 ) {
							$list_item_attributes_current['class'][] = $settings['items_even_background'];
						}

						$this->add_render_attribute( 'list_item', $list_item_attributes_current, true, true );
						$this->add_render_attribute( 'heading_link', $heading_link_attributes, true, true );
						?>
					<div <?php $this->print_render_attribute_string( 'list_item_wrapper' ); ?>>
						<div <?php $this->print_render_attribute_string( 'list_item' ); ?>>
							<?php if ( ! empty( $thumbnail_args ) ) : ?>
								<div class="background-hover__image list-backgrounds__wrapper-img">
									<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
								</div>
							<?php endif; ?>
							<div class="overlay list-backgrounds__overlay background-hover__overlay"></div>
							<div <?php $this->print_render_attribute_string( 'item_container' ); ?>>
								<div class="row align-items-center">
									<?php if ( $settings['dates_enabled'] ) : ?>
										<div class="col-lg-4">
											<div <?php $this->print_render_attribute_string( 'item_date' ); ?>><?php echo get_the_date( '', $post['id'] ); ?></div>
										</div>
									<?php endif; ?>
									<div class="col-lg-8">
										<?php if ( $settings['categories_enabled'] && $settings['text_elements_position'] === 'category_before' ) : ?>
											<div <?php $this->print_render_attribute_string( 'item_info' ); ?>>
												<?php get_template_part( 'template-parts/blog/post/partials/meta', 'categories', $info_args ); ?>
											</div>
										<?php endif; ?>
										<a <?php $this->print_render_attribute_string( 'heading_link' ); ?>>
											<<?php $this->print_html_tag( 'typography_heading_tag' ); ?> <?php $this->print_render_attribute_string( 'heading' ); ?>><?php echo $post['title']; ?></<?php $this->print_html_tag( 'typography_heading_tag' ); ?>>
										</a>
										<?php if ( $settings['categories_enabled'] && $settings['text_elements_position'] === 'category_after' ) : ?>
											<div <?php $this->print_render_attribute_string( 'item_info' ); ?>>
												<?php get_template_part( 'template-parts/blog/post/partials/meta', 'categories', $info_args ); ?>
											</div>
										<?php endif; ?>
									</div>
								</div>
							</div>
						</div>
					</div>
				<?php endforeach; ?>
			</div>
		</div>
		<?php
	}
}
