<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/dynamic/kinsey-widget-trait-dynamic-helpers.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/grid/kinsey-widget-trait-grid-controls.php';

class Kinsey_Widget_Posts_Masonry_Grid extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Dynamic_Helpers;
	use Kinsey_Widget_Trait_Grid_Controls;

	protected static $_instance, $_posts;
	protected static $_post_type          = 'post';
	protected static $_data_static_fields = array(
		'title',
		'permalink',
	);

	public function get_name() {
		return 'kinsey-widget-posts-masonry-grid';
	}

	public function get_title() {
		return esc_html__( 'Posts Masonry Grid', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-sitemap icon-kinsey-widget-dynamic';
	}

	public function get_categories() {
		return array( 'kinsey-dynamic' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions'        => array( 'widgetType' => $name ),
			'fields'            => array(
				array(
					'field'       => 'cursor_heading_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Cursor: Heading Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
			'integration-class' => 'WPML_Elementor_Kinsey_Widget_Posts_Masonry_Grid',
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {

		/**
		 * Posts Toggles and Posts Amount Control
		 */
		$this->add_controls_posts_toggles();

		/**
		 * Content Elements to Show
		 */
		$this->start_controls_section(
			'elements_section',
			array(
				'label' => esc_html__( 'Elements', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$this->add_control(
			'dates_enabled',
			array(
				'type'    => Controls_Manager::SWITCHER,
				'label'   => esc_html__( 'Show Dates', 'kinsey' ),
				'default' => 'yes',
			)
		);

		$this->add_control(
			'authors_enabled',
			array(
				'type'    => Controls_Manager::SWITCHER,
				'label'   => esc_html__( 'Show Authors', 'kinsey' ),
				'default' => 'yes',
			)
		);

		$this->add_control(
			'categories_enabled',
			array(
				'type'    => Controls_Manager::SWITCHER,
				'label'   => esc_html__( 'Show Categories', 'kinsey' ),
				'default' => 'yes',
			)
		);

		$this->add_control(
			'comments_enabled',
			array(
				'type'    => Controls_Manager::SWITCHER,
				'label'   => esc_html__( 'Show Comments Counter', 'kinsey' ),
				'default' => 'yes',
			)
		);

		$this->end_controls_section();

		/**
		 * Layout Options
		 */
		$this->start_controls_section(
			'layout_section',
			array(
				'label'       => esc_html__( 'Layout', 'kinsey' ),
				'label_block' => true,
				'tab'         => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'items_padding',
			array(
				'label'       => esc_html__( 'Items Inner Space', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'p-xsmall',
				'options'     => ARTS_THEME_DISTANCE_ARRAY['padding']['all'],
			)
		);

		$this->end_controls_section();

		/**
		 * Grid
		 */
		$this->start_controls_section(
			'grid_section',
			array(
				'label' => esc_html__( 'Grid', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);
		$this->add_controls_grid_options();
		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		/**
		 * Overlay
		 */
		$this->start_controls_section(
			'overlay_section',
			array(
				'label' => esc_html__( 'Overlay', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			array(
				'name'     => 'background_overlay',
				'selector' => '{{WRAPPER}} .background-hover__overlay',
			)
		);

		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Heading' => array(
					'preset' => 'h3',
					'tag'    => 'h2',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Heading' => array( 'scale', 'hide_native', 'label', 'icon' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation();
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$posts    = $this->get_posts_to_display();

		if ( empty( $posts ) ) {
			return;
		}

		$col_desktop = 'grid__item_desktop-' . $settings['grid_columns'];
		$col_tablet  = 'grid__item_tablet-' . $settings['grid_columns_tablet'];
		$col_mobile  = 'grid__item_mobile-' . $settings['grid_columns_mobile'];

		$section_attributes = array(
			'class' => array( 'section', 'section-blog', 'section-grid' ),
		);

		$grid_attributes = array(
			'class' => array( 'grid', 'js-grid' ),
		);

		$item_attributes = array(
			'class' => array( 'figure-post', 'figure-post_card', 'background-hover', $settings['items_padding'] ),
		);

		$item_wrapper_attributes = array(
			'class' => array( 'w-100', 'h-100', 'overflow' ),
		);

		$grid_item_attributes = array(
			'class' => array( 'grid__item', 'js-grid__item', $col_desktop, $col_tablet, $col_mobile ),
		);

		$sizer_attributes = array(
			'class' => array( 'grid__sizer', 'js-grid__sizer', $col_desktop, $col_tablet, $col_mobile ),
		);

		$heading_attributes = array(
			'class' => array( 'mt-0', $settings['typography_heading_preset'], 'underline-hover__target' ),
		);

		$author_args = array(
			'force_date'  => true,
			'hide_date'   => ! $settings['dates_enabled'],
			'show_author' => ! ! $settings['authors_enabled'],
		);

		$bottom_info_args = array(
			'attributes' => array(
				'class' => array( 'post-meta', 'post-meta_flex' ),
			),
			'set'        => array(),
		);

		if ( $settings['grid_fancy_enabled'] && $settings['grid_columns'] !== '12' ) {
			$grid_attributes['class'][] = 'grid_fancy';
		}

		if ( $settings['grid_equal_columns_height_enabled'] ) {
			$grid_attributes['class'][] = 'js-grid-equal-heights';
		}

		if ( $settings['categories_enabled'] ) {
			$bottom_info_args['set'][] = 'categories';
		}

		if ( $settings['comments_enabled'] ) {
			$bottom_info_args['set'][] = 'comments';
		}

		if ( $settings['animation_enabled'] ) {
			$item_wrapper_attributes = $this->get_animation_attributes( $item_wrapper_attributes, 'animateJump' );
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'grid', $grid_attributes );
		$this->add_render_attribute( 'grid_item', $grid_item_attributes );
		$this->add_render_attribute( 'sizer', $sizer_attributes );
		$this->add_render_attribute( 'item', $item_attributes );
		$this->add_render_attribute( 'item_wrapper', $item_wrapper_attributes );
		$this->add_render_attribute( 'heading', $heading_attributes );
		?>
		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div <?php $this->print_render_attribute_string( 'grid' ); ?>>
				<!-- sizer -->
				<div <?php $this->print_render_attribute_string( 'sizer' ); ?>></div>
				<?php foreach ( $posts as $index => $post ) : ?>
					<?php
					if ( array_key_exists( 'image_id', $post ) ) {
						$thumbnail_args = array(
							'id'   => $post['image_id'],
							'type' => 'background',
							'size' => $this->get_thumbnail_size( $post['image_id'] ),
						);
					} else {
						$thumbnail_args = array();
					}

						$heading_link_attributes = array(
							'class' => array( 'underline-hover' ),
							'href'  => $post['permalink'],
						);

						$bottom_info_args['id'] = $post['id'];
						$author_args['id']      = $post['id'];

						if ( $settings['cursor_heading_enabled'] ) {
							$heading_link_attributes = $this->add_cursor_attributes( $heading_link_attributes, 'Heading' );
						}

						$this->add_render_attribute( 'heading_link', $heading_link_attributes, true, true );
						?>
					<div <?php $this->print_render_attribute_string( 'grid_item' ); ?>>
						<div <?php $this->print_render_attribute_string( 'item_wrapper' ); ?>>
							<div <?php $this->print_render_attribute_string( 'item' ); ?>>
								<?php if ( ! empty( $thumbnail_args ) ) : ?>
									<div class="background-hover__image">
										<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
									</div>
								<?php endif; ?>
								<div class="background-hover__overlay overlay"></div>
								<div class="background-hover__content figure-post__content figure-post__content_card">
									<?php if ( $settings['authors_enabled'] || $settings['dates_enabled'] ) : ?>
										<div class="figure-post__wrapper-info small">
											<?php get_template_part( 'template-parts/blog/post/partials/author', '', $author_args ); ?>
										</div>
									<?php endif; ?>
									<div class="figure-post__header py-medium">
										<a <?php $this->print_render_attribute_string( 'heading_link' ); ?>>
											<<?php $this->print_html_tag( 'typography_heading_tag' ); ?> <?php $this->print_render_attribute_string( 'heading' ); ?>><?php echo esc_html( $post['title'] ); ?></<?php $this->print_html_tag( 'typography_heading_tag' ); ?>>
										</a>
									</div>
									<div class="figure-post__wrapper-info small">
										<?php get_template_part( 'template-parts/blog/post/partials/meta', '', $bottom_info_args ); ?>
									</div>
								</div>
							</div>
						</div>
					</div>
				<?php endforeach; ?>
			</div>
		</div>
		<?php
	}
}
