<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/dynamic/kinsey-widget-trait-dynamic-helpers.php';

class Kinsey_Widget_Services_Grid extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Dynamic_Helpers;

	protected static $_instance, $_posts;
	protected static $_post_type          = 'arts_service';
	protected static $_data_static_fields = array(
		'title',
		'permalink',
		'description',
	);

	public function get_name() {
		return 'kinsey-widget-services-grid';
	}

	public function get_title() {
		return esc_html__( 'Services Grid', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-sitemap icon-kinsey-widget-dynamic';
	}

	public function get_categories() {
		return array( 'kinsey-dynamic' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions'        => array( 'widgetType' => $name ),
			'fields'            => array(
				array(
					'field'       => 'cursor_clickable_links_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Cursor: Clickable Links Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
			'integration-class' => 'WPML_Elementor_Kinsey_Widget_Services_Grid',
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {

		/**
		 * Posts Toggles and Posts Amount Control
		 */
		$this->add_controls_posts_toggles();

		/**
		 * Content Elements to Show
		 */
		$this->start_controls_section(
			'elements_section',
			array(
				'label' => esc_html__( 'Elements', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_elements_appearance( array( 'description', 'properties', 'counter' ) );
		$this->end_controls_section();

		/**
		 * Interaction Options
		 */
		$this->start_controls_section(
			'interaction_section',
			array(
				'label' => esc_html__( 'Interaction', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$this->add_control(
			'clickability_heading',
			array(
				'label' => esc_html__( 'Clickability', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);

		$this->add_control(
			'headings_clickable_enabled',
			array(
				'label'   => esc_html__( 'Enable Links on Headings', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->end_controls_section();

		/**
		 * Layout
		 */
		$this->start_controls_section(
			'layout_section',
			array(
				'label' => esc_html__( 'Layout', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_responsive_control(
			'items_columns_width',
			array(
				'label'           => esc_html__( 'Items Columns Width', 'kinsey' ),
				'label_block'     => true,
				'type'            => Controls_Manager::SELECT,
				'options'         => array(
					'1'  => '8%',
					'2'  => '16%',
					'3'  => '25%',
					'4'  => '33%',
					'5'  => '41%',
					'6'  => '50%',
					'7'  => '58%',
					'8'  => '66%',
					'9'  => '75%',
					'10' => '83%',
					'11' => '91%',
					'12' => '100%',
				),
				'render_type'     => 'template',
				'desktop_default' => '6',
				'tablet_default'  => '6',
				'mobile_default'  => '12',
			)
		);

		$this->add_control(
			'items_padding',
			array(
				'label'       => esc_html__( 'Items Inner Space', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'p-xsmall',
				'options'     => ARTS_THEME_DISTANCE_ARRAY['padding']['all'],
			)
		);

		$this->end_controls_section();

		/**
		 * Style
		 */
		$this->start_controls_section(
			'style_section',
			array(
				'label' => esc_html__( 'Style', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'cards_color_theme',
			array(
				'label'   => esc_html__( 'Cards Color Theme', 'kinsey' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'bg-light-3',
				'options' => ARTS_THEME_COLORS_ARRAY,
			)
		);

		$this->add_control(
			'cards_elements_color',
			array(
				'label'   => esc_html__( 'Cards Elements Color', 'kinsey' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '',
				'options' => ARTS_THEME_COLOR_THEMES_ARRAY,
			)
		);

		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Heading'     => array(
					'preset' => 'h3',
					'tag'    => 'h2',
				),
				'Properties'  => array(
					'preset' => 'paragraph',
				),
				'Description' => array(
					'preset' => 'paragraph',
					'tag'    => 'p',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Clickable Links' => array( 'scale', 'hide_native', 'label', 'icon' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$posts    = $this->get_posts_to_display();
		$counter  = 0;

		if ( empty( $posts ) ) {
			return;
		}

		$section_attributes = array(
			'class' => array( 'section', 'section-services', 'section-content' ),
		);

		$wrapper_item_attributes = array(
			'class' => array( 'w-100', 'h-100' ),
		);

		$heading_attributes = array(
			'class' => array( $settings['typography_heading_preset'], 'my-0' ),
		);

		$description_attributes = array(
			'class' => array( $settings['typography_description_preset'], 'mt-3', 'mb-0' ),
		);

		$counter_attributes = array(
			'class' => array( 'card__counter', 'small' ),
		);

		$card_attributes = array(
			'class'                => array( 'card', $settings['items_padding'], $settings['cards_color_theme'] ),
			'data-arts-theme-text' => $settings['cards_elements_color'],
		);

		$column_item_attributes = array(
			'class' => array(
				'col-lg-' . $settings['items_columns_width'],
				'col-sm-' . $settings['items_columns_width_tablet'],
				'col-' . $settings['items_columns_width_mobile'],
			),
		);

		$link_tag = 'div';

		if ( $settings['animation_enabled'] ) {
			$wrapper_item_attributes['class'][] = 'mask-reveal';

			$wrapper_item_attributes = $this->get_animation_attributes(
				$wrapper_item_attributes,
				'animateMask',
				array(
					'direction' => $settings['animation_mask_reveal_direction'],
					'scale'     => $settings['animation_mask_scale_from']['size'],
				)
			);

			$heading_attributes = $this->get_split_text_attributes(
				$heading_attributes,
				array(
					'by'        => 'lines',
					'set'       => false,
					'overflow'  => false,
					'animation' => false,
				)
			);
		}

		if ( $settings['headings_clickable_enabled'] ) {
			$link_tag                      = 'a';
			$heading_attributes['class'][] = 'underline-hover__target';
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'column_item', $column_item_attributes );
		$this->add_render_attribute( 'wrapper_item', $wrapper_item_attributes );
		$this->add_render_attribute( 'heading', $heading_attributes );
		$this->add_render_attribute( 'description', $description_attributes );
		$this->add_render_attribute( 'counter', $counter_attributes );
		$this->add_render_attribute( 'card', $card_attributes );
		?>
		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div class="row g-sm-5 g-4">
				<?php foreach ( $posts as $post ) : ?>
					<?php
						$counter++;

						$heading_link_attributes = array(
							'class' => array( 'd-flex', 'justify-content-between', 'align-items-center' ),
						);

						$properties_args = array(
							'post_id' => $post['id'],
							'list'    => array(
								'class' => array( $settings['typography_properties_preset'] ),
							),
							'name'    => array(
								'class' => array(),
							),
							'value'   => array(
								'class' => array(),
							),
						);

						$has_item_properties = arts_have_rows( 'properties', $post['id'] );

						if ( $settings['headings_clickable_enabled'] ) {
							$heading_link_attributes['class'][] = 'underline-hover';
							$heading_link_attributes['href']    = $post['permalink'];

							if ( array_key_exists( 'permalink_attributes', $post ) ) {

								if ( array_key_exists( 'is_external', $post['permalink_attributes'] ) && $post['permalink_attributes']['is_external'] ) {
									$heading_link_attributes['target'] = '_blank';
								}

								if ( array_key_exists( 'nofollow', $post['permalink_attributes'] ) && $post['permalink_attributes']['nofollow'] ) {
									$heading_link_attributes['rel'] = 'nofollow';
								}
							}
						}

						if ( $settings['cursor_clickable_links_enabled'] ) {
							$heading_link_attributes = $this->add_cursor_attributes( $heading_link_attributes, 'Clickable Links' );
						}
						$this->remove_render_attribute( 'heading_link' );
						$this->add_render_attribute( 'heading_link', $heading_link_attributes, true, true );
						?>
					<div <?php $this->print_render_attribute_string( 'column_item' ); ?>>
						<div <?php $this->print_render_attribute_string( 'wrapper_item' ); ?>>
							<?php if ( $settings['animation_enabled'] ) : ?>
							<div class="mask-reveal__layer mask-reveal__layer-1">
								<div class="mask-reveal__layer mask-reveal__layer-2">
							<?php endif; ?>
									<div <?php $this->print_render_attribute_string( 'card' ); ?>>
										<div class="card__header">
											<<?php echo $link_tag; ?> <?php $this->print_render_attribute_string( 'heading_link' ); ?>>
												<h3 <?php $this->print_render_attribute_string( 'heading' ); ?>><?php echo $post['title']; ?></h3>
												<i class="card__arrow knz-arrow-right"></i>
											</<?php echo $link_tag; ?>>
										</div>
										<div class="card__content content">
										<?php if ( $settings['properties_enabled'] && $has_item_properties ) : ?>
											<?php get_template_part( 'template-parts/list/list', 'properties', $properties_args ); ?>
										<?php endif; ?>
										<?php if ( $settings['description_enabled'] && $post['description'] ) : ?>
											<<?php $this->print_html_tag( 'typography_description_tag' ); ?> <?php $this->print_render_attribute_string( 'description' ); ?>><?php echo $post['description']; ?></<?php $this->print_html_tag( 'typography_description_tag' ); ?>>
										<?php endif; ?>
										</div>
										<?php if ( $settings['counters_enabled'] ) : ?>
											<div <?php $this->print_render_attribute_string( 'counter' ); ?>><?php echo $this->get_prefix_zeros( $counter ); ?></div>
										<?php endif; ?>
									</div>
							<?php if ( $settings['animation_enabled'] ) : ?>
								</div>
							</div>
							<?php endif; ?>
						</div>
					</div>
				<?php endforeach; ?>
			</div>
		</div>
		<?php
	}
}
