<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kinsey_Widget_Button extends Kinsey_Widget_Base {
	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-button';
	}

	public function get_title() {
		return esc_html__( 'Button', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions' => array( 'widgetType' => $name ),
			'fields'     => array(
				array(
					'field'       => 'button_title',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Button: Title', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'button_title_hover',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Button: Hover Title', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'mouse_drag_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Mouse: Cursor Drag Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'button_section',
			array(
				'label' => esc_html__( 'Button', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_controls_button();
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Button' => array( 'scale', 'hide_native', 'magnetic' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation();
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$section_attributes = array(
			'class' => array( 'section', 'section-content' ),
		);

		$section_wrapper_button_attributes = array(
			'class' => array( 'section-content__wrapper-button' ),
		);

		$button_args = array(
			'title'       => $settings['button_title'],
			'title_hover' => $settings['button_title_hover'],
			'attributes'  => array(
				'href'  => $settings['button_link']['url'],
				'class' => array( 'button', $settings['button_border'], $settings['button_color'] ),
			),
			'icon'        => array(),
		);

		if ( $settings['button_style'] ) {
			$button_args['attributes']['class'][] = $settings['button_style'];
		}

		if ( $settings['button_icon_before'] ) {
			$button_args['class'][]        = 'button_icon';
			$button_args['icon']['before'] = $settings['button_icon_before'];
		}

		if ( $settings['button_icon_after'] ) {
			$button_args['class'][]       = 'button_icon';
			$button_args['icon']['after'] = $settings['button_icon_after'];
		}

		if ( $settings['cursor_button_enabled'] ) {
			$button_args['attributes'] = $this->add_cursor_attributes( $button_args['attributes'], 'Button' );
		}

		if ( array_key_exists( 'is_external', $settings['button_link'] ) && $settings['button_link']['is_external'] ) {
			$button_args['attributes']['target'] = '_blank';
		}

		if ( array_key_exists( 'is_external', $settings['button_link'] ) && $settings['button_link']['nofollow'] ) {
			$button_args['attributes']['rel'] = 'nofollow';
		}

		if ( $settings['animation_enabled'] ) {
			$section_wrapper_button_attributes = $this->get_animation_attributes( $section_wrapper_button_attributes, 'animateJump' );
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'section_wrapper_button', $section_wrapper_button_attributes );
		?>
		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div <?php $this->print_render_attribute_string( 'section_wrapper_button' ); ?>>
				<?php get_template_part( 'template-parts/button/button', 'normal', $button_args ); ?>
			</div>
		</div>
		<?php
	}
}
