<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kinsey_Widget_Coming_Soon extends Kinsey_Widget_Base {
	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-coming-soon';
	}

	public function get_title() {
		return esc_html__( 'Coming Soon Fullscreen', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions' => array( 'widgetType' => $name ),
			'fields'     => array(
				array(
					'field'       => 'text',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Content', 'kinsey' ) ),
					'editor_type' => 'VISUAL',
				),
				array(
					'field'       => 'countdown_label_days',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Label: Days', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'countdown_label_hours',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Label: Hours', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'countdown_label_minutes',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Label: Minutes', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'countdown_label_seconds',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Label: Seconds', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'text',
			array(
				'type'    => Controls_Manager::WYSIWYG,
				'default' => '<h6>Subheading...</h6><h2>Heading...</h2><p>Text text text...</p>',
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'countdown_section',
			array(
				'label' => esc_html__( 'Countdown', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'countdown_target',
			array(
				'label'          => esc_html__( 'Target Date', 'kinsey' ),
				'type'           => Controls_Manager::DATE_TIME,
				'picker_options' => array(
					'enableTime' => false,
				),
				'default'        => '2022-02-01',
			)
		);

		/**
		 * Days
		 */
		$this->add_control(
			'countdown_label_days_heading',
			array(
				'label'     => esc_html__( 'Days', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_control(
			'countdown_days_enabled',
			array(
				'label'   => esc_html__( 'Enabled', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'countdown_label_days',
			array(
				'label'     => esc_html__( 'Label', 'kinsey' ),
				'type'      => Controls_Manager::TEXT,
				'dynamic'   => array(
					'active' => true,
				),
				'default'   => esc_html__( 'Days', 'kinsey' ),
				'condition' => array(
					'countdown_days_enabled' => 'yes',
				),
			)
		);

		/**
		 * Hours
		 */
		$this->add_control(
			'countdown_label_hours_heading',
			array(
				'label'     => esc_html__( 'Hours', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_control(
			'countdown_hours_enabled',
			array(
				'label'   => esc_html__( 'Enabled', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'countdown_label_hours',
			array(
				'label'     => esc_html__( 'Label', 'kinsey' ),
				'type'      => Controls_Manager::TEXT,
				'dynamic'   => array(
					'active' => true,
				),
				'default'   => esc_html__( 'Hours', 'kinsey' ),
				'condition' => array(
					'countdown_hours_enabled' => 'yes',
				),
			)
		);

		/**
		 * Minutes
		 */
		$this->add_control(
			'countdown_label_minutes_heading',
			array(
				'label'     => esc_html__( 'Minutes', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_control(
			'countdown_minutes_enabled',
			array(
				'label'   => esc_html__( 'Enabled', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'countdown_label_minutes',
			array(
				'label'     => esc_html__( 'Label', 'kinsey' ),
				'type'      => Controls_Manager::TEXT,
				'dynamic'   => array(
					'active' => true,
				),
				'default'   => esc_html__( 'Minutes', 'kinsey' ),
				'condition' => array(
					'countdown_minutes_enabled' => 'yes',
				),
			)
		);

		/**
		 * Seconds
		 */
		$this->add_control(
			'countdown_label_seconds_heading',
			array(
				'label'     => esc_html__( 'Seconds', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_control(
			'countdown_seconds_enabled',
			array(
				'label'   => esc_html__( 'Enabled', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'countdown_label_seconds',
			array(
				'label'     => esc_html__( 'Label', 'kinsey' ),
				'type'      => Controls_Manager::TEXT,
				'dynamic'   => array(
					'active' => true,
				),
				'default'   => esc_html__( 'Seconds', 'kinsey' ),
				'condition' => array(
					'countdown_seconds_enabled' => 'yes',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'social_section',
			array(
				'label' => esc_html__( 'Social Icons', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'social_link',
			array(
				'label'         => esc_html__( 'Link', 'kinsey' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://...', 'kinsey' ),
				'show_external' => true,
				'dynamic'       => array(
					'active' => true,
				),
				'default'       => array(
					'is_external' => true,
					'nofollow'    => true,
				),
			)
		);

		$repeater->add_control(
			'social_icon',
			array(
				'label' => esc_html__( 'Icon', 'kinsey' ),
				'type'  => Controls_Manager::ICONS,
			)
		);

		$this->add_control(
			'social',
			array(
				'type'          => Controls_Manager::REPEATER,
				'fields'        => $repeater->get_controls(),
				'prevent_empty' => false,
			)
		);

		$this->end_controls_section();

		/**
		 * Style
		 */
		$this->start_controls_section(
			'style_section',
			array(
				'label' => esc_html__( 'Style', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'counter_column_color_theme',
			array(
				'label'   => esc_html__( 'Counter Column Color Theme', 'kinsey' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => 'bg-dark-2',
				'options' => ARTS_THEME_COLORS_ARRAY,
			)
		);

		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Counter Number'        => array(
					'preset' => 'h1',
					'tag'    => 'div',
				),
				'Counter Label'         => array(
					'preset' => 'small',
					'tag'    => 'div',
				),
				'Mobile Counter Number' => array(
					'preset' => 'h3',
					'tag'    => 'div',
				),
				'Mobile Counter Label'  => array(
					'preset' => 'small',
					'tag'    => 'div',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation();
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$section_attributes = array(
			'class'           => array( 'section-coming-soon', 'section-content', 'section-fullheight' ),
			'data-count-down' => $settings['countdown_target'],
		);

		$section_content_attributes = array(
			'class' => array( 'section-content__content', 'content', 'mb-4', 'mb-md-0' ),
		);

		$row_desktop_attributes = array(
			'class' => array( 'row', 'h-100', 'align-items-center', 'justify-content-center', 'text-center', 'g-4' ),
		);

		$row_mobile_attributes = array(
			'class' => array( 'row', 'd-lg-none' ),
		);

		$counter_number_attributes = array(
			'class' => array( 'counter__number', $settings['typography_counter_number_preset'] ),
		);

		$counter_label_attributes = array(
			'class' => array( 'counter__label', $settings['typography_counter_label_preset'] ),
		);

		$mobile_counter_number_attributes = array(
			'class' => array( 'counter__number', $settings['typography_mobile_counter_number_preset'] ),
		);

		$mobile_counter_label_attributes = array(
			'class' => array( 'counter__label', $settings['typography_mobile_counter_label_preset'] ),
		);

		$col_social_attributes = array(
			'class' => array( 'col-auto', 'w-100' ),
		);

		$col_countdown = array(
			'class' => array( 'col-lg-6', 'align-items-center', $settings['counter_column_color_theme'] ),
		);

		if ( $settings['animation_enabled'] ) {
			$section_content_attributes = $this->get_split_text_attributes(
				$section_content_attributes,
				array(
					'by'       => 'lines',
					'set'      => 'lines',
					'overflow' => 'lines',
				)
			);

			$row_mobile_attributes  = $this->get_animation_attributes( $row_mobile_attributes, 'animateJump' );
			$row_desktop_attributes = $this->get_animation_attributes( $row_desktop_attributes, 'animateJump' );
			$col_social_attributes  = $this->get_animation_attributes( $col_social_attributes, 'animateJump' );
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'section_content', $section_content_attributes );
		$this->add_render_attribute( 'row_mobile', $row_mobile_attributes );
		$this->add_render_attribute( 'row_desktop', $row_desktop_attributes );
		$this->add_render_attribute( 'counter_number', $counter_number_attributes );
		$this->add_render_attribute( 'counter_label', $counter_label_attributes );
		$this->add_render_attribute( 'mobile_counter_number', $mobile_counter_number_attributes );
		$this->add_render_attribute( 'mobile_counter_label', $mobile_counter_label_attributes );
		$this->add_render_attribute( 'col_social', $col_social_attributes );
		$this->add_render_attribute( 'col_countdown', $col_countdown );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div class="row g-0 w-100">
				<div class="col-lg-6">
					<div class="container-fluid pt-large pb-xsmall ml-0 section-fullheight__inner section-fullheight__inner_mobile section__content">
						<div class="row h-100 flex-column justify-content-center">
							<div class="col-auto my-auto">
								<div <?php $this->print_render_attribute_string( 'section_content' ); ?>><?php echo $settings['text']; ?></div>
								<!-- mobile counter (only mobiles)-->
								<div <?php $this->print_render_attribute_string( 'row_mobile' ); ?>>
									<?php if ( $settings['countdown_days_enabled'] ) : ?>
										<div class="col-3">
											<div class="counter">
												<div <?php $this->print_render_attribute_string( 'mobile_counter_number' ); ?> data-count-down-element="D">--</div>
												<?php if ( ! empty( $settings['countdown_label_days'] ) ) : ?>
													<div <?php $this->print_render_attribute_string( 'mobile_counter_label' ); ?>><?php echo esc_html( $settings['countdown_label_days'] ); ?></div>
												<?php endif; ?>
											</div>
										</div>
									<?php endif; ?>
									<?php if ( $settings['countdown_hours_enabled'] ) : ?>
										<div class="col-3">
											<div class="counter">
												<div <?php $this->print_render_attribute_string( 'mobile_counter_number' ); ?> data-count-down-element="H">--</div>
												<?php if ( ! empty( $settings['countdown_label_hours'] ) ) : ?>
													<div <?php $this->print_render_attribute_string( 'mobile_counter_label' ); ?>><?php echo esc_html( $settings['countdown_label_hours'] ); ?></div>
												<?php endif; ?>
											</div>
										</div>
									<?php endif; ?>
									<?php if ( $settings['countdown_minutes_enabled'] ) : ?>
										<div class="col-3">
											<div class="counter">
												<div <?php $this->print_render_attribute_string( 'mobile_counter_number' ); ?> data-count-down-element="M">--</div>
												<?php if ( ! empty( $settings['countdown_label_minutes'] ) ) : ?>
													<div <?php $this->print_render_attribute_string( 'mobile_counter_label' ); ?>><?php echo esc_html( $settings['countdown_label_minutes'] ); ?></div>
												<?php endif; ?>
											</div>
										</div>
									<?php endif; ?>
									<?php if ( $settings['countdown_seconds_enabled'] ) : ?>
										<div class="col-3">
											<div class="counter">
												<div <?php $this->print_render_attribute_string( 'mobile_counter_number' ); ?> data-count-down-element="S">--</div>
												<?php if ( ! empty( $settings['countdown_label_seconds'] ) ) : ?>
													<div <?php $this->print_render_attribute_string( 'mobile_counter_label' ); ?>><?php echo esc_html( $settings['countdown_label_seconds'] ); ?></div>
												<?php endif; ?>
											</div>
										</div>
									<?php endif; ?>
								</div>
								<!-- - mobile counter (only mobiles)-->
							</div>
							<?php if ( ! empty( $settings['social'] ) ) : ?>
								<div <?php $this->print_render_attribute_string( 'col_social' ); ?>><?php $this->print_social_media_list(); ?></div>
							<?php endif; ?>
						</div>
					</div>
				</div>
				<div <?php $this->print_render_attribute_string( 'col_countdown' ); ?>>
					<div class="container-fluid pt-medium d-none d-lg-flex section-fullheight__inner section__content">
						<div <?php $this->print_render_attribute_string( 'row_desktop' ); ?>>
							<?php if ( $settings['countdown_days_enabled'] ) : ?>
								<div class="col-sm-4">
									<div class="counter">
										<div <?php $this->print_render_attribute_string( 'counter_number' ); ?> data-count-down-element="D">--</div>
										<?php if ( ! empty( $settings['countdown_label_days'] ) ) : ?>
											<div <?php $this->print_render_attribute_string( 'counter_label' ); ?>><?php echo esc_html( $settings['countdown_label_days'] ); ?></div>
										<?php endif; ?>
									</div>
								</div>
							<?php endif; ?>
							<?php if ( $settings['countdown_hours_enabled'] ) : ?>
								<div class="col-sm-4">
									<div class="counter">
										<div <?php $this->print_render_attribute_string( 'counter_number' ); ?> data-count-down-element="H">--</div>
										<?php if ( ! empty( $settings['countdown_label_hours'] ) ) : ?>
											<div <?php $this->print_render_attribute_string( 'counter_label' ); ?>><?php echo esc_html( $settings['countdown_label_hours'] ); ?></div>
										<?php endif; ?>
									</div>
								</div>
							<?php endif; ?>
							<div class="w-100"></div>
							<?php if ( $settings['countdown_minutes_enabled'] ) : ?>
								<div class="col-sm-4">
									<div class="counter">
										<div <?php $this->print_render_attribute_string( 'counter_number' ); ?> data-count-down-element="M">--</div>
										<?php if ( ! empty( $settings['countdown_label_minutes'] ) ) : ?>
											<div <?php $this->print_render_attribute_string( 'counter_label' ); ?>><?php echo esc_html( $settings['countdown_label_minutes'] ); ?></div>
										<?php endif; ?>
									</div>
								</div>
							<?php endif; ?>
							<?php if ( $settings['countdown_seconds_enabled'] ) : ?>
								<div class="col-sm-4">
									<div class="counter">
										<div <?php $this->print_render_attribute_string( 'counter_number' ); ?> data-count-down-element="S">--</div>
										<?php if ( ! empty( $settings['countdown_label_seconds'] ) ) : ?>
											<div <?php $this->print_render_attribute_string( 'counter_label' ); ?>><?php echo esc_html( $settings['countdown_label_seconds'] ); ?></div>
										<?php endif; ?>
									</div>
								</div>
							<?php endif; ?>
						</div>
					</div>
				</div>
			</div>
		</div>

		<?php
	}

}
