<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kinsey_Widget_Content_Block extends Kinsey_Widget_Base {
	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-content-block';
	}

	public function get_title() {
		return esc_html__( 'Content Block', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions' => array( 'widgetType' => $name ),
			'fields'     => array(
				array(
					'field'       => 'text',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Content', 'kinsey' ) ),
					'editor_type' => 'VISUAL',
				),
			),
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'headline_before_enabled',
			array(
				'label'   => esc_html__( 'Enable Headline Before', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => '',
			)
		);

		$this->add_control(
			'headline_before_alignment',
			array(
				'label'     => esc_html__( 'Position', 'kinsey' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => array(
					'me-auto' => array(
						'title' => esc_html__( 'Left', 'kinsey' ),
						'icon'  => 'eicon-h-align-left',
					),
					'mx-auto' => array(
						'title' => esc_html__( 'Center', 'kinsey' ),
						'icon'  => 'eicon-h-align-center',
					),
					'ms-auto' => array(
						'title' => esc_html__( 'Right', 'kinsey' ),
						'icon'  => 'eicon-h-align-right',
					),
				),
				'default'   => 'me-auto',
				'condition' => array(
					'headline_before_enabled' => 'yes',
				),
				'toggle'    => true,
				'separator' => 'after',
			)
		);

		$this->add_control(
			'headline_after_enabled',
			array(
				'label'   => esc_html__( 'Enable Headline After', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => '',
			)
		);

		$this->add_control(
			'headline_after_alignment',
			array(
				'label'     => esc_html__( 'Position', 'kinsey' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => array(
					'me-auto' => array(
						'title' => esc_html__( 'Left', 'kinsey' ),
						'icon'  => 'eicon-h-align-left',
					),
					'mx-auto' => array(
						'title' => esc_html__( 'Center', 'kinsey' ),
						'icon'  => 'eicon-h-align-center',
					),
					'ms-auto' => array(
						'title' => esc_html__( 'Right', 'kinsey' ),
						'icon'  => 'eicon-h-align-right',
					),
				),
				'default'   => 'me-auto',
				'condition' => array(
					'headline_after_enabled' => 'yes',
				),
				'toggle'    => true,
				'separator' => 'after',
			)
		);

		$this->add_control(
			'text',
			array(
				'type'    => Controls_Manager::WYSIWYG,
				'dynamic' => array(
					'active' => true,
				),
				'default' => '<h6>Subheading...</h6><h2>Heading...</h2><p>Text text text...</p>',
			)
		);

		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation();
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$section_attributes = array(
			'class' => array( 'section', 'section-content' ),
		);

		$section_content_attributes = array(
			'class' => array( 'section-content__content', 'content' ),
		);

		$headline_before_attributes = array(
			'class' => array( 'section__headline', 'section__headline_before', 'mb-md-3', 'mb-2', $settings['headline_before_alignment'] ),
		);

		$headline_after_attributes = array(
			'class' => array( 'section__headline', 'section__headline_after', 'mt-md-4', 'mt-3', $settings['headline_after_alignment'] ),
		);

		if ( $settings['animation_enabled'] ) {
			$section_content_attributes = $this->get_split_text_attributes(
				$section_content_attributes,
				array(
					'by'       => 'lines',
					'set'      => 'lines',
					'overflow' => 'lines',
				)
			);

			$headline_before_attributes = $this->get_animation_attributes( $headline_before_attributes, 'animateHeadline' );
			$headline_after_attributes  = $this->get_animation_attributes( $headline_after_attributes, 'animateHeadline' );
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'section_content', $section_content_attributes );
		$this->add_render_attribute( 'headline_before', $headline_before_attributes );
		$this->add_render_attribute( 'headline_after', $headline_after_attributes );

		?>
		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<?php if ( $settings['headline_before_enabled'] ) : ?>
				<div <?php $this->print_render_attribute_string( 'headline_before' ); ?>></div>
			<?php endif; ?>
			<div <?php $this->print_render_attribute_string( 'section_content' ); ?>><?php echo $settings['text']; ?></div>
			<?php if ( $settings['headline_after_enabled'] ) : ?>
				<div <?php $this->print_render_attribute_string( 'headline_after' ); ?>></div>
			<?php endif; ?>
		</div>
		<?php
	}
}
