<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kinsey_Widget_Counter extends Kinsey_Widget_Base {
	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-counter';
	}

	public function get_title() {
		return esc_html__( 'Counter', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions' => array( 'widgetType' => $name ),
			'fields'     => array(
				array(
					'field'       => 'label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Counter Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'prefix',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Counter Prefix', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'suffix',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Counter Suffix', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'label',
			array(
				'label'   => esc_html__( 'Label', 'kinsey' ),
				'type'    => Controls_Manager::TEXT,
				'dynamic' => array(
					'active' => true,
				),
				'default' => esc_html__( 'Label...', 'kinsey' ),
			)
		);

		$this->add_control(
			'prefix',
			array(
				'label'   => esc_html__( 'Prefix', 'kinsey' ),
				'type'    => Controls_Manager::TEXT,
				'dynamic' => array(
					'active' => true,
				),
				'default' => '',
			)
		);

		$this->add_control(
			'suffix',
			array(
				'label'   => esc_html__( 'Suffix', 'kinsey' ),
				'type'    => Controls_Manager::TEXT,
				'dynamic' => array(
					'active' => true,
				),
				'default' => '',
			)
		);

		$this->add_control(
			'add_zeros',
			array(
				'label'   => esc_html__( 'Add Zeros', 'kinsey' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 1,
				'options' => array(
					0 => esc_html__( 'None', 'kinsey' ),
					1 => esc_html__( '1 Zero', 'kinsey' ),
					2 => esc_html__( '2 Zeros', 'kinsey' ),
				),
			)
		);

		$this->add_control(
			'start',
			array(
				'label'   => esc_html__( 'Start Number', 'kinsey' ),
				'type'    => Controls_Manager::NUMBER,
				'dynamic' => array(
					'active' => true,
				),
				'min'     => 1,
				'max'     => 500,
				'step'    => 1,
				'default' => 0,
			)
		);

		$this->add_control(
			'target',
			array(
				'label'   => esc_html__( 'Target Number', 'kinsey' ),
				'type'    => Controls_Manager::NUMBER,
				'dynamic' => array(
					'active' => true,
				),
				'min'     => 1,
				'max'     => 500,
				'step'    => 1,
				'default' => 20,
			)
		);

		$this->add_control(
			'duration',
			array(
				'label'      => esc_html__( 'Duration (seconds)', 'kinsey' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => array( 'seconds' ),
				'range'      => array(
					'seconds' => array(
						'min'  => 0.3,
						'max'  => 10,
						'step' => 0.1,
					),
				),
				'default'    => array(
					'unit' => 'seconds',
					'size' => 2.4,
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Style
		 */
		$this->start_controls_section(
			'style_section',
			array(
				'label' => esc_html__( 'Style', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'circle_enabled',
			array(
				'label'   => esc_html__( 'Enable Circle', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => '',
			)
		);

		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_controls_typography(
			array(
				'Number' => array(
					'preset' => 'xl',
					'tag'    => 'div',
				),
				'Label'  => array(
					'preset' => 'paragraph',
					'tag'    => 'div',
				),
			)
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$section_attributes = array(
			'class' => array( 'section', 'section-content' ),
		);

		$counter_attributes = array(
			'class' => array( 'counter', 'js-counter' ),
		);

		$counter_args = array(
			'zeros'    => $settings['add_zeros'] + 1,
			'prefix'   => $settings['prefix'],
			'start'    => $settings['start'],
			'target'   => $settings['target'],
			'suffix'   => $settings['suffix'],
			'duration' => $settings['duration']['size'],
		);

		$counter_attributes = $this->get_animation_attributes( $counter_attributes, 'animateCounter', $counter_args );

		$number_attributes = array(
			'class' => array( 'counter__number', 'js-counter__number', $settings['typography_number_preset'] ),
		);

		$label_attributes = array(
			'class' => array( 'counter__label', $settings['typography_label_preset'] ),
		);

		if ( $settings['circle_enabled'] ) {
			$counter_attributes['class'][] = 'counter_circle';
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'counter', $counter_attributes );
		$this->add_render_attribute( 'number', $number_attributes );
		$this->add_render_attribute( 'label', $label_attributes );
		?>
		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div <?php $this->print_render_attribute_string( 'counter' ); ?>>
				<<?php $this->print_html_tag( 'typography_number_tag' ); ?> <?php $this->print_render_attribute_string( 'number' ); ?>>00</<?php $this->print_html_tag( 'typography_number_tag' ); ?>>
				<?php if ( ! empty( $settings['label'] ) ) : ?>
					<<?php $this->print_html_tag( 'typography_label_tag' ); ?> <?php $this->print_render_attribute_string( 'label' ); ?>><?php echo esc_html( $settings['label'] ); ?></<?php $this->print_html_tag( 'typography_label_tag' ); ?>>
				<?php endif; ?>
				<?php if ( ! empty( $settings['circle_enabled'] ) ) : ?>
					<svg class="svg-circle" viewBox="0 0 280 280">
						<circle class="circle" cx="140" cy="140" r="139" fill="none"></circle>
					</svg>
				<?php endif; ?>
			</div>
		</div>

		<?php
	}

}
