<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kinsey_Widget_Definitions_List extends Kinsey_Widget_Base {
	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-definitions-list';
	}

	public function get_title() {
		return esc_html__( 'Definitions List', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name = $this->get_name();

		$widgets[ $name ] = array(
			'conditions'        => array( 'widgetType' => $name ),
			'fields'            => array(),
			'integration-class' => 'WPML_Elementor_Kinsey_Widget_Definitions_List',
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'name',
			array(
				'label'   => esc_html__( 'Name', 'kinsey' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'Item...', 'kinsey' ),
			)
		);

		$repeater->add_control(
			'description',
			array(
				'label'   => esc_html__( 'Description', 'kinsey' ),
				'type'    => Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'Text...', 'kinsey' ),
			)
		);

		$this->add_control(
			'items',
			array(
				'type'          => Controls_Manager::REPEATER,
				'fields'        => $repeater->get_controls(),
				'title_field'   => '{{{ name }}}',
				'prevent_empty' => false,
			)
		);

		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Name'        => array(
					'preset' => 'h3',
					'tag'    => 'h5',
				),
				'Description' => array(
					'preset' => 'paragraph',
					'tag'    => 'p',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation();
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( empty( $settings['items'] ) ) {
			return;
		}

		$item_wrapper_attributes = array(
			'class' => array( 'row', 'section-content__wrapper-item', 'py-3' ),
		);

		$name_wrapper_attributes = array(
			'class' => array( 'section-content__content', 'content', 'mb-2' ),
		);

		$name_attributes = array(
			'class' => array( $settings['typography_name_preset'] ),
		);

		$description_wrapper_attributes = array(
			'class' => array( 'section-content__content', 'content' ),
		);

		$description_attributes = array(
			'class' => array( $settings['typography_description_preset'] ),
		);

		$section_attributes = array(
			'class' => array( 'section', 'section-content' ),
		);

		if ( $settings['animation_enabled'] ) {
			$item_wrapper_attributes = $this->get_animation_attributes( $item_wrapper_attributes, 'animateText' );

			$name_wrapper_attributes = $this->get_split_text_attributes(
				$name_wrapper_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);

			$description_wrapper_attributes = $this->get_split_text_attributes(
				$description_wrapper_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'item_wrapper', $item_wrapper_attributes );
		$this->add_render_attribute( 'name_wrapper', $name_wrapper_attributes );
		$this->add_render_attribute( 'name', $name_attributes );
		$this->add_render_attribute( 'description_wrapper', $description_wrapper_attributes );
		$this->add_render_attribute( 'description', $description_attributes );

		?>
		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<?php foreach ( $settings['items'] as $item ) : ?>
				<div <?php $this->print_render_attribute_string( 'item_wrapper' ); ?>>
					<div class="section-content__divider"></div>
					<div class="col-lg-6">
						<?php if ( ! empty( $item['name'] ) ) : ?>
							<div <?php $this->print_render_attribute_string( 'name_wrapper' ); ?>>
								<<?php $this->print_html_tag( 'typography_name_tag' ); ?> <?php $this->print_render_attribute_string( 'name' ); ?>><?php echo esc_html( $item['name'] ); ?></<?php $this->print_html_tag( 'typography_name_tag' ); ?>>
							</div>
						<?php endif; ?>
					</div>
					<div class="col-lg-6">
						<?php if ( ! empty( $item['description'] ) ) : ?>
							<div <?php $this->print_render_attribute_string( 'description_wrapper' ); ?>>
								<<?php $this->print_html_tag( 'typography_description_tag' ); ?> <?php $this->print_render_attribute_string( 'description' ); ?>><?php echo $item['description']; ?></<?php $this->print_html_tag( 'typography_description_tag' ); ?>>
							</div>
						<?php endif; ?>
					</div>
				</div>
			<?php endforeach; ?>
		</div>
		<?php
	}

}
