<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/horizontal/kinsey-widget-trait-horizontal-controls.php';

class Kinsey_Widget_Images_Fullscreen_Horizontal_Scrolling extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Horizontal_Controls;

	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-images-fullscreen-horizontal-scrolling';
	}

	public function get_title() {
		return esc_html__( 'Images Fullscreen Horizontal Scrolling', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions' => array( 'widgetType' => $name ),
			'fields'     => array(
				array(
					'field'       => 'section_header_heading',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Section Header: Heading', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'section_header_helper',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Section Header: Helper Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'images_gallery',
			array(
				'type'    => Controls_Manager::GALLERY,
				'default' => array(),
			)
		);

		$this->end_controls_section();

		/**
		 * Section Header
		 */
		$this->start_controls_section(
			'header_section',
			array(
				'label' => esc_html__( 'Section Header', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'section_header_heading',
			array(
				'label'   => esc_html__( 'Heading', 'kinsey' ),
				'type'    => Controls_Manager::TEXT,
				'dynamic' => array(
					'active' => true,
				),
				'default' => esc_html__( 'Heading...', 'kinsey' ),
			)
		);

		$this->add_control(
			'section_header_helper',
			array(
				'label'     => esc_html__( 'Helper Label', 'kinsey' ),
				'type'      => Controls_Manager::TEXT,
				'dynamic'   => array(
					'active' => true,
				),
				'default'   => esc_html__( 'Scroll...', 'kinsey' ),
				'condition' => array(
					'section_header_heading!' => '',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Horizontal Scrolling Options
		 */
		$this->start_controls_section(
			'horizontal_scroll_section',
			array(
				'label' => esc_html__( 'Horizontal Scroll', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_horizontal_scrolling_options();
		$this->end_controls_section();

		/**
		 * Layout
		 */
		$this->start_controls_section(
			'layout_section',
			array(
				'label' => esc_html__( 'Layout', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'section_header_column_width',
			array(
				'label'       => esc_html__( 'Section Header Column Width', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'options'     => array(
					'1'  => '8%',
					'2'  => '16%',
					'3'  => '25%',
					'4'  => '33%',
					'5'  => '41%',
					'6'  => '50%',
					'7'  => '58%',
					'8'  => '66%',
					'9'  => '75%',
					'10' => '83%',
					'11' => '91%',
					'12' => '100%',
				),
				'default'     => '6',
			)
		);

		$this->add_responsive_control(
			'items_columns_width',
			array(
				'label'           => esc_html__( 'Items Columns Width', 'kinsey' ),
				'label_block'     => true,
				'type'            => Controls_Manager::SELECT,
				'options'         => array(
					'1'  => '8%',
					'2'  => '16%',
					'3'  => '25%',
					'4'  => '33%',
					'5'  => '41%',
					'6'  => '50%',
					'7'  => '58%',
					'8'  => '66%',
					'9'  => '75%',
					'10' => '83%',
					'11' => '91%',
					'12' => '100%',
				),
				'desktop_default' => '4',
				'tablet_default'  => '6',
				'mobile_default'  => '12',
			)
		);

		$this->add_control(
			'items_padding_h',
			array(
				'label'       => esc_html__( 'Items Horizontal Space', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'px-medium',
				'options'     => ARTS_THEME_DISTANCE_ARRAY['padding']['horizontal'],
			)
		);

		$this->add_control(
			'items_padding_v',
			array(
				'label'       => esc_html__( 'Items Vertical Space', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'default'     => 'py-large',
				'options'     => ARTS_THEME_DISTANCE_ARRAY['padding']['vertical'],
			)
		);

		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->add_control(
			'image_placement',
			array(
				'label'   => esc_html__( 'Placement', 'kinsey' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => array(
					'image'         => array(
						'title' => esc_html__( 'Responsive (Unlimited Width)', 'kinsey' ),
						'icon'  => 'eicon-image-bold',
					),
					'image_limited' => array(
						'title' => esc_html__( 'Responsive (Limited Width)', 'kinsey' ),
						'icon'  => 'eicon-image-before-after',
					),
					'background'    => array(
						'title' => esc_html__( 'Background', 'kinsey' ),
						'icon'  => 'eicon-image',
					),
				),
				'default' => 'image',
				'toggle'  => false,
			)
		);

		$this->end_controls_section();

		/**
		 * Background
		 */
		$this->start_controls_section(
			'background_section',
			array(
				'label' => esc_html__( 'Background', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'background_theme',
			array(
				'label'   => esc_html__( 'Background Color Theme', 'kinsey' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '',
				'options' => ARTS_THEME_COLORS_ARRAY,
			)
		);

		$this->add_control(
			'background_alignment',
			array(
				'label'     => esc_html__( 'Background Alignment', 'kinsey' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => array(
					'section__bg-container-left'  => array(
						'title' => esc_html__( 'Left', 'kinsey' ),
						'icon'  => 'eicon-h-align-left',
					),
					'section__bg-container-right' => array(
						'title' => esc_html__( 'Right', 'kinsey' ),
						'icon'  => 'eicon-h-align-right',
					),
				),
				'default'   => 'section__bg-container-right',
				'toggle'    => false,
				'condition' => array(
					'background_theme!' => '',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Section Heading' => array(
					'preset' => 'h1',
					'tag'    => 'h2',
				),
				'Section Helper'  => array(
					'preset' => 'h6',
				),
				'Caption'         => array(
					'preset' => 'h6',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( empty( $settings['images_gallery'] ) ) {
			return;
		}

		$section_attributes = array(
			'class'                                    => array( 'section', 'section-content', 'section-fullheight', 'section-fullscreen-columns', 'section-horizontal-scroll', 'pb-lg-0', 'pt-lg-0', 'py-large' ),
			'data-arts-horizontal-scroll'              => 'container',
			'data-arts-horizontal-scroll-type'         => $settings['horizontal_scroll_type'],
			'data-arts-horizontal-scroll-toggle-class' => $settings['horizontal_scroll_in_view_class'],
		);

		$section_wrapper_attributes = array(
			'class'                       => array( 'z-50', 'section-horizontal-scroll__wrapper' ),
			'data-arts-horizontal-scroll' => 'wrapper',
		);

		$section_header_attributes = array(
			'class'                       => array( 'section-fullscreen-columns__header', 'd-flex', 'flex-wrap', 'col-lg-' . $settings['section_header_column_width'], 'container-fluid' ),
			'data-arts-horizontal-scroll' => 'section',
		);

		$section_header_heading_attributes = array(
			'class' => array( 'section__heading', 'my-0', $settings['typography_section_heading_preset'] ),
		);

		$section_header_helper_attributes = array(
			'class' => array( $settings['typography_section_helper_preset'] ),
		);

		$section_bg_attributes = array(
			'class' => array( 'section__bg', $settings['background_alignment'], $settings['background_theme'] ),
		);

		$item_col_attributes = array(
			'class'                       => array( 'col-lg-' . $settings['items_columns_width'], 'col-sm-' . $settings['items_columns_width_tablet'], 'col-' . $settings['items_columns_width_mobile'], 'text-center', 'd-flex', 'align-items-center', $settings['items_padding_h'], $settings['items_padding_v'], 'section-horizontal-scroll__wrapper-item', 'flex-column' ),
			'data-arts-horizontal-scroll' => 'section',
		);

		$caption_attributes = array(
			'class' => array( 'w-100', 'mt-3', 'mb-lg-3', $settings['typography_caption_preset'] ),
		);

		$image_wrapper_attributes = array(
			'class' => array( 'w-100', 'h-100', 'overflow' ),
		);

		if ( $settings['horizontal_scroll_type'] === 'modular' ) {
			$item_col_attributes['data-arts-horizontal-scroll'] = 'section';
		}

		if ( array_key_exists( 'rtl_scrolling_enabled', $settings ) ) {
			$section_attributes['data-arts-horizontal-scroll-direction'] = $settings['rtl_scrolling_enabled'] ? 'left' : 'right';
		}

		if ( $settings['animation_enabled'] ) {
			$image_wrapper_attributes = $this->get_animation_attributes( $image_wrapper_attributes, 'animateJump' );

			$section_header_heading_attributes = $this->get_split_text_attributes(
				$section_header_heading_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => true,
				)
			);

			$section_header_helper_attributes = $this->get_split_text_attributes(
				$section_header_helper_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => true,
				)
			);

			$section_bg_attributes = $this->get_animation_attributes(
				$section_bg_attributes,
				'animateScale',
				array(
					'direction' => $settings['animation_mask_reveal_direction'],
					// 'scale'     => $settings['animation_mask_scale_from']['size'],
				)
			);
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'section_wrapper', $section_wrapper_attributes );
		$this->add_render_attribute( 'section_header', $section_header_attributes );
		$this->add_render_attribute( 'section_header_heading', $section_header_heading_attributes );
		$this->add_render_attribute( 'section_header_helper', $section_header_helper_attributes );
		$this->add_render_attribute( 'item_col', $item_col_attributes );
		$this->add_render_attribute( 'caption', $caption_attributes );
		$this->add_render_attribute( 'image_wrapper', $image_wrapper_attributes );
		$this->add_render_attribute( 'section_bg', $section_bg_attributes );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div <?php $this->print_render_attribute_string( 'section_wrapper' ); ?>>
				<div class="d-flex flex-wrap flex-lg-nowrap w-100vw h-lg-100vh-fix-bar z-50 position-relative">
					<?php if ( ! empty( $settings['section_header_heading'] ) ) : ?>
						<div <?php $this->print_render_attribute_string( 'section_header' ); ?>>
							<div class="w-100 mt-auto">
								<<?php $this->print_html_tag( 'typography_section_heading_tag' ); ?> <?php $this->print_render_attribute_string( 'section_header_heading' ); ?>><?php echo esc_html( $settings['section_header_heading'] ); ?></<?php $this->print_html_tag( 'typography_section_heading_tag' ); ?>>
							</div>
							<?php if ( ! empty( $settings['section_header_helper'] ) ) : ?>
								<div class="w-100 align-self-end">
									<div <?php $this->print_render_attribute_string( 'section_header_helper' ); ?>><?php echo esc_html( $settings['section_header_helper'] ); ?></div>
								</div>
							<?php endif; ?>
						</div>
					<?php endif; ?>
					<?php foreach ( $settings['images_gallery'] as $image ) : ?>
						<?php
							$thumbnail_args = array(
								'id'    => $image['id'],
								'size'  => $this->get_thumbnail_size( $image['id'] ),
								'type'  => $settings['image_placement'],
								'image' => array(
									'class' => array(),
								),
								'outer' => array(
									'class' => array( 'h-100' ),
								),
								'inner' => array(
									'class' => array( 'w-100', 'h-100' ),
								),
							);

							if ( $settings['image_placement'] === 'image' || $settings['image_placement'] === 'image_limited' ) {
								$thumbnail_args['image']['class'][] = 'of-contain';
							}

							$caption = wp_get_attachment_caption( $image['id'] );
							?>
						<div <?php $this->print_render_attribute_string( 'item_col' ); ?>>
							<div <?php $this->print_render_attribute_string( 'image_wrapper' ); ?>>
								<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
							</div>
							<?php if ( ! empty( $caption ) ) : ?>
									<div <?php $this->print_render_attribute_string( 'caption' ); ?>><?php echo esc_html( $caption ); ?></div>
								<?php endif; ?>
						</div>
					<?php endforeach; ?>
				</div>
			</div>
			<?php if ( ! empty( $settings['background_theme'] ) ) : ?>
				<div <?php $this->print_render_attribute_string( 'section_bg' ); ?>></div>
			<?php endif; ?>
		</div>

		<?php
	}

}
