<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kinsey_Widget_Lightbox_Video extends Kinsey_Widget_Base {
	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-lightbox-video';
	}

	public function get_title() {
		return esc_html__( 'Lightbox Video', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {

		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions' => array( 'widgetType' => $name ),
			'fields'     => array(
				array(
					'field'       => 'cursor_play_button_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Cursor Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'video_external',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'External Video URL', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
		);

		return $widgets;

	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Background', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'image',
			array(
				'label'   => esc_html__( 'Background Image', 'kinsey' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => array(
					'active' => true,
				),
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),
			)
		);

		$this->add_responsive_control(
			'height',
			array(
				'label'           => esc_html__( 'Background Height', 'kinsey' ),
				'type'            => Controls_Manager::SLIDER,
				'desktop_default' => array(
					'size' => 800,
					'unit' => 'px',
				),
				'tablet_default'  => array(
					'size' => 70,
					'unit' => 'vh',
				),
				'mobile_default'  => array(
					'size' => 50,
					'unit' => 'vh',
				),
				'range'           => array(
					'px' => array(
						'min' => 0,
						'max' => 1440,
					),
					'vh' => array(
						'min' => 0,
						'max' => 100,
					),
				),
				'size_units'      => array( 'px', 'vh', '%' ),
				'selectors'       => array(
					'{{WRAPPER}}.elementor-absolute' => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}}.elementor-absolute .elementor-widget-container' => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .section-video__container' => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}}.elementor-absolute .section-video' => 'height: {{SIZE}}{{UNIT}};',
				),
				'condition'       => array(
					'image!' => array(
						'id'  => '',
						'url' => '',
					),
				),
			)
		);

		$background_position_selectors = arts_elementor_should_selectors_have_responsive_prefixes() ? array(
			'(desktop) {{WRAPPER}} .section-video__container img' => 'object-position: {{background_position_x.SIZE}}{{background_position_x.UNIT}} {{background_position_y.SIZE}}{{background_position_y.UNIT}};',
			'(tablet) {{WRAPPER}} .section-video__container img' => 'object-position: {{background_position_x_tablet.SIZE}}{{background_position_x_tablet.UNIT}} {{background_position_y_tablet.SIZE}}{{background_position_y_tablet.UNIT}};',
			'(mobile) {{WRAPPER}} .section-video__container img' => 'object-position: {{background_position_x_mobile.SIZE}}{{background_position_x_mobile.UNIT}} {{background_position_y_mobile.SIZE}}{{background_position_y_mobile.UNIT}};',
		) : array(
			'{{WRAPPER}} .section-video__container img' => 'object-position: {{background_position_x.SIZE}}{{background_position_x.UNIT}} {{background_position_y.SIZE}}{{background_position_y.UNIT}};',
		);
		$this->add_responsive_control(
			'background_position_x',
			array(
				'label'           => esc_html__( 'Background Position X', 'kinsey' ),
				'type'            => Controls_Manager::SLIDER,
				'desktop_default' => array(
					'size' => 50,
					'unit' => '%',
				),
				'tablet_default'  => array(
					'size' => 50,
					'unit' => '%',
				),
				'mobile_default'  => array(
					'size' => 50,
					'unit' => '%',
				),
				'range'           => array(
					'%' => array(
						'min' => 0,
						'max' => 100,
					),
				),
				'size_units'      => array( '%' ),
				'selectors'       => $background_position_selectors,
				'condition'       => array(
					'image!' => array(
						'id'  => '',
						'url' => '',
					),
				),
			)
		);

		$this->add_responsive_control(
			'background_position_y',
			array(
				'label'           => esc_html__( 'Background Position Y', 'kinsey' ),
				'type'            => Controls_Manager::SLIDER,
				'desktop_default' => array(
					'size' => 50,
					'unit' => '%',
				),
				'tablet_default'  => array(
					'size' => 50,
					'unit' => '%',
				),
				'mobile_default'  => array(
					'size' => 50,
					'unit' => '%',
				),
				'range'           => array(
					'%' => array(
						'min' => 0,
						'max' => 100,
					),
				),
				'selectors'       => $background_position_selectors,
				'size_units'      => array( '%' ),
				'condition'       => array(
					'image!' => array(
						'id'  => '',
						'url' => '',
					),
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'video_section',
			array(
				'label' => esc_html__( 'Video', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'video_type',
			array(
				'label'   => esc_html__( 'Video Type', 'kinsey' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => array(
					'self_hosted' => array(
						'title' => esc_html__( 'Self Hosted', 'kinsey' ),
						'icon'  => 'eicon-video-camera',
					),
					'external'    => array(
						'title' => esc_html__( 'External Source', 'kinsey' ),
						'icon'  => 'eicon-external-link-square',
					),
				),
				'default' => 'self_hosted',
				'toggle'  => false,
			)
		);

		$this->add_control(
			'video_self_hosted',
			array(
				'label'      => esc_html__( 'Choose Video', 'kinsey' ),
				'type'       => Controls_Manager::MEDIA,
				'dynamic'    => array(
					'active' => true,
				),
				'media_type' => 'video',
				'condition'  => array(
					'video_type' => 'self_hosted',
				),
			)
		);

		$this->add_control(
			'video_external',
			array(
				'label'         => esc_html__( 'External Video URL (YouTube, Vimeo)', 'kinsey' ),
				'type'          => Controls_Manager::URL,
				'dynamic'       => array(
					'active' => true,
				),
				'show_external' => false,
				'condition'     => array(
					'video_type' => 'external',
				),
			)
		);

		$this->add_control(
			'video_autoplay_enabled',
			array(
				'label'   => esc_html__( 'Enable Autoplay', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'video_muted_enabled',
			array(
				'label'     => esc_html__( 'Enable Muted Playing', 'kinsey' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => '',
				'condition' => array(
					'video_type' => 'self_hosted',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'button_section',
			array(
				'label' => esc_html__( 'Button', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'button_no_cursor_label',
			array(
				'label'     => esc_html__( 'Button Label', 'kinsey' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => esc_html__( 'Play', 'kinsey' ),
				'dynamic'   => array(
					'active' => true,
				),
				'condition' => array(
					'is_active_cursor_plugin' => false,
				),
			)
		);

		$this->add_control(
			'button_background_color',
			array(
				'label'   => esc_html__( 'Button Color Theme', 'kinsey' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'bg-dark-1',
				'options' => ARTS_THEME_COLORS_ARRAY,
			)
		);

		$this->add_control(
			'button_label_color',
			array(
				'label'       => esc_html__( 'Button Color', 'kinsey' ),
				'type'        => Controls_Manager::COLOR,
				'default'     => 'rgba(255,255,255,1)',
				'selectors'   => array(
					'{{WRAPPER}} .section-video__link-inner' => 'color: {{VALUE}}',
				),
				'render_type' => 'template',
			)
		);

		$this->end_controls_section();

		/**
		 * Effects
		 */
		$this->start_controls_section(
			'effects_section',
			array(
				'label' => esc_html__( 'Effects', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'heading_parallax',
			array(
				'label' => esc_html__( 'Parallax', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);
		$this->add_controls_parallax();
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Play Button' => array( 'scale', 'hide_native', 'magnetic', 'label' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings        = $this->get_settings_for_display();
		$parallax_config = $this->get_parallax_config();

		$thumbnail_args = array(
			'type'     => 'background',
			'parallax' => $parallax_config,
			'outer'    => array(
				'class' => array( 'w-100', 'h-100' ),
			),
		);

		$section_attributes = array(
			'class'         => array( 'section', 'section-video', 'section-content', 'js-gallery' ),
			'data-nonce'    => wp_create_nonce( 'pswp' ),
			'data-pswp-uid' => $this->get_id(),
		);

		$video_link_attributes = array(
			'class'                        => array( 'section-video__link' ),
			'data-elementor-open-lightbox' => 'no',
		);

		$video_link_inner_attributes = array(
			'class' => array( 'section-video__link-inner', $settings['button_background_color'] ),
		);

		if ( $settings['image'] && $settings['image']['id'] ) {
			$thumbnail_args['id']   = $settings['image']['id'];
			$thumbnail_args['size'] = $this->get_thumbnail_size( $settings['image']['id'] );
		}

		if ( $settings['video_autoplay_enabled'] ) {
			$video_link_attributes['data-autoplay'] = 'true';
		}

		if ( $settings['video_type'] === 'self_hosted' && $settings['video_self_hosted'] ) {
			$video_link_attributes['href'] = $settings['video_self_hosted']['url'];

			$video_link_attributes['data-no-muted'] = ! $settings['video_muted_enabled'];
		}

		if ( $settings['video_type'] === 'external' && $settings['video_external'] ) {
			$video_link_attributes['href'] = $settings['video_external']['url'];
		}

		if ( $settings['cursor_play_button_enabled'] ) {
			$video_link_attributes['class'][]                      = 'js-arts-cursor-no-highlight';
			$video_link_inner_attributes                           = $this->add_cursor_attributes( $video_link_inner_attributes, 'Play Button' );
			$video_link_inner_attributes['data-arts-cursor-color'] = $settings['button_label_color'];
		}

		if ( ! class_exists( 'Arts_Mouse_Cursor_Follower' ) ) {
			$video_link_inner_attributes['data-arts-cursor-label'] = $settings['button_no_cursor_label'];
		}

		if ( $settings['animation_enabled'] ) {
			$video_link_inner_attributes = $this->get_animation_attributes( $video_link_inner_attributes, 'animateJump' );

			$thumbnail_args['animations']['animateMask'] = $this->get_animation_mask_config();
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'video_link', $video_link_attributes );
		$this->add_render_attribute( 'video_link_inner', $video_link_inner_attributes );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div class="section-video__container">
				<a <?php $this->print_render_attribute_string( 'video_link' ); ?>>
					<div <?php $this->print_render_attribute_string( 'video_link_inner' ); ?>>
						<div class="section-video__icon material-icons">play_arrow</div>
					</div>
				</a>
				<div class="section__bg">
					<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
				</div>
			</div>
		</div>

		<?php
	}

}
