<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kinsey_Widget_Logos_Grid extends Kinsey_Widget_Base {
	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-logos-grid';
	}

	public function get_title() {
		return esc_html__( 'Logos Grid', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'images_gallery',
			array(
				'type'    => Controls_Manager::GALLERY,
				'default' => array(),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'layout_section',
			array(
				'label' => esc_html__( 'Layout', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'columns',
			array(
				'label'      => esc_html__( 'Columns in a Row', 'kinsey' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => array( 'px' ),
				'range'      => array(
					'px' => array(
						'min'  => 2,
						'max'  => 6,
						'step' => 1,
					),
				),
				'default'    => array(
					'unit' => 'px',
					'size' => 3,
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'image_placement',
			array(
				'label'     => esc_html__( 'Placement', 'kinsey' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => array(
					'image'         => array(
						'title' => esc_html__( 'Responsive (Unlimited Width)', 'kinsey' ),
						'icon'  => 'eicon-image-bold',
					),
					'image_limited' => array(
						'title' => esc_html__( 'Responsive (Limited Width)', 'kinsey' ),
						'icon'  => 'eicon-image-before-after',
					),
				),
				'default'   => 'image',
				'toggle'    => false,
				'condition' => array(
					'image!' => array(
						'id'  => '',
						'url' => '',
					),
				),
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation();
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( empty( $settings['images_gallery'] ) ) {
			return;
		}

		$columns      = $settings['columns']['size'];
		$items_amount = count( $settings['images_gallery'] );
		$rows_amount  = ceil( $items_amount / $columns );

		$section_attributes = array(
			'class' => array( 'section', 'section-logos', 'section-content' ),
		);

		$wrapper_logo_attributes = array(
			'class' => array( 'w-100', 'h-100' ),
		);

		if ( $settings['animation_enabled'] ) {
			$wrapper_logo_attributes = $this->get_animation_attributes(
				$wrapper_logo_attributes,
				'animateJump',
				array(
					'direction' => 'up',
					'y'         => '66%',
					'scale'     => '1.5',
				)
			);
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'wrapper_logo', $wrapper_logo_attributes );

		?>
		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<table class="table table_no-outer-borders table-xs-flex">
				<tbody>
					<?php for ( $i = 0; $i < $rows_amount * $columns; $i = $i + $columns ) : ?>
						<tr>
							<?php for ( $j = $i; $j < $i + $columns; $j++ ) : ?>
								<?php if ( array_key_exists( $j, $settings['images_gallery'] ) ) : ?>
									<?php
										$current_image  = $settings['images_gallery'][ $j ];
										$thumbnail_args = array(
											'id'   => $current_image['id'],
											'type' => 'image_limited',
											'size' => $this->get_thumbnail_size( $current_image['id'] ),
										);
										?>
										<td>
											<div <?php $this->print_render_attribute_string( 'wrapper_logo' ); ?>>
												<div class="section-logos__wrapper-logo">
													<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
												</div>
											</div>
										</td>
								<?php endif; ?>
							<?php endfor; ?>
						</tr>
					<?php endfor; ?>
				</tbody>
			</table>
		</div>
		<?php
	}

}
