<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/grid/kinsey-widget-trait-grid-controls.php';

class Kinsey_Widget_Masonry_Grid_Images extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Grid_Controls;

	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-masonry-grid-images';
	}

	public function get_title() {
		return esc_html__( 'Masonry Grid Images', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions' => array( 'widgetType' => $name ),
			'fields'     => array(
				array(
					'field'       => 'cursor_clickable_links_label',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Cursor: Clickable Links Label', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {
		/**
		 * Content
		 */
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'images_gallery',
			array(
				'type'    => Controls_Manager::GALLERY,
				'default' => array(),
			)
		);

		$this->end_controls_section();

		/**
		 * Section Settings
		 */
		$this->start_controls_section(
			'settings_section',
			array(
				'label' => esc_html__( 'Settings', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$this->add_control(
			'mode',
			array(
				'label'   => esc_html__( 'Mode', 'kinsey' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'lightbox',
				'options' => array(
					''             => esc_html__( 'None', 'kinsey' ),
					'lightbox'     => esc_html__( 'Lightbox', 'kinsey' ),
					'external_url' => esc_html__( 'Open Page from "External URL" fields', 'kinsey' ),
				),
			)
		);

		$this->add_control(
			'embed_external_url_lightbox_enabled',
			array(
				'label'     => esc_html__( 'Embed External URL Content to Lightbox', 'kinsey' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => '',
				'condition' => array(
					'mode' => 'lightbox',
				),
			)
		);

		$this->add_control(
			'mode_embed_external_url_lightbox_info',
			array(
				'type'            => Controls_Manager::RAW_HTML,
				'separator'       => 'after',
				'raw'             => sprintf(
					'%1$s<br><br>%2$s <a href="%3$s" target="_blank">%4$s</a>',
					esc_html__( 'The content from "External URL" field on the images will be embeded to lightbox.', 'kinsey' ),
					esc_html__( 'Use "External URL" field on an image', 'kinsey' ),
					admin_url( 'upload.php' ),
					esc_html__( 'in WordPress media library', 'kinsey' )
				),
				'content_classes' => 'elementor-panel-alert elementor-panel-alert-success',
				'condition'       => array(
					'mode'                                => 'lightbox',
					'embed_external_url_lightbox_enabled' => 'yes',
				),
			)
		);

		$this->add_control(
			'mode_external_info',
			array(
				'type'            => Controls_Manager::RAW_HTML,
				'separator'       => 'after',
				'raw'             => sprintf(
					'%1$s <a href="%2$s" target="_blank">%3$s</a>',
					esc_html__( 'Use "External URL" field on an image to assign a page URL', 'kinsey' ),
					admin_url( 'upload.php' ),
					esc_html__( 'in WordPress media library', 'kinsey' )
				),
				'content_classes' => 'elementor-panel-alert elementor-panel-alert-success',
				'condition'       => array(
					'mode' => 'external_url',
				),
			)
		);

		/**
		 * Enable Captions
		 */
		$this->add_control(
			'captions_enabled',
			array(
				'label'   => esc_html__( 'Enable Image Captions', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'captions_alignment',
			array(
				'label'     => esc_html__( 'Captions Alignment', 'kinsey' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => array(
					'text-start'  => array(
						'title' => esc_html__( 'Left', 'kinsey' ),
						'icon'  => 'eicon-text-align-left',
					),
					'text-center' => array(
						'title' => esc_html__( 'Center', 'kinsey' ),
						'icon'  => 'eicon-text-align-center',
					),
					'text-end'    => array(
						'title' => esc_html__( 'Right', 'kinsey' ),
						'icon'  => 'eicon-text-align-right',
					),
				),
				'default'   => 'text-center',
				'toggle'    => false,
				'condition' => array(
					'captions_enabled' => 'yes',
				),
			)
		);

		$this->add_control(
			'captions_position',
			array(
				'label'     => esc_html__( 'Captions Position', 'kinsey' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => array(
					'top'    => array(
						'title' => esc_html__( 'Top', 'kinsey' ),
						'icon'  => 'eicon-v-align-top',
					),
					'bottom' => array(
						'title' => esc_html__( 'Bottom', 'kinsey' ),
						'icon'  => 'eicon-v-align-bottom',
					),
				),
				'default'   => 'bottom',
				'toggle'    => false,
				'condition' => array(
					'captions_enabled' => 'yes',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Grid
		 */
		$this->start_controls_section(
			'grid_section',
			array(
				'label' => esc_html__( 'Grid', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);
		$this->add_controls_grid_options();
		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'image_placement',
			array(
				'label'   => esc_html__( 'Placement', 'kinsey' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => array(
					'image'         => array(
						'title' => esc_html__( 'Responsive (Unlimited Width)', 'kinsey' ),
						'icon'  => 'eicon-image-bold',
					),
					'image_limited' => array(
						'title' => esc_html__( 'Responsive (Limited Width)', 'kinsey' ),
						'icon'  => 'eicon-image-before-after',
					),
				),
				'default' => 'image',
				'toggle'  => false,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		/**
		 * Effects
		 */
		$this->start_controls_section(
			'effects_section',
			array(
				'label' => esc_html__( 'Effects', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'heading_hover_zoom',
			array(
				'label' => esc_html__( 'Hover', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);

		$this->add_control(
			'hover_zoom_enabled',
			array(
				'label'     => esc_html__( 'Enable Hover Zoom Effect', 'kinsey' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'yes',
				'separator' => 'after',
			)
		);

		$this->add_control(
			'heading_parallax',
			array(
				'label' => esc_html__( 'Parallax', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);
		$this->add_controls_parallax();

		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Caption' => array(
					'preset' => 'h6',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Clickable Links' => array( 'scale', 'hide_native', 'label', 'icon' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings        = $this->get_settings_for_display();
		$parallax_config = $this->get_parallax_config();
		$image_link_tag  = 'div';

		if ( empty( $settings['images_gallery'] ) ) {
			return;
		}

		$col_desktop = 'grid__item_desktop-' . $settings['grid_columns'];
		$col_tablet  = 'grid__item_tablet-' . $settings['grid_columns_tablet'];
		$col_mobile  = 'grid__item_mobile-' . $settings['grid_columns_mobile'];

		$section_attributes = array(
			'class' => array( 'section', 'section-grid' ),
		);

		$grid_attributes = array(
			'class' => array( 'grid', 'js-grid' ),
		);

		$sizer_attributes = array(
			'class' => array( 'grid__sizer', 'js-grid__sizer', $col_desktop, $col_tablet, $col_mobile ),
		);

		$item_attributes = array(
			'class' => array( 'grid__item', 'js-grid__item', $col_desktop, $col_tablet, $col_mobile ),
		);

		$image_link_attributes = array(
			'class' => array( 'd-block', 'w-100', 'overflow' ),
		);

		$wrapper_caption_attributes = array(
			'class' => array( 'd-block', $settings['captions_alignment'] ),
		);

		$caption_attributes = array(
			'class' => array( 'inline-block', $settings['typography_caption_preset'] ),
		);

		if ( $settings['mode'] === 'lightbox' ) {
			$image_link_attributes['data-elementor-open-lightbox'] = 'no';
		}

		if ( $settings['mode'] === 'lightbox' || $settings['mode'] === 'external_url' ) {
			$image_link_tag                   = 'a';
			$image_link_attributes['class'][] = 'underline-hover';

			$caption_attributes['class'][] = 'underline-hover__target';

			if ( $settings['hover_zoom_enabled'] ) {
				$image_link_attributes['class'][]      = 'hover-zoom';
				$wrapper_caption_attributes['class'][] = 'hover-zoom__caption';
			}

			if ( $settings['cursor_clickable_links_enabled'] ) {
				$image_link_attributes = $this->add_cursor_attributes( $image_link_attributes, 'Clickable Links' );
			}
		}

		if ( $settings['mode'] === 'lightbox' ) {
			$section_attributes['class'][]       = 'js-gallery';
			$section_attributes['data-nonce']    = wp_create_nonce( 'pswp' );
			$section_attributes['data-pswp-uid'] = $this->get_id();
		}

		if ( $settings['mode'] === 'external_url' ) {
			$section_attributes['class'][] = 'js-gallery_external-urls';
		}

		if ( $settings['captions_position'] === 'top' ) {
			$wrapper_caption_attributes['class'][] = 'mb-3';
		} else {
			$wrapper_caption_attributes['class'][] = 'mt-3';
		}

		if ( $settings['grid_fancy_enabled'] && $settings['grid_columns'] !== '12' ) {
			$grid_attributes['class'][] = 'grid_fancy';
		}

		if ( $settings['grid_equal_columns_height_enabled'] ) {
			$grid_attributes['class'][] = 'js-grid-equal-heights';
		}

		if ( $settings['animation_enabled'] ) {
			$caption_attributes = $this->get_split_text_attributes(
				$caption_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => true,
				)
			);
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'grid', $grid_attributes );
		$this->add_render_attribute( 'item', $item_attributes );
		$this->add_render_attribute( 'sizer', $sizer_attributes );
		$this->add_render_attribute( 'caption', $caption_attributes );
		$this->add_render_attribute( 'wrapper_caption', $wrapper_caption_attributes );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div <?php $this->print_render_attribute_string( 'grid' ); ?>>
				<!-- sizer -->
				<div <?php $this->print_render_attribute_string( 'sizer' ); ?>></div>
				<?php foreach ( $settings['images_gallery'] as $image ) : ?>
					<?php
						$this->remove_render_attribute( 'image_link' );

						$size                          = $this->get_thumbnail_size( $image['id'] );
						$text_caption                  = wp_get_attachment_caption( $image['id'] );
						$current_image_link_attributes = $image_link_attributes;

						$thumbnail_args = array(
							'id'               => $image['id'],
							'type'             => $settings['image_placement'],
							'size'             => $size,
							'image'            => array(
								'class' => array( 'va-middle' ),
							),
							'inner_additional' => array(
								// 'class' => array(),
							),
							'parallax'         => $parallax_config,
						);

						if ( $settings['mode'] === 'lightbox' || $settings['mode'] === 'external_url' ) {
							$img_full = wp_get_attachment_image_src( $image['id'], $size );

							if ( $img_full ) {
								$current_image_link_attributes['href']          = $img_full[0];
								$current_image_link_attributes['data-size']     = "{$img_full[1]}x{$img_full[2]}";
								$current_image_link_attributes['data-autoplay'] = 'true';
							}

							if ( $settings['captions_enabled'] ) {
								$current_image_link_attributes['data-title'] = esc_attr( $text_caption );
							}

							if ( $settings['hover_zoom_enabled'] ) {
								$thumbnail_args['image']['class'][]            = 'hover-zoom__zoom';
								$thumbnail_args['inner_additional']['class'][] = 'hover-zoom__inner';
							}
						}

						if ( $settings['mode'] === 'external_url' || ( $settings['mode'] === 'lightbox' && $settings['embed_external_url_lightbox_enabled'] ) ) {
							$external_media = arts_get_field( 'external_media', $image['id'] );

							if ( ! empty( $external_media ) ) {
								$current_image_link_attributes['href'] = $external_media['url'];

								if ( $external_media['target'] ) {
									$current_image_link_attributes['target'] = $external_media['target'];
								}
							}
						}

						if ( $settings['animation_enabled'] ) {
							$thumbnail_args['animations']['animateMask'] = $this->get_animation_mask_config();
						}

						$this->add_render_attribute( 'image_link', $current_image_link_attributes, true, true );
						?>
					<!-- item -->
					<div <?php $this->print_render_attribute_string( 'item' ); ?>>
						<?php if ( $settings['grid_equal_columns_height_enabled'] ) : ?>
							<div class="d-flex-centered w-100 h-100">
						<?php endif; ?>
								<<?php echo esc_html( $image_link_tag ); ?> <?php $this->print_render_attribute_string( 'image_link' ); ?>>
									<?php if ( $settings['captions_enabled'] && $settings['captions_position'] === 'top' && ! empty( $text_caption ) ) : ?>
										<div <?php $this->print_render_attribute_string( 'wrapper_caption' ); ?>>
											<div <?php $this->print_render_attribute_string( 'caption' ); ?>><?php echo esc_html( $text_caption ); ?></div>
										</div>
									<?php endif; ?>
									<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
									<?php if ( $settings['captions_enabled'] && $settings['captions_position'] === 'bottom' && ! empty( $text_caption ) ) : ?>
										<div <?php $this->print_render_attribute_string( 'wrapper_caption' ); ?>>
											<div <?php $this->print_render_attribute_string( 'caption' ); ?>><?php echo esc_html( $text_caption ); ?></div>
										</div>
									<?php endif; ?>
								</<?php echo esc_html( $image_link_tag ); ?>>
						<?php if ( $settings['grid_equal_columns_height_enabled'] ) : ?>
							</div>
						<?php endif; ?>
					</div>
				<?php endforeach; ?>
			</div>
		</div>

		<?php
	}

}
