<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kinsey_Widget_Parallax_Background extends Kinsey_Widget_Base {
	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-parallax-background';
	}

	public function get_title() {
		return esc_html__( 'Parallax Background', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'heading_background',
			array(
				'label' => esc_html__( 'Background', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);

		$this->add_control(
			'background_type',
			array(
				'label'   => esc_html__( 'Type', 'kinsey' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => array(
					'image' => array(
						'title' => esc_html__( 'Image', 'kinsey' ),
						'icon'  => 'eicon-image-bold',
					),
					'video' => array(
						'title' => esc_html__( 'Video', 'kinsey' ),
						'icon'  => 'eicon-video-camera',
					),
				),
				'default' => 'image',
				'toggle'  => false,
			)
		);

		$this->add_control(
			'image',
			array(
				'label'     => esc_html__( 'Choose Image', 'kinsey' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => array(
					'url' => Utils::get_placeholder_image_src(),
				),
				'dynamic'   => array(
					'active' => true,
				),
				'condition' => array(
					'background_type' => 'image',
				),
			)
		);

		$this->add_control(
			'video',
			array(
				'label'      => esc_html__( 'Choose Video', 'kinsey' ),
				'type'       => Controls_Manager::MEDIA,
				'dynamic'    => array(
					'active' => true,
				),
				'media_type' => 'video',
				'condition'  => array(
					'background_type' => 'video',
				),
			)
		);

		$this->add_control(
			'image_placement',
			array(
				'label'     => esc_html__( 'Placement', 'kinsey' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => array(
					'image'         => array(
						'title' => esc_html__( 'Responsive (Unlimited Width)', 'kinsey' ),
						'icon'  => 'eicon-image-bold',
					),
					'image_limited' => array(
						'title' => esc_html__( 'Responsive (Limited Width)', 'kinsey' ),
						'icon'  => 'eicon-image-before-after',
					),
					'background'    => array(
						'title' => esc_html__( 'Background', 'kinsey' ),
						'icon'  => 'eicon-image',
					),
				),
				'default'   => 'image',
				'toggle'    => false,
				'condition' => array(
					'image!' => array(
						'id'  => '',
						'url' => '',
					),
				),
			)
		);

		$this->add_responsive_control(
			'height',
			array(
				'label'           => esc_html__( 'Background Height', 'kinsey' ),
				'type'            => Controls_Manager::SLIDER,
				'desktop_default' => array(
					'size' => 800,
					'unit' => 'px',
				),
				'tablet_default'  => array(
					'size' => 70,
					'unit' => 'vh',
				),
				'mobile_default'  => array(
					'size' => 50,
					'unit' => 'vh',
				),
				'range'           => array(
					'px' => array(
						'min' => 0,
						'max' => 1440,
					),
					'vh' => array(
						'min' => 0,
						'max' => 100,
					),
				),
				'size_units'      => array( 'px', 'vh', '%' ),
				'selectors'       => array(
					'{{WRAPPER}}.elementor-absolute'      => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}}.elementor-absolute .elementor-widget-container' => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .section-image__wrapper' => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}}.elementor-absolute .section-image' => 'height: {{SIZE}}{{UNIT}};',
				),
				'condition'       => array(
					'image_placement' => 'background',
					'image!'          => array(
						'id'  => '',
						'url' => '',
					),
				),
			)
		);

		$background_position_selectors = arts_elementor_should_selectors_have_responsive_prefixes() ? array(
			'(desktop) {{WRAPPER}} .section-image__wrapper img' => 'object-position: {{background_position_x.SIZE}}{{background_position_x.UNIT}} {{background_position_y.SIZE}}{{background_position_y.UNIT}};',
			'(tablet) {{WRAPPER}} .section-image__wrapper img' => 'object-position: {{background_position_x_tablet.SIZE}}{{background_position_x_tablet.UNIT}} {{background_position_y_tablet.SIZE}}{{background_position_y_tablet.UNIT}};',
			'(mobile) {{WRAPPER}} .section-image__wrapper img' => 'object-position: {{background_position_x_mobile.SIZE}}{{background_position_x_mobile.UNIT}} {{background_position_y_mobile.SIZE}}{{background_position_y_mobile.UNIT}};'
		) : array(
			'{{WRAPPER}} .section-image__wrapper img' => 'object-position: {{background_position_x.SIZE}}{{background_position_x.UNIT}} {{background_position_y.SIZE}}{{background_position_y.UNIT}};'
		);
		$this->add_responsive_control(
			'background_position_x',
			array(
				'label'           => esc_html__( 'Background Position X', 'kinsey' ),
				'type'            => Controls_Manager::SLIDER,
				'desktop_default' => array(
					'size' => 50,
					'unit' => '%',
				),
				'tablet_default'  => array(
					'size' => 50,
					'unit' => '%',
				),
				'mobile_default'  => array(
					'size' => 50,
					'unit' => '%',
				),
				'range'           => array(
					'%' => array(
						'min' => 0,
						'max' => 100,
					),
				),
				'size_units'      => array( '%' ),
				'selectors'       => $background_position_selectors,
				'condition'       => array(
					'image_placement' => 'background',
					'image!'          => array(
						'id'  => '',
						'url' => '',
					),
				),
			)
		);

		$this->add_responsive_control(
			'background_position_y',
			array(
				'label'           => esc_html__( 'Background Position Y', 'kinsey' ),
				'type'            => Controls_Manager::SLIDER,
				'desktop_default' => array(
					'size' => 50,
					'unit' => '%',
				),
				'tablet_default'  => array(
					'size' => 50,
					'unit' => '%',
				),
				'mobile_default'  => array(
					'size' => 50,
					'unit' => '%',
				),
				'range'           => array(
					'%' => array(
						'min' => 0,
						'max' => 100,
					),
				),
				'selectors'       => $background_position_selectors,
				'size_units'      => array( '%' ),
				'condition'       => array(
					'image_placement' => 'background',
					'image!'          => array(
						'id'  => '',
						'url' => '',
					),
				),
			)
		);

		$this->add_control(
			'heading_caption',
			array(
				'label'     => esc_html__( 'Caption', 'kinsey' ),
				'separator' => 'before',
				'type'      => Controls_Manager::HEADING,
				'condition' => array(
					'image!' => array(
						'id'  => '',
						'url' => '',
					),
				),
			)
		);

		$this->add_control(
			'caption_enabled',
			array(
				'label'     => esc_html__( 'Enable Caption', 'kinsey' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'yes',
				'condition' => array(
					'image!' => array(
						'id'  => '',
						'url' => '',
					),
				),
			)
		);

		$this->add_control(
			'caption_style',
			array(
				'label'     => esc_html__( 'Caption Style', 'kinsey' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'horizontal',
				'options'   => array(
					'horizontal' => esc_html__( 'Horizontal', 'kinsey' ),
					'vertical'   => esc_html__( 'Vertical', 'kinsey' ),
				),
				'condition' => array(
					'image!'          => array(
						'id'  => '',
						'url' => '',
					),
					'caption_enabled' => 'yes',
				),
			)
		);

		$this->add_control(
			'caption_position',
			array(
				'label'     => esc_html__( 'Caption Position', 'kinsey' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => array(
					'top'    => array(
						'title' => esc_html__( 'Top', 'kinsey' ),
						'icon'  => 'eicon-v-align-top',
					),
					'bottom' => array(
						'title' => esc_html__( 'Bottom', 'kinsey' ),
						'icon'  => 'eicon-v-align-bottom',
					),
				),
				'default'   => 'bottom',
				'toggle'    => false,
				'condition' => array(
					'caption_enabled' => 'yes',
					'caption_style'   => 'horizontal',
				),
			)
		);

		$this->add_control(
			'message_incompatible_layout',
			array(
				'type'            => Controls_Manager::RAW_HTML,
				'raw'             => esc_html__( 'The selected image layout may not display vertical captions due to no left/right block space. Please adjust your image layout.', 'kinsey' ),
				'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
				'condition'       => array(
					'caption_style' => 'vertical',
					'layout'        => 'section text-center',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'layout_section',
			array(
				'label' => esc_html__( 'Layout', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'layout',
			array(
				'label'   => esc_html__( 'Background Alignment', 'kinsey' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => array(
					'section text-center'       => array(
						'title' => esc_html__( 'Fullwidth', 'kinsey' ),
						'icon'  => 'eicon-h-align-stretch',
					),
					'section_w-container-left'  => array(
						'title' => esc_html__( 'Left', 'kinsey' ),
						'icon'  => 'eicon-h-align-left',
					),
					'container text-center'     => array(
						'title' => esc_html__( 'Center', 'kinsey' ),
						'icon'  => 'eicon-h-align-center',
					),
					'section_w-container-right' => array(
						'title' => esc_html__( 'Right', 'kinsey' ),
						'icon'  => 'eicon-h-align-right',
					),
				),
				'default' => 'section text-center',
				'toggle'  => false,
			)
		);

		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		/**
		 * Effects
		 */
		$this->start_controls_section(
			'effects_section',
			array(
				'label' => esc_html__( 'Effects', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'heading_parallax',
			array(
				'label' => esc_html__( 'Parallax', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);
		$this->add_controls_parallax();
		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Caption' => array(
					'preset' => 'h6',
					'tag'    => 'div',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings        = $this->get_settings_for_display();
		$parallax_config = $this->get_parallax_config();
		$caption         = '';

		$section_attributes = array(
			'class' => array( 'section', 'section-image', 'section-content', $settings['layout'] ),
		);

		$thumbnail_args = array(
			'type'     => $settings['image_placement'],
			'parallax' => $parallax_config,
			'outer'    => array(
				'class' => array( 'h-100' ),
			),
		);

		$caption_attributes = array(
			'class' => array( 'section-image__caption', $settings['typography_caption_preset'], 'mt-3', 'mb-0' ),
		);

		if ( $settings['background_type'] === 'image' && $settings['image'] ) {
			$thumbnail_args['id']   = $settings['image']['id'];
			$thumbnail_args['size'] = $this->get_thumbnail_size( $settings['image']['id'] );
		}

		if ( $settings['background_type'] === 'video' && $settings['video'] ) {
			$thumbnail_args['video'] = array(
				'src'        => $settings['video']['url'],
				'attributes' => array(
					'autoplay' => true,
				),
			);
		}

		if ( $settings['caption_position'] === 'top' ) {
			$caption_attributes['class'][] = 'section-image__caption-horizontal_top';
		}

		if ( $settings['caption_enabled'] ) {

			if ( $settings['background_type'] === 'video' ) {
				$caption = wp_get_attachment_caption( $settings['video']['id'] );
			} else {
				$caption = wp_get_attachment_caption( $settings['image']['id'] );
			}

			switch ( $settings['layout'] ) {
				case 'section text-center': {
					if ( $settings['caption_style'] === 'vertical' ) {
						$caption_attributes['class'][] = 'section-image__caption-vertical-left';
					} else {
						$caption_attributes['class'][] = 'section-image__caption-horizontal';
					}
					break;
				}
				case 'section_w-container-left': {
					if ( $settings['caption_style'] === 'vertical' ) {
						$caption_attributes['class'][] = 'section-image__caption-vertical-right';
					} else {
						$caption_attributes['class'][] = 'section-image__caption-horizontal';
					}
					break;
				}
				case 'container text-center': {
					if ( $settings['caption_style'] === 'vertical' ) {
						$caption_attributes['class'][] = 'section-image__caption-vertical-left';
					} else {
						$caption_attributes['class'][] = 'section-image__caption-horizontal';
					}
					break;
				}
				case 'section_w-container-right': {
					if ( $settings['caption_style'] === 'vertical' ) {
						$caption_attributes['class'][] = 'section-image__caption-vertical-left';
					} else {
						$caption_attributes['class'][] = 'section-image__caption-horizontal';
					}
					break;
				}
			}
		}

		if ( $settings['animation_enabled'] ) {
			$caption_attributes = $this->get_split_text_attributes(
				$caption_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => true,
				)
			);

			$thumbnail_args['animations']['animateMask'] = $this->get_animation_mask_config();
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'caption', $caption_attributes );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div class="section-image__wrapper overflow">
				<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
				<?php if ( $settings['caption_enabled'] && ! empty( $caption ) ) : ?>
					<<?php $this->print_html_tag( 'typography_caption_tag' ); ?> <?php $this->print_render_attribute_string( 'caption' ); ?>><?php echo $caption; ?></<?php $this->print_html_tag( 'typography_caption_tag' ); ?>>
				<?php endif; ?>
			</div>
		</div>

		<?php
	}

}
