<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/dynamic/kinsey-widget-trait-dynamic-helpers.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-controls.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-helpers.php';

class Kinsey_Widget_Slider_Images extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Dynamic_Helpers;
	use Kinsey_Widget_Trait_Slider_Controls;
	use Kinsey_Widget_Trait_Slider_Helpers;

	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-slider-images';
	}

	public function get_title() {
		return esc_html__( 'Slider Images', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'images_gallery',
			array(
				'type'    => Controls_Manager::GALLERY,
				'default' => array(),
			)
		);

		$this->end_controls_section();

		/**
		 * Content Elements to Show
		 */
		$this->start_controls_section(
			'elements_section',
			array(
				'label' => esc_html__( 'Elements', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_elements_appearance( array( 'captions', 'counter', 'counter_suffix' ) );
		$this->end_controls_section();

		/**
		 * Slider Options
		 */
		$this->start_controls_section(
			'slider_section',
			array(
				'label' => esc_html__( 'Slider', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_options( array( 'speed', 'autoplay', 'centered_slides', 'vertical_centered_slides', 'space_between' ) );

		$this->add_responsive_control(
			'slides_per_view',
			array(
				'label'           => esc_html__( 'Slides Per Screen', 'kinsey' ),
				'type'            => Controls_Manager::SLIDER,
				'range'           => array(
					'number' => array(
						'min'  => 1,
						'max'  => 4,
						'step' => 1,
					),
				),
				'devices'         => array( 'desktop', 'tablet', 'mobile' ),
				'desktop_default' => array(
					'size' => 1,
					'unit' => 'number',
				),
				'tablet_default'  => array(
					'size' => 1.5,
					'unit' => 'number',
				),
				'mobile_default'  => array(
					'size' => 1.25,
					'unit' => 'number',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Slider Controls
		 */
		$this->start_controls_section(
			'controls_section',
			array(
				'label' => esc_html__( 'Controls', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$this->add_control(
			'arrows_heading',
			array(
				'label' => esc_html__( 'Arrows', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);

		$this->add_control(
			'arrows_enabled',
			array(
				'label'   => esc_html__( 'Enable Arrows', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'arrows_position',
			array(
				'label'     => esc_html__( 'Position', 'kinsey' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'outside',
				'options'   => array(
					'inside'  => esc_html__( 'Inside Slider', 'kinsey' ),
					'outside' => esc_html__( 'Outside Slider', 'kinsey' ),
				),
				'condition' => array(
					'arrows_enabled' => 'yes',
				),
			)
		);

		$this->add_control(
			'arrows_heading_separator',
			array(
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_controls_slider_controls( array( 'progress' ) );
		$this->end_controls_section();

		/**
		 * Slider Interaction Options
		 */
		$this->start_controls_section(
			'interaction_section',
			array(
				'label' => esc_html__( 'Interaction', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_interaction( array( 'drag' ) );
		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_control(
			'image_placement',
			array(
				'label'   => esc_html__( 'Placement', 'kinsey' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => array(
					'image'         => array(
						'title' => esc_html__( 'Responsive (Unlimited Width)', 'kinsey' ),
						'icon'  => 'eicon-image-bold',
					),
					'image_limited' => array(
						'title' => esc_html__( 'Responsive (Limited Width)', 'kinsey' ),
						'icon'  => 'eicon-image-before-after',
					),
				),
				'default' => 'image',
				'toggle'  => false,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Caption' => array(
					'preset' => 'h6',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Prev & Next Arrows' => array( 'scale', 'hide_native', 'magnetic' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$counter  = 0;

		if ( empty( $settings['images_gallery'] ) ) {
			return;
		}

		$section_attributes = array(
			'class' => array( 'section', 'section-slider-images' ),
		);

		$swiper_images_attributes = array(
			'class'                        => array( 'slider-images__slider', 'swiper', 'swiper-container', 'js-slider-images__slider' ),
			'data-auto-height'             => 'true',
			'data-touch-ratio'             => 2,
			'data-slides-per-view'         => $settings['slides_per_view']['size'],
			'data-slides-per-view-tablet'  => $settings['slides_per_view_tablet']['size'],
			'data-slides-per-view-mobile ' => $settings['slides_per_view_mobile']['size'],
			'data-centered-slides'         => $settings['centered_slides'],
			'data-centered-slides-tablet'  => $settings['centered_slides_tablet'],
			'data-centered-slides-mobile'  => $settings['centered_slides_mobile'],
			'data-space-between'           => $settings['space_between']['size'],
			'data-space-between-tablet'    => $settings['space_between_tablet']['size'],
			'data-space-between-mobile'    => $settings['space_between_mobile']['size'],
		);
		$swiper_images_attributes = $this->add_swiper_images_attributes( $swiper_images_attributes );

		$swiper_captions_attributes = array(
			'class'                       => array( 'container', 'slider-images__captions', 'swiper', 'swiper-container', 'js-slider-images__captions', 'mt-xsmall' ),
			'data-slides-per-view'        => $settings['slides_per_view']['size'] === 1 ? 3 : $settings['slides_per_view']['size'],
			'data-slides-per-view-tablet' => $settings['slides_per_view_tablet']['size'],
			'data-slides-per-view-mobile' => $settings['slides_per_view_mobile']['size'],
			'data-centered-slides'        => $settings['centered_slides'],
			'data-centered-slides-tablet' => $settings['centered_slides_tablet'],
			'data-centered-slides-mobile' => $settings['centered_slides_mobile'],
		);

		$arrow_left_args = array(
			'attributes' => array(
				'class' => array( 'material-icons' ),
			),
			'output'     => array( 'prev' ),
		);

		$arrow_right_args = array(
			'attributes' => array(
				'class' => array( 'material-icons' ),
			),
			'output'     => array( 'next' ),
		);

		$arrow_wrapper_left_attributes = array(
			'class' => array( 'slider__arrow', 'slider__arrow_absolute', 'slider__arrow_left' ),
		);

		$arrow_wrapper_right_attributes = array(
			'class' => array( 'slider__arrow', 'slider__arrow_absolute', 'slider__arrow_right' ),
		);

		$caption_attributes = array(
			'class' => array( 'slider-images__caption', $settings['typography_caption_preset'] ),
		);

		$progress_bar_wrapper_attributes = array(
			'class' => array( 'slider__wrapper-scrollbar', 'mt-xsmall', 'text-center', 'small' ),
		);

		$progress_bar_attributes = array(
			'class' => array( 'slider__scrollbar', 'slider__scrollbar_horizontal', 'js-slider__scrollbar' ),
		);

		if ( $settings['arrows_position'] === 'inside' ) {
			$arrow_wrapper_left_attributes['class'][]  = 'slider__arrow_left-inside';
			$arrow_wrapper_right_attributes['class'][] = 'slider__arrow_right-inside';
		}

		if ( $settings['arrows_position'] === 'outside' ) {
			$arrow_wrapper_left_attributes['class'][]  = 'slider__arrow_left-outside';
			$arrow_wrapper_right_attributes['class'][] = 'slider__arrow_right-outside';
		}

		if ( $settings['progress_bar_slides_numbers_enabled'] ) {
			$progress_bar_attributes['class'][] = 'slider__scrollbar_counter';
		}

		if ( $settings['vertical_centered_slides'] ) {
			$swiper_images_attributes['class'][] = 'slider_vertical-centered';
		}

		if ( $settings['progress_bar_style'] === 'long' ) {
			$progress_bar_attributes['class'][] = 'slider__scrollbar_horizontal_long';
		}

		if ( $settings['animation_enabled'] ) {
			$swiper_captions_attributes      = $this->get_animation_attributes( $swiper_captions_attributes, 'animateJump' );
			$progress_bar_wrapper_attributes = $this->get_animation_attributes( $progress_bar_wrapper_attributes, 'animateJump' );

			$arrow_wrapper_left_attributes = $this->get_animation_attributes(
				$arrow_wrapper_left_attributes,
				'animateJump',
				array(
					'x' => '-30',
					'y' => '0',
				)
			);

			$arrow_wrapper_right_attributes = $this->get_animation_attributes(
				$arrow_wrapper_right_attributes,
				'animateJump',
				array(
					'x' => '-30',
					'y' => '0',
				)
			);
		}
		if ( $settings['cursor_prev___next_arrows_enabled'] ) {
			$arrow_left_args['cursor_attributes']  = $this->add_cursor_attributes( array(), 'Prev & Next Arrows' );
			$arrow_right_args['cursor_attributes'] = $this->add_cursor_attributes( array(), 'Prev & Next Arrows' );
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'swiper_images', $swiper_images_attributes );
		$this->add_render_attribute( 'swiper_captions', $swiper_captions_attributes );
		$this->add_render_attribute( 'caption', $caption_attributes );
		$this->add_render_attribute( 'arrow_wrapper_left', $arrow_wrapper_left_attributes );
		$this->add_render_attribute( 'arrow_wrapper_right', $arrow_wrapper_right_attributes );
		$this->add_render_attribute( 'progress_bar_wrapper', $progress_bar_wrapper_attributes );
		$this->add_render_attribute( 'progress_bar', $progress_bar_attributes );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div class="slider slider-images js-slider-images">
				<div <?php $this->print_render_attribute_string( 'swiper_images' ); ?>>
					<div class="swiper-wrapper">
						<?php foreach ( $settings['images_gallery'] as $image ) : ?>
							<?php
								$thumbnail_args = array(
									'id'    => $image['id'],
									'type'  => $settings['image_placement'],
									'size'  => $this->get_thumbnail_size( $image['id'] ),
									'image' => array(
										'class' => array( 'swiper-lazy' ),
									),
								);

								if ( $settings['animation_enabled'] ) {
									$thumbnail_args['animations']['animateMask'] = $this->get_animation_mask_config();
								}
								?>
							<!-- item -->
							<div class="swiper-slide slider-images__slide overflow">
								<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
							</div>
						<?php endforeach; ?>
					</div>
					<div class="is-dragging__blocker"></div>
				</div>
				<?php if ( $settings['captions_enabled'] ) : ?>
					<!-- slider CAPTIONS -->
					<div <?php $this->print_render_attribute_string( 'swiper_captions' ); ?>>
						<div class="swiper-wrapper">
							<?php foreach ( $settings['images_gallery'] as $image ) : ?>
								<?php
									$counter++;
									$caption = wp_get_attachment_caption( $image['id'] );

								if ( $settings['counters_enabled'] ) {
									$counter = $this->get_prefix_zeros( $counter );
									$string  = $counter . $settings['counters_suffix'] . $caption;
								} else {
									$string = $caption;
								}
								?>
								<!-- caption -->
								<div class="swiper-slide pt-3 js-arts-cursor-highlight">
									<div <?php $this->print_render_attribute_string( 'caption' ); ?>><?php echo esc_html( $string ); ?></div>
								</div>
							<?php endforeach; ?>
							<div class="slider-images__underline js-slider-images__underline"></div>
						</div>
					</div>
					<!-- - slider CAPTIONS -->
				<?php endif; ?>
				<?php if ( $settings['progress_bar_enabled'] && ! $settings['captions_enabled'] ) : ?>
					<!-- slider SCROLLBAR -->
					<div <?php $this->print_render_attribute_string( 'progress_bar_wrapper' ); ?>>
						<div <?php $this->print_render_attribute_string( 'progress_bar' ); ?>></div>
					</div>
					<!-- - slider SCROLLBAR -->
				<?php endif; ?>
				<?php if ( $settings['arrows_enabled'] ) : ?>
					<!-- slider ARROWS -->
					<div <?php $this->print_render_attribute_string( 'arrow_wrapper_left' ); ?>>
						<?php get_template_part( 'template-parts/slider/slider', 'arrows', $arrow_left_args ); ?>
					</div>
					<div <?php $this->print_render_attribute_string( 'arrow_wrapper_right' ); ?>>
						<?php get_template_part( 'template-parts/slider/slider', 'arrows', $arrow_right_args ); ?>
					</div>
					<!-- - slider ARROWS -->
				<?php endif; ?>
			</div>
		</div>

		<?php
	}
}
