<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-controls.php';
require_once ARTS_KINSEY_CORE_PLUGIN_PATH . '/elementor/widgets/base/slider/kinsey-widget-trait-slider-helpers.php';

class Kinsey_Widget_Slider_Testimonials extends Kinsey_Widget_Base {
	use Kinsey_Widget_Trait_Slider_Controls;
	use Kinsey_Widget_Trait_Slider_Helpers;

	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-slider-testimonials';
	}

	public function get_title() {
		return esc_html__( 'Slider Testimonials', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions'        => array( 'widgetType' => $name ),
			'fields'            => array(),
			'integration-class' => 'WPML_Elementor_Kinsey_Widget_Slider_Testimonials',
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'text',
			array(
				'label'       => esc_html__( 'Text', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => array(
					'active' => true,
				),
				'default'     => esc_html__( 'Text...', 'kinsey' ),
			)
		);

		$repeater->add_control(
			'author',
			array(
				'label'       => esc_html__( 'Author', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'default'     => esc_html__( 'Author...', 'kinsey' ),
			)
		);

		$this->add_control(
			'testimonials',
			array(
				'type'          => Controls_Manager::REPEATER,
				'fields'        => $repeater->get_controls(),
				'title_field'   => '{{{ author }}}',
				'prevent_empty' => false,
			)
		);

		$this->end_controls_section();

		/**
		 * Elements to Show
		 */
		$this->start_controls_section(
			'elements_section',
			array(
				'label' => esc_html__( 'Elements', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$this->add_control(
			'quotes_enabled',
			array(
				'type'    => Controls_Manager::SWITCHER,
				'label'   => esc_html__( 'Show Quotes', 'kinsey' ),
				'default' => 'yes',
			)
		);

		$this->end_controls_section();

		/**
		 * Slider Options
		 */
		$this->start_controls_section(
			'slider_section',
			array(
				'label' => esc_html__( 'Slider', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_options( array( 'speed', 'autoplay' ) );
		$this->end_controls_section();

		/**
		 * Slider Controls
		 */
		$this->start_controls_section(
			'controls_section',
			array(
				'label' => esc_html__( 'Controls', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);
		$this->add_controls_slider_controls( array( 'arrows', 'dots' ) );
		$this->end_controls_section();

		/**
		 * Effects
		 */
		$this->start_controls_section(
			'effects_section',
			array(
				'label' => esc_html__( 'Effects', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'transition_text_enabled',
			array(
				'label'   => esc_html__( 'Enable Text Transition', 'kinsey' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Text'   => array(
					'preset' => 'h3',
					'tag'    => 'div',
				),
				'Author' => array(
					'preset' => 'paragraph',
					'tag'    => 'div',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Cursor Options
		 */
		$this->start_controls_section(
			'cursor_section',
			array(
				'label' => esc_html__( 'Interactive Cursor', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_cursor_interaction(
			array(
				'Prev & Next Arrows' => array( 'scale', 'hide_native', 'magnetic' ),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation();
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( empty( $settings['testimonials'] ) ) {
			return;
		}

		$section_attributes = array(
			'class' => array( 'section', 'section-slider-testimonials' ),
		);

		$text_attributes = array(
			'class' => array( 'slider__text', 'slider-testimonials__text', $settings['typography_text_preset'], 'my-0' ),
		);

		$author_attributes = array(
			'class' => array( 'slider__text', 'slider-testimonials__author', $settings['typography_author_preset'], 'mt-4', 'mb-0' ),
		);

		$dots_attributes = array(
			'class' => array( 'slider__dots', 'js-slider__dots' ),
		);

		$arrows_attributes = array(
			'class' => array( 'slider__wrapper-arrows', 'slider__wrapper-arrows_vertical', 'd-lg-flex', 'd-none' ),
		);

		$arrows_args = array(
			'type' => 'vertical',
		);

		$text_attributes = $this->get_split_text_attributes(
			$text_attributes,
			array(
				'by'        => 'lines',
				'set'       => 'lines',
				'overflow'  => 'lines',
				'animation' => $settings['animation_enabled'] ? true : false,
			)
		);

		$author_attributes = $this->get_split_text_attributes(
			$author_attributes,
			array(
				'by'        => 'lines',
				'set'       => 'lines',
				'overflow'  => 'lines',
				'animation' => $settings['animation_enabled'] ? true : false,
			)
		);

		$swiper_attributes = $this->add_swiper_content_attributes(
			array(
				'class' => array( 'slider', 'slider-testimonials', 'swiper', 'swiper-container', 'js-slider' ),
			)
		);

		$col_swiper_attributes = array(
			'class' => 'col-lg-10',
		);

		$img_quote_attributes = array(
			'class'  => array( 'slider-testimonials__quote' ),
			'src'    => ARTS_KINSEY_CORE_PLUGIN_URL . '/img/quote-black.svg',
			'width'  => 50,
			'height' => 44,
			'alt'    => '',
		);

		if ( $settings['autoplay_enabled'] ) {
			$swiper_attributes['data-autoplay-enabled'] = 'true';
			$swiper_attributes['data-autoplay-delay']   = $settings['autoplay_delay']['size'];
		}

		if ( $settings['animation_enabled'] ) {
			$dots_attributes = $this->get_animation_attributes( $dots_attributes, 'animateJump' );

			$arrows_attributes = $this->get_animation_attributes(
				$arrows_attributes,
				'animateJump',
				array(
					'x' => '30',
					'y' => '0',
				)
			);
		}

		if ( $settings['cursor_prev___next_arrows_enabled'] ) {
			$arrows_args['cursor_attributes'] = $this->add_cursor_attributes( array(), 'Prev & Next Arrows' );
		}

		if ( $settings['quotes_enabled'] && ! $settings['arrows_enabled'] ) {
			$col_swiper_attributes['class'] = 'col-lg-10';
		}

		if ( ! $settings['quotes_enabled'] && ! $settings['arrows_enabled'] ) {
			$col_swiper_attributes['class'] = 'col-lg-12';
		}

		if ( $settings['quotes_enabled'] && $settings['arrows_enabled'] ) {
			$col_swiper_attributes['class'] = 'col-lg-9';
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'swiper', $swiper_attributes );
		$this->add_render_attribute( 'col_swiper', $col_swiper_attributes );
		$this->add_render_attribute( 'dots', $dots_attributes );
		$this->add_render_attribute( 'arrows', $arrows_attributes );
		$this->add_render_attribute( 'img_quote', $img_quote_attributes );
		?>
		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div class="row justify-content-between">
				<?php if ( $settings['quotes_enabled'] ) : ?>
					<div class="col-auto">
						<div class="slider-testimonials__wrapper-circle mb-4" data-arts-os-animation="true" data-arts-os-animation-name="animateJump">
							<img <?php $this->print_render_attribute_string( 'img_quote' ); ?>>
							<svg class="svg-circle" viewBox="0 0 60 60">
								<circle class="circle" cx="30" cy="30" r="29" fill="none"></circle>
							</svg>
						</div>
					</div>
				<?php endif; ?>
				<div <?php $this->print_render_attribute_string( 'col_swiper' ); ?>>
					<div <?php $this->print_render_attribute_string( 'swiper' ); ?>>
						<div class="swiper-wrapper">
							<?php foreach ( $settings['testimonials'] as $index => $item ) : ?>
								<?php
									$text_key   = $this->get_repeater_setting_key( 'text', 'testimonials', $index );
									$author_key = $this->get_repeater_setting_key( 'author', 'testimonials', $index );

									$this->add_render_attribute( $text_key, $text_attributes );
									$this->add_render_attribute( $author_key, $author_attributes );
								?>
								<div class="swiper-slide">
									<?php if ( ! empty( $item['text'] ) ) : ?>
										<<?php $this->print_html_tag( 'typography_text_tag' ); ?> <?php $this->print_render_attribute_string( $text_key ); ?>><?php echo $item['text']; ?></<?php $this->print_html_tag( 'typography_text_tag' ); ?>>
									<?php endif; ?>
									<?php if ( ! empty( $item['author'] ) ) : ?>
										<<?php $this->print_html_tag( 'typography_author_tag' ); ?> <?php $this->print_render_attribute_string( $author_key ); ?>><?php echo $item['author']; ?></<?php $this->print_html_tag( 'typography_author_tag' ); ?>>
									<?php endif; ?>
								</div>
							<?php endforeach; ?>
						</div>
					</div>
					<?php if ( $settings['dots_enabled'] ) : ?>
						<!-- slider DOTS -->
						<div <?php $this->print_render_attribute_string( 'dots' ); ?>>
							<div class="slider__dot"></div>
						</div>
						<!-- - slider DOTS -->
					<?php endif; ?>
				</div>
				<?php if ( $settings['arrows_enabled'] ) : ?>
					<div class="col-lg-1 align-self-center">
						<!-- slider ARROWS -->
						<div <?php $this->print_render_attribute_string( 'arrows' ); ?>>
							<?php get_template_part( 'template-parts/slider/slider', 'arrows', $arrows_args ); ?>
						</div>
						<!-- - slider ARROWS -->
					</div>
				<?php endif; ?>
			</div>
		</div>
		<?php
	}
}
