<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kinsey_Widget_Steps_List extends Kinsey_Widget_Base {
	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-steps-list';
	}

	public function get_title() {
		return esc_html__( 'Steps List', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name = $this->get_name();

		$widgets[ $name ] = array(
			'conditions'        => array( 'widgetType' => $name ),
			'fields'            => array(),
			'integration-class' => 'WPML_Elementor_Kinsey_Widget_Steps_List',
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'text',
			array(
				'label'   => esc_html__( 'Text', 'kinsey' ),
				'type'    => Controls_Manager::TEXTAREA,
				'dynamic' => array(
					'active' => true,
				),
				'default' => esc_html__( 'Item...', 'kinsey' ),
			)
		);

		$this->add_control(
			'items',
			array(
				'type'          => Controls_Manager::REPEATER,
				'fields'        => $repeater->get_controls(),
				'title_field'   => '{{{ text }}}',
				'prevent_empty' => false,
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'settings_section',
			array(
				'label' => esc_html__( 'Settings', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$this->add_control(
			'counters_zeros',
			array(
				'label'   => esc_html__( 'Counters Prefix', 'kinsey' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 1,
				'options' => array(
					0 => esc_html__( 'None', 'kinsey' ),
					1 => esc_html__( '1 Zero', 'kinsey' ),
					2 => esc_html__( '2 Zeros', 'kinsey' ),
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Items' => array(
					'preset' => 'h6',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation();
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$counter  = 0;

		if ( empty( $settings['items'] ) ) {
			return;
		}

		$section_attributes = array(
			'class' => array( 'section', 'section-list', 'section-content' ),
		);

		$wrapper_circle_attributes = array(
			'class' => array( 'section-list__wrapper-circle' ),
		);

		$content_attributes = array(
			'class' => array( 'section-list__content', 'content', $settings['typography_items_preset'] ),
		);

		if ( $settings['animation_enabled'] ) {
			$wrapper_circle_attributes = $this->get_animation_attributes( $wrapper_circle_attributes, 'animateStroke' );
			$content_attributes        = $this->get_split_text_attributes(
				$content_attributes,
				array(
					'by'       => 'lines',
					'set'      => 'lines',
					'overflow' => 'lines',
				)
			);
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'wrapper_circle', $wrapper_circle_attributes );
		$this->add_render_attribute( 'content', $content_attributes );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<?php foreach ( $settings['items'] as $item ) : ?>
				<?php
					$counter++;
					$counter = $this->get_prefix_zeros( $counter );
				?>
				<div class="section-list__item">
					<div class="section-list__counter">
						<div class="section-list__counter-label subheading"><?php echo esc_html( $counter ); ?></div>
						<div <?php $this->print_render_attribute_string( 'wrapper_circle' ); ?>>
							<svg class="svg-circle" viewBox="0 0 60 60">
								<circle class="circle" cx="30" cy="30" r="29" fill="none"></circle>
							</svg>
						</div>
					</div>
					<?php if ( ! empty( $item['text'] ) ) : ?>
						<div <?php $this->print_render_attribute_string( 'content' ); ?>><?php echo $item['text']; ?></div>
					<?php endif; ?>
				</div>
			<?php endforeach; ?>
		</div>

		<?php
	}

}
