<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kinsey_Widget_Swatch extends Kinsey_Widget_Base {
	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-swatch';
	}

	public function get_title() {
		return esc_html__( 'Swatch', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions' => array( 'widgetType' => $name ),
			'fields'     => array(
				array(
					'field'       => 'heading',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Heading', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'subheading',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Subheading', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'type',
			array(
				'label'   => esc_html__( 'Type', 'kinsey' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'color',
				'options' => array(
					'color' => esc_html__( 'Color', 'kinsey' ),
					'image' => esc_html__( 'Image', 'kinsey' ),
					'icon'  => esc_html__( 'Icon', 'kinsey' ),
				),
			)
		);

		/**
		 * Type: Color
		 */
		$this->add_control(
			'color',
			array(
				'label'     => esc_html__( 'Color', 'kinsey' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'selectors' => array(
					'{{WRAPPER}} .swatch__figure_color' => 'background-color: {{VALUE}}',
				),
				'condition' => array(
					'type' => 'color',
				),
			)
		);

		/**
		 * Type: Image
		 */
		$this->add_control(
			'image',
			array(
				'label'     => esc_html__( 'Choose Image', 'kinsey' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => array(
					'active' => true,
				),
				'default'   => array(
					'url' => Utils::get_placeholder_image_src(),
				),
				'condition' => array(
					'type' => 'image',
				),
			)
		);

		/**
		 * Type: Icon
		 */
		$this->add_control(
			'icon',
			array(
				'label'     => esc_html__( 'Choose Icon', 'kinsey' ),
				'type'      => Controls_Manager::ICONS,
				'condition' => array(
					'type' => 'icon',
				),
			)
		);

		$this->add_control(
			'heading',
			array(
				'label'     => esc_html__( 'Heading', 'kinsey' ),
				'type'      => Controls_Manager::TEXT,
				'dynamic'   => array(
					'active' => true,
				),
				'default'   => esc_html__( 'Heading...', 'kinsey' ),
				'separator' => 'before',
			)
		);

		$this->add_control(
			'subheading',
			array(
				'label'   => esc_html__( 'Subheading', 'kinsey' ),
				'type'    => Controls_Manager::TEXT,
				'dynamic' => array(
					'active' => true,
				),
				'default' => esc_html__( 'Subheading...', 'kinsey' ),
			)
		);

		$this->end_controls_section();

		/**
		 * Layout
		 */
		$this->start_controls_section(
			'layout_section',
			array(
				'label' => esc_html__( 'Layout', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_responsive_control(
			'swatch_width_height',
			array(
				'label'           => esc_html__( 'Swatch Size', 'kinsey' ),
				'type'            => Controls_Manager::SLIDER,
				'desktop_default' => array(
					'size' => 120,
					'unit' => 'px',
				),
				'tablet_default'  => array(
					'size' => 120,
					'unit' => 'px',
				),
				'mobile_default'  => array(
					'size' => 120,
					'unit' => 'px',
				),
				'range'           => array(
					'px' => array(
						'min' => 0,
						'max' => 1440,
					),
				),
				'size_units'      => array( 'px' ),
				'selectors'       => array(
					'{{WRAPPER}} .swatch__figure' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; max-width: 100%; max-height: 100%',
				),
				// 'render_type'     => 'template',
			)
		);

		$this->add_control(
			'swatch_radius',
			array(
				'label'      => esc_html__( 'Swatch Radius', 'kinsey' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => array( 'px', '%' ),
				'range'      => array(
					'%'  => array(
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					),
					'px' => array(
						'min'  => 0,
						'max'  => 1000,
						'step' => 1,
					),
				),
				'default'    => array(
					'size' => 100,
					'unit' => '%',
				),
				'selectors'  => array(
					'{{WRAPPER}} .swatch__figure' => 'border-radius: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'swatch_padding',
			array(
				'label'      => esc_html__( 'Swatch Padding', 'kinsey' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => array( 'px', '%' ),
				'range'      => array(
					'%'  => array(
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					),
					'px' => array(
						'min'  => 0,
						'max'  => 1000,
						'step' => 1,
					),
				),
				'default'    => array(
					'size' => 30,
					'unit' => 'px',
				),
				'selectors'  => array(
					'{{WRAPPER}} .swatch__figure' => 'padding: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Images
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Images', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Heading'    => array(
					'preset' => 'h5',
					'tag'    => 'div',
				),
				'Subheading' => array(
					'preset' => 'small',
					'tag'    => 'div',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation();
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$section_attributes = array(
			'class' => array( 'swatch', 'section-content' ),
		);

		$figure_attributes = array(
			'class' => array( 'swatch__figure', 'd-inline-flex-centered', 'overflow' ),
		);

		$header_attributes = array(
			'class' => array( 'swatch__header', 'mt-2' ),
		);

		$heading_attributes = array(
			'class' => array( 'swatch__heading', $settings['typography_heading_preset'] ),
		);

		$subheading_attributes = array(
			'class' => array( 'swatch__subheading', $settings['typography_subheading_preset'] ),
		);

		$thumbnail_args = array(
			'type'         => 'image_limited',
			'lazy_wrapper' => false,
			'outer'        => array(
				'class' => array( 'h-100' ),
			),
			'inner'        => array(
				'class' => array( 'lazy', 'h-100' ),
			),
			'image'        => array(
				'class' => array( 'of-contain' ),
			),
		);

		if ( $settings['type'] === 'color' ) {
			$figure_attributes['class'][] = 'swatch__figure_color';
		}

		if ( $settings['animation_enabled'] ) {
			$figure_attributes = $this->get_animation_attributes(
				$figure_attributes,
				'animateScale',
				array(
					'direction' => 'center',
				)
			);

			$header_attributes = $this->get_split_text_attributes(
				$header_attributes,
				array(
					'by'       => 'lines',
					'set'      => 'lines',
					'overflow' => 'lines',
				)
			);
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'figure', $figure_attributes );
		$this->add_render_attribute( 'header', $header_attributes );
		$this->add_render_attribute( 'heading', $heading_attributes );
		$this->add_render_attribute( 'subheading', $subheading_attributes );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<div <?php $this->print_render_attribute_string( 'figure' ); ?>>
				<?php if ( $settings['type'] === 'image' ) : ?>
					<?php
					if ( $settings['image'] ) {
						$thumbnail_args['id']   = $settings['image']['id'];
						$thumbnail_args['size'] = $this->get_thumbnail_size( $settings['image']['id'] );
					}
					?>
					<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
				<?php endif; ?>
				<?php if ( $settings['type'] === 'icon' ) : ?>
					<?php Icons_Manager::render_icon( $settings['icon'], array( 'aria-hidden' => 'true' ) ); ?>
				<?php endif; ?>
			</div>
			<?php if ( ! empty( $settings['heading'] ) || ! empty( $settings['subheading'] ) ) : ?>
				<div <?php $this->print_render_attribute_string( 'header' ); ?>>
					<?php if ( ! empty( $settings['heading'] ) ) : ?>
						<<?php $this->print_html_tag( $settings['typography_heading_tag'] ); ?> <?php $this->print_render_attribute_string( 'heading' ); ?>><?php echo esc_html( $settings['heading'] ); ?></<?php $this->print_html_tag( $settings['typography_heading_tag'] ); ?>>
					<?php endif; ?>
					<?php if ( ! empty( $settings['subheading'] ) ) : ?>
						<<?php $this->print_html_tag( $settings['typography_subheading_tag'] ); ?> <?php $this->print_render_attribute_string( 'subheading' ); ?>><?php echo esc_html( $settings['subheading'] ); ?></<?php $this->print_html_tag( $settings['typography_subheading_tag'] ); ?>>
					<?php endif; ?>
				</div>
			<?php endif; ?>
		</div>

		<?php
	}

}
