<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kinsey_Widget_Team_Member extends Kinsey_Widget_Base {
	protected static $_instance;

	public function get_name() {
		return 'kinsey-widget-team-member';
	}

	public function get_title() {
		return esc_html__( 'Team Member', 'kinsey' );
	}

	public function get_icon() {
		return 'eicon-plug icon-kinsey-widget-static';
	}

	public function get_categories() {
		return array( 'kinsey-static' );
	}

	public function wpml_widgets_to_translate_filter( $widgets ) {
		$name  = $this->get_name();
		$title = $this->get_title();

		$widgets[ $name ] = array(
			'conditions' => array( 'widgetType' => $name ),
			'fields'     => array(
				array(
					'field'       => 'name',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Name', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
				array(
					'field'       => 'position',
					'type'        => sprintf( '<strong>%1$s</strong><br>%2$s', $title, esc_html__( 'Position', 'kinsey' ) ),
					'editor_type' => 'LINE',
				),
			),
		);

		return $widgets;
	}

	public function add_wpml_support() {
		add_filter( 'wpml_elementor_widgets_to_translate', array( $this, 'wpml_widgets_to_translate_filter' ) );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'name',
			array(
				'label'       => esc_html__( 'Name', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Name...', 'kinsey' ),
				'dynamic'     => array(
					'active' => true,
				),
			)
		);

		$this->add_control(
			'position',
			array(
				'label'       => esc_html__( 'Position', 'kinsey' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Position...', 'kinsey' ),
				'dynamic'     => array(
					'active' => true,
				),
			)
		);

		$this->add_control(
			'social_heading',
			array(
				'label'     => esc_html__( 'Social Media', 'kinsey' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'social_link',
			array(
				'label'         => esc_html__( 'Link', 'kinsey' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://...', 'kinsey' ),
				'show_external' => true,
				'default'       => array(
					'is_external' => true,
					'nofollow'    => true,
				),
				'dynamic'       => array(
					'active' => true,
				),
			)
		);

		$repeater->add_control(
			'social_icon',
			array(
				'label' => esc_html__( 'Icon', 'kinsey' ),
				'type'  => Controls_Manager::ICONS,
			)
		);

		$this->add_control(
			'social',
			array(
				'type'          => Controls_Manager::REPEATER,
				'fields'        => $repeater->get_controls(),
				'prevent_empty' => false,
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'avatar_section',
			array(
				'label' => esc_html__( 'Avatar', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'image',
			array(
				'label'   => esc_html__( 'Choose Avatar', 'kinsey' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Image
		 */
		$this->start_controls_section(
			'images_section',
			array(
				'label' => esc_html__( 'Image', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_LAYOUT,
			)
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'label'   => esc_html__( 'Thumbnail Size', 'kinsey' ),
				'name'    => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
			)
		);

		$this->add_control(
			'image_placement',
			array(
				'label'   => esc_html__( 'Placement', 'kinsey' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => array(
					'image'         => array(
						'title' => esc_html__( 'Responsive (Unlimited Width)', 'kinsey' ),
						'icon'  => 'eicon-image-bold',
					),
					'image_limited' => array(
						'title' => esc_html__( 'Responsive (Limited Width)', 'kinsey' ),
						'icon'  => 'eicon-image-before-after',
					),
				),
				'default' => 'image',
				'toggle'  => false,
			)
		);

		$this->end_controls_section();

		/**
		 * Effects
		 */
		$this->start_controls_section(
			'effects_section',
			array(
				'label' => esc_html__( 'Effects', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'heading_parallax',
			array(
				'label' => esc_html__( 'Parallax', 'kinsey' ),
				'type'  => Controls_Manager::HEADING,
			)
		);
		$this->add_controls_parallax();
		$this->end_controls_section();

		/**
		 * Typography Options
		 */
		$this->start_controls_section(
			'typography_section',
			array(
				'label' => esc_html__( 'Typography', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_typography(
			array(
				'Name'     => array(
					'preset' => 'h3',
					'tag'    => 'div',
				),
				'Position' => array(
					'preset' => 'small',
					'tag'    => 'div',
				),
			)
		);
		$this->end_controls_section();

		/**
		 * Animation
		 */
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'kinsey' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_controls_animation( array( 'mask' ) );
		$this->end_controls_section();
	}

	protected function render() {
		$settings        = $this->get_settings_for_display();
		$parallax_config = $this->get_parallax_config();

		$section_attributes = array(
			'class' => array( 'figure-member', 'section-content' ),
		);

		$name_attributes = array(
			'class' => array( 'figure-member__name', $settings['typography_name_preset'] ),
		);

		$position_attributes = array(
			'class' => array( 'figure-member__position', $settings['typography_position_preset'], 'mt-2' ),
		);

		$content_attributes = array(
			'class' => array( 'figure-member__footer', 'mt-3' ),
		);

		$thumbnail_args = array(
			'type'     => $settings['image_placement'],
			'parallax' => $parallax_config,
			'outer'    => array(
				'class' => array( 'figure-member__avatar' ),
			),
		);

		if ( $settings['image'] ) {
			$thumbnail_args['id']   = $settings['image']['id'];
			$thumbnail_args['size'] = $this->get_thumbnail_size( $settings['image']['id'] );
		}

		if ( $settings['social'] ) {
			$section_attributes['class'][] = 'figure-member_has-social';
		}

		if ( $settings['animation_enabled'] ) {
			$name_attributes = $this->get_split_text_attributes(
				$name_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);

			$position_attributes = $this->get_split_text_attributes(
				$position_attributes,
				array(
					'by'        => 'lines',
					'set'       => 'lines',
					'overflow'  => 'lines',
					'animation' => false,
				)
			);

			$content_attributes = $this->get_animation_attributes( $content_attributes, 'animateText' );

			$thumbnail_args['animations']['animateMask'] = $this->get_animation_mask_config();
		}

		$this->add_render_attribute( 'section', $section_attributes );
		$this->add_render_attribute( 'content', $content_attributes );
		$this->add_render_attribute( 'name', $name_attributes );
		$this->add_render_attribute( 'position', $position_attributes );
		?>

		<div <?php $this->print_render_attribute_string( 'section' ); ?>>
			<!-- avatar -->
			<?php get_template_part( 'template-parts/lazy/lazy', 'image', $thumbnail_args ); ?>
			<!-- - avatar -->
			<!-- content -->
			<div <?php $this->print_render_attribute_string( 'content' ); ?>>
				<<?php $this->print_html_tag( 'typography_name_tag' ); ?> <?php $this->print_render_attribute_string( 'name' ); ?>><?php echo esc_html( $settings['name'] ); ?></<?php $this->print_html_tag( 'typography_name_tag' ); ?>>
				<<?php $this->print_html_tag( 'typography_position_tag' ); ?> <?php $this->print_render_attribute_string( 'position' ); ?>><?php echo esc_html( $settings['position'] ); ?></<?php $this->print_html_tag( 'typography_position_tag' ); ?>>
				<?php if ( ! empty( $settings['social'] ) ) : ?>
					<div class="figure-member__social"><?php $this->print_social_media_list(); ?></div>
				<?php endif; ?>
			</div>
			<!-- - content -->
		</div>

		<?php
	}
}
