<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Arts_Core_Plugin_Update {
	private $theme_id; // "my-theme-slug"
	private $plugin_id; // "my-plugin/my_plugin.php"
	private $icon_path; // icon file relative to plugin directory
	private $endpoint;
	private $remote_plugin_data;
	private $plugin_slug;

	public function __construct(
		$theme_id = '',
		$plugin_id = '',
		$endpoint = 'https://artemsemkin.com/wp-json/updates/v1/plugin',
		$icon_path = 'assets/icon-256x256.jpg'
		) {
		if ( ! $theme_id || ! $plugin_id || ! $endpoint ) {
			return;
		}

		$this->theme_id  = $theme_id;
		$this->plugin_id = $plugin_id;
		$this->endpoint  = $endpoint;
		$this->icon_path = $icon_path;

		$plugin_file       = trailingslashit( WP_PLUGIN_DIR ) . $this->plugin_id;
		$this->plugin_slug = dirname( plugin_basename( $plugin_file ) );

		add_filter( 'plugins_api', array( $this, 'set_remote_plugin_data' ), 99, 3 );
		add_filter( 'update_plugins_artemsemkin.com', array( $this, 'update_plugin' ), 99, 4 );
	}

	public function set_remote_plugin_data( $res, $action, $args ) {
		if ( $action !== 'plugin_information' || $args->slug !== $this->plugin_slug ) {
			return $res;
		}

		$this->remote_plugin_data = $this->fetch_remote_plugin_data();

		$res                = new stdClass();
		$res->name          = $this->remote_plugin_data->plugin;
		$res->slug          = $this->remote_plugin_data->slug;
		$res->path          = $this->remote_plugin_data->id;
		$res->sections      = $this->remote_plugin_data->sections;
		$res->version       = $this->remote_plugin_data->new_version;
		$res->download_link = $this->remote_plugin_data->package;

		return $res;
	}

	public function fetch_remote_plugin_data() {
		$args = array(
			'body' => array(
				'theme'  => $this->theme_id,
				'plugin' => $this->plugin_id,
				'icon'   => $this->icon_path,
			),
		);

		$request = wp_remote_post( $this->endpoint, $args );

		if ( ! is_wp_error( $request ) || wp_remote_retrieve_response_code( $request ) === 200 ) {
			$response = (object) json_decode( stripslashes( $request['body'] ), true );

			return $response;
		}
	}

	public function update_plugin( $update, $plugin_data, $plugin_file, $locales ) {
		if ( $plugin_file !== $this->plugin_id || ! empty( $update ) ) {
			return $update;
		}

		$remote_plugin_data = $this->fetch_remote_plugin_data();

		if ( ! version_compare( $plugin_data['Version'], $remote_plugin_data->new_version, '<' ) ) {
			return $update;
		}

		return $remote_plugin_data;
	}
}
